#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_balText_nl {} {
global balText
set balText(list_of_messages) {Lijst van berichten in de huidige postbus.
U kint de muisknoppen als volgt gebruiken:

    linkerklik  - Toon het bericht
    dubbelklik  - (in bladerstand) toon berichttekst
                  (De tekst van het bericht wordt opgehaald)
    rechterklik - Markeer of demarkeer het bericht (voeg
                  het toe of verwijder het van 'de groep'
                  van gemarkeerde berichten}
set balText(current_folder_name) {Naam van de huidige postbus}
set balText(current_folder_size) {Totale grootte in bytes van de huidige postbus}
set balText(current_folder_nummsg) {Aantal berichten in de huidige postbus}
set balText(status_text) {Berichten van Postilion}
set balText(move_msg) {Dit menu zal een kopie van het huidige bericht plaatsen
in de geselecteerde postbus; het huidige bericht wordt
gemarkeerd voor verwijderen}
set balText(delete_msg) {Markeer het huidige bericht voor verwijderen}
set balText(compose_msg) {Maak een nieuw bericht}
set balText(compose_menu) {Dit menu bevat opdrachten die handig zijn
bij het maken van nieuwe berichten}
set balText(mailbox_menu) {Dit menu bevat opdrachten die werken
op (een) postbus(sen)}
set balText(window_menu) {Dit menu bevat hulpmiddelen voor bekijken van uw
adresboek, postbussen en oude zoekopdrachten}
set balText(edit_menu) {Dit menu helpt u om het bericht
dat u aan het maken bent te wijzigen}
set balText(format_menu) {Dit menu helpt u om de opmaak van het bericht
dat u aan het maken bent aan te passen}
set balText(print_menu) {Opent een dialoogvenster voor het afdrukken
van een bericht of de groep berichten.
(Gebruik de rechtermuisknop of het 'Groep'menu
voor het (de)groeperen van berichten.)}
set balText(vd_open) {Open de geselecteerde postbus in een nieuw venster}
set balText(vd_cut) {Verwijder de geselecteerde postbus van de lijst.
Het kan elders in de lijst worden opgenomen met de
'Plak'opdracht.}
set balText(vd_paste) {Plak een eerder geknipte postbus 
in de lijst boven de huidige-}
set balText(spell) {Open een spellingscontrolevenster 
voor dit bericht}
set balText(clear_addr) {Klik hier met de linkermuisknop om alle
selecties in dit venster te annuleren}
set balText(reply_to_all) {Stuur een antwoord naar alle afzenders en
geadresseerden van het huidige bericht}
set balText(reply_to_sender) {Stuur een antwoord aan de afzender van het huidige bericht}
set balText(no_sig) {Dit betekent dat het huidige bericht niet ondertekend is}
set balText(unchecked_sig) {Dit betekent dat dit bericht is ondertekend, maar dat
de ondertekening nog niet gecontroleerd is. Druk op
de linkermuisknop om dat te doen.}
set balText(good_sig) {De ondertekening van dit bericht is correct}
set balText(bad_sig) {De ondertekening komt NIET overeen met de inhoud van dit bericht}
set balText(part_sig) {Een gedeelte van het bericht is ondertekend, maar niet alles}
set balText(send_deferred) {Veroorzaakt dat alle gebufferde berichten nu
worden verzonden. (Het getal tussen haken is het
aantal berichten in de wachtlijst)}
set balText(show_notifications) {Toont een venster die u verteld of uw bericht ontvangen
is of niet. (Om precies te zijn: het toont de status van
kennisgevingen)}
set balText(watcher_enable) {Hiermee kunt u het waarschuwingsvenster 
voor nieuwe post aan- of uitzetten}
set balText(reread_aliases) {Herleest al uw adresbestanden}
set balText(reread_userproc) {Herleest uw userproc-bestand}
set balText(import_aliases) {Zoekt op een paar standaardplaatsen naar adresbestanden
van andere email-programma's en leest deze bestanden}
set balText(reread_mailcap) {Herleest alle mailcap bestanden}
set balText(take_mail) {Kijkt naar berichten die Netscape uit uw 'in' bakje
heeft gehaald en steelt ze terug (voor uw 'in' bakje)}
set balText(check_dbase) {Controleert de Postilion database op fouten}
set balText(check_fix_dbase) {Controleert de Postilion database op fouten en
doet zijn best om gevonden fouten te herstellen}
set balText(see_log) {Toont een log van alle interne, door Postilion gegenereerde berichten}
set balText(quit) {Verlaat Postilion}
set balText(folder_menu) {Dit menu toont een lijst van al uw postbussen. Dubbelklik
op een postbus om erin te kijken met het huidige aktieve 
lijstvenster of selecteer het en klik op de 'Open' knop om het in
een nieuw venster te openen}
set balText(message_menu) {Dit menu bevat opdrachten die
werken op een bericht}
set balText(clock) {Dit toont de tijd, datum en dag wanneer
het bericht verzonden is (in locale tijd hier).
Klik op de klok met de linkermuisknop als
een sluiproute naar het Voorkeuren venster.}
set balText(mailboxes) {Opent een nieuw venster die u postbussen laat selecteren,
maken en wijzigen. U kunt ook een geselecteerd bericht (of
de groep berichten) naar de geselecteerde postbus verplaatsen.}
set balText(next_msg) {Selecteert het volgende bericht in de lijst.}
set balText(prev_msg) {Selecteert het voorgaande bericht in de lijst.}
set balText(find) {Toon een popupvenster die u laat zoeken in de
berichtenlijst of binnen het huidige bericht}
set balText(compose) {Maak een nieuw bericht}
set balText(reply_sender) {Schrijf een antwoord aan de afzender van het huidige bericht}
set balText(reply_quote_sender) {Schrijf een antwoord aan de afzender
met citaat uit het huidige bericht}
set balText(reply_all) {Schrijf een antwoord aan de afzender en alle 
geadresseerden van het huidige bericht}
set balText(reply_quote_all) {Schrijf een antwoord aan de afzender en alle
geaddresseerden met citaat uit het huidige bericht}
set balText(forward_inline) {Schrijf een bericht met citaat uit het huidige-
en markeer het huidige- als 'doorgestuurd'}
set balText(forward_attached) {Schrijf een bericht met het huidige
bericht als bijlage}
set balText(bounce) {Stuur het huidige bericht naar een nieuw adres}
set balText(compose_held) {Ga verder met een eerder onderbroken bericht}
set balText(extract_adr) {Zoek email adressen in het huidige bericht om één of
meer ervan aan één van uw adresboeken toe te voegen}
set balText(move) {Verplaats het huidige bericht naar een andere postbus}
set balText(delete) {Markeer het huidige bericht voor verwijderen.
Het zal niet eerder daadwerkelijk verwijderd
worden dan bij het 'Opschonen' van de postbus}
set balText(undelete) {Verwijder de 'verwijderen' markering van het huidige bericht}
set balText(print) {Druk het huidige bericht af}
set balText(structure) {Dit submenu toont de interne struktuur
van het bericht en zijn bijlagen}
set balText(show_all_headers) {Toon alle kopregels van berichten.
Normaal gesproken worden slechts een paar
- als Van, Onderwerp - getoond.}
set balText(show_selected_headers) {Toon alleen de geselecteerde kopregels.
Bijv. Van, Onderwerp, Kopie}
set balText(show_no_headers) {Toon geen enkele kopregel}
set balText(group_menu) {Dit menu werkt op 'de groep' - de gemarkeerde
berichten. De groep is gewoon alle berichten die
met een 'F' gemarkeerd zijn. De opdrachten in dit
menu zijn van toepassing op al deze gemarkeerde
berichten in de huidige postbus.

U kunt berichten markeren via zoekakties of door
klikken of slepen met de rechtermuisknop}
set balText(create_in_win) {Maakt een nieuwe lijst met berichten en maakt
een groepmarkering in dat venster}
set balText(create_by_expr) {Voer een zoekaktie uit en markeer alle gevonden 
items. (Gemarkeerde items worden een 'groep' 
genoemd.)}
set balText(use_saved_expr) {Voeg toe aan de groep door een opgeslagen zoekexpressie te hergebruiken}
set balText(clear_group) {Verwijder de groepsmarkering van alle berichten}
set balText(group_all) {Markeer elk bericht - voeg elk bericht toe aan de groep}
set balText(delete_group) {Markeer elk bericht in de groep voor verwijdering}
set balText(print_group) {Druk alle berichten in de groep af}
set balText(move_group) {Verplaats alle berichten in de groep naar een andere postbus}
set balText(admin_menu) {Dit menu bevat diverse beheersmatige opdrachten}
set balText(browse_mode) {Bladerstand is handig wanneer een postbus zich niet op uw eigen
computer bevindt. Het weerhoudt Postilion ervan de inhoud van de
berichten over te halen. De inhoud wordt geladen wanneer u op de
'toon tekst' knop drukt of dubbelklikt op het bericht in de
berichtenlijst.}
set balText(update) {Controleer de huidige postbus op nieuwe berichten.
(Schoont niet op)}
set balText(sync) {Verwijdert permanent alle berichten die voor verwijderen
gemarkeerd zijn in de aktieve postbus en controleert op nieuw
binnengekomen berichten.}
set balText(newedit_folder) {Opent voor u een venster om postbussen toe te
voegen en hun eigenschappen te wijzigen}
set balText(aliases) {Opent het adresboek venster}
set balText(focus) {Toont alleen de gemarkeerde berichten}
set balText(unfocus) {Toont alle berichten (gemarkeerd en ongemarkeerd)}
set balText(hide_size) {Verberg berichtgrootte in lijst}
set balText(hide_deleted) {Verberg voor verwijderde gemarkeerde 
berichten in de lijst}
set balText(hide) {Verberg alle vensters van Postilion}
set balText(preferences) {Open het voorkeuren venster}
set balText(define_keys) {Laat u de toestenbordefinities zien/wijzigen
voor opdrachten in het hoofdvenster}
set balText(saved_expr) {Laat u de opgeslagen zoektermen voor het maken van groepen wijzigen}
set balText(sort_order) {Laat u de sorteervolgorde van de berichten wijzigen}
set balText(sort_subjdate) {Sorteer berichten op datum, maar groepeer
berichten met hetzelfde onderwerp bij elkaar}
set balText(sort_subj) {Sorteer de berichten alfabetisch op onderwerp}
set balText(sort_sender) {Sorteer berichten alfabetisch op afzender}
set balText(sort_natural) {Toon berichten op volgorde van binnenkomst}
set balText(sort_reverse_natural) {Toon berichten in omgekeerde volgorde van binnenkomst}
set balText(sort_date) {Sorteer berichten op verzenddatum (oudste bovenaan)}
set balText(sort_reversedate) {Sorteer berichten op verzenddatum (oudste onderaan)}
set balText(help_menu) {Geeft verschillende vormen van hulp}
set balText(balloon_help) {Aktiveert dit soort ballon help}
set balText(show_version) {Toont welke versie van Postilion u gebruikt}
set balText(explain_ratatosk) {Legt uit waar de naam Ratatosk vandaan komt}
set balText(help_window) {Toont het help venster}
set balText(send_bug) {Laat u een storingsrapport versturen naar de auteur van Postilion}
set balText(group_list_editor) {Maakt gemarkeerde berichten lid van de groep.
Gebruik de linkermuisknop om het huidige bericht te 
markeren of om hiervan de markering te verwijderen.}
set balText(group_window_ok) {Sluit dit venster en verplaats de groepsmarkering naar het postbusvenster}
set balText(group_window_selall) {Markeert alle berichten als lid van de groep}
set balText(group_window_unselall) {Verwijdert de markering van alle berichten}
set balText(cancel) {Breekt af wat u aan het doen bent en sluit dit venster}
set balText(enter_search_exp_here) {Geef hier de zoekterm op}
set balText(toggle_ignore_case) {Geef aan of verschil tussen hoofd- en kleine 
letters bij zoeken van belang is}
set balText(find_exact) {Zoek preciese tekst}
set balText(find_regexp) {Zoek met reguliere expressie}
set balText(find_in_mlist) {Zoekt in de lijst van berichten (niet in de berichten zelf)}
set balText(find_in_body) {Zoekt in de berichten zelf}
set balText(find_first) {Begin een zoekaktie vanuit de top van de postbus}
set balText(find_next) {Zoekt een volgend voorkomen van de zoekterm}
set balText(dismiss) {Sluit venster}
set balText(show_adrbook_menu) {Deze lijst toont uw adresboeken.
Linkerklik op een boek om de adressen te zien.
Selecteer een adres en druk dan op één van de
onderstaande adresknoppen (bijv. de Aan: lijst)
om die persoon automatisch toe te voegen aan de
lijst van geadresseerden van uw bericht.
Of selecteer een boek en druk dan op de adres-
knoppen om uw bericht aan IEDEREEN in dat boek
te sturen.
TIP: U kunt de 'Blinde Kopie' optie aanzetten en 
'Blinde Kopie' toevoegen aan het 'kopregels' veld in 
Voorkeuren->Nieuw bericht. 'Blinde kopie' houdt in
dat niemand kan zien dat u aan de mensen in deze 
lijst een kopie hebt gestuurd.}
set balText(use_system_aliases) {Voeg email adressen toe uit het systeembrede adresboek}
set balText(add_addrbook) {Maak een nieuw adresboek.
De adressen worden opgeslagen
in het bestand dat u opgeeft.}
set balText(delete_addrbook) {Verberg een adresboek. Dit verwijdert het boek alleen van
Postilion's interne tabellen. Het adresboekbestand zelf wordt 
NIET verwijderd.}
set balText(set_default_addrbook) {Selecteer het standaard adresboek. Hieraan worden nieuwe adressen
toegevoegd indien u niet expliciet een ander adresboek opgeeft}
set balText(import_aliases_from_pgm) {Importeer postadressen van door andere programma's gegenereerde
bestanden. D.w.z. maak een nieuw adresboek van een bestand met
adressen in een ander formaat}
set balText(alias_list) {Dit is een lijst met de adressen}
set balText(new_alias) {Maak een nieuw adres}
set balText(edit_alias) {Wijzig een bestaand adres}
set balText(delete_alias) {Verwijder geselecteerde adressen}
set balText(move_alias) {Verplaats geselecteerde adressen naar nieuw adresboek}
set balText(alias_adr_book) {Het adresboek waartoe dit adres zou moeten behoren}
set balText(alias_alias) {Een korter pseudoniem die u kunt typen in plaats van het
hele email adres. Spaties zijn niet toegestaan. U kunt dit
soort naam gebruiken in de Aan:, Kopie: en Blinde Kopie: regels.
Postilion zal het automatisch met de volledige naam en adres 
vervangen.
Hetzelfde adres mag in meerdere adresboeken voorkomen maar een
pseudoniem MOET uniek zijn over alle adresboeken!}
set balText(alias_fullname) {De persoons volledige naam. Deze wordt getoond in uw
adresboek en in de adresregel van uitgaande post}
set balText(alias_content) {Het eigenlijke emailadres als 'jan@het.net'. Dit is wat
werkelijk gebruikt wordt bij het versturen van de post.}
set balText(alias_comment) {Adres commentaar. Alleen voor eigen gebruik.}
set balText(name_of_adrbook) {De naam die Postilion intern moet gebruiken 
om aan dit adresboek te refereren}
set balText(list_of_books_to_delete) {Selecteer die adresboeken die wilt
verwijderen in deze lijst en druk dan op 'verwijder'}
set balText(aliases_adr_book) {Het adresboek waartoe deze adressen zouden moeten behoren}
set balText(aliasadd_use) {Als deze knop ongevinkt is dan wordt 
het adres op deze regel genegeerd}
set balText(alias_chooser) {Deze lijst laat u een adres kiezen om aan uw adresveld toe 
te voegen.
Er zijn verschillende manieren om een adres te selecteren:
    * U kunt er één selecteren met de linker muisknop
    * U kunt de pijltjestoetsen 'omhoog' en 'omlaag' gebruiken
Wanneer u een selectie gemaakt heeft druk dan op de spatiebalk
om uw selectie aan de 'Aan:' regel van het aktieve 
'nieuw bericht' venster toe te voegen, of klik op één van de
knoppen hieronder om aan een specifieke regel toe te voegen.
Drukken op 'Return/Enter' voegt toe aan de 'Aan:' regel en
sluit dit venster. Als geen 'nieuw bericht' venster aktief is
zal een nieuwe voor u geopend worden. U kunt dit venster
zonder een adres te selecteren sluiten door op 'Esc' of 
'Ctrl-C' te drukken.}
set balText(compose_held_pick) {Haal het bericht waaraan u verder wilt werken uit de lijst.
U kunt deze markeren en op 'Ok' drukken of u kunt dubbelklikken}
set balText(compose_insert_file) {Voeg de inhoud van een bestand in op de huidige cursorpositie}
set balText(automatic_wrap) {Stuurt de automatische regelafbreek functie}
set balText(automatic_indent) {Stuurt de automatische inspringen functie}
set balText(abort_compose) {Annuleer dit bericht}
set balText(undo) {Maak de laatste wijziging ongedaan}
set balText(cut) {Verplaats de geselecteerde tekst
naar een intern klembord}
set balText(copy) {Kopieer de geselecteerde tekst
naar een intern klembord}
set balText(paste) {Plak de tekst vanaf het interne klembord
in het bericht op de huidige cursorpositie.
N.B.:
De middelste muisknop zal tekst van het 
X-klembord invoegen op de huidige cursor-
positie}
set balText(cut_all) {Verplaats alle tekst van het bericht
naar het interne klembord}
set balText(copy_all) {Kopieer alle tekst van het bericht}
set balText(wrap_lines) {Lijn de gemarkeerde regels uit}
set balText(run_through_command) {Voer de geselecteerde tekst (alle tekst indien geen
selectie is gemaakt) door een externe opdracht en vervang
het met de uitgevoerde tekst hiervan}
set balText(headers_menu) {Met dit menu kunt u bepalen welke kopregels
worden getoond in het adres-gedeelte van het
'nieuw bericht' venster}
set balText(copy_attached_files) {Als u dit aanzet wordt een kopie van de bijlagen aan dit 
bericht toegevoegd zodra u op 'zenden' drukt. Als u dit uitzet
dan worden de bijlagen pas gelezen op het moment dat het bericht
daadwerklijk verzonden wordt vanaf uw computer. (Dus verwijder
in de tussentijd de bestanden in de bijlagen niet!)}
set balText(request_notification) {Verzoekt 'Aankomst status kennisgeving' van dit bericht.
Met andere woorden; u verzoekt om een kennisgeving zodra 
uw bericht is afgeleverd.}
set balText(pgp_sign) {Onderteken het bericht met een PGP handtekening}
set balText(pgp_encrypt) {Codeer het bericht met PGP}
set balText(command_list) {Wijzig de lijst met opgeslagen opdrachten (waar u tekst doorheen kunt  sturen)}
set balText(compose_body) {De inhoud van het bericht}
set balText(attach_file) {Voeg een bestand als bijlage toe aan het bericht}
set balText(attach_special) {Speciale typen bijlagen}
set balText(attach_keys) {Geeft een popupvenster met uw *publieke* PGP
sleutels, zodat u er één kunt kiezen om aan 
uw bericht toe te voegen.
Lees voor meer informatie over PGP.
PGP staat voor Pretty Good Privacy, een be-
hoorlijk sterk coderingssysteem}
set balText(detach) {Verwijder de gemarkeerde bijlage}
set balText(attachments) {Lijst met bijlagen die u hebt 
toegevoegd aan het bericht}
set balText(send) {Verstuur het bericht en bewaar een kopie in de bestemde
"Bewaar uitgaande" postbus. (U kiest de "Bewaar uitgaande"
postbus via het "Postbussen/Wijzigen" venster. Selecteer een
postbus, klik de rechter muisknop en kies 'Wijzigen...'.
Kies in het wijzigen venster van de geselecteerde postbus
een postbus voor het opslaan van doorslagen m.b.v. de 
'Sla op als' tab. Sommige mensen bewaren graag alle doorslagen
in een enkele postbus 'verzonden', anderen hebben liever
meerdere postbussen, anderen willen geen doorslagen.)}
set balText(sendsave) {Stuur het bericht en bewaar een kopie in een
postbus van uw keuze, gebruik makend van een
popup venster met postbussen}
set balText(hold) {Bewaar het bericht in een speciaal bestand, zodat u later
verder kunt gaan. Als u Postilion verlaat gaat dit bericht niet
verloren. Om met dit bericht verder te gaan selecteert u in een
'nieuw bericht' venster 'Componeer/Klad/Componeer onderbroken'}
set balText(eedit) {Gebruik een externe editor voor de bericht tekst}
set balText(compose_to) {De mensen waarvoor dit bericht in hoofdzaak is bedoeld.
Dit is een adresveld, wat inhoud dat Postilion zal proberen het adres
in nette kolommen te houden, het zal pseudoniemen vervangen zodra u een
komma typt of op Return drukt en zal illegale adressen rood markeren.
U kunt Ctrl-l (El) gebruiken voor een lijst met adressen.}
set balText(compose_subject) {Het onderwerp van het bericht}
set balText(compose_cc) {De mensen die ook geinteresseerd kunnen zijn in een kopie van
dit bericht (een 'Carbon copy'). Dit is een adresveld, wat inhoud 
dat Postilion zal proberen het adres in nette kolommen te houden, 
het zal pseudoniemen vervangen zodra u een komma typt of op Return 
drukt en zal illegale adressen rood markeren.
U kunt Ctrl-l (El) gebruiken voor een lijst met adressen.}
set balText(compose_bcc) {Andere mensen die geinteresseerd kunnen zijn in een kopie maar wiens
adres niet zichtbaar zal zijn in *ieder ander's* adreslijst. Geen van de
andere geadresseerden zal dus in staat zijn af te leiden dat een kopie
werd verstuurd naar de mensen op deze lijst. Een privacy voorziening.
Dit is een adresveld, wat inhoud dat Postilion zal proberen het adres 
in nette kolommen te houden, het zal pseudoniemen vervangen zodra u een 
komma typt of op Return drukt en zal illegale adressen rood markeren.
U kunt Ctrl-l (El) gebruiken voor een lijst met adressen.}
set balText(compose_keywords) {Een verzameling sleutelwoorden die het bericht beschrijft}
set balText(compose_content_description) {Een omschrijving van de inhoud van dit bericht}
set balText(compose_reply_to) {Waar antwoorden op dit bericht naartoe moeten worden gestuurd.
(Standaard worden de antwoorden naar het adres gestuurd waarvanaf u
het bericht verstuurde)
Dit is een adresveld, wat inhoud dat Postilion zal proberen het adres 
in nette kolommen te houden, het zal pseudoniemen vervangen zodra u een 
komma typt of op Return drukt en zal illegale adressen rood markeren.
U kunt Ctrl-l (El) gebruiken voor een lijst met adressen.}
set balText(compose_comments) {Commentaar op het bericht}
set balText(compose_from) {Van wie het bericht afkomstig is}
set balText(type_menu) {Gebruik dit menu om aan te geven van welk type deze bijlage is}
set balText(encoding_menu) {De codering die deze bijlage NU heeft. Dit heeft niets te maken
met de codering waarmee het verzonden zal worden}
set balText(attach_description) {Een korte beschrijving van deze bijlage}
set balText(attach_disposition) {Dit is de bestandsnaam waarmee deze bijlage 
hoogstwaarschijnlijk zal worden opgeslagen.}
set balText(attach_id) {In sommige omstandigheden kan het noodzakelijk zijn
een identificator met de bijlage mee te sturen}
set balText(bounce_to) {Geef het adres van de persoon aan wie het gekaatste bericht moet worden verzonden}
set balText(hold_description) {Geef een beschrijving van het bericht wat moet worden onderbroken}
set balText(choose_msg) {Dit bericht bevat één of meer ingesloten berichten. U moet
nu kiezen op welk bericht u wenst te antwoorden (of door wilt sturen)}
set balText(save_cmd_as) {Als u deze opdracht voor later gebruik wilt opslaan type dan
gewoon een naam en zord ervoor dat deze knop gevinkt is.}
set balText(command_to_run_through) {Type hier een opdrachtregel. De geselecteerde tekst zal
als invoer aan deze opdracht gevoed worden en de selectie zal
vervangen worden met de uitvoer van de opdracht.}
set balText(saved_commands) {Lijst van opgeslagen opdrachten}
set balText(apply_changes_to_cmd) {Pas de wijzigingen aan de opdracht toe}
set balText(delete_command) {Verwijder de geselecteerde opdracht}
set balText(command_content) {Type hier een opdrachtregel. Geselecteerde tekst kan dan
als invoer aan deze opdracht gevoed worden en de selectie
zal vervangen worden met de uitvoer van de opdracht.
%s betekent een bestand met de geselecteerde tekst}
set balText(notification_window) {Het kennisgevingenvenster bevat een lijst met alle berichten
waarvoor een kennisgeving verzocht is en die binnen de laatste
zeven dagen verstuurd is (het aantal dagen in instelbaar). Elk bericht
wordt vermeld met de verzenddatum, onderwerp en alle geadresseerden.
Voor elke geadresseerde wordt de huidige status getoond. Er zijn zes 
mogelijke statussen:

-		- Betekent dat Postilion nog niets over deze geadresseerde
		  weet.
Mislukt		- Het bericht heeft de geadresseerde niet bereikt
Afgeleverd	- Het bericht is correct afgeleverd. Dit impliceert NIET dat
		  de geadresseerde het bericht ook heeft gelezen.
Doorgestuurd	- Het bericht is doorgestuurd naar één of andere email
		  transport agent (MTA) die geen kennisgevingen
		  ondersteunt.
Uitgebreid	- Het bericht is afgeleverd, maar de geadresseerde was een
	          pseudoniem dat na substitutie één of meer adressen
		  opleverde. Verdere kennisgevingen kunnen volgen.
Vertraagd	- Het bericht is nog niet afgeleverd, maar verdere pogingen
		  zullen volgen.

U kunt meer informatie over een kennisgeving krijgen door met de muiscursor 
op de betreffende regel te gaan staan en op de linker muisknop te drukken.}
set balText(dsn_readable) {Hier behoort u een uitleg te zien waarom
deze kennisgeving verzonden is}
set balText(dsn_more_info) {Toon die delen van het oorspronkelijke bericht
die in het tekstveld hierboven werden teruggestuurd}
set balText(switch_expression) {Via dit menu kunt u omschakelen tussen uitgebreide en
standaard zoekexpressies}
set balText(save_expr_as) {Als u deze zoekexpressie wilt bewaren voor later gebruik, type 
dan een etiket hier en verzeker u ervan dat deze knop gevinkt is}
set balText(exp_ok) {Voer de zoekopdracht uit, sluit het venster en markeer elk
bericht dat aan de zoekterm voldoet}
set balText(clear) {Wis het bovenstaande gebied (waar u
de zoekterm maakt)}
set balText(exp_basic_and) {Elke regel onder de 'en' moet overeenkomen net een 
bericht voordat het gemarkeerd wordt}
set balText(exp_basic_or) {Elke bericht dat aan tenminste één van de 
niet-lege regels hieronder wordt gemarkeerd}
set balText(exp_basic_field) {Deze regel voldoet indien tenminste één van de woorden in
het veld kan worden gevonden in de aangegeven kopregel}
set balText(exp_adv_exp) {Hier kunt u uw uitgebreide zoekterm opgeven. U kunt het toetsenbord
gebruiken of een van de knoppen hieronder. Voorbeeldtermen zijn:
	Subject has foo
	Subject is "foo bar" and (To has maf or Cc has maf)}
set balText(exp_adv_fields) {Deze knoppen corresponderen met de verschillende
kopregels waarvoor we de inhoud kunnen vergelijken}
set balText(exp_adv_has) {Het veld bevat deze string, mogelijk gemengd met andere tekst}
set balText(exp_adv_is) {De kopregel komt precies hiermee overeen}
set balText(exp_adv_gt) {Dit groter-dan symbool heeft alleen zin in combinatie met 'Grootte'}
set balText(exp_adv_lt) {Dit kleiner-dan symbool heeft alleen zin in combinatie met 'Grootte'}
set balText(exp_adv_bool) {Deze logische termen kunnen gebruikt worden om expressies te combineren}
set balText(exp_adv_p) {Gebruik haken om expressies te groeperen}
set balText(exp_list) {Een lijst met opgeslagen expressies}
set balText(exp_text) {Inhoud van expressie}
set balText(exp_delete) {Verwijder de gemarkeerde expressie}
set balText(fs_show) {Toon alle bestanden in de huidige directory}
set balText(fs_old) {Menu met eerder bezochte directories}
set balText(mode_menu) {Met dit menu kunt u de permissies van een bestand wijzigen}
set balText(welcome_lang) {Met dit menu laat u de taal kiezen voor de gebruikersinterface.
Kies geen taal die u niet kunt lezen!}
set balText(welcome_shutup) {Met dit menu kunt u kiezen of u geïnformeerd wenst te worden over
wijzigingen in Postilion zodra deze zich voordoen (het is ook
toegankelijk vanuit het voorkeuren venster)}
set balText(welcome_cont) {Sluit dit venster en open het hoofd Postilion venster}
set balText(ok_and_apply) {Sluit dit venster en pas de wijzigingen toe}
set balText(keydef_delete) {Druk eerst op deze knop en dan op één van de toets-knoppen
hierboven om de aangegeven toetsenbord-sluiproute te verwijderen}
set balText(keydef_add) {Om een nieuwe toestenbord-sluiproute voor deze opdracht 
toe te voegen: druk op deze knop en druk op de toets op het
toestenbord (op hetzelfde moment als de meta-toetsen als 
Shift, Control en Alt)}
set balText(keydef_def) {Hier ziet u de toetsenbord-sluiproutes (de combinatie van
toetsen om in te drukken) waarmee u deze opdracht kunt aktiveren}
set balText(apply_prefs) {Pas de wijzigingen toe en bewaar de nieuwe instellingen}
set balText(unit_pref) {Eenheid van waarde}
set balText(pref_clock_format) {Klokweergave (12 of 24 uurs)}
set balText(pref_language) {De taal van de gebruikersinterface. Als u deze wijzigt dient u
Postilion te herstarten voordat het effect merkbaar is.
Kies geen taal die u niet lezen kunt!}
set balText(pref_start_win) {Welke vensters moeten standaard geopend worden als 
Postilion start. Verzeker u ervan dat u in ieder geval 
met 'Postbussen' of 'Bestand' begint, anders kunt u 
geen post lezen!}
set balText(pref_next_menu) {Of u een enkel NeXT stijl menu met submenu's wenst
in plaats van de normale menuregel bovenin.
N.B.:
Gebruik NeXT stijl alleen met 'click-to-focus' modus
van uw windowmanager. Het werkt niet goed met 'focus-
follows-mouse' modus.}
set balText(pref_color_set) {Welk kleurenschema Postilion moet gebruiken}
set balText(pref_paper_color) {Welke kleur gebruikt moet worden voor de berichttekst gebieden}
set balText(pref_new_msg_col) {Welke kleur gebruikt moet worden voor nieuwe berichten}
set balText(pref_sel_msg_col) {Welke kleur gebruikt moet worden voor geselecteerde berichten}
set balText(pref_fnd_msg_col) {Welke kleur gebruikt moet worden voor gevonden berichten}
set balText(pref_flg_msg_col) {Welke kleur gebruikt moet worden voor gemarkeerde berichten}
set balText(pref_del_msg_col) {Welke kleur gebruikt moet worden voor verwijderde berichten}
set balText(pref_seen_msg_col) {Welke kleur gebruikt moet worden voor gelezen berichten}
set balText(pref_ans_msg_col) {Welke kleur gebruikt moet worden voor beantwoorde berichten}
set balText(pref_button_bar) {Of Postilion de knoppenbalk moet weergeven}
set balText(pref_image_buttons) {Of Postilion knoppen of tekst moet weergeven voor opdrachtknoppen}
set balText(pref_sync_but) {Toon een postbus synchronisatieknop in de browser}
set balText(pref_sync_oper) {Of de sync knop de postbus moet comprimeren, voor verwijderen
gemarkeerde berichten verwijderend, of alleen moet bijwerken.}
set balText(pref_iconic) {Hier kunt u aangeven dat Postilion moet starten met zijn
venster(s) geminimaliseerd}
set balText(pref_info_changes) {Wanneer de gebruiker een nieuwe versie van Postilion voor de eerste
keer start, laat het programma een lijst zien met alle nieuwe voorzieningen. 
Deze optie laat u deze 'nieuwsdienst' uitschakelen}
set balText(pref_mail_steal) {Of Postilion moet controleren of Netscape 
berichten heeft 'afgepakt' of niet}
set balText(pref_print_command) {Welke opdracht te gebruiken voor afdrukken. Bijv.: lpr %s
Elke '%s' in de opdrachtregel wordt vervangen door de naam van
het af te drukken bestand. Als geen '%s' aanwezig is, zal het
programma het via zijn invoer krijgen.}
set balText(pref_print_header) {Welke kopregels (als Van:, Aan:, ...) mee te sturen met de af
te drukken tekst. (Alleen 'Alles', 'Beperkt' of 'Geen')}
set balText(pref_print_non_text) {Moeten niet-tekst delen in het bericht afgedrukt worden?}
set balText(pref_tmp) {Directory voor tijdelijke bestanden}
set balText(pref_permissions) {Te gebuiken bestands permissies bij het aanmaken van nieuwe
bestanden (bijv. bij het opslaan van berichten). De aanbevolen
waarde, voor privacy en beveiliging, is 0600.}
set balText(pref_userproc) {Bestand waar alle gebruiker-gedefinieerde procedures zijn opgeslagen}
set balText(pref_hold_dir) {Directory waar 'onderbroken' berichten worden bewaard}
set balText(pref_fontsize) {De normale grootte van alle tekst}
set balText(pref_keep_pos) {Bepaalt of Postilion wel of niet de 
vensterafmetingen en -positie onthoudt}
set balText(pref_mailcap_path) {De namen van het systeemwijde mailcap bestand (lees de mailcap
handleiding voor details). Postilion zal proberen de bestanden te 
lezen (bijv. /etc/mailcap, $HOME/.mailcap). Het zal altijd proberen
om de MAILCAP environment variabele als eerste te verwerken.}
set balText(pref_terminal) {Welke opdracht gebruikt moet worden voor het starten van een 
interaktief terminal venster voor mailcap items die 'needsterminal'
gespecificeerd hebben. Deze opdracht zal voorafgegaan worden door
de 'view' opdracht.}
set balText(pref_message_llength) {Het aantal berichten dat getoond wordt in de berichtenlijst}
set balText(pref_list_mode) {Of Postilion het lijstformaat hieronder voor alle
postbussen moet gebruiken (standaard) of 'per postbos'}
set balText(pref_list_format) {Deze optie bepaalt hoe de berichtenlijst eruit ziet. Deze string
lijkt op het formaat wat gebruikt wordt in de 'C' printf() funktie,
behalve dat het enige wat op een '%' mag volgen (behoudens een 
andere '%') een integer is (die negatief mag zijn) en één van de
volgende tekens:
	s - Onderwerp van het bericht
	n - Naam van de afzender (of mailadres indien geen naam)
	m - Mailadres van de afzender
	r - Naam van de geadresseerde (of mailadres indien geen naam)
	R - Mailadres van de geadresseerde
	b - Geschatte grootte van het bericht in bytes
	B - Als hierboven maar in maximaal vier tekens weergegeven
	d - Berichtdatum (in voor mensen leesbare vorm)
	D - Berichtdatum (in aantal seconden sinds epoch)
	S - Berichtstatus (maximaal 5 tekens)
	    Status kan het volgende zijn:
	    N - Dit bericht is ongelezen
	    A - Dit bericht is beantwoord
	    D - Dit bericht is gemarkeerd voor verwijderen
	    F - Dit bericht is gemarkeerd en daardoor lid van de 
	        huidige groep
	    + - Dit bericht is aan u persoonlijk geadresseerd
	i - Huidige berichtindex
Bijvoorbeeld:
	%3i: %4S %6d  %-24n %4B %s
betekent: Toon het berichtnummer (3 tekens breed), dan een ':', dan de
berichtstatus (4 tekens breed), dan de datum (6 breed), dan 2 spaties,
dan de naam van de afzender (24 tekens en links uitgelijnd), dan de 
grootte en uiteindelijk het onderwerp.}
set balText(pref_show_header) {Welke kopregels van het bericht (als "Aan", "Onderwerp", enz.)
getoond moeten worden ('Alle', 'Beperkt' of 'Geen')}
set balText(pref_show_header_selection) {Als we beperkte kopregels tonen, worden 
alleen kopregels in deze lijst getoond}
set balText(pref_browse) {Of Postilion altijd bladermodus moet gebruiken,
nooit, of de instellingen van de postbus moet gebruiken.

Bladermodus is bruikbaar indien een postbus zich niet op
uw eigen computer bevindt. Het laat de inhoud van de 
berichten op de server totdat u op de 'toon bericht' knop
drukt, of dubbelklikt op het bericht in de berichtenlijst}
set balText(pref_sort_mode) {Of Postilion dezelfde berichtvolgorde moet gebruiken
voor alle postbussen (standaard) of de instellingen per
postbus moet volgen}
set balText(pref_folder_sort) {Hoe de berichtenlijst gesorteerd moet worden}
set balText(pref_adv_on_flag) {Ga automatisch naar het volgende
bericht na markeren van een bericht}
set balText(flag_seen) {Wijzig de 'Gezien' vlag van dit bericht
(m.a.w. dat het wel of niet als een 'nieuw' 
bericht moet worden gezien)}
set balText(flag_ans) {Wijzig de Beantwoord vlag van dit bericht}
set balText(flag_unseen) {Markeer dit bericht als ongelezen
(m.a.w. zodat het als nieuw lijkt)}
set balText(seen_group) {Wijzig de Gelezen vlag van alle gemarkeerde berichten
(m.a.w. zodat ze wel of niet nieuw lijken)}
set balText(unseen_group) {Markeer alle gemarkeerde berichten als Ongelezen
(m.a.w. zodat ze allemaal nieuw lijken)}
set balText(ans_group) {Wijzig de Beantwoord vlag van alle gemarkeerde berichten}
set balText(undelete_group) {Verwijder de Verwijderen vlag van alle gemarkeerde berichten}
set balText(pref_strsel_mode) {Of Postilion de methode hieronder moet gebruiken ('Selecteer
bij openen') voor alle postbussen (standaard) of de per postbus
instellingen moet gebruiken}
set balText(pref_start_selection) {Naar welk bericht wordt gesprongen bij het openen van de postbus
Als de optie hierboven wordt ingesteld op 'Gebruik waarde van 
postbus' dan hangt dit af van de instellingen die u per postbus
aangeeft (door selecteren van 'Wijzigen...' in het popup menu 
van de rechter muisknop in het postbussenvenster)}
set balText(pref_log_timeout) {De tijdsduur dat statusberichten 
getoond moeten worden (in seconden)}
set balText(pref_cache_passwd) {Bepaalt of Postilion wachtwoorden voor IMAP en POP verbindingen
moet bufferen. De wachtwoorden worden alleen in geheugen bewaard en
zijn daarom bij afsluiten van Postilion verloren.}
set balText(pref_cache_passwd_timeout) {Hoe lang wachtwoorden gebufferd moeten worden
(0 betekent zolang Postilion aktief is)}
set balText(pref_cache_conn) {Bepaalt of Postilion IMAP-protocol verbindingen open moet laten
nadat de postbus gesloten is. Een open verbinding mag hergebruikt
worden voor meerdere postbus aktiviteiten}
set balText(pref_cache_conn_timeout) {Hoe lang de verbindingen open moeten blijven
(0 betekent zolang Postilion aktief is)}
set balText(pref_urlprot) {Postilion zal alleen URL's met een protocol
uit onderstaande lijst kleuren}
set balText(pref_url_color) {The color of URLs in the message text
(only used on color displays)}
set balText(pref_quote_color) {De kleur van URL's in de berichttekst
(alleen van toepassing op kleurendisplays)}
set balText(pref_url_viewer) {Welk programma te gebruiken voor URL's.
Dit kan ook een userproc zijn.}
set balText(pref_netscape) {Welke opdracht te gebruiken voor het starten van netscape}
set balText(pref_netscape_args) {Alle extra argumenten die netscape moet krijgen}
set balText(pref_dbase_dir) {Waar de database wordt opgeslagen}
set balText(pref_def_extype) {De standaard vervaldatum aktie}
set balText(pref_def_exdate) {De standaard vervaltijd (in dagen sinds opname in database)}
set balText(pref_dbase_backup) {Wanneer de database de backup vervaldatum optie heeft worden 
verlopen berichten in deze directory opgeslagen (gecomprimeerd)}
set balText(pref_chunksize) {Hoveel berichten zich (tenminste) in elk gecomprimeerd blok van 
berichten in de backup-directory moet bevinden}
set balText(pref_expire_interval) {Hoeveel dagen gewacht moet worden tussen verlopen van de database}
set balText(pref_watcher_enable) {Of het monitorvenster moet verschijnen (voor nieuwe post)}
set balText(pref_watcher_time) {Hoe vaak de monitor de diverse postbussen moet controleren 
op nieuwe post. Dit wordt uitgedrukt als het interval tussen 
controles in seconden. Er zijn twee tijden, één voor databases en
één voor alle andere (standaard)}
set balText(pref_watcher_name) {De titel van het monitorvenster}
set balText(pref_watcher_max_height) {De maximale hoogte (in regels) van de berichtenlijst}
set balText(pref_watcher_font) {Welk lettertype te gebruiken in dit venster}
set balText(pref_watcher_show) {Welke berichten getoond moeten worden ('Alle' of 'Nieuwe')}
set balText(pref_watcher_format) {Het formaat van de lijst. (Zie de help voor het
berichtenvenster voor details over het formaat)}
set balText(pref_watcher_bell) {Hoeveel piepen en gegeven moeten worden
wanneer de monitor nieuwe post signaleert.
N.B.: Als de procedure RatUP_Bell bestaat
dan is deze waarde beschermd en zullen er
geen piepen zijn.}
set balText(pref_reply_mode) {Of Postilion hetzelfde Antwoord-aan adres voor
alle postbussen moet gebruiken (normaal) of de per postbus
instellingen moet gebruiken}
set balText(pref_reply_to_addr) {The default reply-to address}
set balText(pref_reply_to_fn) {Het standaard Antwoord-aan adres}
set balText(pref_compose_headers) {Welke kopregels de gebruiker standaard mag wijzigen. De
lijst van kopregels kan gewijzigd worden in het 'nieuw bericht'
venster}
set balText(pref_custom_headers) {Maatwerk kopregels die in het 'nieuw bericht' 
venster moeten worden getoond}
set balText(pref_editor) {Welke externe editor gestart moet worden als de gebruiker
op de 'externe editor' knop drukt. Een '%s' in deze opdracht zal
worden vervangen door de naam van het te editten bestand.
Het 'nieuw bericht' venster zal worden geblokkeerd totdat de
editor is beëindigt}
set balText(pref_attribution) {Deze regel (indien opgegeven) wordt opgenomen voor elk antwoord.
Het heeft dezelfde syntax als de 'berichtenlijst' optie.
Een voorbeeld is:
  Op %d schreef %n:
waar %d zal verschijnen als datum en %n zal verschijnen als de naam
van de persoon naar wie het antwoord gaat.}
set balText(pref_forwarded_message) {Deze regel wordt ingevoegd voor het doorgestuurde bericht
wanneer u een 'doorsturen ingesloten' doet.}
set balText(pref_reply_lead) {Welk teken te plaatsen aan het begin van elke regel van het
oorspronkelijke bericht wanneer een antwoord wordt geformuleerd. Als
de regel niet al met dit teken begint wordt er een spatie tussengevoegd.
Een gebruikelijk keuze voor dit 'citeren' is het '>' teken.}
set balText(pref_quote) {Deze optie bepaalt of wel of niet de berichttekst 
geciteerd wordt wanneer u antwoord op een bericht}
set balText(pref_skip_sig) {Deze optie bepaalt of u wel of niet de ondertekening van
een bericht invoegt in het bericht wanneer u daarop antwoord}
set balText(pref_no_subject) {Welk onderwerp een antwoord moet hebben op berichten zonder onderwerp}
set balText(pref_sig_mode) {Of Postilion hetzelfde ondertekeningsbestand moet gebruiken voor
alle postbussen (standaard) of de per postbus instellingen moet gebruiken}
set balText(pref_signature) {De naam van het bestand met uw ondertekening}
set balText(pref_lookup_name) {Ja indien Postilion moet proberen om lokale adressen te controleren}
set balText(pref_copy_attached) {Ja indien Postilion een kopie moet maken van een bijlagebestand
zodra de bijlage is gedefinieerd. Als dit 'Nee' is gaat Postilion 
ervan uit dat de bestanden er nog zijn wanneer het bericht verzonden 
moet worden en zal op dat tijdstip de kopieën maken.}
set balText(pref_from_mode) {Of Postilion hetzelfde 'Van:' adres voor alle postbussen
moet gebruiken (standaard) of dat dit op een per postbus
basis moet geschieden}
set balText(pref_from_addr) {Which value the "From:" line should have. Please note that if the From:
line isn't you then a "Sender:" line will be added}
set balText(pref_from_fn) {Welke waarde de 'Van:' regel moet hebben. Let er alstublieft op
dat als u niet de 'Van:' bent, er een 'Zender:' regel zal worden
toegevoegd.}
set balText(pref_date-prefix) {De prefix die gebruikt moet worden bij het maken van
dynamische postbussen (bijv. als deze waarde 'Verstuurd' is,
dan zal de postbus zoiets als 'Verstuurd-Feb-1999' heten)}
set balText(pref_masquerade_as) {Markeer alle berichten die u verstuurt als komend van 
dit domein (bijv. als u xxx.nl als het domein opgeeft, dan lijkt
alle post te komen van uw_naam@xxx.nl. Normaal gesproken vult u
hier het domein van uw internetprovider in)}
set balText(pref_domain) {Het domein waartoe deze machine behoort (als 'wxs.nl').
Als 'Maskeer machine als' NIET gedefinieerd is, dan 
worden uw computernaam en domeinnaam samengevoegd.
Dit betekent dat uw post lijkt te komen van
  uw_naam@uw_machine.uw_domein
en dat antwoorden naar dit adres worden gestuurd.
Als uw machinenaam een '.' bevat, dan wordt het 
domein niet gebruikt.}
set balText(pref_delivery_mode) {Deze modus bepaalt wat er gebeurt wanneer u op één van de verzend-
knoppen in het 'nieuw bericht' venster drukt. Als de modus 'Direkt' 
is dan start het verzenden onmiddelijk (als achtergrondproces). Als 
de instelling 'Bulksgewijs' is gekozen dan wordt het bericht in een 
lijst geplaatst en op een later moment kunt u kiezen om alle wachtende
berichten in één keer te verzenden.}
set balText(pref_sendprot) {Hoe de berichten verzonden moeten worden. Via SMTP of een door
u opgegeven programma. Als een programma gebruikt moet worden, dan 
kunt u die in het veld 'Verzendprogramma' opgeven.}
set balText(pref_smtp_hosts) {Als we berichten via SMTP moeten versturen dan is dit een lijst
van servers die we kunnen proberen om de berichten af te leveren.
Elke servernaam mag van de vorm server:poortnummer zijn waarbij 
poortnummer het TCP poortnummer is van de SMTP service op die server.}
set balText(pref_smtp_timeout) {Hoe lang we bereid zijn te wachten op een antwoord van de SMTP server 
(in seconden)}
set balText(pref_smtp_reuse) {Als Nee dan zal de verbinding met de SMTP server gesloten en geopend
worden voor elk afzonderlijk bericht. Als Ja dan zullen alle berichten
via dezelfde verbinding verstuurd worden.}
set balText(pref_smtp_verbose) {Hoeveel u weten wilt van wat er gebeurt als er 
berichten verzonden worden via SMTP.}
set balText(pref_sendprog) {Dit is het programma wat gebruikt zal worden als berichten verstuurd
moeten worden met een programma. Het wordt geacht het adres van de
geadresseerde als argument te accepteren en vervolgens het bericht van
standaard invoer te lezen (voorbeelden zijn sendmail of qmail)}
set balText(pref_sendprog_8bit) {Dit is het type data wat het verzendende programma kan verwerken
(zeven- of achtbits data)}
set balText(pref_charset) {Welke karakterset we gebruiken}
set balText(pref_force_send) {Als dit Ja is dan zal Postilion proberen berichten te versturen, zelfs
als het de volledige lokale machinenaam niet kent (naam + domein).
Zet dit NIET op Ja, tenzij u precies weet wat u doet.}
set balText(pref_dsn_directory) {Waar de DSN informatie opgeslagen moet worden}
set balText(pref_dsn_request) {De standaard waarde van de bevestigingenknop in het 'nieuw bericht'
venster. Een verzoek voor kennisgeving is een verzoek voor een
automatisch bericht wanneer een bericht dat u verzonden heeft zijn bestemming
bereikt heeft. (Niet alle systemen (willen) voldoen aan zo'n verzoek.)
De Sonde knop test of uw systeem dergelijke verzoeken wil afhandelen.
Zie de 'release-notes' voor verdere informatie (in Engels).}
set balText(pref_dsn_snarf_reports) {Als u verzocht heeft om kennisgevingen, dan worden deze
afgeleverd als berichten. Deze optie bepaalt of deze moeten verschijnen 
in de berichtenlijst of niet. (Ze worden altijd zichtbaar in het 
kennisgevingenvenster)}
set balText(pref_dsn_expiration) {Hoe lang zullen de berichten (en hun eventuele bevestigingen) bewaard
worden in het kennisgevingenvenster. Deze tijd wordt gemeten in
dagen sinds het oorspronkelijke bericht werd verzonden.}
set balText(pref_dsn_verbose) {Het rapporteringsniveau wordt apart ingesteld voor elk type kennisgeving.
Er zijn drie verschillende niveau's:
   Zeg niets
        Laat niet merken dat een kennisgeving binnengekomen is
   Toon in statusregel
        Toon een bericht in de statusregel zodra een kennisgeving binnenkomt.
   Toon in apart venster
        Dit toont de volledige kennisgeving in een apart venster wat verschijnt
	zodra deze binnenkomt.
Merk alstublieft op dat onafhankelijk van het hier ingestelde rapporterings-
niveau alle kennisgevingen zichtbaar zijn in het kennisgevingenvenster.}
set balText(pref_pgp_enable) {Dit laat u het gehele PGP-gedeekte (Pretty Good Privacy) 
aan of uitzetten.}
set balText(pref_pgp_prog) {De volledige padnaam van het pgp programma
(bijv. /usr/local/bin/pgp)}
set balText(pref_pgp_args) {Enig extra argument dat meegegeven moet worden aan het pgp programma.
Probeer de opdracht uit vanaf een prompt om er zeker zijn dat u de
syntax goed heeft.}
set balText(pref_cache_pgp) {Of PGP wachtwoorden gebufferd moeten worden}
set balText(pref_cache_pgp_timeout) {Hoe lang we PGP wachtwoorden moeten onthouden in seconden.
(0 betekent zolang Postilion aktief is)}
set balText(pref_pgp_sign) {Of u uw nieuwe berichten digitaal wenst te ondertekenen (met PGP).
U zult een PGP sleutel gegenereerd moeten hebben ("pgp -kg"). Zie
de PGP handleiding voor verdere informatie.}
set balText(pref_pgp_encrypt) {Of u PGP wenst te gebruiken om nieuwe berichten te coderen.
U zult een PGP sleutel gegenereerd moeten hebben ("pgp -kg"). Zie
de PGP handleiding voor verdere informatie.}
set balText(body_of_message) {Hier ziet u de inhoud van het geselecteerde bericht. Klik hier 
met de rechter muisknop voor een menu met extra opdrachten
en informatie}
set balText(howto_display) {Met dit menu kunt u aangeven hoe u de inhoud van het bericht
wenst te bekijken}
set balText(save_bodypart) {Bewaar het huidige bericht gedeelte van het bericht 
in een bestand van uw keuze.}
set balText(view_as_text) {Als deze knop gevinkt is dan wordt dit gedeelte van
het bericht getoond als ware het tekst.}
set balText(view_source) {Bekijk dit gedeelte van het bericht zoals het verzonden werd
(in een apart venster)}
set balText(add_to_keyring) {Voeg deze publieke sleutel toe aan uw sleutelring}
set balText(run_mailcap) {Start de opdracht zoals aangegeven in de mailcap voor dit type}
set balText(bodypart_entry) {Dit menu werkt op dit gedeelte van het bericht. Het submenu
geeft informatie en geeft u de mogelijkheid tot enige bewerkingen
op dit gedeelte.}
set balText(bodypart_show) {Deze vinkknop laat u aangeven of u dit gedeelte
wel of niet wilt zien. Als u het verbergt dan
blijft het verborgen totdat u de postbus gesloten
en weer geopend hebt.}
set balText(bodypart_save) {Bewaar de inhoud van dit bericht in een bestand}
set balText(dbs_and) {Alle niet-lege regels hieronder moeten precies met
het bericht overeenkomen voordat het wordt opgenomen in
de huidige groep van berichten.}
set balText(dbs_or) {Alle berichten die met één of meer van 
onderstaande regels overeenkomt zal worden
opgenomen in de huidige groep van berichten.}
set balText(dbs_keywords) {Deze regel komt overeen indien enig woord als
sleutelwoord is opgegeven voor een bericht}
set balText(dbs_subject) {Deze regel komt overeen indien één of meer van deze woorden in
het onderwerp van een bericht wordt aangetroffen. Als u een reeks
woorden wilt gebruiken om te zoeken, zet dan quotes ("") eromheen}
set balText(dbs_all) {Deze regel komt overeen indien één of meer van deze woorden in
het bericht wordt aangetroffen. Als u een reeks woorden wilt 
gebruiken om te zoeken, zet dan quotes ("") eromheen}
set balText(dbs_to) {Deze regel komt overeen indien één of meer van deze woorden in
de 'Aan' regel van het bericht wordt aangetroffen. Als u een reeks 
woorden wilt gebruiken om te zoeken, zet dan quotes ("") eromheen}
set balText(dbs_from) {Deze regel komt overeen indien één of meer van deze woorden in
de 'Van' regel van het bericht wordt aangetroffen. Als u een reeks 
woorden wilt gebruiken om te zoeken, zet dan quotes ("") eromheen}
set balText(dbs_cc) {Deze regel komt overeen indien één of meer van deze woorden in
de 'Cc' regel van het bericht wordt aangetroffen. Als u een reeks 
woorden wilt gebruiken om te zoeken, zet dan quotes ("") eromheen}
set balText(keywords) {Sleutelwoorden die het bericht beschrijven}
set balText(exp_none) {Laat dit bericht niet verlopen}
set balText(exp_remove) {Verwijder dit bericht uit de database}
set balText(exp_incoming) {Voeg dit bericht toe aan het 'inkomend' bakje zodra het verloopt}
set balText(exp_backup) {Verplaats dit bericht naar het archief zodra het verloopt}
set balText(exp_date) {Wanneer het bericht verloopt. Op dit moment wordt alleen de '+N' vorm
ondersteund, waarbij N het aantal dagen is dat het bericht in de database
kan blijven voordat het verloopt.}
set balText(vd_createsub) {Maak een nieuw sub-item die zijn eigen 
verzameling postbussen kan bevatten}
set balText(vd_newfile) {Maak een nieuwe postbus als een
eenvoudig Unix postbus bestand}
set balText(vd_newmh) {Maak een nieuwe mh postbus}
set balText(vd_newdbase) {Maak een nieuwe database}
set balText(vd_newimap) {Maak een nieuwe IMAP postbus}
set balText(vd_newpop) {Maak een nieuwe POP3 postbus}
set balText(vd_newdynamic) {Maak een nieuwe dynamische postbus}
set balText(vd_importdir) {Importeer bestandspostbussen van een directory}
set balText(vd_importmh) {Importeer mh-postbussen van een directory}
set balText(vd_importimap) {Importeer IMAP postbussen}
set balText(vd_foldermenu) {Deze menuknop laat u nieuwe postbussen maken en
sub-items voor groepen van postbussen.}
set balText(vd_importmenu) {Dit menu laat u groepen van bestaande postbussen importeren.
De nieuwe ingangen worden geplaatst in het hoofdmenu.}
set balText(vd_edit) {Wijzig deze ingang}
set balText(vd_delete) {Verwijder deze ingang (als deze ingang een submenu is
dan zal er gevraagd worden of u ook alle onderliggende
ingangen wilt verwijderen)}
set balText(vd_setinbox) {Stel deze postbus in als de standaard postbus.
Deze wordt geopend zodra Postilion start.
Normaal gesproken is dit een postbus die nieuwe
post ontvangt.}
set balText(vd_setsaveout) {Stel deze postbus in als ontvanger van kopieën 
van alle door u verzonden berichten. Deze instelling 
kan per postbus afzonderlijk worden ingesteld}
set balText(vd_setstartup) {Open deze postbus zodra Postilion start}
set balText(vd_setstartmin) {Open deze postbus geminimaliseerd zodra Postilion start}
set balText(vd_unsetstartup) {Open deze mailbox niet als Postilion start}
set balText(vd_unsetstartmin) {Open deze mailbox niet geminimaliseerd als Postilion start}
set balText(vd_list) {Dit is een lijst met uw postbussen.
   * Dubbelklik de linker muisknop om een postbus te openen in het
     huidige browservenster of in een nieuw browservenster als
     er nog geen één open is.
   * Druk op de rechter muisknop voor een menu met opdrachten die
     u kunt toepassen op het geselecteerde item, of om een nieuwe
     postbus er achter toe te voegen.
   * Items met een pijltje aan de rechterkant (->) hebben subitems
     die zullen verschijnen in de volgende lijst rechts van deze.
   * U kunt terug naar links door een item in de lijst links van
     deze te selecteren.}
set balText(mbv_list) {Dit is een lijst met uw postbussen.
   * Dubbelklik de linker muisknop om
     een postbus in dit venster te openen.
   * Druk op de rechter muisknop voor een
     menu om de geselecteerde postbus te 
     openen of om de op geselecteerde 
     berichten ernaar te verplaatsen.
   * Items met een pijltje aan de rechter-
     kant (->) hebben subitems die zullen 
     verschijnen in de volgende lijst 
     rechts van deze.
   * U kunt terug naar links door een item 
     in de lijst links van deze te selec-
     teren.}
set balText(mbv_sash_open) {Klik met de linker muisknop op dit kozijn
om een venster met uw postbussen te openen}
set balText(mbv_sash_close) {Klik met de linker muisknop op dit kozijn
om het venster met uw postbussen te sluiten}
set balText(msg_sash) {Sleep dit kozijn omhoog of omlaag met
de muis om de relatieve grootte van de
berichtenlijst (boven) en het berichtvenster
(onder) te wijzigen.}
set balText(vd_menuname) {Naam van nieuw submenu}
set balText(vd_name) {Naam van de postbus}
set balText(vd_mhname) {Naam van de mh-postbus}
set balText(vd_host) {De naam van de server waar de postbus
gevonden kan worden}
set balText(vd_user) {De gebruikersnaam die we moeten gebruiken om bij
de postbus te kunnen komen}
set balText(vd_mbox) {Naam van de IMAP postbus}
set balText(vd_port) {Poortnummer waarnaar de server luistert}
set balText(vd_filepat) {Gebruik alleen bestanden die voldoen aan dit patroon.
Bijv. *mbox zou alle bestanden selecteren die eindigen met
de letters "mbox"}
set balText(vd_dirpat) {Daal alleen af in directories die voldoen aan dit patroon}
set balText(vd_pattern) {Gebruik alleen postbussen die voldoen aan dit patroon}
set balText(watcher) {Druk op de linker muisknop om Postilion's hoofdvenster te laten
verschijnen. Een rechterklik laat dit venster tijdelijk verdwijnen.}
set balText(help_subjlist) {Lijst van help onderwerpen. Klik met de linker 
muisknop op een onderwerp om de help te bekijken.}
set balText(help_text) {Helptekst voor het gekozen onderwerp}
set balText(pref_ispellRecheckAfterAdd) {Kies 'Ja' voor een hercontrole van de spelling van woorden
die nu als foutief gespeld gemarkeerd zijn. Meestal een goed
idee, afgezien van het feit dat het een kleine vertraging kan
veroorzaken indien u woorden aan uw eigen woordenboek hebt
toegevoegd.

U kunt ook de rechter muisknop om woorden te accepteren uit een
menu van mogelijk alternatieven.}
set balText(pref_ispellon) {Dit zet de spellingcontrole optie aan of uit. Let op dat de
optie aan moet staan VOORDAT een bericht geopend wordt.}
set balText(pref_ispelltextOnly) {Vink deze optie als u alleen spellingscontrole wilt uitvoeren op
gedeelten die als 'tekst' gemarkeerd zijn. Dit zou spellingsfouten in
Aan:, Cc: & X-Face regels moeten voorkomen. Bovendien krijgt u een 
kleine verbetering in response-tijd.}
set balText(pref_ispelldefaultCommand) {Dit is het programma dat gebruikt wordt voor het eigenlijke werk.
'ispell -a' is waarschijnlijk een goede keuze. Als u een alternatief
woordenboek wilt gebruiken zal 'ispell -a -d<woordenboekbestand>' van
toepassing zijn. U kunt ondervinden dat '-S' de volgorde van alter-
natieve woorden beter sorteert. Zie de ispell handleiding voor meer 
details.}
set balText(pref_ispellotherCommands) {Andere manieren om het 'ispell' programma te starten. Voornamelijk
bedoeld voor mensen die met meer talen moeten werken. Deze regel
moet in etiket/opdrachtregel paren zijn. Voorbeeld van zo'n paar is:
"Duits { ispell -a -d deutch }"}
set balText(pref_ispellpopupBinding) {Dit bepaalt waaraan het popup venster verbonden is. 
Enige voorbeelden zijn:
	ButtonPress-3 
	ButtonPress-2
	ButtonPress-1
	Shift-3
	Control-3
	Meta-2
	Alt-1
	enz...

Merk op dat het menu verdwijnt op elke ToetsLos}
set balText(pref_ispellviewStyle) {Dit bepaalt hoe foutief gespelde woorden moeten worden 
weergegeven. U kunt de ingebouwde typen gebruiken om nieuwe 
typen te maken met 'anders'. Voor 'kleuren' versies vult u de
kleur hieronder in.
Voorbeelden van 'anders':
	-underline t
	-background red
	-foreground Bisque
	-font <lettertype>
	-fgstipple <bitmap>
	-bgstipple <bitmap>
Bitmaps kan van alles zijn, 'gray50' en 'gray25' zijn bijv. 
populair...
	 -font *italic*
    of   -font *bold*
    of   -font *24*    (Groot!)
    of   -font *italic*24* (Groot schuin)
	 -relief <relief> (Zie tk documenten voor meer info...)
Effecten kunnen ook gecombineerd worden. Bijvoorbeeld:
	-underline t -foreground red
	-bgstipple gray25 -color red}
set balText(pref_ispellviewStyle-Color) {Kleur voor voor- en achtergrondkleur}
set balText(pref_ispellviewStyle-Other) {Stijl als 'anders' is geselecteerd}
set balText(pref_mboxvis) {Of het postusvenster wel of niet bovenin
het browservenster moet worden getoond}
set balText(pref_expunge_on_close) {Of Postilion alle voor verwijdering gemarkeerde berichten
moet schonen bij het sluiten van uw postbus.}
set balText(pref_automatic_wrap) {Stuurt de automatische regelafbreek functie}
set balText(pref_automatic_indent) {Stuurt de automatische inspringen functie}
}
