#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_help_it {} {
global help
set help(title,intro) Introduzione
set help(intro) {                        Sistema d'aiuto per Postilion


Se non sai come usare il sistema d'aiuto, seleziona "Aiuto sull'aiuto"
a destra.


  Introduzione

Postilion e' un programma di posta elettronica (MUA da Mail User Agent), che può
gestire, ricevere e spedire messaggi email.

La finestra principale di Postilion e' la "finestra cartella". Questa e' la
finestra che appare all'avvio di Postilion. La barra dei menu e una linea di
stato che descrive la cartella attiva si trovano in alto alla finestra. Al
di sotto e' visualizzata la lista dei messaggi contenuti nella cartella, che 
possono essere selezionati con il mouse per vederne il contenuto nella parte
inferiore della finestra. Sotto la lista dei messaggi c'e' un'altra linea di
stato e una fila di bottoni. Infine, il contenuto del messaggio selezionato
viene mostrato nella zona inferiore. Per ottenere maggiori informazioni
seleziona "finestra cartella" dalla lista di sezioni.

Prima di spedire un messaggio e' necessario scriverlo. Ci sono vari modi per
raggiungere la finestra di composizione. Se vuoi creare un nuovo messaggio,
devi premere sul bottone Componi. Se invece vuoi rispondere al messaggio
corrente, premi uno dei bottoni di risposta. Per maggiori informazioni su
come spedire messaggi, seleziona "Comporre messaggi" dalla lista di sezioni.

Normalmente la finestra cartella mostra la tua INBOX, cioe' la cartella dove
viene messa la posta in arrivo. Quando hai letto (e forse risposto) ad un
messaggio, magari vuoi salvarlo da qualche altra parte, per mantenere
"ordinata" la tua INBOX. Per fare ciò bisogna muovere il messaggio in
un'altra cartella. Ci sono diversi tipi di cartelle con diverse proprietà.
Seleziona "Cartelle" per saperne di più.

Se un nuovo messaggio arriva mentre il programma e' iconizzato, una piccola
finestra di "osservazione" appare. Seleziona la sezione "Osservazione" per
saperne di più.

Postilion e' un programma molto complesso. Nonostante abbia cercato di renderlo
facile da usare, la complessità viene dimostrata dalle varie opzioni che e'
possibile personalizzare. Tutte le varie opzioni dovrebbero avere valori
standard "ragionevoli", ma se pensi che devi cambiare qualcosa, leggi la
sezione "Preferenze".

  Maggiori informazioni

Informazioni riguardo la versione più recente, ecc. si possono trovare all'URL

 http://www.postilion.org
}
set help(title,deleting) {Cancellare messaggi}
set help(deleting) {				Cancellare messaggi

La cancellazione dei messaggi avviene in due tempi. Prima i messaggi vengono
contrassegnati per la cancellazione, e poi, più tardi, i messaggi vengono
rimossi fisicamente dalla cartella.

I messaggi contrassegnati per la cancellazione sono indicati da una 'D'
nella lista dei messaggi. Per contrassegnare un messaggio per la
cancellazione e' sufficiente premere il bottone "Cancella". Tutte le normali
operazioni sono possibili su tali messaggi fino a che non vengono rimossi
definitivamente dalla cartella.

E' possibile rimuovere il segno 'D' dal messaggio corrente selezionando la
voce "Annulla cancella" dal menu "Messaggi".

La cancellazione fisica dei messaggi contrassegnati avviene quando si
sincronizza o aggiorna la cartella (tramite gli opportuni comandi del menu
"Amministrazione", o quando si chiude la cartella (aprendo un'altra cartella
chiude la cartella corrente. Ciò accade anche quando si esce da Postilion).
}
set help(title,grouping) {Raggruppare i messaggi}
set help(grouping) {				Raggruppare i messaggi

Raggruppare i messaggi e' un modo conveniente per eseguire certe operazioni
su più messaggi contemporaneamente.

Il gruppo corrente consiste in tutti i messaggi selezionati nella cartella
corrente. I messaggi selezionati sono contrassegnati da una 'F' nella lista
dei messaggi (la F fa parte dello stato del messaggio, cosi' se il formato
della lista non contiene %S, non sarà visibile). I messaggi rimangono
selezionati anche dopo un'operazione.

Al momento le seguenti operazioni sono ammesse su un gruppo (tramite il menu
"Gruppo"):
  * Cancella	- Contrassegna i messaggi per la cancellazione
  * Annulla cancella - Recupera i messaggi contrassegnati per la cancellazione
  * Muovi       - Muove i messaggi in un'altra cartella    

Ci sono cinque modi differenti per aggiungere/rimuovere messaggi da un
gruppo:

  * Usando il comando "Cancella selezione di gruppo" dal menu "Gruppo".
    Questa opzione deseleziona tutti messaggi contrassegnati dalla 'F'.

  * Premendo il tasto destro del mouse su un messaggio nella lista dei
    messaggi. Questo seleziona/deseleziona il messaggio.

  * Usando il comando "Crea in finestra..." dal menu "Gruppo"
    Verrà aperta una finestra a parte che contiene una lista di tutti i
    messaggi della cartella corrente in cui e' possibile selezionare e/o
    deselezionare messaggi. Premendo Ok i messaggi selezionati verrano
    raggruppati.

  * Usando il comando "Crea con chiave..." dal menu "Gruppo".
    Verrà aperta una finestra dove e' possibile inserire una chiave secondo
    la quale verranno selezionati i messaggi. Vedere la sezione "Finestra
    chiavi" per maggiori informazioni.

  * Usando il comando "Usa chiavi salvate" dal menu "Gruppo". Questo menu
    contiene un sottomenu con le chiavi salvate in precedenza.
}
set help(title,folders) Cartelle
set help(folders) {                            Cartelle

Una cartella e' una collezione di zero o più messaggi. Ci sono vari modi per salvare e accedere ai messaggi in una cartella. Postilion riconosce quattro diversi tipi di cartella.

Per aprire una cartella, bisogna sapere di quale tipo sia e, in certi
casi, qualche ulteriore informazione.  Per aiutare l'utente Postilion
possiede cartelle virtuali. Quando viene definita una di queste
cartelle, bisogna specificarne il nome, il tipo e altri dati. Il nome
apparirà nei menu "Cartelle" e "Muovi" per facilitarne la selezione.

  Postilion include supporto per i seguenti tipi di cartelle:

* Mailbox Unix
  Una cartella Unix consiste in un file di testo dove i messaggi sono separati
  da una linea di delimitazione ("From" o "^A^A^A^A"). Questo e' il modo
  standard di gestione della posta sotto Unix.
  Dati richiesti: il nome del file.

* IMAP4
  IMAP (versione 4) e' un protocollo per accedere a cartelle attraverso la
  rete. Un utente può avere cartelle IMAP multiple su un host.
  Dati richiesti: il nome del server
                  il nome utente
                  una password
                  il nome della mailbox

* POP3
  POP (versione 3) e' un protocollo per accedere a cartelle attraverso la
  rete. Un utente può avere una sola cartella POP su un host.
  Dati richiesti: il nome del server
                  il nome utente
                  una password

* Database
  Una cartella database e' una collezione di messaggi, dove ogni messaggio
  e' associato a delle chiavi. Aprendo il database e' uguale a effettuarvi una
  ricerca (e' possibile cercare non solo le chiavi). I messaggi possono inoltre
  avere una data di scadenza, e quando questa data viene raggiunta, qualcosa
  accade al messaggio in questione (per esempio, può essere cancellato). Ogni
  utente può avere un database.
  Dati richiesti: una chiave di ricerca
                  data e tipo di scadenza

* Dinamica
  Questa e' una forma speciale di cartella file. Viene specificata come una
  directory dove i singoli messaggi vengono salvati in file separati. Quando 
  viene aperta una cartella dinamica, appare una lista dei file nella directory.
  Dati richiesti: il nome della directory
}
set help(title,folderdef) {Definizione cartelle virtuali}
set help(folderdef) {				Definizione di cartelle virtuali

Postilion permette di organizzare le cartelle in una struttura ad albero. La
struttura e' analoga ad un normale sistema di file. Postilion utilizza i menu
come directory e cartelle al posto dei file. Questa struttura viene utilizzata
per costruire i menu Cartelle e Muovi. Quando viene invocato il comand
"Nuova/Modifica cartella" apparirà la finestra di definizione delle cartelle
virtuali. Questa finestra permette di modificare l'intera struttura (o quanto
può essere mostrato sullo schermo). I menu/directory sono le caselle, mentre
le cartelle sono rappresentate dai loro nomi. Le relazioni tra le directory
vengono mostrate tramite linee. La radice dell'albero e' la cartella
nell'angolo in alto a sinistra. La cartella contrassegnata da un '*' e la
cartella predefinita. Un'altra cartella può essere contrassegnata da un
">", e in tal caso sarà la cartella dove verranno salvati i messaggi
spediti.

La barra dei menu contiene un menu che permette di creare nuove cartelle e
menu. Le cartelle e i menu che vengono creati tramite questo menu vengono
posti nel menu radice.

Quando viene premuto il tasto sinistro del mouse su un elemento, apparirà un
menu che permette di modifcare l'elemento corrente o aggiungere nuovi elementi
nella posizione indicata nella struttura dei menu.

Per muovere gli elementi bisogna utilizzare il bottone destro del mouse.
Premendo questo bottone sopra un elemento e trascinandolo e' possibile
metterlo in una nuova posizione. Rilasciando il bottone del mouse, l'elemento
verrà messo nella posizione corrente. Utilizzando questo metodo e' possibile
muovere sia menu sia cartelle.

Se una struttura di cartelle esiste già su disco, Postilion può leggerla e
costruire la corrispondente struttura di cartelle virtuali automaticamente.
Per fare ciò bisogna selezionare "Directory" dal menu "Importa". E' anche
possibile importare le strutture da una cartella IMAP.

Per chiudere la finestra, scegliere "Chiudi" dal menu "Finestra".
}
set help(title,dbase) {Il Database}
set help(dbase) {				Il database

Il database e' un metodo per salvare messaggi. Ciascun messaggio e' associato
con alcune parole chiave e una data di scadenza (che può essere infinita).

Quando un messaggio viene inserito nel database, e' possibile assegnarvi le
seguenti informazioni:
  * parole chiave       - una lista di parole chiave (opzionale)
  * data di scadenza    - una data in cui il messaggio verrà considerato
			  scaduto. La data viene indicata con un segno "+"
			  e un numero di giorni. Il campo può rimanere vuoto:
			  in questo caso il messaggio non scadrà mai.
  * azione di scadenza  - cosa accade quando il messaggio scade. Le scelte sono:
        * Rimouvi              - rimuove il messaggio
        * Inserisci in entrata - muove il messaggio nella cartella in entrata
        * Muovi in archivio    - muove il messaggio in qualche formato
				 d'archivio
        * Utente               - il messaggio viene passato ad un programma
				 definito dall'utente

Quando si vuole prelevare i messaggi dal database e' possibile effettuare una
ricerca sui seguenti campi: a, da, copia, soggetto, parole chiave e l'intero
messaggio. E' possibile prelevare messaggi che corrispondono a tutti i criteri
di ricerca o solo a uno.
}
set help(title,notification) Notifiche
set help(notification) {				Notifiche

	Cosa sono le notifiche

Le notifiche (il termine tecnico e' Delivery Status Notifications (DSN))
permette di sapere quando un messaggio e' stato consegnato al destinatario.
DSN lavora a livello SMTP, per cui e' necessario usare SMTP per spedire i
messaggi e, poiche' DSN e' un'estensione al protocollo, non tutti i server
SMTP lo supportano. Nella finestra delle preferenze vi e' un bottone "Prova"
che verifica il supporto DSN sul sistema locale. Tutti i sistemi che si
trovano tra il mittente e il destinatario devono supportare DSN perche'
questo funzioni.

	La finestra notifiche

La finestra notifiche contiene una lista di tutti i messaggi per cui e'
stata richiesta una notifica spediti negli ultimi sette giorni (il lasso di
tempo e' configurabile). Per ogni messaggio viene indicata la data di
spedizione, il soggetto e i destinatari. Prima di ogni destinatario vi e' un
indicatore dello stato corrente. Ci sono sei diversi stati:

-		- Significa che Postilion non sa ancora niente.
Fallito	        - Significa che il messaggio non ha potuto raggiungere il
		  destinatario.
Consegnato	- Il messaggio e' stato consegnato, ma ciò non implica che sia
		  stato letto.
Trasferito	- Il messaggio e' stato trasferito ad un server (MTA) che non
		  supporta le notifiche.
Espanso		- Il messaggio e' stato consegnato, ma la destinazione era un
		  alias che e' stato espanso a uno o più indirizzi diversi.
In attesa	- Il messaggio non e' ancora stato consegnato, ma ulteriori
		  tentativi verranno effettuati.

E' possibile ottenere più informazioni, clickando con il pulsante destro
del mouse sulla linea del destinatario. In questo modo apparirà una
finestra contenente maggiori dettagli.

	Il dettaglio delle notifiche

La finestra dei dettagli sulle notifiche contiene del testo leggibile, che
descrive cosa ha causato la notifica. Al di sotto vi sono dei campi che
possono aiutare ulteriormente a capire cosa e' andato storto (oppure no). Il
pulsante "Mostra altro del messaggio di ritorno" mostrerà altro testo
utile contenente le porzioni del messaggio originale ritornate nella
notifica.

Per maggiori informazioni tecniche riguardo le notifiche, vedere gli RFC
1891, 1893 e 1894.
}
set help(title,userproc) {Procedure Utente}
set help(userproc) {			Procedure definite dall'utente

Le procedure definite dall'utente permettono di avere maggiore controllo su
alcune caratteristiche di Postilion. Le procedure sono normali procedure tcl
(cioe' sono scritte in tcl7.5+). Non e' necessario che esistano procedure:
esse vengono usate solo se esistono.

L'utente può definire procedure nel file ~/.ratatosk/userproc file (o
dove specificato dall'opzione userproc). Se le procedure hanno bisogno di
variabili globali, queste devono iniziare con "ratUP_". Le seguenti
procedure possono essere definite:

RatUP_IsMe mailbox domain personal adl
        mailbox  -      Nome del file contenente la posta
        domain   -      Il dominio
        personal -      Il nome (opzionale)
        adl      -      Lista di domini sorgente
	Questa procedura determina se l'indirizzo punta all'utente oppure no.
	Deve ritornare un valore booleano.

RatUP_Translate mailbox domain personal adl
        mailbox  -      Nome del file contenente la posta
        domain   -      Il dominio
        personal -      Il nome (opzionale)
        adl      -      Lista di domini sorgente (probabilmente nulla)
	Quando rispondiamo ad un messaggio, tutti gli indirizzi a cui lo stiamo
	mandando vengono filtrati da questa procedura. Deve ritornare una lista
	di quattro elementi {mailbox domain personal adl}.
RatUP_Signature message
        message -       La funzione per il messaggio a cui verrà aggiunta la
        		signature
	Questa funzione dovrebbe ritornare una stringa di testo che più tardi
	verrà aggiunta alla prima parte di testo del messaggio. Il parametro
	message e' una funzione che può essere utilizzata per raccogliere
	informazioni riguardo al messaggio (vedere il file di interfaccia per
	maggiori informazioni). Notare che questa routine viene chiamata prima
	che l'utente inizi a modificare il messaggio cosi' non ci saranno
	informazioni interessanti disponibili per nuovi messaggi. Tali 
	informazioni saranno però disponibili nel caso si stia rispondendo
	ad un altro messaggio.

RatUP_Bell
    Questa funzione dovrebbe notificare l'utente che nuova posta e' arrivata
    Se questa funzione non esiste allora viene prodotto un suono.    

RatUP_ShowURL url
        url -   L'URL da mostrare
    Questa funzione può essere chiamata quando l'utente preme il bottone
    sinistro del mouse sopra un URL in un messaggio. La funzione dovrebbe
    eseguire un browser (nel background).
}
set help(title,bugreport) {Rapporto malfunzioni}
set help(bugreport) {				Rapporto malfunzioni

Si dovrebbero spedire malfunzionamenti a maf@dtek.chalmers.se. Il modo
migliore per fare ciò e' di selezionare "Spedisci malfunzione..." dal menu
d'Aiuto (della finestra cartella). In tal modo verrà aperta una finestra di
composizione con uno schema di malfunzione. Il destinatario e' già
inserito, cosi' come parte del soggetto. Si deve completare il soggetto e
scrivere una descrizione dettagliata di cosa ha causato la malfunzione (e la
malfunzione stessa) nel corpo del messaggio.

Postilion include automaticamente un allegato contenente informazioni riguardo
la configurazione. Questo allegato contiene l'output di "uname -a" del
sistema, la versione e la data di Postilion, la versione di tcl/tk e una copia
di tutte le preferenze selezionate.

Se si vuole vedere esattamente cosa viene spedito si può guardare il file
~/.ratatosk/send/rat.X.Y (e' probabilmente l'ultimo file). Questo file viene
creato quando si seleziona "Spedisci malfunzione..." e viene rimosso quando
la malfunzione viene spedita.
}
}
