#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_balText_fr {} {
global balText
set balText(list_of_messages) {List of messages in the current mailbox.
You can use the mouse buttons as follows:

    left click   - Show the message
    double left  - (in browse mode) show message body 
		   (The message body is fetched)
    right button - Flag or unflag the message (add or
		   remove it from `the group' of other
		   flagged messages}
set balText(current_folder_name) {Name of the current mailbox}
set balText(current_folder_size) {Total size in bytes of current mailbox}
set balText(current_folder_nummsg) {Number of messages in the current mailbox}
set balText(status_text) {Messages from Postilion}
set balText(move_msg) {This menu will move a copy of the current message
to the selected mailbox, marking the message
for deletion in this mailbox}
set balText(delete_msg) {Mark the current message for deletion.}
set balText(compose_msg) {Write a new message}
set balText(compose_menu) {This menu contains commands that are
useful when writing a message}
set balText(mailbox_menu) {This menu contains commands which
operate on a mailbox(s)}
set balText(window_menu) {This menu contains tools for inspecting your
address book, mailboxes, and old searches}
set balText(edit_menu) {This menu helps you to edit
the message you are writing}
set balText(format_menu) {This menu helps you to adjust the format
(layout) of a message you are writing}
set balText(print_menu) {Opens a dialog box for printing a
message or the grouped messages.
(Use the right mouse button or the Group
menu, to group or ungroup messages.)}
set balText(vd_open) {Open the selected mailbox in a new window}
set balText(vd_cut) {Cut the selected mailbox from the list.  It
can be pasted elsewhere in the list with the
paste command.}
set balText(vd_paste) {Paste a previously-cut mailbox into
the list, above this location}
set balText(spell) {Open a spell check session for
this message}
set balText(clear_addr) {Click here with the left mouse button
to clear all selections in this window}
set balText(reply_to_all) {Send a reply to all senders and receivers
of the current message}
set balText(reply_to_sender) {Send a reply to the sender of the current message}
set balText(no_sig) {This means that the current message is not signed}
set balText(unchecked_sig) {This means that this message is signed but the
signature has not been checked yet. Press left
button to check it}
set balText(good_sig) {The signature on this message is good}
set balText(bad_sig) {The signature does NOT match the content of this letter}
set balText(part_sig) {A part of the letter was signed, but not all of it}
set balText(send_deferred) {Causes all deferred messages to be sent now.
(The number in brackets is the number of
deferred messages)}
set balText(show_notifications) {Pops up a window which tells you if your message
has been received or not.  (To be precise, it shows
the status of receipt-notifications)}
set balText(watcher_enable) {Lets you turn the watcher window
for new mail on or off}
set balText(reread_aliases) {Rereads all your mail address files}
set balText(reread_userproc) {Rereads your userproc file}
set balText(import_aliases) {Searches a few standard places for mail address files
from other mail programs and reads those files}
set balText(reread_mailcap) {Rereads all the system's mail capabilities files}
set balText(take_mail) {Looks for messages which netscape has taken
from your inbox and steals them back (to your
inbox)}
set balText(check_dbase) {Checks the Postilion database for any errors}
set balText(check_fix_dbase) {Checks the Postilion database for any errors,
also does its best to correct any errors found}
set balText(see_log) {Shows a log of all internal messages generated by Postilion}
set balText(quit) {Quits Postilion}
set balText(folder_menu) {This menu shows a list of your mailboxes. Double-click
on a mailbox to look at it in the currently active browser,
or select it and click on the Open button to open it in a 
new browser window.}
set balText(message_menu) {This menu contains commands which
operate on a message}
set balText(clock) {This shows the time, date and day when the
message was sent (in local time here).
Click on teh clock with the left mouse button
as a shortcut to the Preferences window.}
set balText(mailboxes) {Opens a new window which lets you select, create
and edit your mailboxes.  You can also move a selected
message (or the grouped messages) to a selected mailbox.}
set balText(next_msg) {Selects the next message in the list.}
set balText(prev_msg) {Selects the previous message in the list.}
set balText(find) {Pops up a window which lets you search in the
list of messages, or within the current message}
set balText(compose) {Compose a new message}
set balText(reply_sender) {Write a reply to the sender of the current message}
set balText(reply_quote_sender) {Write a reply to the sender, 
quoting the current message}
set balText(reply_all) {Write a reply which goes to the sender and all
recipients of the current message}
set balText(reply_quote_all) {Write a reply which goes to the sender and all
recipients, quoting the current message}
set balText(forward_inline) {Write a message which includes the
 current message, marked as `forwarded'}
set balText(forward_attached) {Write a message with the current
 message included as an attachement}
set balText(bounce) {Bounce the current message to a new address}
set balText(compose_held) {Continue writing a previously-held message}
set balText(extract_adr) {Inspect mail addresses from the current message, to add
 some or all of them to one of your address books}
set balText(move) {Move the current message to another mailbox}
set balText(delete) {Mark the current message for deletion.
It will not be actually deleted until you
"Compact" the mailbox}
set balText(undelete) {Remove the deletion marking on the current message}
set balText(print) {Print the current message}
set balText(structure) {This submenu shows the nternal structure
of the letter and its attachments}
set balText(show_all_headers) {Show all header lines of messages.
Normally, just a few - like From, Subject -
are shown.}
set balText(show_selected_headers) {Show only the selected header lines.
E.g. From, Subject, Cc.}
set balText(show_no_headers) {Do not show any header lines}
set balText(group_menu) {This menu works on `the group' - the flagged
messages.  The group is just all the messages
marked with an 'F'. The commands in this menu apply
to all these flagged messages in the active mailbox.

You can flag messages via searches, or by clicking
or dragging over them with the right mouse button}
set balText(create_in_win) {Popup a new list of messages and do group
marking (flagging) in that window}
set balText(create_by_expr) {Do a search, so that matching items are flagged.
(Flagged items are called a "group")}
set balText(use_saved_expr) {Add to the group by re-using a saved search-expression}
set balText(clear_group) {Remove the group flag from all messages}
set balText(group_all) {Flag every message - add every message to the group}
set balText(delete_group) {Toggle the Deleted flag for all messages in the group}
set balText(print_group) {Print all messages in the group}
set balText(move_group) {Move all messages in the group to another mailbox}
set balText(admin_menu) {This menu contains misc administrative commands}
set balText(browse_mode) {Browse mode is useful when a mailbox file is not
stored on your computer.  It keeps the bodies of
messages from being loaded automatically.  The actual
body of a message only is loaded when you press the
"show body" button, or double click on the message in
the message list}
set balText(update) {Check the current mailbox for new messages. (Does not
delete messages marked for deletion)}
set balText(sync) {Permanently deletes any messages marked for deletion
in the active mailbox, and also checks for newly-arrived
messages}
set balText(newedit_folder) {Opens a window for you to add mailboxes
and edit their properties.}
set balText(aliases) {Open the address-book window}
set balText(focus) {List only the flagged messages}
set balText(unfocus) {List all messages (flagged and unflagged)}
set balText(hide_size) {Hide message sizes in list}
set balText(hide_deleted) {Hide deleted messages in list}
set balText(hide) {Hide all Postilion's windows}
set balText(preferences) {Open the preferences window}
set balText(define_keys) {Lets you view/change the keyboard shortcuts
for commands for the main window}
set balText(saved_expr) {Lets you edit the saved expressions used to create groups}
set balText(sort_order) {Lets you change the order that the messages
in the mailbox are sorted into}
set balText(sort_subjdate) {Sort messages according to date, but group
messages with the same subject together}
set balText(sort_subj) {Sort messages alphabetically on subject}
set balText(sort_sender) {Sort messages alphabetically by sender}
set balText(sort_natural) {Do not sort the messages.
Present them in the order they are stored.}
set balText(sort_reverse_natural) {Present the messages in the reverse
order to which they are stored}
set balText(sort_date) {Sort the messages according to date sent (earliest at the top)}
set balText(sort_reversedate) {Sort the messages according to date sent (earliest at the bottom)}
set balText(help_menu) {Gives various forms of help}
set balText(balloon_help) {Turns this kind of balloon help on and off}
set balText(show_version) {Show which version of Postilion you are using}
set balText(explain_ratatosk) {Explains wehere the name Ratatosk comes from}
set balText(help_window) {Shows the help window}
set balText(send_bug) {Lets you send a bug report to the author of Postilion}
set balText(group_list_editor) {Flagged messages will be members of the group.
Use left mousebutton to clear or set the flag for a message}
set balText(group_window_ok) {Close this window and transfer the group markings to the mailbox window}
set balText(group_window_selall) {Mark all messages as part of the group}
set balText(group_window_unselall) {Unmark all messages}
set balText(cancel) {Cancel what you are doing and close the window}
set balText(enter_search_exp_here) {Write down the search pattern here}
set balText(toggle_ignore_case) {Choose whether upper or lower case matters when searching}
set balText(find_exact) {Find exact string}
set balText(find_regexp) {Find with regular expression}
set balText(find_in_mlist) {Search in the list of messages (not in the actual messages)}
set balText(find_in_body) {Search the body of the current message}
set balText(find_first) {Start a search from the top of the mailbox}
set balText(find_next) {Find next occurrence of the search pattern}
set balText(dismiss) {Close window}
set balText(show_adrbook_menu) {This list shows your address books.
Left-click on a book to see its addresses.
Select an address and then press one of the
address buttons below (e.g. the  To:-list),
to have that person automatically entered in
the list of recipients for your message.
Or select a book and then press one of the
the address buttons, to address your message
to EVERYONE in that book.
TIP: You turn on the Bcc feature by add "Bcc"
to the "Headers" field in Preferences->Compose.
Bcc means `blind carbon copy' - no one can see
you've sent the mail to people in the Bcc list}
set balText(use_system_aliases) {Include mail addresses from the system wide address book}
set balText(add_addrbook) {Add a new address book.
The addresses will be stored
in the file you specify.}
set balText(delete_addrbook) {Hides an addressbook.  This only removes the book from
Postilion's internal tables. The actual address book file
is NOT deleted}
set balText(set_default_addrbook) {Set the default address book.  This is where new mail addresses
get added if you do not explicitly choose otherwise}
set balText(import_aliases_from_pgm) {Import mail addresses from files generated by other
programs.  I.e. create a new address book from a file of
addresses in a different format}
set balText(alias_list) {This is a list of the addresses}
set balText(new_alias) {Create a new address}
set balText(edit_alias) {Edit an existing address}
set balText(delete_alias) {Delete selected addresses}
set balText(move_alias) {Move selected addresses to new address book}
set balText(alias_adr_book) {The address book this address should belong to}
set balText(alias_alias) {A shortcut `alias' you can type instead of the whole email
address.  No spaces are allowed.  You can type this short name
in the To:, Cc:, or Bcc: lines.
Postilion will put in the full name and address automatically.
The same address can appear in many address books - but you
MUST choose a unique alias for every address!}
set balText(alias_fullname) {The person's full name - this is displayed in your
Address book, and also in the address line of outgoing mail}
set balText(alias_content) {The actual email address, like `john@aol.com'.  This is
what is actually used when sending the mail.}
set balText(alias_comment) {Address comment, this is just for your own use}
set balText(name_of_adrbook) {The name Postilion should use internally
to refer to this address book}
set balText(list_of_books_to_delete) {Select those address books you want to
delete in this list, and then press "delete"}
set balText(aliases_adr_book) {The address book these addresses should belong to}
set balText(aliasadd_use) {If this button is unchecked then the
address on this line is ignored}
set balText(alias_chooser) {This list lets you choose an address to add to your
address field.
There are several ways to select an address:
    * You can select one with the left mousebutton
    * You can use the up and down arrow keys
When you have made a selection, press space to 
add your selection to the "To:" line of the
active compose window, or click one of the 
buttons below to insert your selection into a
particular address line. Pressing "Return" will
insert your selection into the "To:" line,
and close this window. If a compose window is
not active, a new one will open for you. You 
can dismiss this window without selecting an
address with the esacape key or ctrl-c.}
set balText(compose_held_pick) {Pick the message you want to continue from this list.
You can mark it and press "ok" or you can doubleclick}
set balText(compose_insert_file) {Insert the content of a file at the current cursor position}
set balText(automatic_wrap) {Controls the automatic line wrapping function}
set balText(automatic_indent) {Control the automatic indent function}
set balText(abort_compose) {Abort the composition}
set balText(undo) {Undo the last change}
set balText(cut) {Cut the selected text to an
internal clipboard}
set balText(copy) {Copy the selected text to an
internal clipboard}
set balText(paste) {Paste text from the internal clipboard
into the message, at the current text-cursor
position.
NOTE:
The middle mouse button will paste the X
clipboard at the mouse position.}
set balText(cut_all) {Cut all text from the message,
into an internal clipboard}
set balText(copy_all) {Copy all text of the message}
set balText(wrap_lines) {Format the marked lines}
set balText(run_through_command) {Feed the selected text (all text if none is marked),
into an external command, and replace it with the output
text}
set balText(headers_menu) {This menu lets you control which header
lines are shown in the address-part of
the compose window}
set balText(copy_attached_files) {If you turn this on, a copy of all attached files are made
as soon as you press "send". If it is turned off, the attached
file is not put in until the message is actually sent from your
computer.  (So don't delete it before then!)}
set balText(request_notification) {Request `Delivery Status Notification' of this message.
In other words you're asking to be informed, if your message
gets delivered.}
set balText(pgp_sign) {Sign the message with a PGP signature}
set balText(pgp_encrypt) {Encrypt the message with PGP}
set balText(command_list) {Edit the list of saved commands (which you can run text through)}
set balText(compose_body) {The body of the message}
set balText(attach_file) {Attach a file to the message}
set balText(attach_special) {Special types of attachments}
set balText(attach_keys) {Pops up a window listing your *public* PGP
encryption keys, so you can choose to attach keys.
For more info, read up on pgp.
PGP stands for Pretty Good Privacy - a
quite strong encryption system}
set balText(detach) {Detach the marked attachment}
set balText(attachments) {This area lists the attachments
you've added to this message.}
set balText(send) {Send the message and save a copy in the designated "save
outgoing" mailbox.  (You choose the save-mailbox via the
"Mailboxes" editor window.  Select a mailbox and press down
with the right mouse button, then choose "Edit...".  In the
edit window for the selected mailbox choose a mailbox for
storing your outgoing messages from the "Save to" tab.
Some people like to store all their outgoing messages
in a single mailbox called "Outgoing", others like multiple
save-mailboxes, some like no copy to be saved.)}
set balText(sendsave) {Send the message and save a copy in a
mailbox of your choice, using the menu
of mailboxes that will pop up}
set balText(hold) {Save the message in a special file, so that you can
continue writing it at a later time.  So that if you
exit from Postilion you won't lose what you have so far
typed for this message.  To return to the message later,
in a compose window choose Compose-->Drafts-->Compose Held}
set balText(eedit) {Use an external editor on the message body}
set balText(compose_to) {The people that this message is mainly intended for.
This is an address field - which means that Postilion will
try to keep the addresses in nice columns, it will expand
shortcut aliases if you type a comma or Return after them,
and will mark illegal addresses in red. You can use ^l 
(CTRL-L) to get a list of addresses}
set balText(compose_subject) {The subject of the message}
set balText(compose_cc) {The people that may also be interested in receiving
a copy of this message (a "carbon copy").
This is an address field, which means that Postilion will
try to keep the addresses in nice columns, it will expand
shortcut aliases (to their full names) and will mark
illegal addresses in red.  You can use ^l (CTRL-I) to get a
list of addresses}
set balText(compose_bcc) {Other people who may be interested in receiving a copy
of, but whose addresses will not appear on *anyone else's*
copy of the message.  So none of the recipients will be able to
see that these people also got the message.  A privacy feature.
(Bcc stands for "Blind carbon copy".)

It is an address field, which means that Postilion
will try to keep the addresses in nice columns, it will
expand shortcut aliases (to their full names) and will
mark illegal addresses in red.  You can use ^l (CTRL-I)
to get a list of addresses}
set balText(compose_keywords) {A set of keywords describing the message}
set balText(compose_content_description) {A description of the content of the message}
set balText(compose_reply_to) {Where replies to the message should be sent.  (By default,
replies will be to the address from which you sent the message.)

This is an address field, which means that Postilion
will try to keep the addresses in nice columns, it will
expand shortcut aliases (to their full names) and will
mark illegal addresses in red. You can use ^l (CTRL-I) to
get a list of addresses}
set balText(compose_comments) {Comments on the message}
set balText(compose_from) {Who the message is from}
set balText(type_menu) {Use this menu to specify which type of attachment this is}
set balText(encoding_menu) {The encoding this attachment has right NOW. This has nothing
to do with which encoding it will be sent in}
set balText(attach_description) {A short description of this attachment}
set balText(attach_disposition) {This is the filename which an attached file will
most likely be saved as.}
set balText(attach_id) {Under some circumstances one may need to send an identifier
with the attachment}
set balText(bounce_to) {Enter the address of the person to whom you wish to bounce this message here}
set balText(hold_description) {Enter a description of the message to hold here}
set balText(choose_msg) {This message contained one or more embedded messages. You
must now choose which message you wish to reply to (or forward)}
set balText(save_cmd_as) {If you wish to save this command for future use then you just write
a label here and make sure the button is checked}
set balText(command_to_run_through) {Write a command line here. The selected text will be fed
into this command line as input, and the selection will be
replaced with the output from the command.}
set balText(saved_commands) {List of saved commands}
set balText(apply_changes_to_cmd) {Apply the changes made to the command}
set balText(delete_command) {Delete the selected command}
set balText(command_content) {Write a command line here.  Selected text can then be fed
 into this command as input, and the selection replaced
 with the output from the command.
 %s means a file containing the selected text}
set balText(notification_window) {The notifications window contains a list of all messages
 for which a notification was requested that has been sent within
 the last seven days (the number of days is configurable). Each
 message is listed with the date of sending, subject and all
 recipients. In front of each recipient is the current status
 shown. There are six different statuses possible:
   
 -		- Means that Postilion does not know anything about this
 		  recipient yet
 Failed		- The message did not reach this recipient
 Delivered 	- The message has been successfully delivered. This does
 		  NOT in any way imply that the recipient has even seen the
 		  message yet
 Relayed	- The message has been forwarded to some mail transfer agent
 		  (MTA) which does not support notifications
 Expanded 	- The message has been delivered, but the destination was an
  		  alias which expanded to one or more different address(es).
  		  Further notifications may arrive
 Delayed	- The message has not yet reached this recipient but further
 		  attempts to deliver it will be made
  
  You can get more information about any notification by pointing at the
  recipient line and pressing the left mousebutton}
set balText(dsn_readable) {Here you should see an explanation
why this notification has been sent}
set balText(dsn_more_info) {Show those parts of the original message which were
returned in the text field above}
set balText(switch_expression) {This menu lets you switch between advanced and
basic search expressions}
set balText(save_expr_as) {If you wish to save this search expression for future use,
just write a label here and make sure the button is checked}
set balText(exp_ok) {Perform the search, close this window, and flag every
message that matches the expression}
set balText(clear) {Erase the area above (where you
create the search exression)}
set balText(exp_basic_and) {Every line below the `and' must match
a message for it to get marked}
set balText(exp_basic_or) {Any message which matches at least one
of the non-empty lines below is marked}
set balText(exp_basic_field) {This line matches if at least one of the words in the
entry field can be found in the indicated header line}
set balText(exp_adv_exp) {Here you can write your advanced expression.  You can use the keyboard
or the convenience buttons below. Example expressions are:
	Subject has foo
	Subject is "foo bar" and (To has maf or Cc has maf)}
set balText(exp_adv_fields) {These buttons correspond to the different header
lines for which we can match the content}
set balText(exp_adv_has) {The field contains this string, possibly
mixed in with other text}
set balText(exp_adv_is) {The header field matches this exactly}
set balText(exp_adv_gt) {This greater-than symbol only makes sense with the Size field}
set balText(exp_adv_lt) {This less-than symbol only makes sense with the Size field}
set balText(exp_adv_bool) {These logical terms can be used to combine expressions}
set balText(exp_adv_p) {Use parentheses to group expressions}
set balText(exp_list) {A list of saved expressions}
set balText(exp_text) {Content of expression}
set balText(exp_delete) {Delete the marked expression}
set balText(fs_show) {Show all files in the current directory}
set balText(fs_old) {Menu containing old directories}
set balText(mode_menu) {This menu lets you modify the permissions of the file}
set balText(welcome_lang) {This menu lets you choose the language used in
the user interface.  Don't choose a language you
can't read!}
set balText(welcome_shutup) {This menu lets you choose if you want to be informed of changes
in Postilion the next time they occur (it is also accessible from
the preferences window}
set balText(welcome_cont) {Close this window and open the mail Postilion window}
set balText(ok_and_apply) {Close this window and apply the changes}
set balText(keydef_delete) {Press this button first, and then one of the
key-buttons above, to delete the indicated
keyboard shortcut}
set balText(keydef_add) {To add a new keyboard shortcut for the command:
press this button then press the key on the keyboard
(at the same time as the modifiers, like Shift or Alt)}
set balText(keydef_def) {Here you see the keyboard shortcuts (the combinations of keys
to be pressed) which you can use as a shortcut for this command}
set balText(apply_prefs) {Apply the changes and save the new settings}
set balText(unit_pref) {Unit of value}
set balText(pref_clock_format) {Clock format (12 or 24 hour)}
set balText(pref_language) {The language of the user interface. If you change this, you
will have to restart Postilion before it will take effect.
Don't choose a language you can't read!}
set balText(pref_start_win) {Which windows should be opened automatically
when Postilion is started.  Make sure you start
with at least one of "Mailboxes" or "Folder", or
you won't be able to read any mail!}
set balText(pref_next_menu) {Whether to use a single NeXT style menu of submenus,
insead of the normal menubar across the top.
Note:
Only use NeXT style only with click-to-focus mode.
It won't work well with focus-follows-mouse modes}
set balText(pref_color_set) {Which color scheme Postilion should use}
set balText(pref_paper_color) {Which color should be used for the message text areas}
set balText(pref_new_msg_col) {Which color should be used for new messages}
set balText(pref_sel_msg_col) {Which color should be used for selected messages}
set balText(pref_fnd_msg_col) {Which color should be used for found messages}
set balText(pref_flg_msg_col) {Which color should be used for flagged messages}
set balText(pref_del_msg_col) {Which color should be used for deleted messages}
set balText(pref_seen_msg_col) {Which color should be used for seen messages}
set balText(pref_ans_msg_col) {Which color should be used for answered messages}
set balText(pref_button_bar) {Should Postilion display the button bar}
set balText(pref_image_buttons) {Should Postilion display icons or text for action buttons}
set balText(pref_sync_but) {Display a mailbox synchronization button in the browser}
set balText(pref_sync_oper) {Whether the sync button should compact the mailbox,
 expunging deleted messages, or just update it.}
set balText(pref_iconic) {Here you can instruct Postilion that it should start up
 with its window(s) minimised (iconised)}
set balText(pref_info_changes) {When the user starts a new version of Postilion for the first time
 the program will pop up a message describing the new features. This
 option lets the user switch off this `news' feature}
set balText(pref_mail_steal) {If Postilion should check for messages taken by netscape or not}
set balText(pref_print_command) {Which command to use for printing.  E.g.: lpr %s
Any `%s' in the command text will be replaced by the name
of the file to print. If no `%s' is present, the program
will get the data from its standard input}
set balText(pref_print_header) {Which headers (like From:, To:...) to include in the text
sent to the print command. (Either `All', `Selected' or `None')}
set balText(pref_print_non_text) {Should non-text message parts be printed?}
set balText(pref_tmp) {Directory to store temporary files in}
set balText(pref_permissions) {File permissions to use when creating new files
(for example when saving messages).  The recommended
value, for privacy and security, is 0600.}
set balText(pref_userproc) {File where any user-defined procedures are stored}
set balText(pref_hold_dir) {Directory where `held' messages are stored}
set balText(pref_fontsize) {The normal size of all text}
set balText(pref_keep_pos) {Controls whether or not Postilion should
remember window placement and size}
set balText(pref_mailcap_path) {The names of the system's mail capabilities files (refer
to the mailcap manual for more details).  Postilion will try to
read the files (e.g. /etc/mailcap, $HOME/.mailcap). It will
always try to read those mentioned in the environment-variable
MAILCAP first}
set balText(pref_terminal) {Which command to use when creating an interactive terminal
window for mailcap entries that have "needsterminal"
set. This command will be prepended to the view-command}
set balText(pref_message_llength) {The number of messages that are shown on screen in the message list}
set balText(pref_list_mode) {Should Postilion use the list format below for all
mailboxes (this is the default), or use the per-mailbox
settings}
set balText(pref_list_format) {This option determines what the list of messages looks like. This
string looks like the format string used in the C printf() function,
except that the only thing that may follow a '%' (except another '%')
is an optional integer (which may be negative), and one of the following
characters:
	s - Subject of message
	n - Name of sender (or mailaddress if there is no name)
	m - Mail address of sender
	r - Name of recipient (or mailaddress if there is no name)
	R - Mail address of recipient
	b - Approximate size of message in bytes
	B - As above but expressed in max four characters.
	d - Message date (in human readable form)
	D - Message date (in seconds since the epoch)
	S - Message status (maximum 5 characters)
	    The following states are used:
	    N - this message is unread
	    A - this message has been answered to
	    D - this message is marked for deletion
	    F - this message is flagged and therefore member of the
	        currrent group
	    + - this message was adressed to you personally
	i - Current message index
        f - Current message index or filename in case of MH folders
For example:
	%3i: %4S %6d  %-24n %4B %s
means: show the message number (3 digits wide) then a colon, then the
message status flags (4 characters wide), then the date (6 width), then
2 spaces then the name of the sender (using 24 spaces, and starting the
name from the left), then the message size, and finally the subject.}
set balText(pref_show_header) {Which headers of the message (like "To", "Subject", etc.)
to show ('All', 'Selected' or 'None')}
set balText(pref_show_header_selection) {If we are showing the selected headers, only those
header lines mentioned in this list will be shown}
set balText(pref_browse) {Should Postilion always use browse mode, never
use browse mode, or use the per-mailbox setting?

Browse mode is useful when a mailbox file is not
stored on your computer.  It keeps the bodies of
messages from being loaded automatically.  The actual
body of a message only is loaded when you press the
"show body" button, or double click on the message in
the message list}
set balText(pref_sort_mode) {Should Postilion use the same message-sorting order for
all mailboxes (normal), or use the per-mailbox settings}
set balText(pref_folder_sort) {How to sort the list of messages}
set balText(pref_adv_on_flag) {Automatically advance to the next
message after flagging a message}
set balText(flag_seen) {Toggle this message's Seen flag (in
other words, so it does or doesn't look new)}
set balText(flag_ans) {Toggle this message's Answered flag}
set balText(flag_unseen) {Flag this message as Unseen (in
other words, so it looks new)}
set balText(seen_group) {Toggle the Seen flags of all flagged messages 
(in other words, so they do or don't look new)}
set balText(unseen_group) {Mark all flagged messages as Unseen
(in other words, so they all look new)}
set balText(ans_group) {Toggle the Answered flag of  all flagged messages}
set balText(undelete_group) {Clear the Deleted flag on all flagged messages}
set balText(pref_strsel_mode) {Should Postilion use the method below ("Select when open")
for all mailboxes (normal), or use the per-mailbox settings}
set balText(pref_start_selection) {Which message to go to when a mailbox is opened.
If the option above is set to "Use folder default value",
then which message is selected depends on what choice
you made per mailbox (by choosing "Edit..." from the
pop-up menu from a right-mouse click in the mailbox window)}
set balText(pref_log_timeout) {The length of time that status messages
are to be displayed (in seconds)}
set balText(pref_cache_passwd) {Determines if Postilion should cache passwords for IMAP
and POP-connections.  The passwords are only kept in memory
and are therefore lost when Postilion quits}
set balText(pref_cache_passwd_timeout) {How long to cache the passwords
(0 means for as long as Postilion is running)}
set balText(pref_cache_conn) {Determines if Postilion should keep IMAP-protocol
connections open after the mailbox is closed. An open
connection may be reused for more mailbox accesses}
set balText(pref_cache_conn_timeout) {How long to keep the connections open
(0 means for as long as Postilion is running)}
set balText(pref_urlprot) {Postilion will only highlight URLs with a
protocol mentioned in this list}
set balText(pref_url_color) {The color of URLs in the message text
(only used on color displays)}
set balText(pref_quote_color) {The color of quoted text in the message text
(only used on color displays)}
set balText(pref_url_viewer) {Which viewer to use for showing URLs.
This can also be a userproc}
set balText(pref_netscape) {Which command to use for starting netscape}
set balText(pref_netscape_args) {Any extra arguments to give to netscape}
set balText(pref_dbase_dir) {Where the database is stored}
set balText(pref_def_extype) {The default expiration action}
set balText(pref_def_exdate) {The default expiration time (in days since inserted into dBase)}
set balText(pref_dbase_backup) {When the database has the backup expiration option,
expired messages are stored in this directory (compressed)}
set balText(pref_chunksize) {How many messages (at least) there must be in each
compressed block of messages in the backup directory}
set balText(pref_expire_interval) {How many days to wait between expirations of the database}
set balText(pref_watcher_enable) {If we should popup the watcher (notifier of new mail) at all}
set balText(pref_watcher_time) {How often the watcher (notifier of new mail)
should check different mailboxes for new messages.
This is expressed as the interval between checks in seconds.
There are two times, one for database mailboxes and one for
all others (standard).
A zero interval disables the checking}
set balText(pref_watcher_name) {The title of the watcher window
(which notifies you of new mail)}
set balText(pref_watcher_max_height) {The maximum height (in lines) of the list of new messages}
set balText(pref_watcher_font) {Which font to use in this window}
set balText(pref_watcher_show) {Which messages to show ('All' or 'New')}
set balText(pref_watcher_format) {The format of the list. (See the help for
the Mailbox window for details on the format}
set balText(pref_watcher_bell) {How many beeps should sound when
the watcher discovers new messages.
NOTE if the userproc RatUP_Bell exists
then this value is locked, and there
will be no beeps}
set balText(pref_reply_mode) {Should Postilion use the same reply-to address for all
mailboxes (normal), or use the per-mailbox settings}
set balText(pref_reply_to_addr) {The default reply-to address}
set balText(pref_reply_to_fn) {The default reply-to full name}
set balText(pref_compose_headers) {Which headers the user may edit by default. The list of
headers can be changed in the compose window}
set balText(pref_custom_headers) {Custom headers to be displayed in compose sessions.}
set balText(pref_editor) {Which external editor to run if the user presses the
'External editor' button. A '%s' in this command will be replaced
with the name of the file to edit. The Compose window will be
locked until you quit from the editor}
set balText(pref_attribution) {This line (if defined) is inserted before any reply.
It has the same syntax as the "List format" option
in the Folder preferences window.  An example is:
  On %d, %n wrote:
where %d will turn into a date, and %n turns into the
name of the person you're replying to.}
set balText(pref_forwarded_message) {This line is inserted before the forwarded
message when you do a "Forward inline"}
set balText(pref_reply_lead) {Which character to place at the beginning of each line from the
original message when constructing a reply. If the line doesn't
already begin with this character a space will be added in between.
A common choice for this `quoting' is the `>' character}
set balText(pref_quote) {This option controls whether or not to quote the
body of a letter you are replying to in the reply}
set balText(pref_skip_sig) {This option controls whether or not to include the
signature of a letter you are replying to in the reply}
set balText(pref_no_subject) {What subject to put on replies to messages with no subject}
set balText(pref_sig_mode) {Should Postilion use the same signature file for all mailboxes
(the default), or use the per-mailbox settings}
set balText(pref_signature) {The name of the file containing the user's signature}
set balText(pref_lookup_name) {True if Postilion should try to verify local addresses
in the passwd-list}
set balText(pref_copy_attached) {True if Postilion should make a copy of an attached file
as soon as the attaching is done. If it is false, Postilion
assumes that the file will still be present when the message
is sent, and try to attach it then}
set balText(pref_from_mode) {Should Postilion use the same "From:" address for all
mailboxes (normal), or use the per-mailbox settings}
set balText(pref_from_addr) {Which value the "From:" line should have. Please note that if the From:
line isn't you then a "Sender:" line will be added}
set balText(pref_from_fn) {Which value the "From:" line should have. Please note that if the From:
line isn't you then a "Sender:" line will be added}
set balText(pref_date-prefix) {The prefix to use when creating dated dynamic mailboxes
(ie: if this value is "sent-mail" then the mailbox would be
named something like sent-mail-Feb-1998)}
set balText(pref_masquerade_as) {Mark all messages you send as coming from this domain
(e.g. if you put xxx.com as the domain, your mail will seem
to have come from your_name@xxx.com.  Typically, you put the
domain name of your Internet Service Provider here.)
This value takes precedence over any other specified domain}
set balText(pref_domain) {The domain this machine belongs to (like aol.com).
If "Masquerade host as" IS NOT defined, then your
computer's name and the domain name are joined.
This means your mail will seem to come from
    your_name@your_machine.your_domain
and replies will be directed there.
If your machine name contains a '.' it won't be used.}
set balText(pref_delivery_mode) {This mode controls what happens when you press one of the send buttons
in the compose window. If the mode is "Direct" then the sending begins
immediately (but in the background). If it is set to "Deferred" then
the message is just put in a queue and at some later time you can
choose to send all the deferred messages}
set balText(pref_sendprot) {How to send messages. Via SMTP or a program.
If via a program, the one set in the "Sending program"
field, below, is used}
set balText(pref_smtp_hosts) {If we are sending messages via SMTP this is a list of host
computers we should try to send it to, to deliver it. Each
hostname may be of the form host:port where port is the
port-number used to contact the host}
set balText(pref_smtp_timeout) {How long we are prepared to wait for an answer from the SMTP server
(in seconds)}
set balText(pref_smtp_reuse) {If false then the channel to the SMTP-server will be closed and
reopened for each message. If true the we will send all our messages
using just one connection}
set balText(pref_smtp_verbose) {How much we want to know about what is happening while we are
sending messages with SMTP}
set balText(pref_sendprog) {This is the program which will be used if we are sending messages
via a program. It is expected to take the recipient address as
an argument and the actual message on stdin (examples are
/usr/sbin/sendmail, or /bin/qmail)}
set balText(pref_sendprog_8bit) {This is the type of data the sending-program can
handle (seven or eight-bit)}
set balText(pref_charset) {Which character set we are using}
set balText(pref_force_send) {If this is true then Postilion will try to send messages even though
it doesn't know the full local host name (name plus domain).
Do NOT enable this option unless you know what you are doing!}
set balText(pref_dsn_directory) {Where to store the DSN information 
Delivery Service Notification)}
set balText(pref_dsn_request) {The default value of the notification selector in the compose menu
of the compose window. A Delivery Status Notification is a request for an
automatic mail when a message you have sent, reaches its destination.
(Some systems do not allow or support such notifications.)
The Probe button tests if your system supports
notifications - see the release-notes for more details}
set balText(pref_dsn_snarf_reports) {If you asked for receipt notifications, such aknowledgements
are delivered as mail items.  This option defines if we should
show them in the list of messages or not.  (They will always
show up in the notifications window)}
set balText(pref_dsn_expiration) {How long should the letters (and their eventual notifications) be 
kept in the notifications window. The time is measured in days since
the original message was sent}
set balText(pref_dsn_verbose) {The report level is set separately for each type of notification.
There are three different levels:
    Keep quiet
        Do not report that a new notification has arrived.
    Display in status line
        Show a message on the status line when a new notification
        arrives.
    Show in separate window
        This shows the full notification in a separate window that
        pops up for the user.
Please observe that, regardless of which level you set, all the
notifications will always show in the notifications window}
set balText(pref_pgp_enable) {This lets you enable or disable the entire PGP part
(Pretty Good Privacy - a quite strong encryption system}
set balText(pref_pgp_prog) {The full pathname of the pgp program
(e.g. /usr/local/bin/pgp)}
set balText(pref_pgp_args) {Any extra arguments that must be given to the pgp program.
Test out the command from a command line to make sure you
have the command syntax correct!}
set balText(pref_cache_pgp) {If we should cache PGP passwords}
set balText(pref_cache_pgp_timeout) {How long we should remember the PGP password,
in seconds.  (0 means until you quit from Postilion.)}
set balText(pref_pgp_sign) {Whether you want to digitally sign (with PGP) messages
you compose.  You will have to have generated a PGP key
some time previously. ("pgp -kg")  See the PGP manual for
full details.  PGP stands for Pretty Good Privacy - a
quite strong encryption system}
set balText(pref_pgp_encrypt) {Whether you want to use PGP to encrypt messages
you compose.  You will have to have generated a PGP key
some time previously. ("pgp -kg")  See the PGP manual for
full details.  PGP stands for Pretty Good Privacy - a
quite strong encryption system}
set balText(body_of_message) {Here you see the contents of the selected message. Clicking
here with the right mousebutton gives a menu of extra commands
and information}
set balText(howto_display) {This menu lets you decide how to display
the body part of this message}
set balText(save_bodypart) {Save the current body part of this
message to a file you choose}
set balText(view_as_text) {If this button is checked then the body part
of the message is shown as if it were text}
set balText(view_source) {View this body part of the message as it
was transmitted (in a separate window)}
set balText(add_to_keyring) {Add this public key to your keyring}
set balText(run_mailcap) {Run the command specified in the mailcap for this type}
set balText(bodypart_entry) {This menu applies to this component of the message
(this "body part"). The submenu gives information
and lets you do some operations on this part}
set balText(bodypart_show) {This checkbutton lets you decide if
this body part should be shown or not.
If you hide it, it will stay hidden
until you close and reopen this mailbox}
set balText(bodypart_save) {Save the body part to file}
set balText(dbs_and) {All the (non-empty) lines below must match
a message exactly, for it to  be flagged
as part of the current group of messages}
set balText(dbs_or) {Any message which matches any of the
non-empty lines below, will be flagged
as part of the current group of messages}
set balText(dbs_keywords) {This line matches if any these words has
been set as keywords on the message}
set balText(dbs_subject) {This line matches if any of these words can be found in the subject.
If you wish to match a sequence of words enclose them in ""}
set balText(dbs_all) {This line matches if any of these words can be found
anywhere in the message.
If you wish to match a sequence of words enclose them in ""}
set balText(dbs_to) {This line matches if any these words can be found in the To-line
If you wish to match a sequence of words enclose them in ""}
set balText(dbs_from) {This line matches if any these words can be found in the From-line
If you wish to match a sequence of words enclose them in ""}
set balText(dbs_cc) {This line matches if any these words can be found in the Cc-line
If you wish to match a sequence of words enclose them in ""}
set balText(keywords) {Keywords describing the message}
set balText(exp_none) {Do not expire this message}
set balText(exp_remove) {Delete this message from the database
mailbox when it expires}
set balText(exp_incoming) {Add this message to the INBOX when it expires}
set balText(exp_backup) {Move this message to backup when it expires}
set balText(exp_date) {When to expire the message. Currently, the only
supported form is `+N', where N is number of days
the message can stay in the database before it expires}
set balText(vd_createsub) {Create a new sub-entry which can
contain its own set of mailboxes}
set balText(vd_newfile) {Create a new mailbox as a simple
Unix mailbox file}
set balText(vd_newmh) {Create a new mh mailbox}
set balText(vd_newdbase) {Create a new database mailbox}
set balText(vd_newimap) {Create new IMAP mailbox}
set balText(vd_newpop) {Create new POP3 mailbox}
set balText(vd_newdynamic) {Create a new dynamic mailbox}
set balText(vd_importdir) {Import file mailboxes from a directory}
set balText(vd_importmh) {Import mh-mailboxes from a directory}
set balText(vd_importimap) {Import IMAP mailboxes}
set balText(vd_foldermenu) {This menubutton lets you create new mailboxes,
and sub-entries for groups of mailboxes.
The new entries are placed in the list above}
set balText(vd_importmenu) {This menu lets you import groups of existing
mailboxes. The new entries are placed in the top menu}
set balText(vd_edit) {Edit this entry}
set balText(vd_delete) {Delete this entry (if this entry is a sub-entry you will
 be asked if you also want to delete all of *its* entries)}
set balText(vd_setinbox) {Set this mailbox to be the default mailbox
 opened when Postilion starts.  Typically this
 will be the mailbox in which new mail arrives}
set balText(vd_setsaveout) {Set this mailbox to store a copy of all the messages
 you send.  This setting can be over-ridden for each
 mailbox individually}
set balText(vd_setstartup) {Set this mailbox to be opened on startup}
set balText(vd_setstartmin) {Set this mailbox to be opened minimized on startup}
set balText(vd_unsetstartup) {Set this mailbox to not be opened on startup}
set balText(vd_unsetstartmin) {Set this mailbox to not be opened minimized on startup}
set balText(vd_list) {This is a list of your mailboxes.  
   * Double-click the left mousebutton to open a mailbox in the current 
     browser window, or in a new browser window if none exists.
   * Press the right mousebutton to get a menu of commands you can
     apply to the selected entry - or to add a new mailbox after it.
   * Entries with an arrow to their right (->) have sub-entries, 
     which will appear in the next box to the right of this one.  
   * You can move back to the left by selecting an entry in the 
     box to the left of this one.}
set balText(mbv_list) {This is a list of your mailboxes.
   * Double-click the left mouse button 
     to open a mailbox in this window
   * Press the right mousebutton to 
     get a menu which lets you open
     the selected mailbox, or move the 
     currently selected messages to it.
   * Entries with an arrow to their 
     right (->) have sub-entries, 
     which will appear in the next 
     box to the right of this one.  
   * You can move back to the left 
     by selecting an entry in the 
     box to the left of this one.}
set balText(mbv_sash_open) {Click this sash with the left mouse 
button to open a view of your mailboxes.}
set balText(mbv_sash_close) {Click this sash with the left mouse 
button to close the mailbox view.}
set balText(msg_sash) {Drag this sash up or down with the 
mouse to change the relative
sizes of the message list (above) and
the message text (below) panes.}
set balText(vd_menuname) {Name of new sub-entry}
set balText(vd_name) {Name of mailbox}
set balText(vd_mhname) {Name of mh-mailbox}
set balText(vd_host) {The name of ths host computer where
the mailbox can be found}
set balText(vd_user) {The user-name we should use to access the mailbox}
set balText(vd_mbox) {Name of remote IMAP mailbox}
set balText(vd_port) {Port-number the server answers at}
set balText(vd_filepat) {Only include files which match this pattern.
E.g. *mbox would match all files that end with
the word "mbox"}
set balText(vd_dirpat) {Only descend into directories which matches this pattern}
set balText(vd_pattern) {Only include mailboxes matching this pattern}
set balText(watcher) {Press left mousebutton to popup main Postilion window.
Right mousebutton wil dismiss this window for now}
set balText(help_subjlist) {List of help subjects. Click the left
mousebutton on a subject to view its help}
set balText(help_text) {Help text for the chosen subject}
set balText(pref_ispellRecheckAfterAdd) {Choose "True" for this to re-check the spelling of words 
currently marked misspelled, after you add to the dictionary 
or session.  Usually a good idea, except it will cause a
small delay after you add words to your personal dictionary.

You can also use the right mouse button to accept words from
a menu of possible corrections.}
set balText(pref_ispellon) {This turns the spell-check feature on and off.  Note that the
feature needs to be turned on BEFORE a message is brought up}
set balText(pref_ispelltextOnly) {Check this box if you want to perform spell checking only
of the text marked as 'text'.  This should avoid spell checking 
To:, Cc: & X-Face: lines, it comes at a small time penalty - turn
it off if you want to see a small improvement in response time.

Note that turning this option on will also not spell check 'attachments'
unless they are marked as Content-Type: text/enriched or text/plain.
If you find that spell checking STOPS working in a section of the
document you may want to turn this off}
set balText(pref_ispelldefaultCommand) {This is the program used to actually do the real work -
'ispell -a' is probably a good choice.  If you want to 
use an alternate dictionary, 'ispell -a -d <dictionary-file>' may be 
appropriate.  You may find that -S sorts the list of possible
words better - see the ispell(1) man page for more details.
(Really, it's got a lot of details and you can really personalize
how it works to fit best with your environment)}
set balText(pref_ispellotherCommands) {Other ways to run the 'Ispell' programs, mostly intended for 
our friends in Europe who have to work in a variety of languages.
This entry should be in label/invocation pairs.  E.g. one pair
would be "German  { ispell -a -d deutsch }"}
set balText(pref_ispellpopupBinding) {This controls what the 'popup' window is bound to, some examples include:
	ButtonPress-3 
	ButtonPress-2
	ButtonPress-1
	Shift-3
	Control-3
	Meta-2
	Alt-1
	etc...

Note that the menu is unposted (vanishes) on any ButtonRelease}
set balText(pref_ispellviewStyle) {This is how to display misspelled words.  You
can use the built in types or create your own
using 'other'.  For 'color' ones fill in the color, below.
Examples of using "other":
	-underline t
	-background red
	-foreground Bisque
	-font <font>
	-fgstipple <bitmap>
	-bgstipple <bitmap>
Bitmaps can be many things, 'gray50' and 'gray25' are popular
For example....
	 -font *italic*
    or   -font *bold*
    or   -font *24*    (Big!)
    or   -font *italic*24* (big italics)
	 -relief <relief> (see tk docs for more info...)
Effects can also be combined.  For example:
	-underline t -foreground red
	-bgstipple gray25 -color red}
set balText(pref_ispellviewStyle-Color) {color for foreground color and background color}
set balText(pref_ispellviewStyle-Other) {Style if 'other' is selected}
set balText(pref_mboxvis) {Whether or not to display the 
mailbox view at the top of the
browser window.}
set balText(pref_expunge_on_close) {If Postilion should automatically expunge all messages
marked for deletion whenever you close the mailbox}
set balText(pref_automatic_wrap) {Controls the automatic line wrapping function}
set balText(pref_automatic_indent) {Control the automatic indent function}
}
