#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_t_de {} {
global t
set t(postilion) Postilion
set t(version) Version
set t(about) Über
set t(quit) Beenden
set t(name) Name
set t(size) Größe
set t(messages) Nachrichten
set t(help) Hilfe
set t(ok) OK
set t(cancel) Abbrechen
set t(ratatosk) {Ratatosk ist etwas aus der nordischen Mythologie, das den Kosmischen- und
den Welten-Baum hoch und runter läuft (oder so ähnlich).}
set t(posthorn) {Ein schönes deutsches Wort, welches wohl nicht - wie in den anderen Sprachen in die der Postilion übersetzt wurde - einer Erklärung bedarf. ::-)}
set t(months) {Jan Feb Mar Apr Mai Jun Jul Aug Sep Okt Nov Dez}
set t(clock_format) Uhrformat
set t(12_hour) {12 Stunden}
set t(24_hour) {24 Stunden}
set t(move) Verschieben
set t(delete) Löschen
set t(undelete) Wiederherstellen
set t(compose) {Neue Nachricht}
set t(reply_quote_sender) {Absender/in antworten (und zitieren)}
set t(reply_quote_all) {Allen antworten (und zitieren)}
set t(quote) {Originalnachricht zitieren}
set t(no_quote) {Originalnachricht nicht zitieren}
set t(reply_sender) {Absender/in antworten}
set t(reply_all) {Allen antworten}
set t(here_is) {Hier ist ein Objekt vom Typ}
set t(show_all) {Alles zeigen}
set t(old_dirs) {Vorher angezeigt}
set t(save_to_file) {In Datei speichern}
set t(save_failed) {Speichern fehlgeschlagen}
set t(message) Nachricht
set t(print) Drucken
set t(show_all_headers) {Zeige gesamten Nachrichtenkopf}
set t(show_selected_headers) {Zeige ausgewählte Nachrichtenkopfzeilen}
set t(show_no_headers) {Zeige den Nachrichtenkopf nicht}
set t(compose_name) {Nachricht erstellen}
set t(edit) Bearbeiten
set t(edit_body) Nachrichtentext
set t(edit_headers) Nachrichtenkopf
set t(custom_headers) {Definierter Nachrichtenkopf}
set t(read_from_file) {Nachrichtentext aus Datei laden}
set t(abort) Abbrechen
set t(headers) Nachrichtenkopf
set t(attachments) Anlagen
set t(attach_file) {Eine Datei anhängen}
set t(attach) Anhängen
set t(attach_special) {Besondere Anlage anhängen}
set t(detach) {Anlage löschen}
set t(send) Senden
set t(send_save) {Senden & speichern}
set t(hold) Zurückstellen
set t(getheld) {Zurückgestellte bearbeiten}
set t(external_editor) {Externer Editor}
set t(running_ext_editor) {Starte externen Editor...}
set t(filename) Dateiname
set t(description) Beschreibung
set t(disposition) Disposition
set t(id) Ident
set t(type) Typ
set t(subtype) Untertyp
set t(encoding) Verschlüsseln
set t(current_encoding) {Derzeitige Verschlüsselung}
set t(other) Andere
set t(custom_type) {Einstellbarer Typ}
set t(need_to) {Sie müssen mindestens eine/n Empfänger/in angeben (An:)}
set t(no_subject) {Kein Betreff}
set t(admin) Verwaltung
set t(newedit_folder) {Postfach neu/bearbeiten}
set t(update_folder) {Postfach aktualisieren}
set t(sync_folder) {Postfach synchronisieren}
set t(update) Aktualisieren
set t(sync) Synchronisieren
set t(continue) Weiter
set t(open_file) {Datei öffnen}
set t(open) Öffnen
set t(open_dbase) {Datenbank durchsuchen}
set t(folders) Postfächer
set t(and) und
set t(or) oder
set t(not) nicht
set t(to) An
set t(subject) Betreff
set t(keywords) Stichwörter
set t(all) Alle
set t(search) Suchen
set t(emptyexp) {Leerer Suchausdruck}
set t(to_file) {In Datei}
set t(to_dbase) {In Datenbank}
set t(insert_into_dbase) {In Datenbank einfügen}
set t(exdate) Mindesthaltbarkeitsdatum
set t(extype) {Aktion nach Mindesthaltbarkeit}
set t(remove) Entfernen
set t(add_incoming) {In Posteingang einfügen}
set t(backup) {Zur Datensicherung verschieben}
set t(insert) Einfügen
set t(already_vfolderdef) {Es ist bereits ein Bearbeitungsfenster geöffnet}
set t(vfolderdef) {Virtuelles Postfach erstellen}
set t(window) Fenster
set t(close) Schliessen
set t(browser) Browser
set t(folder) Postfach
set t(new_file) {Neue Postfach-Datei}
set t(new_mh) {Neue mh-Datei}
set t(new_dbase) {Neues Datenbank Postfach}
set t(new_imap) {Neues IMAP Postfach}
set t(new_pop3) {Neues POP3 Postfach}
set t(new_dynamic) {Neues dynamisches Postfach}
set t(new_folder) {Neues Postfach}
set t(need_name) {Sie müssen einen Namen angeben}
set t(create_submenu) {Untermenü erstellen}
set t(folder_name) Postfachname
set t(submenu_not_empty) {Möchten Sie dieses Menü und alle darunterliegenden Einträge wirklich
löschen?}
set t(need_postilion_dir_title) {Neues Verzeichnis erstellen?}
set t(need_postilion_dir1) {Dieses Programm braucht für die Konfigurationsdateien ein eigenes
Verzeichnis.}
set t(need_postilion_dir2) {Es wird jetzt erstellt werden.}
set t(create) Erstellen
set t(dont_create) {Nicht erstellen}
set t(failed_create) {Erstellen des Verzeichnisses fehlgeschlagen}
set t(do_without_dir) {Ich werde es ohne versuchen, aber eventuell wird es nicht einwandfrei
funktionieren}
set t(hold_message) {Nachricht als Entwurf speichern}
set t(hold_failed) {Als Entwurf speichern fehlgeschlagen}
set t(no_held) {Es gibt keine gespeicherten Entwürfe}
set t(must_select) {Sie müssen eine Nachricht auswählen}
set t(error_in_userproc) {Es ist ein Fehler in der Nutzer/in-Scriptdatei}
set t(translate_error) {RatUP_Translate hat eine fehlerhafte Ausgabe für folgende Eingabe erzeugt}
set t(reread_userproc) {Nutzer/in-Script nochmals einlesen}
set t(preferences) Eigenschaften
set t(watcher) Postfachüberwachung
set t(folderwindow) Postfachfenster
set t(general) Allgemein
set t(appearance) Erscheinungsbild
set t(sending) Senden
set t(under_construction) {Noch im Aufbau}
set t(language) Sprache
set t(show_changes) {Ändere Nachrichten}
set t(start_win) {Zeige Fenster}
set t(show) Zeige
set t(dont_show) Verstecke
set t(dbase_dir) Datenbank-Verzeichnis
set t(apply) Übernehmen
set t(reset) Zurücksetzen
set t(unapplied_changes_title) {Änderungen verwerfen}
set t(unapplied_changes) {Sie haben Änderungen vorgenommen. Was soll mit den Änderungen geschehen?}
set t(discard) Verwerfen
set t(print_command) Druckbefehl
set t(tmp_dir) {Temporäres Verzeichnis}
set t(file_permissions) Dateiattribute
set t(userproc_file) Nutzer/in-Scriptdatei
set t(hold_dir) {Verzeichnis für Entwürfe}
set t(window_name) Fenstername
set t(window_geometry) Fensterposition
set t(icon_name) Ikonenname
set t(default_folder) Standardpostfach
set t(default_list_format_mode) Modus-Listenformat
set t(list_format) Listenformat
set t(show_header_selection) {Ausgewählte Nachrichtenkopfzeilen}
set t(show_headers) Modus-Kopfzeilen
set t(default_sort_order_mode) Modus-Sortierung
set t(sort_order) Sortierung
set t(natural_order) {Wie eingegangen}
set t(reverse_natural_order) {Wie eingegangen rückwärts}
set t(by_date) {Nach Datum}
set t(reverse_date) {Nach Datum rückwärts}
set t(intervals) Intervalle
set t(stdfolders) Standardpostfach
set t(dbase_folders) Datenbankpostfach
set t(width) Breite
set t(lines) Zeilen
set t(font) Zeichensatz
set t(bell_ringings) {Akustisches Signal}
set t(show_messages) {Nachrichten anzeigen}
set t(new) Neu
set t(reply_lead) {Leitung antworten}
set t(signature_file) Unterschriftsdatei
set t(masquerade_host_as) {Rechnerdomäne ausgeben als}
set t(domain) Domäne
set t(smtp_hosts) {SMTP Server}
set t(charset) Zeichensatz
set t(attribution) Attribute
set t(forwarded_label) {Weitergeleitete Überschrift}
set t(alias) Alias
set t(fullname) {Voller Name}
set t(content) Inhalt
set t(need_alias_and_content) {Ich benötige beides, Alias und Inhalt}
set t(reread_aliases) {Alias'e nochmals einlesen}
set t(dismiss) Schliessen
set t(save) Speichern
set t(save_out) {Abgesendete speichern}
set t(save_to) {Speichern in}
set t(create_vfolder) {Neues vPostfach}
set t(dont_save) {Nicht speichern}
set t(found_aliases) {Die Überprüfung Ihrer alten Dateien ergab insgesamt}
set t(num_aliases) alias
set t(see_log) {Alte Nachrichten ansehen}
set t(seelog_title) {Alte Nachrichten}
set t(does_not_exist) {existiert nicht}
set t(no_folder) {Kein geöffnetes Postfach}
set t(already_login) {Ein anderer Prozess läuft bereits. Bitte schliessen Sie diesen zuerst.}
set t(login) Login
set t(opening) Öffnen
set t(mailbox_on) {Postfach auf}
set t(mailbox) Postfach
set t(mailboxes) Postfächer
set t(host) Server
set t(user) Benutzer/in
set t(passwd) Passwort
set t(mbox) {Name des Postfachs}
set t(reply_to_which) {Diese Nachricht enthält eingebettete Nachrichten.
Bitte wählen Sie die
Nachricht die Sie beantworten wollen aus.}
set t(forward_which) {Diese Nachricht enthält eingebettete Nachrichten.
Bitte wählen Sie die
Nachricht die Sie weiterleiten wollen aus.}
set t(forwarded_message) {Weitergeleitete Nachricht}
set t(forward_as_attachment) {Als Anlage weiterleiten}
set t(forward_inline) {Bearbeitet weiterleiten}
set t(forward) Weiterleiten
set t(bounce) Weiterleiten
set t(empty_message) {Leere Nachricht}
set t(structure) Struktur
set t(view_source) {Quelle ansehen}
set t(source) Quelle
set t(help_window) Hilfe
set t(site) Adresse
set t(access-type) Zugriffstyp
set t(directory) Verzeichnis
set t(server) Server
set t(smtp) SMTP
set t(user_program) {Nutzer/in definiertes Programm}
set t(sendprot) {Sende über}
set t(sendprog) {Programm zum Senden}
set t(progin) Programm-Eingabedaten
set t(eightbit) {8 bit (unverändert)}
set t(sevenbit) {7 bit}
set t(subject_by_date) {Betreff nach Datum}
set t(import) Importieren
set t(import_directory) {Verzeichnis importieren}
set t(cant_read) {Einlesen nicht möglich}
set t(ignored_not_file_not_dir) {wird ignoriert, da weder Verzeichnis noch Datei.}
set t(bounce_which) {Diese Nachricht enthält eingebettete Nachrichten.
Bitte wählen Sie die
Nachricht die Sie weiterleiten wollen aus.}
set t(lookup_name) {Namen nachschlagen}
set t(do_lookup) Nachschlagen
set t(dont_lookup) {Nicht nachschlagen}
set t(dbase) Datenbank
set t(dbase_backup) Sicherungsverzeichnis
set t(expire_interval) Verfallsintervall
set t(do_expire) {Lösche alte Einträge in der Datenbank}
set t(expire) {Alte Einträge löschen}
set t(expire_result) {Ergebnisse der Wartung}
set t(scanned) Gelesen
set t(deleted) Gelöscht
set t(backedup) {Zur Sicherung verschieben}
set t(inbox) {Zum Posteingang verschoben}
set t(db_expire) {Warte Datenbank}
set t(packing_backup) {Komprimiere Sicherungsdateien}
set t(chunksize) Mindestanzahl
set t(default_start_selection_mode) {Modus-Auswahl beim Öffnen}
set t(start_selection) {Auswahl beim Öffnen}
set t(first_message) {Erste Nachricht im Postfach}
set t(last_message) {Letzte Nachricht im Postfach}
set t(first_new_message) {Erste ungelesene Nachricht im Postfach}
set t(before_first_new_message) {Die Nachricht vor der ersten ungelesenen}
set t(notifications) Benachrichtigungen
set t(notification) Benachrichtigung
set t(failed) Fehlgeschlagen
set t(delayed) Verspätet
set t(delivered) Ausgeliefert
set t(relayed) Gesendet
set t(expanded) Weitergeleitet
set t(dsn_text_failed) {Ihre Nachricht an %s (%s) wurde nicht zugestellt.}
set t(dsn_text_delayed) {Ihre Nachricht an %s (%s) hat Verspätung.}
set t(dsn_text_delivered) {Ihre Nachricht an %s (%s) wurde zugestellt.}
set t(dsn_text_relayed) {Ihre Nachricht an %s (%s) wurde gesendet.}
set t(dsn_text_expanded) {Ihre Nachricht an %s (%s) wurde an andere Empänger/in weitergeleitet.}
set t(see_more_of_message) {Mehr der zurückgekommenen Nachricht ansehen}
set t(original-envelope-id) {ID der Versandhülle}
set t(reporting-mta) {Berichtender MTA}
set t(dsn-gateway) {DNS Gateway}
set t(received-from-mta) {Erhalten von MTA}
set t(arrival-date) Eingangsdatum
set t(original-recipient) {Ursprüngliche Empfänger/in}
set t(final-recipient) {Letzte/r Empfänger/in}
set t(action) Aktion
set t(status) Status
set t(remote-mta) {Entfernter MTA}
set t(diagnostic-code) {Diagnose Kode}
set t(last-attempt-date) {Datum des letzten Zugriffs}
set t(final-log-id) {Letzte Log-ID}
set t(will-retry-until) {Werde es versuchen bis}
set t(log_timeout) {Status Zeitüberschreitung}
set t(extra) Extra
set t(request_notification) {Benachrichtigung anfordern}
set t(dsn_directory) {DNS Verzeichnis}
set t(default_action) Standardaktion
set t(request_dsn) {Benachrichtigung anfordern}
set t(not_request_dsn) {Benachrichtigung nicht anfordern}
set t(not_snarf_dsn) {Benachrichtigungen in Nachrichtenliste anzeigen}
set t(snarf_dsn) {Benachrichtigungen in Nachrichtenliste nicht anzeigen}
set t(dsn_expiration) Mindesthaltbarkeitsdatum
set t(report_level) Berichtsstufe
set t(rl_none) Keine
set t(rl_status) {Zeige in Statuszeile}
set t(rl_notify) {Zeige in eigenem Fenster}
set t(cc) Kopie
set t(bcc) {Unsichtbare Kopie}
set t(content_description) Inhaltsbeschreibung
set t(reply_to) {Antworte an}
set t(bounce_to) {Weiterleiten an}
set t(reply) Antworte
set t(comments) Kommentare
set t(comment) Kommentar
set t(default_from_mode) Modus-`From'(Von)
set t(from) Von
set t(date) Datum
set t(received) Erhalten
set t(message-id) Nachrichten-ID
set t(mime-version) MIME-Version
set t(content-type) Inhaltstyp
set t(auto-submitted) {Automatisch vorgelegt}
set t(default_reply_to_mode) {Standard Antwort-Modus}
set t(default_reply_to_addr) {Standard Antwortadresse}
set t(default_reply_to_fn) {Standard vollständiger Name für Antwort}
set t(default_reply_to) {Default Reply-To}
set t(probe) Testen
set t(dsn_need_smtp) {Sie müssen SMTP zum Senden benutzen, damit Benachrichtigungen
funktionieren.}
set t(probing) teste
set t(supports_dsn) {unterstützt Benachrichtigungen}
set t(no_dsn_support) {Benachrichtigungen werden nicht unterstützt}
set t(character_size) Zeichengröße
set t(need_restart) {Sie müssen Postilion leider neu starten, damit die Einstellungen wirksam
werden.}
set t(opening_folder) {Öffne Postfach}
set t(read) Lesen
set t(write) Schreiben
set t(exec) Ausführen
set t(perm_user) Benutzer/in
set t(perm_group) Gruppe
set t(perm_other) Andere
set t(mode) Modus
set t(all_read) {Alle lesen}
set t(all_read_write) {Alle lesen & schreiben}
set t(max_height) {Max. Höhe}
set t(insert_failed) {Einordnen der Nachricht fehlgeschlagen}
set t(define_keys) {Tasten definieren}
set t(folder_key_find) Suchen
set t(folder_key_compose) {Neue Nachricht}
set t(folder_key_quit) Ende
set t(folder_key_nextu) {Nächste ungelesene}
set t(folder_key_sync) Synchronisieren
set t(folder_key_update) Aktualisieren
set t(folder_key_delete) Löschen
set t(folder_key_undelete) Wiederherstellen
set t(folder_key_flag) {Nachricht markieren}
set t(folder_key_seen) {Gelesenstatus ändern}
set t(folder_key_ans) {Antwortstatus ändern}
set t(folder_key_next) Nächste
set t(folder_key_prev) Vorherige
set t(folder_key_home) {Anfang der Nachricht}
set t(folder_key_bottom) {Ende der Nachricht}
set t(folder_key_pagedown) {Seite nach unten}
set t(folder_key_pageup) {Seite nach oben}
set t(folder_key_linedown) {Zeile nach unten}
set t(folder_key_lineup) {Zeile nach oben}
set t(folder_key_replya) {Allen antworten}
set t(folder_key_replyq) {An Absender/in (zitiert)}
set t(folder_key_replyqa) {An alle (zitiert)}
set t(folder_key_replys) {Absender/in antworten}
set t(folder_key_forward_a) {Als Anlage weiterleiten}
set t(folder_key_forward_i) Weiterleiten
set t(folder_key_bounce) Weiterleiten
set t(folder_key_select_all) {Alle markieren}
set t(folder_key_deselect_all) {Alle Markierungen entfernen}
set t(add_key) Zufügen
set t(press_key) {Neue Taste drücken}
set t(key_defined) {Diese Taste ist bereits zugeordnet}
set t(replace_key) {Durch neue Zuordnung ersetzen}
set t(do_delete) {Drücken Sie die Zuordnung die gelöscht werden soll}
set t(netscape_steal) {Netscape hat anscheinend einige Nachrichten abgefangen. Was soll mit
diesen geschehen?}
set t(steal_back) {Nachrichten zurückholen}
set t(nothing) Nichts
set t(check_stolen_mail) {Auf abgefangene Nachrichten prüfen}
set t(check) Prüfen
set t(dont_check) {Nicht prüfen}
set t(take_mail) {Nachrichten von Netscape übernehmen}
set t(remember_pos) Fenstergeometrie
set t(do_remember) Erinnern
set t(dont_remember) {Nicht erinnern}
set t(import_IMAP) IMAP-Postfach
set t(pattern) Suchbegriff
set t(host_required) {Sie müssen einen Server angeben}
set t(import_failed) {Import fehlgeschlagen}
set t(warning_sendprog) {Warnung: Das Sendeprogramm existiert nicht oder ist nicht ausführbar}
set t(automatic_wrap) {Automatischer Zeilenumbruch}
set t(automatic_indent) {Automatische Identifizierung}
set t(need_keyword) {Sie müssen mindestens ein Stichwort angeben}
set t(need_host_and_user) {Sie müssen mindestens eine/n Empfänger/in angeben}
set t(opening_connection) {Öffne Verbindung...}
set t(wait_greeting) {Warte auf Begrüßung...}
set t(get_capabilities) {Hole Möglichkeiten...}
set t(send_envelope) {Sende Versandhüllen Informationen...}
set t(send_from) {Sende Absender/in Adresse...}
set t(send_rcpt) {Sende Empfänger/in}
set t(send_data) {Sende Daten...}
set t(wait_ack) {Warte auf Bestätigung...}
set t(closing) {Schliesse Verbindung...}
set t(sending_message) {Sende Nachricht...}
set t(smtpv) {SMTP alles anzeigen}
set t(normal) Normal
set t(verbose) Alles
set t(terse) Minimal
set t(import_aliases) {Alias'e importieren}
set t(upgrade_dbase) {Datenbank upgraden}
set t(old_dbase) {Sie haben eine alte Datenbankversion. Um sie zu benutzten, muß ich sie
konvertieren.}
set t(unlinked_messages) {Nachricht nicht gebunden}
set t(unl_m1) {Dort wo}
set t(unl_m2) {Es befinden sich nicht gebundene Nachricht(en) in der Datenbank. Sie finden diese im
UnlinkedMessages Verzeichnis (das ist das Verzeichnis mit ~/UnlinkedMessages
als Datei)}
set t(send_deferred) {Zurückgestellte senden}
set t(delivery_mode) Modus-Zurückstellen
set t(direct) Direkt
set t(deferred) Zurückstellen
set t(sending_deferred) {Sende zurückgestellte Nachrichten}
set t(to_send) {Zum Senden}
set t(sent) Versandt
set t(you_have) {Sie haben}
set t(deferred_messages) {zurückgestellte Nachrichten. Möchten Sie diese jetzt senden?}
set t(deferred_message) {zurückgestellte Nachricht. Möchten Sie diese jetzt senden?}
set t(send_now) {Sende jetzt}
set t(no) Nein
set t(waiting_on_sender) {Warte auf den Sendeprozesses (ich sende)...}
set t(illegal_file_spec) {Ungültige Datei ausgewählt}
set t(copy_attached_files) {Kopiere Dateianlagen}
set t(cache_conn) Zwischenspeicherverbindung
set t(failed_to_create_send_cache) {Sie werden keine Nachrichten versenden können, solange kein
Zwischenspeicher erstellt werden kann.}
set t(mh_name) MH-Name
set t(need_mh_name) {Sie müssen einen MH-Namen angeben}
set t(failed_to_make_copy) {Kopiervorgang fehlgeschlagen}
set t(color_scheme) Farbschema
set t(gray67) Grau
set t(PeachPuff2) Aprikose
set t(bisque) Rosa
set t(SlateBlue1) Blau
set t(SteelBlue4) Stahlblau
set t(SkyBlue1) Hellblau
set t(aquamarine2) Hellgrün
set t(SpringGreen4) Grün
set t(patterns_to_use) {Suchbegriffe für die Objekte}
set t(files) Dateien
set t(directories) Verzeichnisse
set t(cache_passwd) {Passwörter zwischenspeichern}
set t(cache_timeout) {Zwischenspeicher Zeitüberschreitung}
set t(do_cache) Zwischenspeichern
set t(do_not_cache) {Nicht zwischenspeichern}
set t(icon_bitmap) {Ikonen bitmap}
set t(normal_bitmap) {Normal (64x64)}
set t(button_bar) {Schalterleiste anzeigen}
set t(buttons) {Ikonen oder Text für Schalter}
set t(text) Text
set t(icon) Ikone
set t(small_bitmap) {Klein (50x50)}
set t(xpm) {Bild (48x48)}
set t(sync_but) Sync-Schalter
set t(sync_oper) {Sync-Schalter Aktion}
set t(set_to_inbox) {Zum Posteingang erklären}
set t(set_to_open_on_startup) {Öffne beim Programmstart}
set t(set_to_min_on_startup) {Öffne minimiert beim Start}
set t(unset_to_open_on_startup) {Nicht mehr beim Start öffnen}
set t(unset_to_min_on_startup) {Nicht mehr minimiert beim Start öffnen}
set t(group) Gruppe
set t(create_in_win) {Erstelle im Fenster}
set t(create_by_expr) {Nach Ausdruck erstellen}
set t(use_saved_expr) {Benutze gespeicherten Ausdruck}
set t(clear_group) {Lösche Gruppenmarkierung}
set t(select_all) {Alle auswählen}
set t(deselect_all) {Alle Markierungen entfernen}
set t(edit_group) {Gruppe bearbeiten}
set t(create_exp) {Ausdruck erstellen}
set t(basic_mode) Standardmodus
set t(advance_on_flag) {An Markierung voranschreiten}
set t(flag_ans) {Antwortstatus ändern}
set t(flag_seen) {Gelesenstatus ändern}
set t(flag_unseen) {Als ungelesen markieren}
set t(advanced_mode) Expertenmodus
set t(save_as) {Speichern unter}
set t(fields) Felder
set t(operators) Operatoren
set t(booleans) Bool
set t(grouping) Gruppieren
set t(sender) Sender/in
set t(has) hat
set t(is) Ist
set t(clear) Löschen
set t(error_underlined) {Es ist ein Syntaxfehler in dem unterstrichenen Wort}
set t(syntax_error_exp) {Syntaxfehler im Ausdruck}
set t(saved_expr) {Gespeicherte Ausdrücke}
set t(need_one_selected_exp) {Sie müssen einen Ausdruck auswählen}
set t(here_is_text) {Enthält verschlüsselten Text}
set t(which_cant_be_shown) {der nicht korrekt angezeigt werden kann.}
set t(show_sevenbit) {Zeige siebenbit Zeichen}
set t(convert_to_local_nl) {Konvertiere zu lokaler `Zeilenende' Einstellung}
set t(startup) Start
set t(startup_mode) Startmodus
set t(iconic) Minimiert
set t(file) Datei
set t(insert_file) {Datei einfügen}
set t(cut) Ausschneiden
set t(cut_all) {Alles ausschneiden}
set t(copy) Kopieren
set t(copy_all) {Alles kopieren}
set t(paste) Einfügen
set t(wrap_lines) {Zeilen umbrechen}
set t(run_through_command) {Befehl ausführen}
set t(undo) Rückgängig
set t(redo) Wiederherstellen
set t(failed_to_open_file) {Öffnen der Datei fehlgeschlagen}
set t(no_text_selected) {Kein Text markiert}
set t(command_failed) {Befehl fehlgeschlagen}
set t(command) Befehl
set t(command_is_running) {Befehl wird ausgeführt}
set t(folder_key_cycle_header) {Rotiere angezeigte Kopfzeilen}
set t(watcher_enable) {Überwachung aktiviert}
set t(enabled) Aktiviert
set t(disabled) Deaktiviert
set t(command_list) Befehlsliste
set t(compose_key_send) Senden
set t(compose_key_abort) Abbruch
set t(compose_key_editor) {Externes Bearbeitungsprogramm}
set t(compose_key_undo) Rückgängig
set t(compose_key_cut) Ausschneiden
set t(compose_key_copy) Kopieren
set t(compose_key_cut_all) {Alles ausschneiden}
set t(compose_key_paste) Einfügen
set t(compose_key_replya) {Allen antworten}
set t(compose_key_replyq) {Absender/in zitiert antworten}
set t(compose_key_replyqa) {Allen zitiert antworten}
set t(compose_key_replys) {Absender/in antworten}
set t(compose_key_insert) {Datei einfügen}
set t(compose_key_attach) Anhängen
set t(sig_cmd_failed) {RatUP_Signatur fehlgeschlagen}
set t(bell_cmd_failed) {RatUP_Glocke fehlgeschlagen}
set t(sig_cmd_takes_precedence) {Sie haben eine RatUP_Signature angewählt die vorrangig gegenüber. der
Signaturdatei behandelt wird!}
set t(more) Mehr
set t(compose_sessions) {Sie haben bereits ein Bearbeitungsfenster offen}
set t(really_quit) {Wirklich beenden?}
set t(do_quit) Beenden
set t(dont_quit) {Nicht beenden}
set t(use_from_address) {Benutze Absender/in-Adresse}
set t(use_from_fn) {Benutze vollen Namen der Absender/in}
set t(messages_shown) {Nachricht gezeigt}
set t(dbase_error) {Fehler in der Datenbank! Starten Sie das Prüfprogramm im
Administrationsmenü}
set t(dbase_check) {Datenbank prüfen}
set t(check_dbase) {Prüfe Datenbank}
set t(check_fix_dbase) {Prüfe und repariere Datenbank}
set t(checking_dbase) {Prüfe Datenbank}
set t(total_num_messages) {Insgesamt sind im Nachrichtenindex}
set t(num_malformed) {Anzahl der fehlerhaften Einträge}
set t(num_nomessages) {Anzahl der Einträge ohne Nachrichten}
set t(num_unlinked) {Anzahl nichtverbundener Nachrichten}
set t(total_size) {Gesamtgröße aller Nachrichten}
set t(waiting_dbase_lock) {Warte auf Datenbank lock}
set t(port) Port
set t(already_exists) {existiert bereits}
set t(overwrite) Überschreiben
set t(append) Anhängen
set t(file_exists) {Datei existiert}
set t(type_description) Typenbeschreibung
set t(view) Ansicht
set t(view_as_text) {Als einfachen Text ansehen}
set t(external_viewer) {Externes Betrachtungsprogramm}
set t(cant_pipe) {Ich kann keinen Kanal (pipe) in ein Progamm das das Terminalfenster
benutzt öffnen.}
set t(reread_mailcap) {Mailcap nochmal einlesen}
set t(mailcap_path) Mailcap-Pfad
set t(terminal_command) Terminalbefehl
set t(vfolderedit) {Bearbeite virtuelles Postfach}
set t(delete_imap) {Aktuelles IMAP-Postfach ebenfalls löschen?}
set t(dont_delete) {Nicht löschen}
set t(print_headers) {Drucke Kopfzeilen}
set t(print_non_text) {Drucke auch nicht-Text-Teile}
set t(selected) Markiert
set t(aliases) Alias'e
set t(extract_adr) {Adresse extrahieren}
set t(address) Adresse
set t(could_not_find_adr) {Keine Adresse zum Extrahieren vorhanden}
set t(add_aliases) {Alias'e hinzufügen}
set t(use) Benutzen
set t(missing_alias_name) {Fehlender Alias Name. Ein Eintrag wird nicht hinzugefügt.}
set t(alias_chooser) {Alias auswählen}
set t(set_to_save_outgoing) {Hier gesendete Objekte speichern}
set t(unset_to_save_outgoing) {Hier gesendete Objekte nicht mehr speichern}
set t(add) Hinzufügen
set t(smtp_timeout) {SMTP Zeitüberschreitung}
set t(no_send_bad_host) {Postilion kennt nicht die vollständige Adresse mit der Ihre Nachricht
versandt werden soll. Dieser Name kann im Eigenschaftenfenster unter `Senden'
eingestellt werden. Die Felder heißen "Rechnerdomäne ausgeben als" und
"Domäne" (eines genügt). Sie werden keine Nachrichten versenden können, bevor
dies geschehen ist (oder - Senden erzwingen - im gleichen Fenster aktiviert
ist).}
set t(force_send) {Senden erzwingen}
set t(force) Erzwingen
set t(no_force) {Nicht erzwingen}
set t(on_reply) {auf Antworten}
set t(skip_sig) {Signatur nicht einfügen}
set t(keep_sig) {Signatur einfügen}
set t(subjectonly) {Nach Betreff}
set t(bysender) {Nach Absender/in}
set t(sign) Unterschreiben
set t(encrypt) Verschlüsseln
set t(pgp_pass_phrase) {PGP Mantra}
set t(pgp_problem) {PGP Problem}
set t(retry) Wiederholen
set t(sig) Sig
set t(default_signature_mode) {Unterschriften Modus}
set t(signature) Unterschrift
set t(none) Keine
set t(pgp_part) Teil
set t(pgp_none) Keine
set t(pgp_unchecked) ?
set t(pgp_good) Ok
set t(pgp_bad) Ooops
set t(pgp_output) {PGP Ergebnis}
set t(warning_pgp_prog) {WARNUNG: Das angegebene PGP-Programm existiert nicht oder ist nicht
ausführbar}
set t(pgp_handling) {PGP Handhabung}
set t(pgp_program) {PGP Programm}
set t(pgp_extra_args) {Zusätzliche PGP Parameter}
set t(decoded) Entschlüsselt
set t(send_bug) {Sende Fehlerreport}
set t(short_description) {Ersetze mit einer kurzen Beschreibung}
set t(bug_report_template) {[Ersetzen Sie diesen Text mit einer detaillierten Beschreibung des
Fehlers. Wenn Sie einen tcl-Fehler erhalten, teilen Sie den bitte den "Stack
Trace" ebenfalls mit.]}
set t(configuration_information) {Beschreibung Ihrer Konfiguration}
set t(send_bugs_etc) {Bitte senden Sie Fehlerreports und Vorschläge für Verbesserungen an
nic@postilion.org}
set t(send_postcards) {Sie können auch Grüße per Postkarten senden an:
nl {U kunt ook ansichtkaarten met groeten sturen naar:

Martin Forssen
Kabelgatan 13c
414 57 Göteborg
SWEDEN}

Martin Forssen
Kabelgatan 13c
414 57 Göteborg
SWEDEN}
set t(sign_outgoing) {Nachricht unterschreiben}
set t(encrypt_outgoing) {Nachricht verschlüsseln}
set t(true) Wahr
set t(false) Falsch
set t(attach_pgp_keys) {PGP Schlüssel anhängen}
set t(select_keys) {Schlüssel markieren}
set t(bits) Bits
set t(keyid) Schlüssel-ID
set t(user_id) {Benutzer/in ID}
set t(pgp_key_for) {PGP Schlüssel für}
set t(embedded_pgp_keys) {Hier sind einer oder mehrere PGP Schlüssel angehangen}
set t(add_to_keyring) {Zum Schlüsselbund hinzufügen}
set t(press_return_to_dismiss) {Drücken Sie Return um das Fenster zu schließen}
set t(decrypting) Verschlüssele...
set t(seconds) Sekunden
set t(days) Tage
set t(url_viewer) {Link Browser}
set t(userproc) Nutzer/in-Script
set t(netscape_cmd) {Netscape Befehl}
set t(netscape_args) {Netscape Parameter}
set t(url_color) {Farbe von Links}
set t(paper_color) {Farbe des Papiers}
set t(new_msg_col) {Farbe neuer Nachrichten}
set t(sel_msg_col) {Farbe markierter Nachrichten}
set t(fnd_msg_col) {Farbe gefundener Nachrichten}
set t(flg_msg_col) {Farbe markierter Nachrichten}
set t(del_msg_col) {Farbe gelöschter Nachrichten}
set t(seen_msg_col) {Farbe gelesener Nachrichten}
set t(ans_msg_col) {Farbe beantworteter Nachrichten}
set t(smtp_reuse) {SMTP Kanalbenutzung}
set t(addrbooks) Adressbücher
set t(addrbook) Adressbuch
set t(use_system_aliases) {Benutze System-Alias'e}
set t(move_to) {Verschieben nach}
set t(set_default) {Als Standard setzen}
set t(need_writable_book) {Sie müssen mindestens ein beschreibares Adressbuch haben}
set t(book_already_exists) {Es gibt bereits ein Adressbuch mit diesem Namen}
set t(pgp) PGP
set t(find) Suchen
set t(match) Treffer
set t(exact) Exakt
set t(regexp) {Regulärer Ausdruck}
set t(find_in) {Suche in}
set t(message_list) Nachrichtenliste
set t(message_body) Nachrichtentext
set t(find_next) Weitersuchen
set t(colorbug) {Diese von Ihnen benutzte Version von tcl/tk hat einen Fehler der es  unmöglich macht die Farbe über diese Option zu ändern. Der Fehler ist \ in
tcl/tk 8.0 beseitigt.}
set t(out_of_order) {Leider abgeschaltet :;-)}
set t(default_to_browse) {Browse-Modus als Standard}
set t(browse_mode) Browse-Modus
set t(default_browse_mode) {Standard-Modus Browse}
set t(no_browse) {Browse-Modus nicht benutzen}
set t(do_browse) {Browse-Modus benutzen}
set t(use_folder_default) {Benutze Einstellung des Postfachs}
set t(show_body) {Zeige Nachrichtentext}
set t(ignore_case) {Ignoriere Groß/Kleinschreibung}
set t(url_protocols) {Links (URL) Protokolle}
set t(prefix) {Datumstil für Postfach-Präfix}
set t(spell_check) Rechtschreibung
set t(balloon_help) {Popup Hilfe}
set t(subjects) Betreffs
set t(warning) Warnung
set t(do_not_show_again) {Zeige diese Warnung nicht noch einmal}
set t(warn_tk80) {Sie benutzen tk8.0 mit einem schwerem Fehler im Menücode. Dieser erzeugt
einen Fehler beim Öffnen des Postfachmenüs. Sie sollten auf tk8.0p2 (oder höher)
updgraden.}
set t(expunge_on_close) {Beim Schließen tilgen}
set t(do) Machen
set t(do_not) {Nicht machen}
set t(pending_cut) {Sie haben in die Zwischenablage ausgeschnitten aber nirgens eingefügt.
Löschen?}
set t(menu_style) Menüstil
set t(next_style) NeXT-Stil
set t(ispellOnOff) {Benutze Ispell}
set t(ispellRecheckAfterAdd) {Nach Hinzufügen erneut überprüfen}
set t(ispellTextOnly) {Rechtschreibprüfung nur für den Text}
set t(ispellCommand) {Standard Rechtschreibungsprogramm}
set t(ispellOthers) {Anderes Rechtschreibungsprogramm}
set t(ispellPopupBinding) {Popup-Menü anbinden an:}
set t(ispellStyle) {Stil für fehlerhafte Wörter}
set t(ispellStyleColor) {Farben für Vorder- & Hintergrund}
set t(ispellStyleOther) {Stil wenn 'Andere' markiert ist}
set t(underline) Unterstrichen
set t(italic) Kursiv
set t(bold) Fett
set t(bgcolor) Hintergrundfarbe
set t(fgcolor) Vordergrundfarbe
set t(ispell) Rechtschreibung
set t(mboxvis) {Zeige Postfachansicht}
set t(drafts) Entwürfe
set t(new_user) {Konfiguration für neue Benutzer/in}
set t(finish) Fertig
set t(set_name) {Bitte geben Sie Namen und EMail-
Adresse so ein, wie diese in von 
Ihnen gesendeten Nachrichten 
erscheinen soll.}
set t(compose_quit) {Do you wish to hold this draft, or abort it?}
set t(System) System
set t(Personal) Personal
set t(list) listen
set t(hide) Hide
set t(hide-sizes) {Hide Sizes}
set t(hide-deleted) {Hide Deleted}
set t(info) Info
set t(compact) Compact
set t(incorporate-mail) {Incorporate Mail}
set t(focus) Focus
set t(unfocus) Unfocus
set t(services) Services
set t(tcl-error) {Error in Tcl Script}
set t(skip-messages) {Skip Messages}
set t(stack-trace) {Stack Trace}
set t(isp-add) Add
set t(isp-dict) {to dictionary}
set t(isp-accept) Accept
set t(isp-for) {for this session}
set t(alternate) Alternate
set t(default) Default
set t(return_path) Return-Path
set t(pgp_sign) {PGP Sign}
set t(quote_color) {Quote color}
}
