#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_help_sv {} {
global help
set help(title,intro) Introduktion
set help(intro) {			    Hjälpsystem för Postilion


Om du inte vet hur du använder hjälpsystemet så tryck på "Hjälp om Hjälp"
till höger om denna text.


  Översikt

Postilion är ett mailprogram (MUA efter Mail User Agent) avsett för att läsa,
skicka och spara elektronisk post.

Postilion's huvudfönster är mappfönstret. Det är det fönstret som dyker upp när
du startar Postilion. I toppen av det här fönstret finns en menyrad och en rad
som beskriver den aktiva mappen. Nedanför det finns en lista över de brev
som finns i den aktiva mappen. Du kan välja ett brev i listan och se brevets
innehåll längre ner. Nedanför brevlistan kommer en statusrad och en rad med
knappar. Nedanför dem visas innehållet i det aktiva brevet. För mera
information om mappfönstret välj "Mappfönster" i listan över underämnen.

Innan du kan skicka ett brev måste du först komponera det. Det finns
flera sätt att komma till kompositionsfönstret. Om du vill skapa ett nytt
brev så trycker du på "Nytt brev" knappen. Om du vill svara på det
aktiva brevet så trycker du på en av "Svara" knapparna. För mera
information om hur man skicka brev välj "Komponera brev" i
listan över underämnen.

Normalt så visar mappfönstret den brevlåda där din inkommande post lagras
(din INBOX). När du har läst (och eventuellt svarat på) ett brev så kan du
vilja spara det i en annan mapp (för att inte din INBOX skall svämma över
av gamla brev). Det finns flera olika typer av mappar som har olika egenskaper.
Välj "Mappar" i listan över underämnen för att läsa mera om detta.

Om det kommer ett nytt brev under tiden som programmet är ikonifierat så
dyker ett litet väktarfönster upp. Välj "Väktare" i listan över underämnen
för att läsa mer om detta fönster.

Postilion är ett mycket komplext program. Och trots att jag har försökt göra
det enkelt att använda så syns komplexiteten på antalet saker som man
kan ställa in. Allt skall ha bra värden från början, men om du känner för
att ändra nåpgot så kan det hjälpa att läsa underämnet "Inställningar".


  Mer information

Information (på engelska) om den senaste versionen etc kan hitta på
följande URL:

 http://www.postilion.org
}
set help(title,deleting) {Radera brev}
set help(deleting) {				Radera brev

Att radera ett brev är en tvåstegsoperation. Först så markerar man brevet
som raderat, och någon gång senare så tas de märkta breven bort.

Brev som är markerade som raderade har ett 'D' bredvid sig i listan över
brev. För att markera det aktiva brevet som raderat trycker du helt enkelt
på "Radera"-knappen. Du kan fortfarande göra vad du vill med brevet eftersom
det inte har tagits bort ännu.

Man kan ta bort raderat-märket på det aktiva brevet genom att välja
"Ta bort radering" i Brev-menyn.

Själva raderingen av de märkta breven inträffar när du synkroniserar mappen
(via "Synkronisera mapp" i Administration-menyn) eller när du stänger
mappen (om du öppnar en annan mapp så stängs den aktiva mappen, mappen
stängs också om du avslutar Postilion).
}
set help(title,grouping) {Gruppera brev}
set help(grouping) {				Gruppera brev

Att gruppera brev är ett bekvämt sätt att utföra samma operation på ett antal
brev på en gång.

Den aktiva gruppen består alltid av alla markerade brev i den aktiva mappen.
Att ett brev är markerat visas mha 'F'-flaggan i brevlistan (Detta 'F' är
egentligen en del av brevets statusflaggor så om du inte har med %S i ditt
listformat så ser du det inte). Brev kan behålla sin markering nästa gång
mappen öppnas.

För tillfället så kan du göra följande operationer på en grupp (operationerna
måste utföras från gruppmenyn):
  * Radera		- Markera breven för radering
  * Ta bort radering	- Ta bort raderingsmärkning från breven
  * Flytta		- Flytta breven till en annan mapp

Dint finns fyra olika sätt att lägga till/ta bort brev från gruppen:

  * Använd "Ta bort gruppmarkering" ingången i Grupp-menyn
    Detta tar bort samtliga gruppmarkeringar i den aktiva mappen.

  * Tryck höger musknapp på brevet i brevlistan
    Detta byter värde (på/av) på gruppmarkeringen för brevet.

  * Använd "Skapa i fönster..." ingången i Grupp-menyn
    Detta skapar ett separat fönster som innehåller en lista över alla
    brev i den aktiva mappen där du kan välja brev. När du trycker på
    "Ok"-knappen så görs dina val om till den aktiva gruppen.

  * Använd "Skapa mha uttryck..." ingången i Grupp-menyn
    Detta skapar ett fönster där du kan skapa ett reguljäruttryck och som
    sedan lägger in alla brev (i den aktiva mappen) som passar uttrycket i
    den aktiva gruppen. Seu nderämnet "Uttrycksfönster" för mera information.

  * Använd "Använd sparat uttryck" menyn i Grupp-menyn. Denna menyn innehåller
    ingångar för de uttryck som du tidigare har sparat.
}
set help(title,folders) Mappar
set help(folders) {                            Mappar

En mapp är en samling av brev (noll eller flera). Det finns många olika sätt
att spara och komma åt brev i en mapp. Postilion klarar för tillfället av fyra
olika typer av mappar.

För att öppna (välja) en mapp så måste man veta vilken typ det är, och
dessutom ha en del annan typspecifik information. Därför har Postilion någonting
som jag kalla virtuella mappar (också kända som vmappar). När du definierar
en vmapp så anger du vilken typ av mapp och all annan data som behövs, du
måste dessutom ange ett namn på vmappen. Vmappens namn kommer sedan att synas
i "Mappar"- och "Flytta"-menyerna.

  Följande typer av mappar stödjs

* Unix mailbox
  En UNIX mailbox består av en enkel textfil där breven skiljs åt av
  speciella skiljelinjer (som börjar med "From " eller "^A^A^A"). Detta är
  den vanligaste metoden att spara brev på unixsystem.
  Nödvändiga uppgifter: namnet på filen

* IMAP4
  IMAP (version 4) är ett protokoll för att komma åt sina mappar över
  nätverk. En användare kan ha flera IMAP-mappar på en maskin.
  Nödvändiga uppgifter: namnet på maskinen som har mappen
			vilket användrnamn man skall använda
			ett lösenord (frågas efter vi öppning)
			mappens namn

* POP3
  POP (version 3) är ett protokoll för att läsa sin post över nätverk. Varje
  användare kan ha högst en POP-mapp på en maskin.
  Nödvändiga uppgifter: namnet på maskinen som har mappen
			vilket användrnamn man skall använda
			ett lösenord (frågas efter vi öppning)

* Databas
  En databasmapp är en samling av brev där varje brev har nyckelord associerade
  till sig. Att öppna en databasmapp är samma sak som att söka i den (man kan
  söka på fler saker än nyckelord). Brev kan också ha en expireringstid, och
  när den nås så händer någonting med brevet (det kan tex raderas). Varje
  användare kan bara ha en databas (man kan bara komma åt sin egen databas).
  Nödvändiga uppgifter: ett sökuttryck
			expireringstid och typ (när man lägger in brev)

* Dynamisk
  Detta är en specialform a "Unix mailbox". Den anges som ett bibliotek och
  när man lägger in brev i mappen så sparas de i filmappar i biblioteket.
  Filmapparnas namn är första delen av avsändarens epostadress. När du öppnar
  en dynamisk mapp så får du en lista över alla filer som finns i biblioteket.
  Nödvändiga uppgifter: namnet på biblioteket.
}
set help(title,folderdef) {Definiera vmappar}
set help(folderdef) {				Definiera vmappar

Postilion låter dig organisera dina mappar i en trädstruktur. Strukturen liknar
ett normalt filsystem med menyer instället för bibliotek (bilbiotek kallas
ibland mappar) och mappar istället för filer. Denna struktur används till att
bygga "Mappar" och "Flytta" menyerna. När du väljer "Ny/Ändra mapp" så dyker
vmappdefinera-fönstret upp. Detta fönster låter dig se din struktur. Menyerna
representeras av rektanglar och mapparna är texter i rutorna. Relationer
mellan menyerna syns på linjerna som går mellan dem. Rot-menyn finns i det
övre vänstra hörnet. En mapp är markerad med en '*', detta är den mappen
som öppnas vid programstart. Det kan också finnas en mapp som markeras med
'>', det är den mappen som avsända brev sparas i.

I menyraden finns en meny som låter dig skapa nya mappar och menyer. Mappar/
menyer skapade mha denna meny placeras i rot-menyn.

Om du trcker på den vänstra musknappen över en mapp så får du en meny som låter
dig modifiera den aktiva mappen eller lägga till nya mappar/menyer på detta
stället i menystrukturen.

Man använder höger musknapp för att flytta saker. För att flytta ett föremål
så pekar man på det och trycker ner höger musknapp, håll knappen nedtryckt
och dra mappen/menyn till sin nya plats i strukturen, släpp sedan knappen.

Om du redan her en struktur med mappar i filsystemet så kan Postilion bygga
motsvarande vmapp-struktur automatiskt. För att göra detta så väljer du
"Importera bibliotek" från importera-menyn. Man kan också importera
mapp-strukturer från en IMAP-server.

För att stänga fönstret så kan man välja "Stäng" från "Fönster"-menyn.
}
set help(title,dbase) Databasen
set help(dbase) {				Databasen

Databasen är ett ställe där man sparar brev. Varje brev är associerat till
ett antal nyckelord och en expireringstid (kan vara evigheten).

När man lägger in ett brev i databasen så kan du ge följande data:
  * nyckelord		- en lista med nyckelord
  * expireringstid	- tidpunkten när det här brevet expirerar från
			  databasen. Tiden skall ges som ett plustecken
			  omedelbart följt av ett nummer (inget mellanslag).
			  Numret är antalet dagar som brevet skall ligga
			  i databasen. Detta fält kan vara tomot och motsvarar
			  då evigheten.
  * expireringshändelse	- vad som skall hända när brevet expirerar. Möjliga
			  värden är:
	* Ta bort    - radera brevet.
	* Inkommande - lägg in brevet i din INBOX.
	* Arkiv      - arkivera brevet.
	* Egen       - ge brevet till ett egendefinierat program.

När du vill hämta brev från databasen så kan du söka på följande fält:
to, from, cc, subject, nyckelord och hela brev. Du kan få alla brev
som matchar alla kriterier eller de som matchar minst ett.
}
set help(title,notification) Kvittenser
set help(notification) {				Kvittenser

	Om kvittenser

Kvittenser (den tekniska termen är Delivery Status Notifications (DSN)) låter
dig veta när ditt brev har nått mottagarens brevlåda. DSN arbetar på SMTP-
nivån så du måste använda SMTP för att skicka dina brev, och eftersom det
är en utökning av protokollet så stödjer inte alla SMTP-servers det. Det
finns en testknapp i inställningsfönstret som låter dig testa om just ditt
system stödjer DSN. För att det skall fungera krävs dock också att alla
system på vägen till mottagaren också stödjer DSN.

	Kvittenser-fönstret

Kvittenser-fönstret innehåller en lista över all brev där kvittens har
begärts som har skickats de senaste sju dagarna (tiden kan ändras). Varje
brev visas med datumet det skickades, dess ärende och en lista över alla
mottagare. Framför varje mottagare så visas aktuell status. Det finns sex
stycken olika status:

-	      - Betyder att Postilion inte vet något om denna mottagaren ännu.
Misslyckades  - Brevet kom ej fram till denna mottagaren.
Levererat     - Brevet har blivit levererat till mottagaren. Observera att
		detta INTE implicerar att mottagaren ens har sett brevet ännu.
Vidareskickat - Brevet har skickats vidare till en agent (MTA) som inte
		klarar av att returnera kvittenser.
Expanderat    - Brevet har levererats, men mottagaren var ett alias som
		expanderade till en eller flera andra adresser. Fler
		kvittenser kommer att komma.
Försenat      - Brevet har inte nått mottagaren ännu, men systemet kommer
		att göra flera försök att leverera det.

Man kan få mera information om varje kvittens genom att peka på mottagaren
och trycka på vänster musknapp. Då dyker kvittensfönstret, som ger mera
information om en viss kvittens, upp.

	Kvittensfönstret

Kvittensfönstret innehåller en textdel som kan scrollas. Denna del visar en
text som skall vara läsbar för en människa och som beskriver vad som orsakade
denna kvittens. Nedanför finns diverse fält som hjälper den mera kunnige
att lista ut exakt vad som gick fel (elle rätt). Det finns en knapp "Se mera
av det returnerade brevet" som lägger till mera text till textdelen. Den nya
texten är de delar av orginalbrevet som skickades tillbaka i kvittensen.

För mera teknisk information om kvittenser så hänvisas till lämpliga rfc-er
(för tillfället 1891, 1893 och 1894).
}
set help(title,userproc) Userproc
set help(userproc) {			Användardefinierade procedurer

Användardefinierade procedurer är ett sätt för användaren att få mera
kontroll över vissa features. Procedurerna är vanliga tcl-procedurer
(dvs de är skriva i tcl7.5). Ingen av procedurerna måste existera, de
används bara om de finns.

Användaren kan definiera procedurer i  ~/.ratatosk/userproc (eller vad
userproc är satt till). Om procedurerna behöver några globala variabler
så måste dessa heta något som börjar med "ratUP_". Följande procedurer
kan definieras:

RatUP_IsMe brevlåda domän namn adl
        brevlåda  -      Brevlådans namn
        domän     -      Domändelen av adressen
        namn      -      Det personliga namnet (om angivet).
        adl       -      At-domain-list source route
    Denna proceduren skall avgära om den givna adressen pekar på mig
    eller inte. Den skall returnera ett sanningsvärde som skall vara sant
    om adressen pekar på mig.

RatUP_Translate brevlåda domän namn adl
        brevlåda  -      Brevlådans namn
        domän     -      Domändelen av adressen
        namn      -      Det personliga namnet (om angivet).
        adl       -      At-domain-list source route
    När man svarar på ett brev så kommer alla adresserna som vi skickar
    det till att köras genom denna proceduren. Den förväntas returnera
    en lista med fyra element {brevlåda domän namn adl}.

RatUP_Signature brev
        brev -		Ett handtag för det brev som signaturen kommer att
			läggas till i.
    Denna proceduren skall returnera en textsträng som sedan kommer att
    läggas till i slutet av den första textdelen av brevet. Argumentet "brev"
    är ett handtag som kan användas till att få fram information om brevet
    (läs filen interface för mera information). Notera att denna proceduren
    anropas innan användaren har hunnit göra något med brevet så det enda fall
    då det finns någon intressant information tillgänglig är då man svarar på
    eller skickar vidare ett brev.

RapUP_Bell
    Denna funktion skall meddela användaren att ny post har kommit. Om inte
    denna funktionen finns så rings terminalklockan.

RatUP_ShowURL url
	url -	URLen som skall visas
    Denna funktion kan anropas när användaren trycker ned vänster musknapp
    på en URL i ett brev. Den förväntas starta en webbläddrare (i bakgrunden).
}
set help(title,bugreport) Felrapportering
set help(bugreport) {				Felrapportering

Felrapporter skickas till maf@dtek.chalmers.se. Detta görs bäst genom att man
väljer "Skicka felrapport..." ur hjälpmenyn (i mappfönstret). Detta kommer
att skapa ett "Skriva brev"-fönster med en felrapportmall. Mottagaren är redan
ifylld och en del av ämnet. Du måste komplettera ämnet och skriva en detaljerad
version av hur du gjorde för att komma til felet (och av felet) in brödtexten.

Postilion har redan lagt till en bilaga som innehåller information on din
konfiguration. Denna bilagan innehåller utskriften från "uname -a" på ditt
system, Postilions versionsnummer, tcl/tk versionsnummer och en kopa av alla dina
inställningar.

Om du vill se exakt vad som skickas så lagras bilagan i en fil som har ett namn
på formen ~/.ratatosk/send/rat.X.Y (det är troligen den sista filen). Denna
filen skapas när du väljer "Skick felrapport..." och raderas när rapporten
skickas.
}
}
