#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_help_nl {} {
global help
set help(title,intro) Introduktie
set help(intro) {                    Help systeem voor Postilion


Als u niet weet hoe u dit helpsysteem moet gebruiken druk dan op het woord
"Help over Help" aan de rechterkant van deze tekst.


  Overzicht

Postilion is een Mail User Agent (MUA) ofwel email client die bedoeld is voor
het lezen, versturen en administreren van elektronische post.

Het hoofdvenster van Postilion is het Postbus venster. Dit is het venster dat
verschijnt wanneer u Postilion start. Aan de bovenkant van het venster is een
menubalk en een regel die uw huidige postbus beschrijft. Daaronder is een lijst
van de berichten in de postbus. U kunt berichten in deze lijst selecteren met de
muis om de individuele berichten er onder te tonen. Onder de berichtenlijst staat
een berichtenregel en een rij met knoppen. Daaronder wordt de inhoud van het
huidige bericht getoond. Voor meer informatie over het postbusvenster selecteer
"Postbusvenster" in de lijst van onderwerpen.

Voordat u een bericht kunt versturen moet u er eerst één maken (bijv. schrijven).
Er zijn meerdere wegen om bij het 'Nieuw bericht' venster te komen. Wanneer u
een nieuw bericht wenst te versturen moet u op de 'Nieuw bericht' knop drukken.
Wanneer u het huidige bericht wenst te beantwoorden moet u op één van de antwoord-
knoppen drukken. Voor meer informatie over het versturen van berichten selecteer
'Nieuwe berichten' in de lijst van onderwerpen.

Standaard toont het postbusvenster uw INBOX, dat is de postbus waar uw binnen-
komende berichten worden geplaatst. Wanneer u een bericht gelezen (en wellicht
beantwoord) heeft, kunt u deze ergens anders naar verplaatsen (zodat uw INBOX niet
onoverzichtelijk vol wordt). Dit wordt gedaan door het bericht naar een andere
postbus te verplaatsen. Er zijn vele verschillende postbustypen met elk hun eigen
eigenschappen. Selecteer 'Postbussen' in de lijst met onderwerpen om meer te
vernemen over postbussen.

Als er een nieuw bericht arriveert wanneer het programma geminimaliseerd is
klapt er een klein uitkijkvenster open. Selecteer 'Uitkijk' in de lijst van
onderwerpen om hier meer over te vernemen.

Postilion is een erg complex programma. Ofschoon ik geprobeerd heb om het makke-
lijk te maken, komt de complexiteit op een aantal plaatsen naar voren in de vorm
van de vele te wijzigen opties. Al deze verschillende opties zouden redelijke
standaardwaarden moeten hebben, maar als u het gevoel hebt dat iets anders zou
moeten, dan kan het helpen om op het 'Voorkeuren' onderwerp te klikken.


  Meer informatie

Informatie over de laatste versie enz. kan gevonden worden op de volgende URL:

  http://www.postilion.org
}
set help(title,deleting) {Verwijderen van berichten}
set help(deleting) {                            Verwijderen van berichten

Verwijderen van berichten is een tweestaps proces. Eerst worden de berichten
gemarkeerd voor verwijderen en op een later tijdstip worden deze gemarkeerde
berichten daadwerkelijk verwijderd uit de postbus.

Berichten die gemarkeerd zijn voor verwijderen worden in de berichtenlijst
aangegeven door een 'D' er direkt naast. Om deze markering aan te brengen kunt
u eenvoudigweg op de 'Verwijder' knop drukken. U kunt alle gebruikelijke ope-
raties op een voor verwijderen gemarkeerd bericht uitvoeren, aangezien het 
bericht fysiek nog niet weg is.

U kunt de verwijderen markering ongedaan maken door 'Annuleer Verwijder' aan te
klikken in het 'Bericht' menu.

De daadwerkelijke verwijdering van de gemarkeerde berichten vindt plaats op
het moment dat u de postbus synchroniseert (via 'Synchroniseer postbus' in het
Beheer menu) of wanneer u de postbus sluit (het openen van een andere postbus
veroorzaakt het sluiten van de huidige-, evenals het afsluiten van Postilion).
}
set help(title,grouping) {Groeperen van berichten}
set help(grouping) {                            Groeperen van berichten

Groeperen van berichten is een handige manier om dezelfde operatie op
meerdere berichten tegelijk uit te voeren (nadat een groep is gecreëerd).

De huidige groep bestaat altijd uit de gemarkeerde berichten in de huidige
postbus. Deze markering wordt aangegeven door een 'F' in de berichtenlijst
(deze 'F' is eigenlijk een gedeelte van de statusvlag, dus indien u niet
'%S' in uw lijstweergave hebt opgenomen, zult u deze vlag niet kunnen zien).

Op dit moment kunt u de volgende operaties uitvoeren op een groep (moet via
het groepsmenu):
  * Verwijderen           - Markeer de berichten voor verwijderen
  * Annuleer verwijderen  - Verwijder de markering voor verwijderen
  * Verplaats             - Verplaats de berichten naar een andere postbus

Er zijn vier verschillende manieren om berichten toe te voegen aan/te ver-
wijderen uit een groep:

  * Gebruik de 'Schoon groepmarkering' opdracht in het Groep menu
    Dit verwijderd alle groepsmarkeringen in de huidige postbus.

  * Druk op de rechter muisknop op een bericht in de berichtenlijst.
    Dit creëert een apart venster met een lijst van alle berichten in de
    huidige postbus waarin u berichten kunt (de)selecteren. Wanneer u uit-
    eindelijk op de Ok knop drukt, wordt de selectie de groepselectie.

  * Gebruik de 'Maak met zoekterm...' opdracht in het Groep menu
    Dit opent een venster waarin u een zoekterm kunt opgeven waarna alle
    berichten die aan die zoekterm voldoen worden toegevoegd aan de huidige
    groep. Zie het onderwerp 'Zoekterm venster' voor meer informatie hierover.

  * Gebruik het 'Gebruik opgeslagen zoekterm' submenu in het Groep menu. Dit
    menu bevat ingangen voor alle zoektermen die u eerder heeft opgeslagen.
}
set help(title,folders) Postbussen
set help(folders) {                            Postbussen

Een postbus is een collectie van (nul of meer) berichten. Er zijn veel verschil-
lende manieren voor het opslaan en benaderen van berichten in een postbus.
Postilion begrijpt op dit moment vier verschillende typen postbussen.

Om een postbus te openen dient u ervan te weten van welk type deze is en wat meer
typegebonden informatie. Om u te helpen heeft Postilion zoiets als virtuele post-
bussen. Wanneer u een virtuele postbus definieert, dan geeft u de naam, het type
en alle andere gegevens over de postbus. Deze naam zal dan verschijnen in het
'Postbussen' en 'Verplaats' menus voor gemakkelijker toegang.

  De volgende typen postbussen worden ondersteund

* Unix postbussen
  Een Unix postbus bestaat uit een platte-tekst bestand waarin de berichten worden
  gescheiden door een markeringsregel (die begint met 'From ' of '^A^A^A^A'). Dit
  is de gebruikelijke manier van postbehandeling op Unix systemen.
  Benodigde informatie: de naam van het bestand.

* IMAP4
  IMAP (versie 4) is een protocol voor het benaderen van postbussen over een
  netwerk. Per gebruiker kunnen meerdere IMAP postbussen zich op één server bevinden.
  Benodigde informatie: de naam van de server
                        welke gebruiker toegang tot de postbus heeft
                        een wachtwoord (wordt gevraagd bij het openen van de postbus)
			de naam van de postbus

* POP3
  POP (versie 3) is een protocol voor het benaderen van postbussen over een
  netwerk. Elke gebruiker kan maximaal één POP-postbus per server hebben.
  Benodigde informatie: de naam van de server
                        welke gebruiker toegang tot de postbus heeft
                        een wachtwoord (wordt gevraagd bij het openen van de postbus)

* Database
  Een database postbus is een verzameling van berichten waarbij elk bericht
  geassocieerde trefwoorden heeft. Het openen van de database staat gelijk aan
  het doorzoeken ervan (u kunt zoeken op meer dan één trefwoord) Berichten kunnen
  ook een vervaldatum hebben en wanneer deze datum bereikt wordt dan gebeurt er iets
  met het bericht (het kan bijvoorbeeld verwijderd worden). Elke gebruiker kan 
  slechts één database bezitten (u kunt alleen uw eigen database benaderen).
  Benodigde informatie: een zoekterm
                        vervaldatum en type (voor invoegen)

* Dynamisch
  Dit is een speciale vorm van een bestandsdirectory. U geeft de directorynaam op
  en wanneer een bericht in de postbus wordt geplaatst, wordt dit feitelijk in een
  bestands postbus geplaatst binnen deze directory. De naam van deze postbus is het
  eerste gedeelte van het afzenderadres. Wanneer u een dynamische postbus opent dan
  ziet u een lijst van de postbussen binnen deze directory.
  Benodigde informatie: de naam van de directory.
}
set help(title,folderdef) {Het definiëren van virtuele postbussen}
set help(folderdef) {                  Het definiëren van virtuele postbussen

Postilion geeft u de mogelijkheid uw postbussen in een boomstruktuur te 
organiseren naar analogie van een bestandssysteem. Postilion gebruikt
menus in plaats van directories en postbussen in plaats van bestanden.
Deze structuur wordt gebruikt voor het bouwen van de Postbussen en Verplaats
menus. Wanneer u 'Nieuw/Wijzig postbus' kiest, verschijnt het definitievenster
voor een virtuele postbus. Dit venster toont u de volledige struktuur (voor
zover deze binnen het venster past). De menus/directories zijn de postbussen
en de postbussen worden weergegeven door hun naam. Relaties tussen postbussen
worden weergegeven door lijnen. De wortel van de boom is de postbus in de 
linkerbovenhoek. Eén postbus is gemarkeerd met een '*'. Dit is het standaard 
'inkomend' bakje. Er kan één postbus zijn die gemarkeerd is door 
een '>', dit is de postbus waar de uitgaande berichten in worden opgeslagen.

In de menubalk is een menu wat het mogelijk maakt om nieuwe menu's en post-
bussen te maken. Postbussen/menu's die via dit menu gemaakt worden direkt onder
de wortel van de boom geplaatst.

Wanneer u de linkermuisknop klikt op een postbus, dan krijgt u een menu met
de mogelijkheid om de huidige postbus te wijzigen of om nieuwe elementen op die
lokatie toe te voegen in de menustructuur.

Om één en ander te verplaatsen gebruikt u de rechtermuisknop. Druk op die knop
terwijl u op een element staat en houd de knop ingedrukt. U kunt nu het element
verslepen en het zo verplaatsen naar een ander menu: u laat het vallen door
de muisknop weer los te laten. U kunt op deze manier zowel postbussen als
postbakjes verplaatsen.

Als u al een structuur van postbakjes heeft in het bestandssysteem, dan kan 
Postilion deze lezen en hiervanaf de overeenkomende virtuele postbakjes automatisch
aanmaken. Om dit te realiseren kiest u 'Importeer directory' van het import menu.
U kunt ook postbussen van IMAP servers importeren.

Om het venster te sluiten kiest u 'Sluiten' uit het venstermenu.
}
set help(title,dbase) {De database}
set help(dbase) {                            De database

De database is een plaats voor opslag van berichten. Elk bericht wordt voorzien
van een aantal trefwoorden en een vervaldatum (mag oneindig zijn).

Wanneer u een bericht opslaat in de database kunt u de volgende te associëren
informatie opgeven:
  * trefwoorden  - een optionele lijst van trefwoorden
  * vervaldatum  - een tijdstip waarop het bericht moet verlopen.
                   Dit tijdstip wordt opgegeven als een plus-teken
                   en een aantal dagen dat het bericht in de data-
                   base moet blijven. Dit veld mag leeg blijven.
                   In dat geval verloopt het bericht nooit.
  * verval aktie - wat moet er gebeuren als een bericht verloopt.
                   De mogelijkheden zijn:
                   * Verwijder   - verwijder het bericht
                   * Inkomend    - verplaats het bericht opnieuw naar het bakje 
                                   'inkomend'
                   * Archiveer   - verplaats het bericht naar één of ander backupformaat
                   * Specificeer - geef het bericht aan een opgegeven programma.

Wanneer u berichten uit de database wilt halen, dan kunt u zoeken op de volgende
velden: Aan, Van, Kopie, Onderwerp, Trefwoord en op het gehele bericht.
U kunt zoeken op alle kriteria of op slechts één.
}
set help(title,notification) Kennisgevingen
set help(notification) {				Kennisgevingen

	Over kennisgevingen

Kennisgevingen (de Engelse term is Delivery Status Notifications (DSN)) laten
u weten wanneer uw bericht is afgeleverd in de postbus van de geadresseerde.
DSN werkt op het SMTP-niveau, dus u moet SMTP gebruiken voor het versturen
van uw berichten. Aangezien DSN een extensie van het SMTP-protocol is, zullen
ook niet alle servers het ondersteunen. Er is een Sonde-knop in het voor-
keurenvenster die test of uw systeem DSN ondersteunt. Alle systemen op de
route van verzender tot geadresseerde moeten eveneens DSN ondersteunen.

	Het kennisgevingenvenster

De kennisgevingenvenster bevat een lijst met alle berichten waarvoor een
kennisgeving werd verzocht en die verzonden zijn binnen de laatste zeven dagen
(deze waarde is instelbaar). Elk bericht wordt vermeld met de verzenddatum,
onderwerp en alle geadresseerden. Voor elke geadresseerde wordt de huidige
status getoond. Er zijn zes mogelijke waarden:

-		- Betekent dat Postilion nog niets weet over deze geadresseerde
Mislukt		- Het bericht heeft de geadresseerde niet bereikt
Afgeleverd	- Het bericht is succesvol afgeleverd. Dit impliceert NIET
		  dat de geadresseerde het bericht ook gelezen heeft.
Doorgestuurd	- De route van het bericht loopt via een server die geen DSN
		  ondersteunt
Uitgebreid	- Het bericht is afgeleverd, maar de geadresseerde was een
		  alias die na substitutie één of meer adressen heeft
		  opgeleverd. Meerdere kennisgevingen kunnen volgen.
Vertraagd	- Het bericht heeft zijn bestemming nog niet bereikt, maar
		  verdere pogingen zullen volgen.

U kunt meer informatie over een kennisgeving krijgen door de regel met de
geadresseerde aan te wijzen en op de rechter muisknop te drukken. Dit laat een
venster verschijnen met meer gedetailleerde informatie.

	Het detail-kennisgevingenvenster

Het detail-kennisgevingenvenster bevat een scrollend tekstgedeelte. Dit
gedeelte toont een tekst die voor menselijke lezers leesbaar zou moeten zijn
en die beschrijft wat deze kennisgeving heeft veroorzaakt. Daaronder zijn
velden die een wat meer belezen persoon helpen om uit te zoeken wat er precies 
fout ging (of goed). Het 'Toon meer van teruggestuurd bericht' zal meer tekst
toevoegen in het tekst-gedeelte. Deze nieuwe tekst zal de delen van het oor-
spronkelijke bericht bevatten dat werd teruggestuurd met deze kennisgeving.

Voor meer technische informatie over kennisgevingen, zie de betreffende rfc's
(op dit moment 1891, 1893 en 1894).
}
set help(title,userproc) {Gebruikers procedures}
set help(userproc) {			Gebruikers procedures

De gebruikersprocedures zijn een manier voor een gebruiker om meer beheersing
te hebben over bepaalde voorzieningen. De procedures zijn standaard Tcl
procedures (ze worden in tcl7.5 geschreven). Geen van deze procedures hoeft te
bestaan, ze worden alleen gebruikt áls ze bestaan.

De gebruiker mag procedures definiëren in het ~/.ratatosk/userproc bestand
(of wat de userproc optie aangeeft). Als de procedures globale variabelen
nodig hebben dan moeten deze beginnen met "ratUP_". De volgende procedures
mogen gedefinieerd worden:

RatUP_IsMe postbus domein persoonlijk adl
	postbus		-  Naam van de postbus
	domein		-  Het domein gedeelte
	persoonlijk	-  De persoonlijke naam frase (indien aanwezig)
	adl		-  At-domein-lijst bronroute.
    Deze procedure behoort te onderzoeken of een adres van uzelf is of niet.
    Het moet een booleaanse waarde teruggeven die waar moet zijn als het
    adres van uzelf is.

RatUP_Translate postbus domain persoonlijk adl
	postbus		-  Naam van de postbus
	domein		-  Het domein gedeelte
	persoonlijk	-  De persoonlijke naam frase (indien aanwezig)
	adl		-  At-domein-lijst bronroute (waarschijnlijk leeg)
    Wanneer we antwoorden op een bericht gaan alle adressen waarnaar we sturen
    door deze procedure heen. Het wordt geacht een lijst met vier elementen
    terug te geven {postbus domein persoonlijk adl}.

RatUP_Signature bericht
	bericht		-  De handler voor het bericht waaraan het signature
			   moet worden toegevoegd.
    Deze funktie behoort een tekst string terug te geven die later zal worden
    toegevoegd aan het eerste tekstgedeelte van het bericht. Het bericht-
    argument is een 'handler' die gebruikt kan worden om informatie aangaande
    het bericht in te winnen (zie het interfacebestand voor meer informatie).
    Let op dat deze routine aangeroepen wordt voordat de gebuiker de kans
    heeft gehad het bericht te wijzigen, dus er zal geen interessante infor-
    matie beschikbaar zijn voor nieuwe berichten. De informatie is alleen
    interessant voor antwoorden en doorsturingen.

RatUP_Bell
    Deze functie moet de gebruiker informeren dat een nieuw bericht is aan-
    gekomen. Als deze functie niet bestaat wordt de terminalbel geluid.

RatUP_ShowURL url
	url	- Een URL die getoond moet worden
   Deze functie kan aangeroepen worden wanneer u de linker muisknop indrukt
   boven een URL in een bericht. Hij wordt verondersteld een browser aan te
   roepen (in de achtergrond).
}
set help(title,bugreport) {Rapporteren van storingen}
set help(bugreport) {				Rapporteren van storingen

U behoort storingsrapporten te sturen naar maf@dtek.chalmers.se. Dit gaat
het eenvoudigst door 'Stuur storingsrapport' te selecteren in het 'Info' menu.
Dit zal een 'nieuw bericht' venster openen met een storingsrapport-sjabloon.
De geadresseerde is al ingevuld, evenals een gedeelte van het onderwerp.
U moet het onderwerp aanvullen (in het Engels) en een gedetailleerde
beschrijving geven van de storing en hoe die precies is ontstaan (in het 
Engels) in de tekst van het bericht.

Postilion heeft al een bijlage gemaakt met informatie over uw systeemconfigu-
ratie. Deze bestaat uit de uitvoer van 'uname -a' op uw systeem, Postilion's
versienummer en datum, de gebruikte tcl/tk versie en een kopie van de
instellingen in het voorkeurenvenster.

Als u precies wilt weten wat er verstuurd gaat worden; het wordt opgeslagen 
in het bestand ~/.ratatosk/send/rat.X.Y (het is waarschijnlijk het jongste
bestand). Dit bestand wordt aangemaakt zodra u 'Stuur storingsrapport...'
selecteert en wordt verwijderd na het verzenden.
}
}
