#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_t_en {} {
global t
set t(postilion) Postilion
set t(version) Version
set t(about) About
set t(quit) Quit
set t(name) Name
set t(size) Size
set t(messages) Messages
set t(help) Help
set t(ok) Ok
set t(cancel) Cancel
set t(ratatosk) {Ratatosk (swift-tusked). In Norse mythology, the squirrel that runs up and down the cosmic or world tree, Yggdrasil, carrying abusive language from the dragon Nidhog at the bottom of the tree to the eagle at the top, and vice versa.}
set t(posthorn) {Postilion. A person who rides on a horse which is pulling a carriage, to guide it. It was only in the early nineteenth century that roads suitable for vehicles made it possible for coaches to cross Alpine passes. The postal horn was an essential instrument to the postilion, who used it to signal his presence on the steep, winding roads. The postal horn is the symbol in yellow shown in the icon for Postilion. Do you know why a horn appears on mailboxes? Messengers and postilions used a small brass horn to signal their arrival. Use of the horn soon became obligatory for the postilion, who had to know at least eight signals, each with a particular meaning: arrival, distress, departure, and so on. But what made the horn so popular was its constant use over several centuries, rather than the regulations requiring that it be carried. Today the horn is the postal emblem of many countries.}
set t(months) {Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec}
set t(clock_format) {Clock format}
set t(12_hour) {12 Hour}
set t(24_hour) {24 Hour}
set t(move) Move
set t(delete) Delete
set t(undelete) Undelete
set t(compose) Compose
set t(reply_quote_sender) {Quote to sender}
set t(reply_quote_all) {Quote to all}
set t(quote) {Quote original message}
set t(no_quote) {Do not quote original message}
set t(reply_sender) {Reply to sender}
set t(reply_all) {Reply to all}
set t(here_is) {Here is an object of type}
set t(show_all) {Show all}
set t(old_dirs) {Previously used}
set t(save_to_file) {Save to file}
set t(save_failed) {Save failed}
set t(message) Message
set t(print) Print
set t(show_all_headers) {Show all headers}
set t(show_selected_headers) {Show selected headers}
set t(show_no_headers) {Show no headers}
set t(compose_name) {Compose message}
set t(edit) Edit
set t(edit_body) {Message body}
set t(edit_headers) {Message headers}
set t(custom_headers) {Custom headers}
set t(read_from_file) {Read body from file}
set t(abort) Abort
set t(headers) Headers
set t(attachments) Attachments
set t(attach_file) {Attach file}
set t(attach) Attach
set t(attach_special) {Attach special}
set t(detach) Detach
set t(send) Send
set t(send_save) {Send & Save}
set t(hold) Hold
set t(getheld) {Compose held}
set t(external_editor) {External editor}
set t(running_ext_editor) {Running external editor...}
set t(filename) Filename
set t(description) Description
set t(disposition) Disposition
set t(id) Identifier
set t(type) Type
set t(subtype) Subtype
set t(encoding) Encoding
set t(current_encoding) {Current encoding}
set t(other) other
set t(custom_type) {Custom type}
set t(need_to) {You must specify at least one recipient (To:)}
set t(no_subject) {No subject}
set t(admin) Admin
set t(newedit_folder) {New/Edit mailbox}
set t(update_folder) {Update mailbox}
set t(sync_folder) {Synchronize mailbox}
set t(update) {Update mailbox}
set t(sync) {Synchronize mailbox}
set t(continue) Continue
set t(open_file) {Open file}
set t(open) Open
set t(open_dbase) {Search dbase}
set t(folders) Mailboxes
set t(and) And
set t(or) Or
set t(not) Not
set t(to) To
set t(subject) Subject
set t(keywords) Keywords
set t(all) All
set t(search) Search
set t(emptyexp) {Empty search expression}
set t(to_file) {To file}
set t(to_dbase) {To dbase}
set t(insert_into_dbase) {Insert into dbase}
set t(exdate) {Expiration date}
set t(extype) {Expiration action}
set t(remove) Remove
set t(add_incoming) {Insert into incoming}
set t(backup) {Move to backup}
set t(insert) Insert
set t(already_vfolderdef) {There is already one mailbox edit window}
set t(vfolderdef) {Define virtual mailbox}
set t(window) Window
set t(close) Close
set t(browser) Browser
set t(folder) Mailbox
set t(new_file) {New file mailbox}
set t(new_mh) {New mh mailbox}
set t(new_dbase) {New dbase mailbox}
set t(new_imap) {New IMAP mailbox}
set t(new_pop3) {New POP3 mailbox}
set t(new_dynamic) {New dynamic mailbox}
set t(new_folder) {New mailbox}
set t(need_name) {You must specify a name}
set t(create_submenu) {Create submenu}
set t(folder_name) {Mailbox name}
set t(submenu_not_empty) {Do you really wish to delete this menu and all its children?}
set t(need_postilion_dir_title) {Create a directory?}
set t(need_postilion_dir1) {This program needs a configuration directory }
set t(need_postilion_dir2) {It will now be created.}
set t(create) Create
set t(dont_create) {Do not create}
set t(failed_create) {Failed to create the directory}
set t(do_without_dir) {I will try to do without it, but be advised that some operations may fail.}
set t(hold_message) {Hold message}
set t(hold_failed) {Failed to insert message into hold}
set t(no_held) {There are no held messages}
set t(must_select) {You must select a message}
set t(error_in_userproc) {There was an error in the userproc file}
set t(translate_error) {RatUP_Translate generated illegal output for the following input}
set t(reread_userproc) {Reread userproc}
set t(preferences) Preferences
set t(watcher) Watcher
set t(folderwindow) {Mailbox window}
set t(general) General
set t(appearance) Appearance
set t(sending) Sending
set t(under_construction) {Area under construction}
set t(language) Language
set t(show_changes) {Changes messages}
set t(start_win) {Show windows}
set t(show) Show
set t(dont_show) {Do not show}
set t(dbase_dir) {Database directory}
set t(apply) Apply
set t(reset) Reset
set t(unapplied_changes_title) {Unapplied changes}
set t(unapplied_changes) {You have made changes which are not applied. What do you want to do with them}
set t(discard) Discard
set t(print_command) {Print command}
set t(tmp_dir) {Temporary directory}
set t(file_permissions) {File creation perms}
set t(userproc_file) {Userproc file}
set t(hold_dir) {Hold directory}
set t(window_name) {Window name}
set t(window_geometry) {Window placement}
set t(icon_name) {Icon name}
set t(default_folder) {Default mailbox}
set t(default_list_format_mode) {List format mode}
set t(list_format) {List format}
set t(show_header_selection) {Selected headers}
set t(show_headers) {Show headers}
set t(default_sort_order_mode) {Sort order mode}
set t(sort_order) {Sort order}
set t(natural_order) {Natural order}
set t(reverse_natural_order) {Reverse natural order}
set t(by_date) {By date}
set t(reverse_date) {By reverse date}
set t(intervals) Intervals
set t(stdfolders) {Standard mailbox}
set t(dbase_folders) {Database mailbox}
set t(width) Width
set t(lines) Lines
set t(font) Font
set t(bell_ringings) {Bell ringings}
set t(show_messages) {Show messages}
set t(new) New
set t(reply_lead) {Reply lead}
set t(signature_file) {Signature file}
set t(masquerade_host_as) {Masquerade host as}
set t(domain) Domain
set t(smtp_hosts) {SMTP host}
set t(charset) {Character set}
set t(attribution) Attribution
set t(forwarded_label) {Forwarded label}
set t(alias) Alias
set t(fullname) {Full Name}
set t(content) Content
set t(need_alias_and_content) {I need both an aliasname and content}
set t(reread_aliases) {Reread aliases}
set t(dismiss) Dismiss
set t(save) Save
set t(save_out) {Save outgoing}
set t(save_to) {Save to}
set t(create_vfolder) {Create vmailbox}
set t(dont_save) {Do not save}
set t(found_aliases) {I scanned your old files and found a total of}
set t(num_aliases) aliases
set t(see_log) {See old messages}
set t(seelog_title) {Old messages}
set t(does_not_exist) {does not exist}
set t(no_folder) {No open mailbox}
set t(already_login) {There is another login process running. Complete that one first}
set t(login) Login
set t(opening) Opening
set t(mailbox_on) {mailbox on}
set t(mailbox) Mailbox
set t(mailboxes) Mailboxes
set t(host) Host
set t(user) User
set t(passwd) Passwd
set t(mbox) {Mailbox name}
set t(reply_to_which) {This message contains embedded messages.
Choose which message you want to reply to}
set t(forward_which) {This message contains embedded messages.
Choose which message you want to forward}
set t(forwarded_message) {Forwarded message}
set t(forward_as_attachment) {Forward as attachment}
set t(forward_inline) {Forward inline}
set t(forward) Forward
set t(bounce) Bounce
set t(empty_message) {Empty message}
set t(structure) Structure
set t(view_source) {View source}
set t(source) Source
set t(help_window) {Help window}
set t(site) Site
set t(access-type) Access-type
set t(directory) Directory
set t(server) Server
set t(smtp) SMTP
set t(user_program) {User defined program}
set t(sendprot) {Send via}
set t(sendprog) {Sending program}
set t(progin) {Program input}
set t(eightbit) {Eight bit data}
set t(sevenbit) {only seven bit data}
set t(subject_by_date) {Subject by date}
set t(import) Import
set t(import_directory) {Import directory}
set t(cant_read) {Can not read}
set t(ignored_not_file_not_dir) {is ignored it is neither a file nor a directory.}
set t(bounce_which) {This message contains embedded messages.
Choose which message you want to bounce}
set t(lookup_name) {Lookup name}
set t(do_lookup) {Do lookup}
set t(dont_lookup) {Do not lookup}
set t(dbase) Dbase
set t(dbase_backup) {Backup directory}
set t(expire_interval) {Expire interval}
set t(do_expire) {Expiring database}
set t(expire) Expire
set t(expire_result) {Expiration results}
set t(scanned) Scanned
set t(deleted) Deleted
set t(backedup) {Moved to backup}
set t(inbox) {Moved to inbox}
set t(db_expire) {Expiring database}
set t(packing_backup) {Compressing backup files}
set t(chunksize) {Chunk size}
set t(default_start_selection_mode) {Select when open mode}
set t(start_selection) {Select when open}
set t(first_message) {First message in mailbox}
set t(last_message) {Last message in mailbox}
set t(first_new_message) {First unread message in mailbox}
set t(before_first_new_message) {The message before the first unread}
set t(notifications) Notifications
set t(notification) Notification
set t(failed) Failed
set t(delayed) Delayed
set t(delivered) Delivered
set t(relayed) Relayed
set t(expanded) Expanded
set t(dsn_text_failed) {Your message to %s (%s) failed to get there.}
set t(dsn_text_delayed) {Your message to %s (%s) has been delayed.}
set t(dsn_text_delivered) {Your message to %s (%s) has been delivered.}
set t(dsn_text_relayed) {Your message to %s (%s) has been relayed.}
set t(dsn_text_expanded) {Your message to %s (%s) has been expanded.}
set t(see_more_of_message) {See more of returned message}
set t(original-envelope-id) {Original Envelope Id}
set t(reporting-mta) {Reporting MTA}
set t(dsn-gateway) {DSN Gateway}
set t(received-from-mta) {Received From MTA}
set t(arrival-date) {Arrival Date}
set t(original-recipient) {Original Recipient}
set t(final-recipient) {Final Recipient}
set t(action) Action
set t(status) Status
set t(remote-mta) {Remote MTA}
set t(diagnostic-code) {Diagnostic Code}
set t(last-attempt-date) {Last Attempt Date}
set t(final-log-id) {Final log ID}
set t(will-retry-until) {Will Retry Until}
set t(log_timeout) {Status timeout}
set t(extra) Extra
set t(request_notification) {Request notification}
set t(dsn_directory) {DSN directory}
set t(default_action) {Default action}
set t(request_dsn) {Request Notification}
set t(not_request_dsn) {Do not request Notification}
set t(not_snarf_dsn) {Show Notifications in message list}
set t(snarf_dsn) {Do not show Notifications in message list}
set t(dsn_expiration) {Expiration time}
set t(report_level) {Report level}
set t(rl_none) {Keep quiet}
set t(rl_status) {Display in status line}
set t(rl_notify) {Show in separate window}
set t(cc) Cc
set t(bcc) Bcc
set t(content_description) Content-Description
set t(reply_to) Reply-To
set t(bounce_to) {Bounce to}
set t(reply) Reply
set t(comments) Comments
set t(comment) Comment
set t(default_from_mode) {From mode}
set t(from) From
set t(date) Date
set t(received) Received
set t(message-id) Message-Id
set t(mime-version) MIME-Version
set t(content-type) Content-Type
set t(auto-submitted) Auto-Submitted
set t(default_reply_to_mode) {Default Reply-To mode}
set t(default_reply_to_addr) {Default Reply-To Address}
set t(default_reply_to_fn) {Default Reply-To full name}
set t(default_reply_to) {Default Reply-To}
set t(probe) Probe
set t(dsn_need_smtp) {You must use SMTP to send messages for notifications to work}
set t(probing) probing
set t(supports_dsn) {supports notifications}
set t(no_dsn_support) {no notifications support}
set t(character_size) {Character size}
set t(need_restart) {You need to restart Postilion for your changes to take full effect.}
set t(opening_folder) {Opening mailbox}
set t(read) Read
set t(write) Write
set t(exec) Exec
set t(perm_user) User
set t(perm_group) Group
set t(perm_other) Other
set t(mode) Mode
set t(all_read) {All read}
set t(all_read_write) {All read & write}
set t(max_height) {Max height}
set t(insert_failed) {Failed to insert message}
set t(define_keys) {Define keys}
set t(folder_key_find) Find
set t(folder_key_compose) Compose
set t(folder_key_quit) Quit
set t(folder_key_nextu) {Next unread}
set t(folder_key_sync) Synchronize
set t(folder_key_update) Update
set t(folder_key_delete) Delete
set t(folder_key_undelete) Undelete
set t(folder_key_flag) {Flag message}
set t(folder_key_seen) {Toggle Seen flag}
set t(folder_key_ans) {Toggle Answered flag}
set t(folder_key_next) Next
set t(folder_key_prev) Previous
set t(folder_key_home) {Top of letter}
set t(folder_key_bottom) {End of letter}
set t(folder_key_pagedown) {Page down}
set t(folder_key_pageup) {Page up}
set t(folder_key_linedown) {Line down}
set t(folder_key_lineup) {Line up}
set t(folder_key_replya) {Reply to all}
set t(folder_key_replyq) {Quote to sender}
set t(folder_key_replyqa) {Quote to all}
set t(folder_key_replys) {Reply to sender}
set t(folder_key_forward_a) {Forward as attachment}
set t(folder_key_forward_i) {Forward inline}
set t(folder_key_bounce) Bounce
set t(folder_key_select_all) {Select all}
set t(folder_key_deselect_all) {Deselect all}
set t(add_key) Add
set t(press_key) {Press the new key}
set t(key_defined) {This key is already bound to}
set t(replace_key) {Replace with new binding}
set t(do_delete) {Press the binding to delete}
set t(netscape_steal) {Netscape seems to have taken some your messages. What should we do about it?}
set t(steal_back) {Take them back}
set t(nothing) Nothing
set t(check_stolen_mail) {Check for taken mail}
set t(check) Check
set t(dont_check) {Do not check}
set t(take_mail) {Take mail from netscape}
set t(remember_pos) {Window geometry}
set t(do_remember) {Do remember}
set t(dont_remember) {Do not remember}
set t(import_IMAP) {IMAP mailboxes}
set t(pattern) Pattern
set t(host_required) {You must specify an host}
set t(import_failed) {Import failed}
set t(warning_sendprog) {WARNING: The specified sending program does not exist or is not executable}
set t(automatic_wrap) {Automatic line-wrap}
set t(automatic_indent) {Automatic indenting}
set t(need_keyword) {You must specify at least one keyword.}
set t(need_host_and_user) {You must specify both Host and User.}
set t(opening_connection) {Opening connection...}
set t(wait_greeting) {Waiting for greeting...}
set t(get_capabilities) {Getting capabilities...}
set t(send_envelope) {Sending envelope information...}
set t(send_from) {Sending From address...}
set t(send_rcpt) {Sending recipient}
set t(send_data) {Sending data...}
set t(wait_ack) {Waiting for acknowledgement...}
set t(closing) {Closing channel...}
set t(sending_message) {Sending message...}
set t(smtpv) {SMTP verbose}
set t(normal) Normal
set t(verbose) Verbose
set t(terse) Terse
set t(import_aliases) {Import aliases}
set t(upgrade_dbase) {Upgrade dbase}
set t(old_dbase) {You have an old version of the database. I must convert it to be able to use it}
set t(unlinked_messages) {Unlinked messages}
set t(unl_m1) {There were}
set t(unl_m2) {unlinked messages in the database. They can be found in the UnlinkedMessages mailbox (which is a filefolder with ~/UnlinkedMessages as the file)}
set t(send_deferred) {Send deferred}
set t(delivery_mode) {Delivery mode}
set t(direct) Direct
set t(deferred) Deferred
set t(sending_deferred) {Sending deferred messages}
set t(to_send) {To send}
set t(sent) Sent
set t(you_have) {You have}
set t(deferred_messages) {deferred messages. Do you want to send them now?}
set t(deferred_message) {deferred message. Do you want to send it now?}
set t(send_now) {Send now}
set t(no) No
set t(waiting_on_sender) {Waiting on sender process (it is sending)...}
set t(illegal_file_spec) {Illegal file specified}
set t(copy_attached_files) {Copy attached files}
set t(cache_conn) {Cache connections}
set t(failed_to_create_send_cache) {You will not be able to send messages since I failed to create the send cache}
set t(mh_name) MH-name
set t(need_mh_name) {You must give a mh-name}
set t(failed_to_make_copy) {Failed to make a local copy}
set t(color_scheme) {Color scheme}
set t(gray67) Gray
set t(PeachPuff2) Peach
set t(bisque) Bisque
set t(SlateBlue1) Blue
set t(SteelBlue4) {Steel Blue}
set t(SkyBlue1) {Light blue}
set t(aquamarine2) {Light green}
set t(SpringGreen4) Green
set t(patterns_to_use) {Patterns to match found objects against}
set t(files) Files
set t(directories) Directories
set t(cache_passwd) {Cache passwords}
set t(cache_timeout) {Cache timeout}
set t(do_cache) {Do cache}
set t(do_not_cache) {Do not cache}
set t(icon_bitmap) {Icon bitmap}
set t(normal_bitmap) {Normal (64x64)}
set t(button_bar) {Display button bar}
set t(buttons) {Icons or text for buttons}
set t(text) Text
set t(icon) Icon
set t(small_bitmap) {Small (50x50)}
set t(xpm) {Image (48x48)}
set t(sync_but) {Sync button}
set t(sync_oper) {Sync button operation}
set t(set_to_inbox) {Set to inbox}
set t(set_to_open_on_startup) {Set to open on startup}
set t(set_to_min_on_startup) {Set to open minimized on startup}
set t(unset_to_open_on_startup) {Set to not open on startup}
set t(unset_to_min_on_startup) {Set to not open minimized on startup}
set t(group) Group
set t(create_in_win) {Create in window}
set t(create_by_expr) {Create by expression}
set t(use_saved_expr) {Use saved expression}
set t(clear_group) {Clear group marking}
set t(select_all) {Select all}
set t(deselect_all) {Deselect all}
set t(edit_group) {Edit group}
set t(create_exp) {Create expression}
set t(basic_mode) {Basic mode}
set t(advance_on_flag) {Advance on flag}
set t(flag_ans) {Toggle the Answered flag}
set t(flag_seen) {Toggle the Seen flag}
set t(flag_unseen) {Flag as unseen}
set t(advanced_mode) {Advanced mode}
set t(save_as) {Save as}
set t(fields) Fields
set t(operators) Operators
set t(booleans) Booleans
set t(grouping) Grouping
set t(sender) Sender
set t(has) Has
set t(is) Is
set t(clear) Clear
set t(error_underlined) {There is a syntax error at the underlined word}
set t(syntax_error_exp) {Syntax error in expression}
set t(saved_expr) {Saved expressions}
set t(need_one_selected_exp) {You must select one expression}
set t(here_is_text) {Here is text encoded in}
set t(which_cant_be_shown) {which can't be shown correctly.}
set t(show_sevenbit) {Show sevenbit characters}
set t(convert_to_local_nl) {Convert to local newline conventions}
set t(startup) Startup
set t(startup_mode) {Startup mode}
set t(iconic) Iconic
set t(file) File
set t(insert_file) {Insert file}
set t(cut) Cut
set t(cut_all) {Cut all}
set t(copy) Copy
set t(copy_all) {Copy all}
set t(paste) Paste
set t(wrap_lines) {Wrap lines}
set t(run_through_command) {Run through command}
set t(undo) Undo
set t(redo) Redo
set t(failed_to_open_file) {Failed to open file}
set t(no_text_selected) {No text selected}
set t(command_failed) {Command failed}
set t(command) Command
set t(command_is_running) {Command is running}
set t(folder_key_cycle_header) {Cycle shown headers}
set t(watcher_enable) {Watcher enable}
set t(enabled) Enabled
set t(disabled) Disabled
set t(command_list) {Command list}
set t(compose_key_send) Send
set t(compose_key_abort) Abort
set t(compose_key_editor) {External editor}
set t(compose_key_undo) Undo
set t(compose_key_cut) Cut
set t(compose_key_copy) Copy
set t(compose_key_cut_all) {Cut all}
set t(compose_key_paste) Paste
set t(compose_key_replya) {Reply to all}
set t(compose_key_replyq) {Quote to sender}
set t(compose_key_replyqa) {Quote to all}
set t(compose_key_replys) {Reply to sender}
set t(compose_key_insert) {Insert file}
set t(compose_key_attach) Attach
set t(sig_cmd_failed) {RatUP_Signature failed}
set t(bell_cmd_failed) {RatUP_Bell failed}
set t(sig_cmd_takes_precedence) {You have defined a RatUP_Signature which takes precedence over the signature file!}
set t(more) More
set t(compose_sessions) {You still have at least one compose window active}
set t(really_quit) {Really quit?}
set t(do_quit) {Do quit}
set t(dont_quit) {Do not quit}
set t(use_from_address) {Use from address}
set t(use_from_fn) {Use from full name}
set t(messages_shown) {Messages shown}
set t(dbase_error) {Error in database! Run the dbase check in the Admin menu}
set t(dbase_check) {Database check}
set t(check_dbase) {Check database}
set t(check_fix_dbase) {Check & fix database}
set t(checking_dbase) {Checking database}
set t(total_num_messages) {Total number of messages in index}
set t(num_malformed) {Number of malformed entries}
set t(num_nomessages) {Number of entries without messages}
set t(num_unlinked) {Number of unlinked messages}
set t(total_size) {Total size of all messages}
set t(waiting_dbase_lock) {Waiting on database lock}
set t(port) Port
set t(already_exists) {already exists}
set t(overwrite) Overwrite
set t(append) Append
set t(file_exists) {File exists}
set t(type_description) {Type description}
set t(view) View
set t(view_as_text) {View as plain text}
set t(external_viewer) {External viewer}
set t(cant_pipe) {I can not pipe input into programs that uses the terminal window}
set t(reread_mailcap) {Reread mailcap}
set t(mailcap_path) {Mailcap path}
set t(terminal_command) {Terminal command}
set t(vfolderedit) {Edit virtual mailbox}
set t(delete_imap) {Delete the actual IMAP-mailbox as well?}
set t(dont_delete) {Do not delete}
set t(print_headers) {Print headers}
set t(print_non_text) {Print non-text message parts}
set t(selected) Selected
set t(aliases) Aliases
set t(extract_adr) {Extract addresses}
set t(address) Address
set t(could_not_find_adr) {Could not find any addresses to extract}
set t(add_aliases) {Add aliases}
set t(use) Use
set t(missing_alias_name) {Missing alias name. One entry will not be added.}
set t(alias_chooser) {Alias chooser}
set t(set_to_save_outgoing) {Set to save outgoing}
set t(unset_to_save_outgoing) {Unset to save outgoing}
set t(add) Add
set t(smtp_timeout) {SMTP timeout}
set t(no_send_bad_host) {Postilion does not know the fully qualified name your mail should be sent from!
This name can be provided in the preferences window under sending. The
variables are "Masquerade host as" and "Domain" (one of them is enough). You
will not be able to send any messages until you fix this (unless you enable the
override on the same page)}
set t(force_send) {Force send}
set t(force) Force
set t(no_force) {Do not force}
set t(on_reply) {On replies}
set t(skip_sig) {Do not include the signature}
set t(keep_sig) {Include the signature}
set t(subjectonly) {By subject}
set t(bysender) {By sender}
set t(sign) Sign
set t(encrypt) Encrypt
set t(pgp_pass_phrase) {PGP pass phrase}
set t(pgp_problem) {PGP problem}
set t(retry) Retry
set t(sig) Sig
set t(default_signature_mode) {Signature mode}
set t(signature) Signature
set t(none) None
set t(pgp_part) Part
set t(pgp_none) None
set t(pgp_unchecked) ?
set t(pgp_good) Ok
set t(pgp_bad) Bad
set t(pgp_output) {PGP output}
set t(warning_pgp_prog) {WARNING: The specified pgp program does not exist or is not executable}
set t(pgp_handling) {PGP handling}
set t(pgp_program) {PGP program}
set t(pgp_extra_args) {PGP extra arguments}
set t(decoded) Decoded
set t(send_bug) {Send bug report}
set t(short_description) {Replace with short description}
set t(bug_report_template) {[Replace this text with a detailed description of your bug. If you
get a tcl-error then be sure to include the stack trace]}
set t(configuration_information) {Description of your configuration}
set t(send_bugs_etc) {Please send bug-reports and suggestions for improvements to nic@postilion.org}
set t(send_postcards) {You can also send postcards with greetings to:

Martin Forssen
Kabelgatan 13c
414 57 Göteborg
SWEDEN}
set t(sign_outgoing) {Sign messages}
set t(encrypt_outgoing) {Encrypt messages}
set t(true) True
set t(false) False
set t(attach_pgp_keys) {Attach PGP keys}
set t(select_keys) {Select keys}
set t(bits) Bits
set t(keyid) KeyID
set t(user_id) {User ID}
set t(pgp_key_for) {PGP key for}
set t(embedded_pgp_keys) {Here are one or more PGP keys attached}
set t(add_to_keyring) {Add to keyring}
set t(press_return_to_dismiss) {Press return to dismiss window}
set t(decrypting) Decrypting...
set t(seconds) seconds
set t(days) days
set t(url_viewer) {URL viewer}
set t(userproc) Userproc
set t(netscape_cmd) {Netscape command}
set t(netscape_args) {Netscape arguments}
set t(url_color) {URL color}
set t(paper_color) {Paper color}
set t(new_msg_col) {New message color}
set t(sel_msg_col) {Selected message color}
set t(fnd_msg_col) {Found message color}
set t(flg_msg_col) {Flagged message color}
set t(del_msg_col) {Deleted message color}
set t(seen_msg_col) {Seen message color}
set t(ans_msg_col) {Answered message color}
set t(smtp_reuse) {SMTP reuse}
set t(addrbooks) {Address books}
set t(addrbook) {Address book}
set t(use_system_aliases) {Use system aliases}
set t(move_to) {Move to}
set t(set_default) {Set default}
set t(need_writable_book) {You must leave at least one writable address book}
set t(book_already_exists) {There already exists an address book with that name}
set t(pgp) PGP
set t(find) Find
set t(match) Match
set t(exact) Exact
set t(regexp) {Regular expression}
set t(find_in) {Find in}
set t(message_list) {Message list}
set t(message_body) {Message body}
set t(find_next) {Find next}
set t(colorbug) {The version of tcl/tk that you use has a bug which makes it impossible  to change the color via this option. This bug has been fixed in tcl/tk 8.0.}
set t(out_of_order) {Out of order}
set t(default_to_browse) {Default to browse mode}
set t(browse_mode) {Browse mode}
set t(default_browse_mode) {Default browse mode}
set t(no_browse) {Do not use browse mode}
set t(do_browse) {Use browse mode}
set t(use_folder_default) {Use mailbox default value}
set t(show_body) {Show body}
set t(ignore_case) {Ignore case}
set t(url_protocols) {URL protocols}
set t(prefix) {Date style mailbox prefix}
set t(spell_check) Spell
set t(balloon_help) {Balloon help}
set t(subjects) Subjects
set t(warning) Warning
set t(do_not_show_again) {Do not show this warning again}
set t(warn_tk80) {You are using tk8.0 which has a serious bug
in the menu code. This will give an error when
you try to open the mailbox menu. You should upgrade
to tk8.0p2 (or later) instead.}
set t(expunge_on_close) {Expunge on close}
set t(do) Do
set t(do_not) {Do not}
set t(pending_cut) {There is a pending cut operation, delete it?}
set t(menu_style) {Menu style}
set t(next_style) {NeXT style}
set t(ispellOnOff) {Use Ispell}
set t(ispellRecheckAfterAdd) {Re-Verify after Adds}
set t(ispellTextOnly) {Spell Check 'Text' only}
set t(ispellCommand) {Default speller invocation}
set t(ispellOthers) {Other Invocations}
set t(ispellPopupBinding) {Menu popup bound to:}
set t(ispellStyle) {Miss-spelled word style}
set t(ispellStyleColor) {color for fgcolor and bgcolor}
set t(ispellStyleOther) {Style if 'other' is selected}
set t(underline) Underline
set t(italic) Italic
set t(bold) Bold
set t(bgcolor) {Background color}
set t(fgcolor) {Foreground color}
set t(ispell) Ispell
set t(mboxvis) {Show mailbox view}
set t(drafts) Drafts
set t(new_user) {New user settings}
set t(finish) Finish
set t(set_name) {Please enter your full name
and your email address as
it should appear in your
messages.}
set t(compose_quit) {Do you wish to hold this draft, or abort it?}
set t(System) System
set t(Personal) Personal
set t(list) list
set t(hide) Hide
set t(hide-sizes) {Hide Sizes}
set t(hide-deleted) {Hide Deleted}
set t(info) Info
set t(compact) Compact
set t(incorporate-mail) {Incorporate Mail}
set t(focus) Focus
set t(unfocus) Unfocus
set t(services) Services
set t(tcl-error) {Error in Tcl Script}
set t(skip-messages) {Skip Messages}
set t(stack-trace) {Stack Trace}
set t(isp-add) Add
set t(isp-dict) {to dictionary}
set t(isp-accept) Accept
set t(isp-for) {for this session}
set t(alternate) Alternate
set t(default) Default
set t(return_path) Return-Path
set t(pgp_sign) {PGP Sign}
set t(quote_color) {Quote color}
}
