#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


proc GetLanguages {} {return " {sv Svenska iso-8859-1} 
		{en English us-ascii}
		{it Italiano iso-8859-1}
		{fr Français iso-8859-1}
		{de Deutsch iso-8859-1}
		{nl Nederlands iso-8859-1}
"}


# InitMessages --
#
# Initializes a set of messages.
#
# Arguments:
# lang -	The language if the messages
# var  -	The variable the messages are in

proc InitMessages {lang var} {
    upvar #0 currentLanguage_$var currentLanguage

    set currentLanguage $lang
    eval init_${var}_${lang}
}


