#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_t_sv {} {
global t
set t(postilion) Postilion
set t(version) Version
set t(about) Om
set t(quit) Avsluta
set t(name) Namn
set t(size) Storlek
set t(messages) Brev
set t(help) Hjälp
set t(ok) Klar
set t(cancel) Avbryt
set t(ratatosk) {Ratatosk. I nordisk mytologi, ekorren som springer upp och ner i världsträdet, Yggdrasil, bärandes förtal från draken Nidhog vid roten till örnin i dess top, och vice versa.}
set t(posthorn) {Postiljon. En beriden person som drar en vagn eller släde för att befodra post.Det var först i början av 1800-talet som vägarna blev farbara för vagnar och dessa kunde färdas genom alperna. Posthornet var ett viktigt redskap för att väcka uppmärksamhet längs de branta och vindlande vägarna. Det är posthornet som blivit symbol för Postilion. Vet du varför det brukar finnas ett posthorn på brevlådorna?\ Postilionen och hans passagerare använde små mässingshorn för att visa sin ankomst. Det blev snart obligatoriskt för postiljonen att använda den, och han behövde kunna minst åtta olika signaler - var och en med en särskild innebörd: ankomst, nöd, avfärd, och så vidare. Men det som gjorde posthornet så populärt var dess användning under flera århundraden, snarare än reglerna som krävde dess an- vändning. Idag är posthornet postens emblem i många länder.}
set t(months) {Jan Feb Mar Apr Maj Jun Jul Aug Sep Okt Nov Dec}
set t(clock_format) Tidsformat
set t(12_hour) {12 timmar}
set t(24_hour) {24 timmar}
set t(move) Flytta
set t(delete) Radera
set t(undelete) {Ångra radering}
set t(compose) {Nytt brev}
set t(reply_quote_sender) {Svara citerat}
set t(reply_quote_all) {Svara till alla citerat}
set t(quote) {Citera ursprungligt brev}
set t(no_quote) {Citera inte ursprungligt brev}
set t(reply_sender) {Svara ociterat}
set t(reply_all) {Svara alla ociterat}
set t(here_is) {Här är ett objekt av typen}
set t(show_all) {Visa allt}
set t(old_dirs) {Tidigare använda}
set t(save_to_file) {Spara till fil}
set t(save_failed) {Skrivningen misslyckades}
set t(message) Brev
set t(print) {Skriv ut}
set t(show_all_headers) {Visa alla huvudrader}
set t(show_selected_headers) {Visa valda huvudrader}
set t(show_no_headers) {Visa inga huvudrader}
set t(compose_name) {Skriva brev}
set t(edit) Redigera
set t(edit_body) Brödtexten
set t(edit_headers) Huvudfält
set t(custom_headers) {Custom headers}
set t(read_from_file) {Läs brödtext från fil}
set t(abort) Avbryt
set t(headers) Huvudfält
set t(attachments) Bilagor
set t(attach_file) {Lägg till fil}
set t(attach) {Lägg till}
set t(attach_special) {Lägg till special}
set t(detach) {Ta bort}
set t(send) Skicka
set t(send_save) {Skicka & Spara}
set t(hold) Lagra
set t(getheld) {Komponera lagrat}
set t(external_editor) {Extern editor}
set t(running_ext_editor) {Texten redigeras i en extern editor...}
set t(filename) Filnamn
set t(description) Beskrivning
set t(disposition) Disposition
set t(id) Identifierare
set t(type) Typ
set t(subtype) Undertyp
set t(encoding) Kodning
set t(current_encoding) {Nuvarande kodning}
set t(other) annat
set t(custom_type) {Egen typ}
set t(need_to) {Du måste ange minst en mottagare (To:)}
set t(no_subject) {Inget ämne}
set t(admin) Administration
set t(newedit_folder) {Ny/Ändra mapp}
set t(update_folder) {Uppdatera mapp}
set t(sync_folder) {Synkronisera mapp}
set t(update) {Uppdatera mapp}
set t(sync) {Synkronisera mapp}
set t(continue) Fortsätt
set t(open_file) {Öppna fil}
set t(open) Öppna
set t(open_dbase) {Sök i databasen}
set t(folders) Mappar
set t(and) Och
set t(or) Eller
set t(not) Icke
set t(to) Till
set t(subject) Ämne
set t(keywords) Nyckelord
set t(all) Allt
set t(search) Sök
set t(emptyexp) {Tomt sökuttryck}
set t(to_file) {Till fil}
set t(to_dbase) {Till databasen}
set t(insert_into_dbase) {Lägg till i databasen}
set t(exdate) Expireringsdag
set t(extype) Expireringsåtgärd
set t(remove) {Ta bort}
set t(add_incoming) {Lägg till inkommande}
set t(backup) {Flytta till arkiv}
set t(insert) {Lägg till}
set t(already_vfolderdef) {Det finns redan ett mappredigeringsfönster}
set t(vfolderdef) {Definiera virtuell mapp}
set t(window) Fönster
set t(close) Stäng
set t(browser) Browser
set t(folder) Mapp
set t(new_file) {Ny filmapp}
set t(new_mh) {Ny mh-mapp}
set t(new_dbase) {Ny databasmapp}
set t(new_imap) {Ny IMAP mapp}
set t(new_pop3) {Ny POP3 mapp}
set t(new_dynamic) {Ny dynamisk mapp}
set t(new_folder) {Ny mapp}
set t(need_name) {Du måste ange ett namn}
set t(create_submenu) {Skapa undermeny}
set t(folder_name) Mappnamn
set t(submenu_not_empty) {Vill du verkligen radera den här menyn och alla dess barn?}
set t(need_postilion_dir_title) {Skapa en katalog?}
set t(need_postilion_dir1) {Detta program behöver en katalog för sina konfigureringsfiler }
set t(need_postilion_dir2) {Den kommer nu att skapas.}
set t(create) Skapa
set t(dont_create) {Skapa inte}
set t(failed_create) {Misslyckades skapa katalogen}
set t(do_without_dir) {Jag skall försöka att klara mig utan det, men vissa operationer kan misslyckas.}
set t(hold_message) {Spara brev}
set t(hold_failed) {Misslyckades med att spara brevet}
set t(no_held) {Det finns inga sparade brev}
set t(must_select) {Du måste välja ett brev}
set t(error_in_userproc) {Misslyckades med att läsa dina egendefinierade procedurer}
set t(translate_error) {RatUP_Translate genererar ett felaktigt svar vid följande indata}
set t(reread_userproc) {Uppdatera userproc}
set t(preferences) Inställningar
set t(watcher) Väktare
set t(folderwindow) Mappfönster
set t(general) Huvudinställningar
set t(appearance) Utseende
set t(sending) {Skicka brev}
set t(under_construction) Byggarbetsplats
set t(language) Språk
set t(show_changes) Ändringsmeddelanden
set t(start_win) {Visa fönster}
set t(show) Visa
set t(dont_show) {Visa inte}
set t(dbase_dir) Databaskatalog
set t(apply) Applicera
set t(reset) Återställ
set t(unapplied_changes_title) {Oapplicerade ändringar}
set t(unapplied_changes) {Du har gjort ändringar som du inte har applicerat. Vad vill du göra med dem}
set t(discard) {Kasta bort}
set t(print_command) Utskriftskommando
set t(tmp_dir) {Temporär katalog}
set t(file_permissions) Filrättigheter
set t(userproc_file) {Userproc fil}
set t(hold_dir) Lagringskatalog
set t(window_name) Fönstertitel
set t(window_geometry) Fönsterplacering
set t(icon_name) Ikonnamn
set t(default_folder) Startmapp
set t(default_list_format_mode) Listformatläge
set t(list_format) Listformat
set t(show_header_selection) {Valda huvudfält}
set t(show_headers) {Visa huvudfält}
set t(default_sort_order_mode) Sorteringsordningsläge
set t(sort_order) Sorteringsordning
set t(natural_order) {Naturlig ordning}
set t(reverse_natural_order) {Omvänd naturlig ordning}
set t(by_date) Datumordning
set t(reverse_date) {Omvänd datumordning}
set t(intervals) Tidsintervall
set t(stdfolders) Standardmappar
set t(dbase_folders) Databasmappar
set t(width) Bredd
set t(lines) Rader
set t(font) Typsnitt
set t(bell_ringings) Klockringningar
set t(show_messages) {Visa brev}
set t(new) Nya
set t(reply_lead) Citering
set t(signature_file) Signaturfil
set t(masquerade_host_as) {Maskera datorn som}
set t(domain) Domän
set t(smtp_hosts) {SMTP server}
set t(charset) Teckenset
set t(attribution) Källhänvisning
set t(forwarded_label) {Vidareskickat markering}
set t(alias) Alias
set t(fullname) {Långt namn}
set t(content) Innehåll
set t(need_alias_and_content) {Jag behöver både ett alias och innehåll}
set t(reread_aliases) {Uppdatera alias}
set t(dismiss) Stäng
set t(save) Spara
set t(save_out) {Spara avsänt}
set t(save_to) {Spara till}
set t(create_vfolder) {Skapa vfolder}
set t(dont_save) {Spara inte}
set t(found_aliases) {Jag tittade i dina gamla filer och hittade}
set t(num_aliases) alias
set t(see_log) {Se gamla meddelanden}
set t(seelog_title) {Gamla meddelanden}
set t(does_not_exist) {finns inte}
set t(no_folder) {Ingen öppen folder}
set t(already_login) {Det kör redan en login-process. Kör färdigt den först}
set t(login) Login
set t(opening) Öppnar
set t(mailbox_on) {brevlåda på}
set t(mailbox) Brevlåda
set t(mailboxes) Brevlådor
set t(host) Server
set t(user) Användare
set t(passwd) Lösenord
set t(mbox) {Brevlådans namn}
set t(reply_to_which) {Det här brevet innehåller inbäddade brev.
Välj vilket du vill svara på}
set t(forward_which) {Det här brevet innehåller inbäddade brev.
Välj vilket du vill skicka vidare}
set t(forwarded_message) {Vidareskickat brev}
set t(forward_as_attachment) {Skicka vidare som bilaga}
set t(forward_inline) {Skicka vidare inbäddat}
set t(forward) {Skicka vidare}
set t(bounce) Studsa
set t(empty_message) {Tomt brev}
set t(structure) Struktur
set t(view_source) {Visa källkod}
set t(source) Källkod
set t(help_window) Hjälpfönster
set t(site) Adress
set t(access-type) Åtkomsttyp
set t(directory) Katalog
set t(server) Server
set t(smtp) SMTP
set t(user_program) {Användardefinierat program}
set t(sendprot) {Skicka via}
set t(sendprog) Sändprogram
set t(progin) Programindata
set t(eightbit) Åttabitarsdata
set t(sevenbit) {endast sjubitarsdata}
set t(subject_by_date) {Ämne och tid}
set t(import) Importera
set t(import_directory) {Importera katalog}
set t(cant_read) {Kan ej läsa}
set t(ignored_not_file_not_dir) {ignoreras eftersom den varken är en fil eller en katalog.}
set t(bounce_which) {Det här brevet innehåller inbäddade brev.
Välj vilket du vill studsa}
set t(lookup_name) {Leta upp namn}
set t(do_lookup) {Leta upp}
set t(dont_lookup) {Leta inte upp}
set t(dbase) Databasen
set t(dbase_backup) Arkivkatalogen
set t(expire_interval) Expireringsintervall
set t(do_expire) {Expirerar databasen}
set t(expire) Expirera
set t(expire_result) Expireringsresultat
set t(scanned) Genomsökta
set t(deleted) Raderade
set t(backedup) {Flyttade till backup}
set t(inbox) {Flyttade till inbox}
set t(db_expire) {Expirerar databasen}
set t(packing_backup) {Komprimerar arkiverade kopior}
set t(chunksize) Blockstorlek
set t(default_start_selection_mode) {Välj vid mappöppningsläge}
set t(start_selection) {Välj vid mappöppning}
set t(first_message) {Första brevet i mappen}
set t(last_message) {Sista brevet i mappen}
set t(first_new_message) {Första olästa brev i mappen}
set t(before_first_new_message) {Brevet före det första olästa}
set t(notifications) Kvittenser
set t(notification) Kvittens
set t(failed) Misslyckades
set t(delayed) Försenat
set t(delivered) Levererat
set t(relayed) Vidareskickat
set t(expanded) Expanderat
set t(dsn_text_failed) {Ditt brev till %s (%s) kom inte fram}
set t(dsn_text_delayed) {Ditt brev till %s (%s) har blivit försenat}
set t(dsn_text_delivered) {Ditt brev till %s (%s) har kommit fram}
set t(dsn_text_relayed) {Ditt brev till %s (%s) har blivit vidareskickat}
set t(dsn_text_expanded) {Ditt brev till %s (%s) har blivit expanderat}
set t(see_more_of_message) {Se mera av det returnerade brevet}
set t(original-envelope-id) {Originalkuvertets ID}
set t(reporting-mta) {Raporterande MTA}
set t(dsn-gateway) {DSN brygga}
set t(received-from-mta) {Mottaget från MTA}
set t(arrival-date) Ankomsttid
set t(original-recipient) {Ursprunglig mottagare}
set t(final-recipient) {Slutgiltig mottagare}
set t(action) Åtgärd
set t(status) Status
set t(remote-mta) {Slutgiltig MTA}
set t(diagnostic-code) {Diagnostisk kod}
set t(last-attempt-date) {Sista försökets tid}
set t(final-log-id) {Slutgilitig logg ID}
set t(will-retry-until) {Kommer att försöka igen till}
set t(log_timeout) {Status intervall}
set t(extra) Extra
set t(request_notification) {Begär kvittens}
set t(dsn_directory) {DSN katalog}
set t(default_action) Standardåtgärd
set t(request_dsn) {Begär kvittens}
set t(not_request_dsn) {Begär inte kvittens}
set t(not_snarf_dsn) {Visa kvittenser i brevlistan}
set t(snarf_dsn) {Visa inte kvittenser i brevlistan}
set t(dsn_expiration) Expireringstid
set t(report_level) Rapporteringsnivå
set t(rl_none) {Håll tyst}
set t(rl_status) {Visa i statusraden}
set t(rl_notify) {Visa i separat fönster}
set t(cc) Kopia
set t(bcc) Blind-kopia
set t(content_description) Innehållsbeskrivning
set t(reply_to) Svara-till
set t(bounce_to) {Studsa till}
set t(reply) Svara
set t(comments) Kommentarer
set t(comment) Kommentar
set t(default_from_mode) Frånläge
set t(from) Från
set t(date) Datum
set t(received) Mottaget
set t(message-id) Meddelande-Id
set t(mime-version) MIME-version
set t(content-type) Innehåll
set t(auto-submitted) Automatgenererat
set t(default_reply_to_mode) {Standard Svara-Till läge}
set t(default_reply_to_addr) {Standard Svara-Till Adress}
set t(default_reply_to_fn) {Standard Svara-Till Långt namn}
set t(default_reply_to) {Standard Svara-Till}
set t(probe) Testa
set t(dsn_need_smtp) {Du måste använda SMTP till att skicka brev för att kunna begära kvittenser}
set t(probing) testar
set t(supports_dsn) {stöder kvittenser}
set t(no_dsn_support) {inget stöd för kvittenser}
set t(character_size) Teckenstorlek
set t(need_restart) {Du måste starta om Postilion för att dina ändringar skall nå full effekt.}
set t(opening_folder) {Öppnar mapp}
set t(read) Läs
set t(write) Skriv
set t(exec) Kör
set t(perm_user) Användare
set t(perm_group) Grupp
set t(perm_other) Andra
set t(mode) Läge
set t(all_read) {Alla läs}
set t(all_read_write) {Alla läs & skriv}
set t(max_height) {Max höjd}
set t(insert_failed) {Misslyckades att lägga in brevet}
set t(define_keys) {Definiera tangenter}
set t(folder_key_find) Sök
set t(folder_key_compose) {Nytt brev}
set t(folder_key_quit) Avsluta
set t(folder_key_nextu) {Nästa olästa}
set t(folder_key_sync) Synkronisera
set t(folder_key_update) Uppdatera
set t(folder_key_delete) Radera
set t(folder_key_undelete) {Ångra radering}
set t(folder_key_flag) {Markera brev}
set t(folder_key_seen) {Markera som läst}
set t(folder_key_ans) {Toggle Answered flag}
set t(folder_key_next) Nästa
set t(folder_key_prev) Föregående
set t(folder_key_home) {Början av brevet}
set t(folder_key_bottom) {Slutet av brevet}
set t(folder_key_pagedown) {Sida ner}
set t(folder_key_pageup) {Sida upp}
set t(folder_key_linedown) {Rad ner}
set t(folder_key_lineup) {Rad upp}
set t(folder_key_replya) {Svara till alla}
set t(folder_key_replyq) {Svara avsändaren med citat}
set t(folder_key_replyqa) {Svara alla med citat}
set t(folder_key_replys) {Svara avsändaren}
set t(folder_key_forward_a) {Skicka vidare som bilaga}
set t(folder_key_forward_i) {Skicka vidare inbäddat}
set t(folder_key_bounce) Studsa
set t(folder_key_select_all) {Välj alla}
set t(folder_key_deselect_all) {Välj bort alla}
set t(add_key) Ny
set t(press_key) {Tryck på den nya tangenten}
set t(key_defined) {Denna tangenten är redan definierad till}
set t(replace_key) {Byt till ny definition}
set t(do_delete) {Tryck på definitionen som skall bort}
set t(netscape_steal) {Netscape verkar ha tagit dina brev. Vad skall vi göra åt det?}
set t(steal_back) {Ta tillbaka dem}
set t(nothing) Ingenting
set t(check_stolen_mail) {Leta efter tagna brev}
set t(check) Leta
set t(dont_check) {Leta inte}
set t(take_mail) {Ta brev från netscape}
set t(remember_pos) Fönstergeometri
set t(do_remember) {Kom ihåg}
set t(dont_remember) {Kom ej ihåg}
set t(import_IMAP) IMAP-mappar
set t(pattern) Mönster
set t(host_required) {Du måste ange en maskin}
set t(import_failed) {Importeringen misslyckades}
set t(warning_sendprog) {VARNING: Det specificerade sändprogrammet finns inte eller är inte körbart}
set t(automatic_wrap) {Automatisk radbrytning}
set t(automatic_indent) {Automatisk indentering}
set t(need_keyword) {Du måste ange minst ett nyckelord.}
set t(need_host_and_user) {Du måste ange både maskin och användare.}
set t(opening_connection) {Öppnar förbindelse...}
set t(wait_greeting) {Väntar på välkomnande...}
set t(get_capabilities) {Hämtar egenskaper...}
set t(send_envelope) {Skicka kuvertinformation...}
set t(send_from) {Skickar avsändare...}
set t(send_rcpt) {Skickar mottagare}
set t(send_data) {Skickar data...}
set t(wait_ack) {Väntar på sändningskvittens...}
set t(closing) {Stänger förbindelsen...}
set t(sending_message) {Skickar brevet...}
set t(smtpv) {SMTP loggning}
set t(normal) Normal
set t(verbose) Mångordig
set t(terse) Minimal
set t(import_aliases) {Importera alias}
set t(upgrade_dbase) {Uppgradera databasen}
set t(old_dbase) {Du har en gammal version av databasen. Jag måste konvertera den för att kunna använda den.}
set t(unlinked_messages) {Okända brev}
set t(unl_m1) {Det fanns}
set t(unl_m2) {okända brev i databasen. Det har flyttats till UnlinkedMessages-mappen (som är en filmapp med ~/UnlinkedMessages som fil).}
set t(send_deferred) {Skicka uppskjutna}
set t(delivery_mode) Leveranstyp
set t(direct) Direkt
set t(deferred) Uppskjuten
set t(sending_deferred) {Skicka uppskjutna brev}
set t(to_send) {Att skicka}
set t(sent) Skickade
set t(you_have) {Du har}
set t(deferred_messages) {uppskjutna brev. Vill du skicka dem nu?}
set t(deferred_message) {uppskjutet brev. Vill du skicka det nu?}
set t(send_now) {Skicka nu}
set t(no) Nej
set t(waiting_on_sender) {Väntar på den sändande processen (den sänder)...}
set t(illegal_file_spec) {Otillåten fil angiven}
set t(copy_attached_files) {Kopiera bilagor}
set t(cache_conn) {Behåll förbindelser}
set t(failed_to_create_send_cache) {Du kommer inte att kunna skicka brev eftersom jag misslykades med att skapa sändbiblioteket}
set t(mh_name) MH-namn
set t(need_mh_name) {Du måste ange ett mh-namn}
set t(failed_to_make_copy) {Misslyckades att skapa en privat kopia}
set t(color_scheme) Färgskala
set t(gray67) Grå
set t(PeachPuff2) Aprikos
set t(bisque) Emalj
set t(SlateBlue1) Blå
set t(SteelBlue4) Stålblå
set t(SkyBlue1) Ljusblå
set t(aquamarine2) Ljusgrön
set t(SpringGreen4) Grön
set t(patterns_to_use) {Möster att matcha funna objekt mot}
set t(files) Filer
set t(directories) Kataloger
set t(cache_passwd) {Kom ihåg lösenord}
set t(cache_timeout) {Kom ihåg intervall}
set t(do_cache) {Kom ihåg}
set t(do_not_cache) {Kom ej ihåg}
set t(icon_bitmap) Ikonutseende
set t(normal_bitmap) {Normal (64x64)}
set t(button_bar) {Display button bar}
set t(buttons) {Ikoner eller text på knapparna}
set t(text) Text
set t(icon) Ikon
set t(small_bitmap) {Liten (50x50)}
set t(xpm) {Image (48x48)}
set t(sync_but) Synkronisera
set t(sync_oper) Synkronisering
set t(set_to_inbox) {Sätt till inkommande}
set t(set_to_open_on_startup) {Öppna vid start}
set t(set_to_min_on_startup) {Öppna minimerad vid start}
set t(unset_to_open_on_startup) {Öppna inte vid start}
set t(unset_to_min_on_startup) {Öppna inte som minimerad vid start}
set t(group) Grupp
set t(create_in_win) {Skapa i fönster}
set t(create_by_expr) {Skapa med hjälp av uttryck}
set t(use_saved_expr) {Använd sparat uttryck}
set t(clear_group) {Ta bort gruppmarkering}
set t(select_all) {Välj alla}
set t(deselect_all) {Välj bort alla}
set t(edit_group) {Editera grupp}
set t(create_exp) {Skapa uttryck}
set t(basic_mode) Standardläge
set t(advance_on_flag) {Gå vidare vid markering}
set t(flag_ans) {Toggle the Answered flag}
set t(flag_seen) {Markera som läst}
set t(flag_unseen) {Markera som oläst}
set t(advanced_mode) {Avancerat läge}
set t(save_as) {Spara som}
set t(fields) Fält
set t(operators) Operatorer
set t(booleans) Logiska
set t(grouping) Gruppering
set t(sender) Avsändare
set t(has) Har
set t(is) Är
set t(clear) Rensa
set t(error_underlined) {Det är ett syntaxfel vid det understrukna ordet}
set t(syntax_error_exp) {Syntaxfel i uttrycket}
set t(saved_expr) {Sparade uttryck}
set t(need_one_selected_exp) {Du måste välja ett uttryck}
set t(here_is_text) {Här kommer text kodad i}
set t(which_cant_be_shown) {som inte kan visas korrekt.}
set t(show_sevenbit) {Visa sjubitarsbokstäver}
set t(convert_to_local_nl) {Konvertera till lokala radslut}
set t(startup) Start
set t(startup_mode) Startläge
set t(iconic) Ikonifierad
set t(file) Fil
set t(insert_file) {Läs in fil}
set t(cut) {Klipp ut}
set t(cut_all) {Klipp ut allt}
set t(copy) Kopiera
set t(copy_all) {Kopiera allt}
set t(paste) {Klistra in}
set t(wrap_lines) {Bryt rader}
set t(run_through_command) {Kör genom kommando}
set t(undo) Ångra
set t(redo) Upprepa
set t(failed_to_open_file) {Misslyckades att öppna filen}
set t(no_text_selected) {Ingen text vald}
set t(command_failed) {Kommandot misslyckades}
set t(command) Kommando
set t(command_is_running) {Kommandot körs}
set t(folder_key_cycle_header) {Rotera visade huvudrader}
set t(watcher_enable) {Väktare aktiv}
set t(enabled) Påslagen
set t(disabled) Avslagen
set t(command_list) Kommandolista
set t(compose_key_send) Skicka
set t(compose_key_abort) Avbryt
set t(compose_key_editor) {Extern editor}
set t(compose_key_undo) Ångra
set t(compose_key_cut) {Klipp ut}
set t(compose_key_copy) Kopiera
set t(compose_key_cut_all) {Klipp ut allt}
set t(compose_key_paste) {Klistra in}
set t(compose_key_replya) {Svara till alla}
set t(compose_key_replyq) {Svara avsändaren med citat}
set t(compose_key_replyqa) {Svara alla med citat}
set t(compose_key_replys) {Svara avsändaren}
set t(compose_key_insert) {Läs in fil}
set t(compose_key_attach) {Lägg till}
set t(sig_cmd_failed) {RatUP_Signature misslyckades}
set t(bell_cmd_failed) {RatUP_Bell misslyckades}
set t(sig_cmd_takes_precedence) {Du har definierat RatUP_Signature som har förtur över signaturfilen!}
set t(more) Mera
set t(compose_sessions) {Du har fortfarande kvar minst ett aktivt "Skriva brev"-fönster}
set t(really_quit) {Verkligen avsluta?}
set t(do_quit) Avsluta
set t(dont_quit) {Avsluta inte}
set t(use_from_address) {Använd avsändaradress}
set t(use_from_fn) {Använd avsändar Långt namn}
set t(messages_shown) {Antal visade brev}
set t(dbase_error) {Fel i databasen! Kör databaskontrollen i administrationsmenyn}
set t(dbase_check) Databaskontroll
set t(check_dbase) {Kontrollera databasen}
set t(check_fix_dbase) {Kontrollera & reparera databasen}
set t(checking_dbase) {Kontrollerar databasen}
set t(total_num_messages) {Totalt antal brev i indexet}
set t(num_malformed) {Antal ogiltiga ingångar}
set t(num_nomessages) {Antal ingångar utan tillhörande brev}
set t(num_unlinked) {Antal brev ej nämnda i index}
set t(total_size) {Sammanlagd storlek av alla brev}
set t(waiting_dbase_lock) {Väntar på databaslåset}
set t(port) Port
set t(already_exists) {finns redan}
set t(overwrite) {Skriv över}
set t(append) {Lägg till}
set t(file_exists) {Filen finns}
set t(type_description) Typbeskrivning
set t(view) Visa
set t(view_as_text) {Visa som ren text}
set t(external_viewer) {Externt program}
set t(cant_pipe) {Jag kan inte skicka data till program som använder terminalfönstret}
set t(reread_mailcap) {Läs om mailcap}
set t(mailcap_path) {Mailcap sökväg}
set t(terminal_command) Terminalkommando
set t(vfolderedit) {Redigera virtuell mappar}
set t(delete_imap) {Radera själva IMAP-mappen också?}
set t(dont_delete) {Radera inte}
set t(print_headers) {Skriv ut huvudfält}
set t(print_non_text) {Skriv ut de delar som inte är delar av texten}
set t(selected) Valda
set t(aliases) Alias
set t(extract_adr) {Extrahera adresser}
set t(address) Adress
set t(could_not_find_adr) {Kunde inte hitta några adresser att extrahera}
set t(add_aliases) {Lägg till alias}
set t(use) Använd
set t(missing_alias_name) {Saknar aliasnamn. En ingång blev inte använd.}
set t(alias_chooser) {Alias väljare}
set t(set_to_save_outgoing) {Sätt till spara utgående}
set t(unset_to_save_outgoing) {Sätt till ej spara utgående}
set t(add) {Lägg till}
set t(smtp_timeout) {SMTP svarstid}
set t(no_send_bad_host) {Postilion känner inte till det kompletta namnet som din post skall skickas
från. Detta namnet kan anges i inställningsfönstret under "Skicka brev".
Variablerna är "Skicka som" och "Domän" (det räcker med en av dem). Du
kommer inte att kunna skicka några brev innan du åtgärdar detta (så länge du
inte använder tvingafunktionen på samma sida).}
set t(force_send) {Tvinga skicka}
set t(force) Tvinga
set t(no_force) {Tvinga ej}
set t(on_reply) {Vid svar}
set t(skip_sig) {Inkludera inte signaturen}
set t(keep_sig) {Inkludera signaturen}
set t(subjectonly) {Efter ämne}
set t(bysender) {Efter avsändare}
set t(sign) Signera
set t(encrypt) Kryptera
set t(pgp_pass_phrase) {PGP lösenordssekvens}
set t(pgp_problem) {PGP problem}
set t(retry) {Försök igen}
set t(sig) Sig
set t(default_signature_mode) Signaturläge
set t(signature) Signatur
set t(none) Ingen
set t(pgp_part) Del
set t(pgp_none) Ingen
set t(pgp_unchecked) ?
set t(pgp_good) Ok
set t(pgp_bad) Fel
set t(pgp_output) {PGP utdata}
set t(warning_pgp_prog) {VARNING: Det specificerade pgpprogrammet finns inte eller är inte körbart}
set t(pgp_handling) PGPhantering
set t(pgp_program) {PGP program}
set t(pgp_extra_args) {PGP extra argument}
set t(decoded) Avkodad
set t(send_bug) {Skicka felrapport}
set t(short_description) {Skriv en kort beskrivning här}
set t(bug_report_template) {[Byt ut denna texten mot en detaljerad beskrivning av ditt problem.
Om du får ett tcl-fel så inkludera en "Stack trace" i beskrivningen]}
set t(configuration_information) {Beskrivning av din konfiguration}
set t(send_bugs_etc) {Vänligen skicka felrapporter och förslag till förbättringar till nic@postilion.org
angående den svenska översättningen: chimbis@bahnhof.se}
set t(send_postcards) {Du kan också skicka vykort med hälsningar till:

Martin Forssen
Kabelgatan 13c
414 57 Göteborg}
set t(sign_outgoing) {Signera brev}
set t(encrypt_outgoing) {Kryptera brev}
set t(true) Sant
set t(false) Falskt
set t(attach_pgp_keys) {Bifoga PGP-nycklar}
set t(select_keys) {Välj nycklar}
set t(bits) Bitar
set t(keyid) NyckelID
set t(user_id) Användarid
set t(pgp_key_for) {PGP-nyckel för}
set t(embedded_pgp_keys) {Här är en eller flera PGP-nycklar bifogade}
set t(add_to_keyring) {Lägg till i nyckelknippa}
set t(press_return_to_dismiss) {Tryck på retur för att stänga fönstret}
set t(decrypting) Dekrypterar...
set t(seconds) sekunder
set t(days) dagar
set t(url_viewer) {URL läsare}
set t(userproc) Egendefinierad
set t(netscape_cmd) {Netscape kommando}
set t(netscape_args) {Netscape argument}
set t(url_color) {URL färg}
set t(paper_color) Pappersfärg
set t(new_msg_col) {Färg på nya brev}
set t(sel_msg_col) {Färg på valda brev}
set t(fnd_msg_col) {Färg på funna brev}
set t(flg_msg_col) {Färg på markerade brev}
set t(del_msg_col) {Färg på raderade brev}
set t(seen_msg_col) {Färg på lästa brev}
set t(ans_msg_col) {Färg på besvarade brev}
set t(smtp_reuse) {SMTP återanvänd}
set t(addrbooks) Adressböcker
set t(addrbook) Adressbok
set t(use_system_aliases) {Använd systemets alias}
set t(move_to) {Flytta till}
set t(set_default) {Ange som standard}
set t(need_writable_book) {Du måste spara minst en skrivbar adressbok}
set t(book_already_exists) {Det finns redan en adressbook med det namnet}
set t(pgp) PGP
set t(find) Sök
set t(match) Matcha
set t(exact) Exakt
set t(regexp) Reguljäruttryck
set t(find_in) {Sök i}
set t(message_list) Brevlista
set t(message_body) {Brevets innehåll}
set t(find_next) {Sök nästa}
set t(colorbug) {Den version av tcl/tk som du använder har en bug som gör det omöjligt  att ändra färgen med denna inställning. Denna bug är fixad i tcl/tk 8.0}
set t(out_of_order) {Ur funktion}
set t(default_to_browse) {Använd titta-läge i normalfallet}
set t(browse_mode) Titta-läge
set t(default_browse_mode) {Normalt titta-läge}
set t(no_browse) {Använd inte titta-läge}
set t(do_browse) {Använd titta-läge}
set t(use_folder_default) {Använd mappens standardvärde}
set t(show_body) {Visa texten}
set t(ignore_case) {Ignorera bokstavsstorlek}
set t(url_protocols) {URL protokoll}
set t(prefix) {Datumtyp för mapp-prefix}
set t(spell_check) Stava
set t(balloon_help) Ballonghjälp
set t(subjects) Ämnen
set t(warning) Varning
set t(do_not_show_again) {Visa inte denna varning nästa gång}
set t(warn_tk80) {Du använder tk8.0 som har en allvarlig bug i
meny-koden. Detta kommer att ge ett felmeddelande
när du försöker öppna mapp-menyn. Uppgradera till
version 8.0p2 (eller senare) istället.}
set t(expunge_on_close) {Radera vid stängning}
set t(do) Gör
set t(do_not) {Gör inte}
set t(pending_cut) {Det finns en planerad 'klipp ut data' operation, vill du avbryta den?}
set t(menu_style) Menystil
set t(next_style) {NeXT stil}
set t(ispellOnOff) {Använd Ispell}
set t(ispellRecheckAfterAdd) {Verifiera igen efter tillägg}
set t(ispellTextOnly) {Rättstavning enbart av text}
set t(ispellCommand) {Standardanrop till rättstavningsprogram}
set t(ispellOthers) {Andra anrop}
set t(ispellPopupBinding) {Popupmenyn knuten till:}
set t(ispellStyle) {Markering av felstavade ord}
set t(ispellStyleColor) {Text- och bakgrundsfärger}
set t(ispellStyleOther) {Markering om 'andra' används}
set t(underline) Understruket
set t(italic) Kursiverat
set t(bold) Fet
set t(bgcolor) Bakgrundsfärg
set t(fgcolor) Textfärg
set t(ispell) Stavningskontroll
set t(mboxvis) {Visa brevlådor}
set t(drafts) Kladd
set t(new_user) {New user settings}
set t(finish) Avslutar
set t(set_name) {Please enter your full name
and your email address as
it should appear in your
messages.}
set t(compose_quit) {Do you wish to hold this draft, or abort it?}
set t(System) Systemets
set t(Personal) Personal
set t(list) list
set t(hide) Hide
set t(hide-sizes) {Hide Sizes}
set t(hide-deleted) {Hide Deleted}
set t(info) Info
set t(compact) Compact
set t(incorporate-mail) {Incorporate Mail}
set t(focus) Focus
set t(unfocus) Unfocus
set t(services) Services
set t(tcl-error) {Error in Tcl Script}
set t(skip-messages) {Skip Messages}
set t(stack-trace) {Stack Trace}
set t(isp-add) Add
set t(isp-dict) {to dictionary}
set t(isp-accept) Accept
set t(isp-for) {for this session}
set t(alternate) Alternate
set t(default) Default
set t(return_path) Return-Path
set t(pgp_sign) {PGP Sign}
set t(quote_color) {Quote color}
}
