#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_t_nl {} {
global t
set t(postilion) Postilion
set t(version) Versie
set t(about) Over
set t(quit) Verlaat
set t(name) Naam
set t(size) Grootte
set t(messages) Berichten
set t(help) Hulp
set t(ok) Ok
set t(cancel) Annuleren
set t(ratatosk) {Ratatosk. In de Noorse mythologie de eekhoorn die op en neer rent door de kosmische wereldboom, Yggdrasil, terwijl hij krachttermen van de draak Nidhog aan de voet van de boom naar de arend in de kroon brengt en vice versa.}
set t(posthorn) {Postillion. Een persoon die op een aangespannen paard rijdt om een rijtuig te begeleiden.
Pas in het begin van de negentiende eeuw waren de wegen in de Alpenpassen begaanbaar voor koetsen. De posthoorn was een onmisbaar instrument voor de postillion om zijn aanwezigheid kenbaar te maken op de stijle, bochtige wegen. De posthoorn is het gele symbool in het ikoon voor Postilion.
Weet u waarom een posthoorn op brievenbussen wordt afgebeeld? Herauten en postillions gebruikten een kleine koperen hoorn om hun komst kenbaar te maken. Gebruik van de hoorn was al snel verplicht en de postillion moest tenminste acht verschillende signalen kennen met elk hun aparte betekenis:  aankomst, nood, vertrek, enzovoorts. Maar wat de hoorn zo populair maakte  was niet het feit dat hij was voorgeschreven, maar het voortdurende gebruik door de diverse eeuwen heen. De posthoorn is vandaag de dag het postembleem van vele landen.}
set t(months) {Jan Feb Mrt Apr Mei Jun Jul Aug Sep Okt Nov Dec}
set t(clock_format) Tijdsweergave
set t(12_hour) {12 uurs}
set t(24_hour) {24 uurs}
set t(move) Verplaatsen
set t(delete) Verwijderen
set t(undelete) {Annuleer verwijdering}
set t(compose) {Nieuw bericht}
set t(reply_quote_sender) {Citeer bericht aan afzender}
set t(reply_quote_all) {Citeer bericht aan allen}
set t(quote) {Citeer oorspronkelijke bericht}
set t(no_quote) {Citeer oorspronkelijke bericht niet}
set t(reply_sender) {Antwoord afzender}
set t(reply_all) {Antwoord aan allen}
set t(here_is) {Hier is een object van type}
set t(show_all) {Toon alles}
set t(old_dirs) {Eerder gebruikt}
set t(save_to_file) {Sla op in bestand}
set t(save_failed) {Opslaan mislukt}
set t(message) Bericht
set t(print) Afdrukken
set t(show_all_headers) {Toon briefhoofd}
set t(show_selected_headers) {Toon beperkt briefhoofd}
set t(show_no_headers) {Toon geen briefhoofd}
set t(compose_name) {Maak nieuw bericht}
set t(edit) Wijzigen
set t(edit_body) Berichttekst
set t(edit_headers) Briefhoofd
set t(custom_headers) {Briefhoofd op maat}
set t(read_from_file) {Lees bericht van bestand}
set t(abort) Annuleer
set t(headers) Briefhoofd
set t(attachments) Bijlagen
set t(attach_file) {Voeg bestand toe}
set t(attach) Bijlage
set t(attach_special) {Speciale bijlage}
set t(detach) Verwijder
set t(send) Verstuur
set t(send_save) {Verstuur & Sla op}
set t(hold) Onderbreken
set t(getheld) {Continueer onderbroken bericht}
set t(external_editor) {Externe editor}
set t(running_ext_editor) {Start externe editor...}
set t(filename) Bestandsnaam
set t(description) Omschrijving
set t(disposition) Dispositie
set t(id) Label
set t(type) Type
set t(subtype) Subtype
set t(encoding) Codering
set t(current_encoding) {Huidige codering}
set t(other) anders
set t(custom_type) {Eigen type}
set t(need_to) {U dient tenminste één ontvanger op te geven (Aan:)}
set t(no_subject) {Geen onderwerp}
set t(admin) Beheer
set t(newedit_folder) {Maak/wijzig postbus}
set t(update_folder) {Werk postbus bij}
set t(sync_folder) {Synchroniseer postbus}
set t(update) {Werk postbus bij}
set t(sync) {Synchroniseer postbus}
set t(continue) Doorgaan
set t(open_file) {Open bestand}
set t(open) Open
set t(open_dbase) {Zoek in database}
set t(folders) Postbussen
set t(and) En
set t(or) Of
set t(not) Niet
set t(to) Aan
set t(subject) Onderwerp
set t(keywords) Sleutelwoorden
set t(all) Alle
set t(search) Zoek
set t(emptyexp) {Lege zoekterm}
set t(to_file) {Naar bestand}
set t(to_dbase) {Naar database}
set t(insert_into_dbase) {Voeg toe aan database}
set t(exdate) Vervaldatum
set t(extype) Vervalaktie
set t(remove) Verwijder
set t(add_incoming) {Voeg toe aan inkomend}
set t(backup) {Verplaats naar archief}
set t(insert) Tussenvoegen
set t(already_vfolderdef) {Er is al een wijzigingsvenster voor een postbus}
set t(vfolderdef) {Definieer virtuele postbus}
set t(window) Venster
set t(close) Sluiten
set t(browser) Berichtenvenster
set t(folder) Postbus
set t(new_file) {Nieuwe bestandspostbus}
set t(new_mh) {Nieuwe MH postbus}
set t(new_dbase) {Nieuwe database}
set t(new_imap) {Nieuwe IMAP postbus}
set t(new_pop3) {Nieuwe POP3 postbus}
set t(new_dynamic) {Nieuwe dynamische postbus}
set t(new_folder) {Nieuwe postbus}
set t(need_name) {U moet een naam opgeven}
set t(create_submenu) {Maak submenu}
set t(folder_name) Postbusnaam
set t(submenu_not_empty) {Wilt u echt dit menu met inhoud en al verwijderen?}
set t(need_postilion_dir_title) {Directory maken?}
set t(need_postilion_dir1) {Dit programma heeft een configuratie-directory nodig }
set t(need_postilion_dir2) {Deze wordt nu gemaakt.}
set t(create) Maak
set t(dont_create) {Maak niet}
set t(failed_create) {Directory maken mislukt}
set t(do_without_dir) {Ik zal proberen om het zonder te doen, maar wees gewaarschuwd dat sommige akties kunnen mislukken}
set t(hold_message) {Onderbreek bericht}
set t(hold_failed) {Onderbreken van bericht mislukt}
set t(no_held) {Er is geen onderbroken post}
set t(must_select) {U moet een bericht selecteren}
set t(error_in_userproc) {Er was een fout in het userproc bestand}
set t(translate_error) {RatUP_Translate produceerde foutieve uitvoer voor de volgende invoer}
set t(reread_userproc) {Herlees userproc}
set t(preferences) Voorkeuren
set t(watcher) Monitor
set t(folderwindow) Postbussenvenster
set t(general) Algemeen
set t(appearance) Uiterlijk
set t(sending) Verzenden
set t(under_construction) {Werk in uitvoering}
set t(language) Taal
set t(show_changes) Mutatieberichten
set t(start_win) {Toon vensters}
set t(show) Toon
set t(dont_show) Verberg
set t(dbase_dir) {Database directory}
set t(apply) Toepassen
set t(reset) Herstel
set t(unapplied_changes_title) {Niet toegepaste wijzigingen}
set t(unapplied_changes) {U heeft wijzigingen gemaakt die niet toegepast zijn. Wat wilt u daarmee doen}
set t(discard) Negeren
set t(print_command) Afdrukopdracht
set t(tmp_dir) {Directory voor tijdelijke bestanden}
set t(file_permissions) Bestandspermissies
set t(userproc_file) {Userproc bestand}
set t(hold_dir) {Directory voor onderbroken post}
set t(window_name) Vensternaam
set t(window_geometry) Vensterplaatsing
set t(icon_name) Ikoonnaam
set t(default_folder) {Standaard postbus}
set t(default_list_format_mode) Lijstweergavemodus
set t(list_format) Lijstformaat
set t(show_header_selection) {Beperkt briefhoofd}
set t(show_headers) {Toon briefhoofd}
set t(default_sort_order_mode) {Sorteervolgorde instelling}
set t(sort_order) Sorteervolgorde
set t(natural_order) {Natuurlijke volgorde}
set t(reverse_natural_order) {Omgekeerd natuurlijke volgorde}
set t(by_date) {Op datum}
set t(reverse_date) {Aflopend op datum}
set t(intervals) Interval
set t(stdfolders) {Standaard postbussen}
set t(dbase_folders) Database
set t(width) Breedte
set t(lines) Regels
set t(font) Lettertype
set t(bell_ringings) {Aantal alarmbellen}
set t(show_messages) {Toon post}
set t(new) Nieuw
set t(reply_lead) Citaatintro
set t(signature_file) {Bestand met ondertekening}
set t(masquerade_host_as) {Maskeer machine als}
set t(domain) Domein
set t(smtp_hosts) {SMTP server}
set t(charset) Karakterset
set t(attribution) Attributie
set t(forwarded_label) Doorgestuurd-etiket
set t(alias) Pseudoniem
set t(fullname) {Volledige naam}
set t(content) Inhoud
set t(need_alias_and_content) {Ik heb zowel een pseudoniem als een inhoud nodig}
set t(reread_aliases) {Herlees pseudoniemen}
set t(dismiss) Verdwijn
set t(save) Opslaan
set t(save_out) {Sla uitgaande op}
set t(save_to) {Sla op als}
set t(create_vfolder) {Maak virtuele postbus}
set t(dont_save) {Sla niet op}
set t(found_aliases) {Ik bekeek uw oude bestanden en vond een totaal van}
set t(num_aliases) pseudoniemen
set t(see_log) {Zie oude post}
set t(seelog_title) {Oude post}
set t(does_not_exist) {bestaat niet}
set t(no_folder) {Geen geopende postbus}
set t(already_login) {Er loopt al een ander aanmeldproces. Voltooi die eerst}
set t(login) Aanmelden
set t(opening) Openen
set t(mailbox_on) {Postbus op}
set t(mailbox) Postbus
set t(mailboxes) Postbussen
set t(host) Server
set t(user) Gebruiker
set t(passwd) Wachtwoord
set t(mbox) Postbusnaam
set t(reply_to_which) {Dit bericht bevat ingesloten post.
Geef aan welk bericht u wilt beantwoorden}
set t(forward_which) {Dit bericht bevat ingesloten post.
Geef aan welk bericht u wilt doorsturen}
set t(forwarded_message) {Doorgestuurd bericht}
set t(forward_as_attachment) {Doorsturen als bijlage}
set t(forward_inline) {Doorsturen ingesloten}
set t(forward) Doorsturen
set t(bounce) Kaatsen
set t(empty_message) {Leeg bericht}
set t(structure) Struktuur
set t(view_source) {Bekijk broncode}
set t(source) Bron
set t(help_window) Helpvenster
set t(site) Adres
set t(access-type) Toegangstype
set t(directory) Folder
set t(server) Server
set t(smtp) SMTP
set t(user_program) {Door gebruiker opgegeven programma}
set t(sendprot) {Stuur via}
set t(sendprog) Verzendprogramma
set t(progin) Programma-invoer
set t(eightbit) {Achtbits data}
set t(sevenbit) {Alleen zevenbits data}
set t(subject_by_date) {Op onderwerp, daarbinnen op datum}
set t(import) Importeer
set t(import_directory) {Importeer folder}
set t(cant_read) {Kan niet lezen}
set t(ignored_not_file_not_dir) {wordt genegeerd; het is noch een bestand, noch een folder}
set t(bounce_which) {Dit bericht bevat ingesloten post.
Geef aan welk bericht u wilt kaatsen}
set t(lookup_name) {Zoek op naam}
set t(do_lookup) Zoek
set t(dont_lookup) {Zoek niet}
set t(dbase) Database
set t(dbase_backup) Archieffolder
set t(expire_interval) Verloopinterval
set t(do_expire) {Laat database verlopen}
set t(expire) Opschonen
set t(expire_result) Verloopresultaten
set t(scanned) Bekeken
set t(deleted) Verwijderd
set t(backedup) {Verplaatst naar archief}
set t(inbox) {Verplaatst naar "in" postbus}
set t(db_expire) {Verloop database}
set t(packing_backup) {Comprimeer archiefbestanden}
set t(chunksize) Blokgrootte
set t(default_start_selection_mode) {Selecteer bij openen modus}
set t(start_selection) {Selecteer bij openen}
set t(first_message) {Eerste bericht in postbus}
set t(last_message) {Laatste bericht in postbus}
set t(first_new_message) {Eerste ongelezen bericht in postbus}
set t(before_first_new_message) {Het bericht voor het eerste ongelezen-}
set t(notifications) Kennisgevingen
set t(notification) Kennisgeving
set t(failed) Mislukt
set t(delayed) Vertraagd
set t(delivered) Afgeleverd
set t(relayed) Doorgestuurd
set t(expanded) Uitgebreid
set t(dsn_text_failed) {Uw bericht aan %s (%s) is niet aangekomen.}
set t(dsn_text_delayed) {Uw bericht aan %s (%s) is vertraagd.}
set t(dsn_text_delivered) {Uw bericht aan %s (%s) is afgeleverd.}
set t(dsn_text_relayed) {Uw bericht aan %s (%s) is doorgestuurd.}
set t(dsn_text_expanded) {Uw bericht aan %s (%s) is uitgebreid.}
set t(see_more_of_message) {Bekijk meer van teruggekomen bericht}
set t(original-envelope-id) {Oorspronkelijke envelopreferentie}
set t(reporting-mta) {Rapporteer MTA}
set t(dsn-gateway) {DSN gateway}
set t(received-from-mta) {Ontvangen van MTA}
set t(arrival-date) Aankomstdatum
set t(original-recipient) {Oorspronkelijke geadresseerde}
set t(final-recipient) {Uiteindelijke geadresseerde}
set t(action) Aktie
set t(status) Status
set t(remote-mta) {Afgelegen MTA}
set t(diagnostic-code) Diagnosecode
set t(last-attempt-date) {Laatst geprobeerde datum}
set t(final-log-id) {Uiteindelijk logreferentie}
set t(will-retry-until) {Blijf proberen tot}
set t(log_timeout) {Status interval (timeout)}
set t(extra) Extra
set t(request_notification) Ontvangstbevestiging
set t(dsn_directory) {DSN folder}
set t(default_action) {Standaard aktie}
set t(request_dsn) {Vraag kennisgeving}
set t(not_request_dsn) {Vraag geen kennisgeving}
set t(not_snarf_dsn) {Toon onvangstbevestigingen in postlijst}
set t(snarf_dsn) {Toon onvangstbevestigingen niet in postlijst}
set t(dsn_expiration) Verlooptijd
set t(report_level) Rapporteringsniveau
set t(rl_none) {Zeg niets}
set t(rl_status) {Toon in statusregel}
set t(rl_notify) {Toon in apart venster}
set t(cc) Kopie
set t(bcc) {Blinde kopie}
set t(content_description) Inhoudsomschrijving
set t(reply_to) {Antwoord aan}
set t(bounce_to) {Kaatsen naar}
set t(reply) Antwoord
set t(comments) Commentaar
set t(comment) Commentaar
set t(default_from_mode) {Afzender modus}
set t(from) Van
set t(date) Datum
set t(received) Ontvangen
set t(message-id) Bericht-Id
set t(mime-version) MIME-versie
set t(content-type) Inhouds-Type
set t(auto-submitted) Automatisch-Verzonden
set t(default_reply_to_mode) {Standaard Antwoord-Aan modus}
set t(default_reply_to_addr) {Default Reply-To Address}
set t(default_reply_to_fn) {Default Reply-To full name}
set t(default_reply_to) {Standaard Antwoord-Aan}
set t(probe) Sonde
set t(dsn_need_smtp) {Voor het verzenden met kennisgeving moet u SMTP gebuiken}
set t(probing) sonderen
set t(supports_dsn) {Ondersteunt kennisgevingen}
set t(no_dsn_support) {Geen ondersteuning voor kennisgevingen}
set t(character_size) Tekengrootte
set t(need_restart) {Postilion moet herstart worden om uw wijzigingen te effectueren.}
set t(opening_folder) {Open postbus}
set t(read) Lezen
set t(write) Schrijven
set t(exec) Uitvoeren
set t(perm_user) Gebruiker
set t(perm_group) Groep
set t(perm_other) Anderen
set t(mode) Modus
set t(all_read) {Allen lezen}
set t(all_read_write) {Allen lezen & schrijven}
set t(max_height) {Maximum hoogte}
set t(insert_failed) {Bericht tussenvoegen mislukt}
set t(define_keys) {Definieer toesten}
set t(folder_key_find) Zoek
set t(folder_key_compose) {Nieuw bericht}
set t(folder_key_quit) Verlaat
set t(folder_key_nextu) {Volgende ongelezen}
set t(folder_key_sync) Synchroniseer
set t(folder_key_update) Bijwerken
set t(folder_key_delete) Verwijder
set t(folder_key_undelete) {Annuleer verwijder}
set t(folder_key_flag) {Markeer bericht}
set t(folder_key_seen) {Markeer gelezen}
set t(folder_key_ans) {Markeer beantwoord}
set t(folder_key_next) Volgende
set t(folder_key_prev) Vorige
set t(folder_key_home) {Begin van bericht}
set t(folder_key_bottom) {Einde van bericht}
set t(folder_key_pagedown) {Volgende pagina}
set t(folder_key_pageup) {Vorige pagina}
set t(folder_key_linedown) {Volgende regel}
set t(folder_key_lineup) {Vorige regel}
set t(folder_key_replya) {Antwoord aan allen}
set t(folder_key_replyq) {Citeer aan afzender}
set t(folder_key_replyqa) {Citeer aan allen}
set t(folder_key_replys) {Antwoord afzender}
set t(folder_key_forward_a) {Stuur door als bijlage}
set t(folder_key_forward_i) {Stuur door in bericht}
set t(folder_key_bounce) Kaats
set t(folder_key_select_all) {Selecteer alles}
set t(folder_key_deselect_all) {Annuleer selectie}
set t(add_key) Toevoegen
set t(press_key) {Druk op de nieuwe toets}
set t(key_defined) {Deze toets is al gedefinieerd als}
set t(replace_key) {Vervang door de nieuwe definitie}
set t(do_delete) {Druk op de gedefinieerde toets voor verwijderen}
set t(netscape_steal) {Netscape heeft ogenschijnlijk enige post overgenomen. Wat zullen we hieraan doen?}
set t(steal_back) {Haal ze terug}
set t(nothing) Niets
set t(check_stolen_mail) {Controleer voor overgenomen post}
set t(check) Controleer
set t(dont_check) {Controleer niet}
set t(take_mail) {Neem post over van Netscape}
set t(remember_pos) Venstergeometrie
set t(do_remember) Onthoud
set t(dont_remember) Vergeet
set t(import_IMAP) {IMAP postbussen}
set t(pattern) Patroon
set t(host_required) {U moet een server opgeven}
set t(import_failed) {Import mislukt}
set t(warning_sendprog) {WAARSCHUWING: Het opgegeven verzendprogramma bestaat niet of is niet uitvoerbaar}
set t(automatic_wrap) {Automatisch regels afbreken}
set t(automatic_indent) {Automatisch inspringen}
set t(need_keyword) {U moet tenminste één sleutelwoord opgeven.}
set t(need_host_and_user) {U moet zowel server als gebruiker opgeven.}
set t(opening_connection) {Open verbinding...}
set t(wait_greeting) {Wacht op servergroet...}
set t(get_capabilities) {Lees servereigenschappen...}
set t(send_envelope) {Stuur envelopinfo...}
set t(send_from) {Stuur afzender...}
set t(send_rcpt) {Stuur geadresseerde...}
set t(send_data) {Stuur data...}
set t(wait_ack) {Wacht op bevestiging...}
set t(closing) {Sluit verbinding...}
set t(sending_message) {Stuur bericht...}
set t(smtpv) {SMTP boodschappen}
set t(normal) Normaal
set t(verbose) Uitvoerig
set t(terse) Beperkt
set t(import_aliases) {Importeer pseudoniemen}
set t(upgrade_dbase) {Werk database bij}
set t(old_dbase) {U heeft een oude versie van de database. Ik moet deze converteren om hem te kunnen gebruiken}
set t(unlinked_messages) {Losse berichten}
set t(unl_m1) {Er waren}
set t(unl_m2) {losse berichten in de database. Deze kunnen gevonden worden in het bakje 'Losse Berichten' (wat een bestandsmap is met ~/UnlinkedMessages als bestandsnaam)}
set t(send_deferred) {Verstuur in bulk}
set t(delivery_mode) Verzendmodus
set t(direct) Direkt
set t(deferred) Bulksgewijs
set t(sending_deferred) {Verstuur gebufferde berichten}
set t(to_send) {Te versturen}
set t(sent) Verzonden
set t(you_have) {U hebt}
set t(deferred_messages) {gebufferde berichten. Wilt u deze nu verzenden?}
set t(deferred_message) {gebufferd berichten. Wilt u deze nu verzenden?}
set t(send_now) {Verstuur nu}
set t(no) Nee
set t(waiting_on_sender) {Wacht op verzendproces (het is aan het verzenden)...}
set t(illegal_file_spec) {Foutief bestand opgegeven}
set t(copy_attached_files) {Kopieer bijgevoegde bestanden}
set t(cache_conn) {Buffer verbindingen}
set t(failed_to_create_send_cache) {U zult niet in staat zijn berichten te versturen aangezien ik de verzendbuffer niet kon aanmaken}
set t(mh_name) MH-naam
set t(need_mh_name) {U moet een mh-naam opgeven}
set t(failed_to_make_copy) {Maken van lokale kopie mislukt}
set t(color_scheme) Kleurenpalet
set t(gray67) Grijs
set t(PeachPuff2) Perzik
set t(bisque) Oranjegeel
set t(SlateBlue1) Blauw
set t(SteelBlue4) Staalblauw
set t(SkyBlue1) Hemelsblauw
set t(aquamarine2) Lichtgroen
set t(SpringGreen4) Groen
set t(patterns_to_use) {Patronen om gevonden objecten mee te vergelijken}
set t(files) Bestanden
set t(directories) Directories
set t(cache_passwd) {Buffer wachtwoorden}
set t(cache_timeout) {Verlooptijd buffer}
set t(do_cache) Buffer
set t(do_not_cache) {Buffer niet}
set t(icon_bitmap) Ikoon
set t(normal_bitmap) {Normaal (64x64)}
set t(button_bar) {Toon knoppenbalk}
set t(buttons) {Ikonen of tekst voor knoppen}
set t(text) Tekst
set t(icon) Ikoon
set t(small_bitmap) {Klein (50x50)}
set t(xpm) {Afbeelding (48x48)}
set t(sync_but) Synchroniseer
set t(sync_oper) {Synchronisatieknop werking}
set t(set_to_inbox) {Stel in als 'inkomend'}
set t(set_to_open_on_startup) {Openen bij starten}
set t(set_to_min_on_startup) {Open geminimaliseerd bij starten}
set t(unset_to_open_on_startup) {Niet openen bij starten}
set t(unset_to_min_on_startup) {Niet geminimaliseerd openen bij starten}
set t(group) Groep
set t(create_in_win) {Maak in venster}
set t(create_by_expr) {Maak m.b.v. zoekterm}
set t(use_saved_expr) {Gebruik opgeslagen zoekterm}
set t(clear_group) {Annuleer groepsselectie}
set t(select_all) {Selecteer alles}
set t(deselect_all) {Annuleer selectie}
set t(edit_group) {Wijzig groep}
set t(create_exp) {Maak zoekterm}
set t(basic_mode) {Standaard modus}
set t(advance_on_flag) {Ga verder na markeren}
set t(flag_ans) {(De)markeer als Beantwoord}
set t(flag_seen) {(De)markeer als Gelezen}
set t(flag_unseen) {Markeer als niet-gelezen}
set t(advanced_mode) {Uitgebreide modus}
set t(save_as) {Sla op als}
set t(fields) Velden
set t(operators) Operatoren
set t(booleans) Booleaans
set t(grouping) Groepering
set t(sender) Afzender
set t(has) Heeft
set t(is) Is
set t(clear) Afbreken
set t(error_underlined) {Er is een syntaxfout bij het onderstreepte woord}
set t(syntax_error_exp) {Syntaxfout in zoekterm}
set t(saved_expr) {Opgeslagen zoektermen}
set t(need_one_selected_exp) {U moet een zoekterm selecteren}
set t(here_is_text) {Nu volgt tekst gecodeerd volgens}
set t(which_cant_be_shown) {wat hier niet correct kan worden getoond.}
set t(show_sevenbit) {Toon zevenbits tekens}
set t(convert_to_local_nl) {Converteer naar lokale regeleinde conventies}
set t(startup) Start
set t(startup_mode) Startmodus
set t(iconic) {Als ikoon}
set t(file) Bestand
set t(insert_file) {Voeg bestand toe}
set t(cut) Knip
set t(cut_all) {Knip alles}
set t(copy) Kopieer
set t(copy_all) {Kopieer alles}
set t(paste) Plak
set t(wrap_lines) {Breek regels af}
set t(run_through_command) {Filter door opdracht}
set t(undo) Herstel
set t(redo) {Opnieuw uitvoeren}
set t(failed_to_open_file) {Openen van bestand mislukt}
set t(no_text_selected) {Geen tekst geselecteerd}
set t(command_failed) {Opdracht mislukt}
set t(command) Opdracht
set t(command_is_running) {Opdracht wordt uitgevoerd}
set t(folder_key_cycle_header) {Roteer getoond briefhoofd}
set t(watcher_enable) {Monitor aan}
set t(enabled) Geactiveerd
set t(disabled) Gedeactiveerd
set t(command_list) Opdrachtenlijst
set t(compose_key_send) Verstuur
set t(compose_key_abort) Annuleer
set t(compose_key_editor) {Externe editor}
set t(compose_key_undo) Herstel
set t(compose_key_cut) Knip
set t(compose_key_copy) Kopieer
set t(compose_key_cut_all) {Knip alles}
set t(compose_key_paste) Plak
set t(compose_key_replya) {Antwoord aan allen}
set t(compose_key_replyq) {Citeer aan afzender}
set t(compose_key_replyqa) {Citeer aan allen}
set t(compose_key_replys) {Antwoord aan afzender}
set t(compose_key_insert) {Insert file}
set t(compose_key_attach) {Lees bestand in}
set t(sig_cmd_failed) {RatUP_Signature ging fout}
set t(bell_cmd_failed) {RatUP_Bell ging fout}
set t(sig_cmd_takes_precedence) {U heeft een RatUP_Signature gedefinieerd. Deze heeft voorrang op het signature bestand!}
set t(more) Meer
set t(compose_sessions) {U heeft nog tenminste één 'nieuw bericht'-venster open}
set t(really_quit) {Echt einde?}
set t(do_quit) Einde
set t(dont_quit) {Nee, doorgaan}
set t(use_from_address) {Use from address}
set t(use_from_fn) {Gebruik afzenderadres}
set t(messages_shown) {Aantal getoonde berichten}
set t(dbase_error) {Fout in database! Kies 'Database controle' in het Beheermenu}
set t(dbase_check) {Database controle}
set t(check_dbase) {Controleer database}
set t(check_fix_dbase) {Controleer & herstel database}
set t(checking_dbase) {Controleer database}
set t(total_num_messages) {Totaal aantal berichten in index}
set t(num_malformed) {Aantal beschadigde ingangen}
set t(num_nomessages) {Aantal ingangen zonder berichten}
set t(num_unlinked) {Aantal 'losse' berichten}
set t(total_size) {Totale grootte van alle berichten}
set t(waiting_dbase_lock) {Wacht op database-slot}
set t(port) Poort
set t(already_exists) {bestaat al}
set t(overwrite) Overschrijf
set t(append) {Voeg toe}
set t(file_exists) {Bestand bestaat al}
set t(type_description) {Type beschrijving}
set t(view) Bekijk
set t(view_as_text) {Bekijk als klare tekst}
set t(external_viewer) {Extern programma}
set t(cant_pipe) {Ik kan geen invoer sturen naar programma's die van een terminalvenster gebruik maken}
set t(reread_mailcap) {Herlees mailcap}
set t(mailcap_path) {Mailcap pad}
set t(terminal_command) {Opdracht voor terminal}
set t(vfolderedit) {Wijzig virtuele postbus}
set t(delete_imap) {Zal ik de achterliggende IMAP postbus ook verwijderen?}
set t(dont_delete) {Niet verwijderen}
set t(print_headers) {Druk briefhoofd af}
set t(print_non_text) {Druk de niet-tekst delen af}
set t(selected) Geselecteerd
set t(aliases) Pseudoniemen
set t(extract_adr) {Extraheer adressen}
set t(address) Adres
set t(could_not_find_adr) {Kon geen te extraheren adressen vinden}
set t(add_aliases) {Voeg pseudoniemen toe}
set t(use) Gebruik
set t(missing_alias_name) {Pseudoniem ontbreekt. Eén ingang zal niet toegevoegd worden.}
set t(alias_chooser) Pseudoniemenkiezer
set t(set_to_save_outgoing) {Aktiveer voor bewaren uitgaande post}
set t(unset_to_save_outgoing) {Deaktiveer voor bewaren uitgaande post}
set t(add) {Voeg toe}
set t(smtp_timeout) {SMTP wachttijd}
set t(no_send_bad_host) {Postilion kent niet uw volledige afzenderadres! Dit adres kan opgegeven worden in het voorkeurenvenster onder Verzenden. De variabelen zijn 'Maskeer server als' en 'Domein' (één van beide is toereikend). U zult niet in staat zijn berichten te versturen totdat u dit geregeld heeft (tenzij u het 'overschrijven' aktiveert op dezelfde pagina)}
set t(force_send) {Geforceerd verzenden}
set t(force) Forceer
set t(no_force) {Niet forceren}
set t(on_reply) {Bij beantwoorden}
set t(skip_sig) {Voeg de ondertekening niet toe}
set t(keep_sig) {Voeg de ondertekening toe}
set t(subjectonly) {Op onderwerp}
set t(bysender) {Op afzender}
set t(sign) Onderteken
set t(encrypt) Vercijfer
set t(pgp_pass_phrase) {PGP wachtwoordtekst}
set t(pgp_problem) {PGP probleem}
set t(retry) Opnieuw
set t(sig) Sig
set t(default_signature_mode) Ondertekeningsmodus
set t(signature) Ondertekening
set t(none) Niets
set t(pgp_part) Deel
set t(pgp_none) Niets
set t(pgp_unchecked) ?
set t(pgp_good) Ok
set t(pgp_bad) Fout
set t(pgp_output) {PGP resultaat}
set t(warning_pgp_prog) {WAARSCHUWING: Het opgegeven pgp programma bestaat niet of is niet uitvoerbaar}
set t(pgp_handling) {PGP gebruik}
set t(pgp_program) {PGP programma}
set t(pgp_extra_args) {PGP extra argumenten}
set t(decoded) Ontcijfer
set t(send_bug) {Stuur storingsrapport}
set t(short_description) {Vervang door korte omschrijving}
set t(bug_report_template) {[Vervang deze tekst met een gedetailleerde omschrijving van uw storing.
Als u een tcl-fout krijgt, stuur dan de stack trace mee.]}
set t(configuration_information) {Beschrijving van uw configuratie}
set t(send_bugs_etc) {Zend u alstublieft storingsrapporten en suggesties ter verbetering aan nic@postilion.orq}
set t(send_postcards) {You can also send postcards with greetings to:

Martin Forssen
Kabelgatan 13c
414 57 Göteborg
SWEDEN}
set t(sign_outgoing) {Onderteken berichten}
set t(encrypt_outgoing) {Vercijfer berichten}
set t(true) Ja
set t(false) Nee
set t(attach_pgp_keys) {Voeg PGP sleutels toe}
set t(select_keys) {Kies sleutel}
set t(bits) Bits
set t(keyid) {Sleutel Id}
set t(user_id) {Gebruikers Id}
set t(pgp_key_for) {PGP-sleutel voor}
set t(embedded_pgp_keys) {Hier zijn één of meer PGP-sleutels bijgevoegd}
set t(add_to_keyring) {Voeg toe aan sleutelbos}
set t(press_return_to_dismiss) {Druk op return om venster te verlaten}
set t(decrypting) Ontcijferen...
set t(seconds) seconden
set t(days) dagen
set t(url_viewer) {URL browser}
set t(userproc) {Eigen procedure}
set t(netscape_cmd) {Netscape's commando}
set t(netscape_args) {Netscape's argumenten}
set t(url_color) {URL kleur}
set t(paper_color) Papierkleur
set t(new_msg_col) {Kleur van nieuw bericht}
set t(sel_msg_col) {Kleur van geselecteerd bericht}
set t(fnd_msg_col) {Kleur van gevonden bericht}
set t(flg_msg_col) {Kleur van gemarkeerd bericht}
set t(del_msg_col) {Kleur van verwijderd bericht}
set t(seen_msg_col) {Kleur van gelezen bericht}
set t(ans_msg_col) {Kleur van beantwoord bericht}
set t(smtp_reuse) {SMTP hergebruik}
set t(addrbooks) Adresboeken
set t(addrbook) Adresboek
set t(use_system_aliases) {Gebruik systeem pseudoniemen}
set t(move_to) {Verplaats naar}
set t(set_default) {Stel standaard}
set t(need_writable_book) {U moet tenminste één schrijfbaar adresboek overlaten}
set t(book_already_exists) {Er bestaat al een adresboek met die naam}
set t(pgp) PGP
set t(find) Zoek
set t(match) Vergelijk
set t(exact) Precies
set t(regexp) {Reguliere expressie}
set t(find_in) {Zoek in}
set t(message_list) Berichtenlijst
set t(message_body) Berichttekst
set t(find_next) {Zoek volgende}
set t(colorbug) {De versie van tcl/tk die u gebruikt heeft een bug die het onmogelijk maakt
om de kleur via deze optie te wijzigen. Deze bug is verwijderd uit tcl/tk 8.0.}
set t(out_of_order) {Buiten gebruik}
set t(default_to_browse) {Standaard in bladerenmodus}
set t(browse_mode) Bladermodus
set t(default_browse_mode) {Standaard bladerenmodus}
set t(no_browse) {Gebruik geen bladerenmodus}
set t(do_browse) {Gebruik bladerenmodus}
set t(use_folder_default) {Gebruik waarde van postbus}
set t(show_body) {Toon tekst}
set t(ignore_case) {Negeer hoofd-/kleine letters}
set t(url_protocols) {URL protocol}
set t(prefix) {Datumtype voor bestandsprefix}
set t(spell_check) Spelling
set t(balloon_help) Ballonhelp
set t(subjects) Onderwerpen
set t(warning) Waarschuwing
set t(do_not_show_again) {Toon deze waarschuwing niet opnieuw}
set t(warn_tk80) {U gebruikt tk8.0 die een ernstige fout in de menu code heeft.
Dit zal een fout veroorzaken bij het openen van het postbussen menu.
U zou in plaats daarvan moeten opwaarderen tot tk8.0p2 (of later).}
set t(expunge_on_close) {Opschonen bij sluiten}
set t(do) Ja
set t(do_not) Nee
set t(pending_cut) {Er is nog een uitstaande knipaktie. Verwijderen?}
set t(menu_style) Menustijl
set t(next_style) {NeXT stijl}
set t(ispellOnOff) {Gebruik Ispell}
set t(ispellRecheckAfterAdd) {Controleer opnieuw na toevoegingen}
set t(ispellTextOnly) {Controleer alleen tekst}
set t(ispellCommand) {Standaard aanroep spellingsprogramma}
set t(ispellOthers) {Andere aanroepen}
set t(ispellPopupBinding) {Popupmenu verbonden aan}
set t(ispellStyle) {Stijl foutief gespeld woord}
set t(ispellStyleColor) {Voor- en achtergrondkleur}
set t(ispellStyleOther) {Stijl als 'anders' is gekozen}
set t(underline) Onderstreept
set t(italic) Cursief
set t(bold) Vet
set t(bgcolor) Achtergrondkleur
set t(fgcolor) Voorgrondkleur
set t(ispell) Spellingscontrole
set t(mboxvis) {Toon postbussen}
set t(drafts) Kladversies
set t(new_user) {New user settings}
set t(finish) Finish
set t(set_name) {Please enter your full name
and your email address as
it should appear in your
messages.}
set t(compose_quit) {Wilt u dit bericht onderbreken of annuleren?}
set t(System) System
set t(Personal) Personal
set t(list) list
set t(hide) Verberg
set t(hide-sizes) {Verberg Groottes}
set t(hide-deleted) {Verberg Verwijderde}
set t(info) Informatie
set t(compact) Comprimeer
set t(incorporate-mail) {Sluit Post In}
set t(focus) Inzoomen
set t(unfocus) Uitzoomen
set t(services) Diensten
set t(tcl-error) {Error in Tcl Script}
set t(skip-messages) {Skip Messages}
set t(stack-trace) {Stack Trace}
set t(isp-add) Add
set t(isp-dict) {to dictionary}
set t(isp-accept) Accept
set t(isp-for) {for this session}
set t(alternate) Alternate
set t(default) Default
set t(return_path) Return-Path
set t(pgp_sign) {PGP Sign}
set t(quote_color) {Quote color}
}
