#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_help_en {} {
global help
set help(title,intro) Introduction
set help(intro) {                        Help system for Postilion


If you do not know how to use the help system press the word "Help on Help"
to the right of this text.


  Overview

Postilion is a Mail User Agent (MUA) which is meant for reading, sending and
managing electronic mail.

The main window of Postilion is the folder window. This is the window that appears
when you start Postilion. At the top of this window is a menu bar and a line which
describes the current folder. Below that is a listing of the messages in the
folder, you can select messages in this list with the mouse to see the
individual message below. Below the folder listing comes a message line and a
row of buttons. Below that is the content of the current message shown.
For more information on the folder window select "Folder Window" from the
list of subtopics.

Before you can send a message you must first compose (i.e. write) it.
There are multiple ways to reach the compose window. If you want to create
a new message you should press the compose button. If you wish to reply
to the current message you should press one of the reply buttons.
For more information on sending message select "Composing messages" from the
list of subtopics.

By default the folder window shows your INBOX, that is the folder where your
incoming mail is placed. When you have read (and perhaps replied to) a message
you might want to save it somewhere else (so as to not clutter up your
INBOX). This is done by moving the message to another folder. There are
many different types of folders with different properties. Select "Folders"
from the list of subtopics to read more on folders.

If a new message arrives when the program is iconified a small watcher
window pops up. Select the "Watcher" subitem to read more about this window.

Postilion is a very complex program. And although I have tried to make it easy to
use the complexity shows in the number of different things you can customize.
All the different options should have reasonable defaults, but if you feel
that you have to change something it can help to  check the "Preferences"
subtopic.


  More information

Information about the latest version etc. can be found at the following URL:

 http://www.postilion.org
}
set help(title,deleting) {Deleting messages}
set help(deleting) {				Deleting messages

Deletion of messages is a two step process. First the messages are marked
for deletion, and then at some later time the marked messages are actually
removed from the folder.

Messages marked for deletion are indicated by a 'D' next to them in the list
of messages. To mark the current message for deletion simply press the
"Delete" button. You can do all the usual operations on a message marked for
deletion since the message is not actually deleted yet.

You can remove the deletion mark from the current message by selecting
"Undelete" in the message menu.

The actual deletion of the marked messages occur whenever you synchronize the
folder (via "Synchronize folder" in the Admin menu) or when you close the
folder (opening another folder causes the current folder to be closed, as
does quitting Postilion).
}
set help(title,grouping) {Grouping messages}
set help(grouping) {				Grouping messages

Grouping messages is a convenient way of doing the same operation on multiple
messages in just one step (after the group is created).

The current group always consists of all flagged messages in the current folder.
Flagged messages are indicated by an 'F' in the list of messages (this F is
actually a part of the status flags so if you do not have %S in you list format
you will not see it). Messages may keep their flagged status next time they 
are accessed.

Currently you can do the following operations on a group (must be done via
the group menu):
  * Delete	- Mark messages for deletion
  * Undelete	- Remove deletion mark from messages
  * Move	- Move messages to another folder

There are currently four different ways to add/remove messages from a group:

  * Use the "Clear group marking" entry in the Group menu
    This will remove all group markings in the current folder

  * Press the right mousebutton on a message in the message list
    This will toggle the group flag for that message.

  * Use the "Create in window..." entry in the Group menu
    This will create a separate window which contains a list of all messages
    in the current folder and you can select/deselect messages in it. Finally
    when you press the Ok button your selection will become the group selection.

  * Use the "Create by expression..." entry in the Group menu
    This opens an window where you can give an expression and will then 
    add all messages in the current folder that matches that expression
    to the current group. See the "Expression window" subtopic for more
    information about this window.

  * Use the "Use saved expression" submenu in the Group menu. This menu
    contains entries for each expression you have saved earlier.
}
set help(title,folders) Folders
set help(folders) {                            Folders

A folder is a collection (zero or more) of messages. There are a lot of
different ways of storing and accessing the messages in a folder. Postilion
currently understands four different types of folders.

To open a folder you need to know which type it is, and some more type-
specific data about it. To help you Postilion has something called
virtual folders (also known as vfolders). When you define a vfolder you
have to specify a name, type and all other data about the folder. This
name will then appear in the "Folders" and "Move" menus for easy selection
and message insertion.

  The following types of folders are supported

* Unix mailbox
  A unix mailbox consists of a flat text-file where the messages are separated
  by a certain marker line (which starts with "From " or "^A^A^A"). This is the
  normal way of handling mail on UNIX systems.
  Data needed: the name of the file

* IMAP4
  IMAP (version 4) is a protocol for accessing mailboxes over a network.
  One user can have multiple imap-mailboxes on one host.
  Data needed: the name of the server
	       which user to access the folder as
	       a password (asked for when opening the folder).
	       the name of the mailbox

* POP3
  POP (version 3) is a protocol for accessing mailboxes over a network.
  Each user can have a maximum of one POP-mailbox on one host.
  Data needed: the name of the server
	       which user to access the folder as
	       a password (asked for when opening the folder).

* Database
  A database folder is a collection of messages where each message has
  keywords associated with it. Opening the database is equivalent to
  searching it (you can search more things than the keywords). Messages
  can also have an expiration time, and when this time is reached something
  happens to the message (it may for example be deleted). Each user can have
  one database each (you can only access your own database).
  Data needed: a search expression
	       expiration time and type (for insertion)

* Dynamic
  This is a special form of the file folder. It is specified as a directory
  and when you insert messages into it the message is actually placed in
  a filefolder in that directory. The name of the filefolder is the first
  part of the sender mail address. When you open a dynamic folder you will
  get a list of the files in that directory.
  Data needed: the name of the directory.
}
set help(title,folderdef) {Defining vfolders}
set help(folderdef) {				Defining vfolders

Postilion lets you organize your folders in a tree-like structure. The structure is
analogous with a normal filesystem. Postilion uses menus as directories and folders
instead of files. This structure is the used to build the Folders and Move
menus. When you call "New/Edit folder" the vfolderdef window will appear. This
window lets you see the whole structure (or at least as much as fits on the
screen). The menus/directories are the boxes and folders are represented by
their names. Relations between directories are symbolized by lines. The root
of the tree is the folder in the upper left corner. One folder is marked
with an '*', this is the default inbox folder. There migth be one folder that
is marked with an '>', this is the folder that outgoing messages get saved in.

In the menu-bar there is a menu which lets you create new folders and menus.
Folders/menus created via this menu are placed in the root menu.

When yu press the left mousebutton on an entry you will get a menu which
lets you modify the current entry or add new entries at that location in the
menu structure.

To move things around you use the right mousebutton. Press this button while
over an item and keep it pressed. You can now drag the item around and thus
move it to another menu, you drop it by releasing the mousebutton. You can
move both menus and folders this way.

If you already have a structure of folders in the filesystem Postilion can read
this and build the corresponding vfolder definitions automatically. To do
this select "Import directory" from the import menu. You can also import
folder structures from an IMAP server.

To close the window select close from the window menu.
}
set help(title,dbase) {The database}
set help(dbase) {				The database

The database is a place for storing messages. Each message is associated with
a number of keywords and an expiration time (can be eternity).

When you insert a message into the database you can give the following
information to be associated with it:
  * keywords		- an optional list of keywords
  * expiration time	- a time when the message expires from the database.
			  The time is given as a plus sign and a number and
			  the number is the number of days it should remain in
			  the database. The filed may be blank and then the
			  message never expires.
  * expiration action	- what to do when the message expires. The possible
			  actions are:
	* Remove   - delete the message.
	* Incoming - move the message to the incoming folder again.
	* Backup   - move the message to some backup format.
	* Custom   - give the message to a custom program.

When you want to fetch messages from the database you can search the
following fields: to, from, cc, subject, keywords and the entire message.
You can get messages which matches all criterias or just one.
}
set help(title,notification) Notifications
set help(notification) {				Notifications

	About notifications

Notifications (the technical term is Delivery Status Notifications (DSN)) lets
you know when your message has been delivered to the recipients mailbox. DSN
works on SMTP level so you must use SMTP to send your messages, and since it
is an extension to the protocol not all SMTP servers support it. There is a
probe button in the preferences window which lets you test if your system
supports DSN. All systems on the route to the recipient must also support
DSN for it to work.

	The Notifications window

The notifications window contains a list of all messages for which a
notification was requested that has been sent within the last seven days
(the time is configurable). Each message is listed with the date of sending,
subject and all recipients. In front of each recipient is the current status
shown. There are six different statuses possible:

-	  - Means that Postilion do not know anything about this recipient yet..
Failed	  - The messages did not reach this recipient.
Delivered - The message has been successfully delivered. This does NOT in
	    any way imply that the recipient has even seen the message yet.
Relayed	  - The message has been forwarded to some agent (MTA) which does not
	    support notifications.
Expanded  - The message has been delivered, but the destination was an alias
	    which expanded to one or more different address(es). Further
	    notifications will arrive.
Delayed	  - The message has not yet reached this recipient but further
	    attempts to deliver it will be done.

You can get more information about any notification by pointing at the
recipient line and pressing the right mousebutton. This will pop up the
notification window which shows one notification in greater detail.

	The Notification window

The notification window contains one scrollable text part. This part will
show a text that should be readable by a human being and describes what
caused this notification. Below that are fields which will help the more
knowledgeable person to determine exactly what went wrong (or right). The
"See more of returned message" will add more text in the text part. The new
text will be the portions of the original message that was returned in this
notification.

For more technical information about notifications see the approporiate
rfc's (currently 1891, 1893 and 1894).
}
set help(title,userproc) Userprocs
set help(userproc) {			User defined procedures

User defined procedures is a way for the user to have more control over
certain features. The procedures are ordinary tcl procedures (i.e. they are
written in tcl7.5). None of the procedures must exist, they will be used
only if they exists.

The user may define procedures in the ~/.ratatosk/userproc file (or
whatever the userproc option is set to). If the procedures need any global
variables these must start with "ratUP_". The following procedures may
be defined:

RatUP_IsMe mailbox domain personal adl
        mailbox  -      Mailbox name
        domain   -      The domain part
        personal -      The personal name phrase (if any)
        adl      -      At-domain-list source route
    This procedure should determine if the address is pointing to me or not.
    It should return a boolean value, which should be true if the address
    is pointing at me.

RatUP_Translate mailbox domain personal adl
        mailbox  -      Mailbox name
        domain   -      The domain part
        personal -      The personal name phrase (if any)
        adl      -      At-domain-list source route (probably empty)
    When we are replying to a message all addresses we are sending it to
    are run through this procedure. It is expected to return a list with
    four elements {mailbox domain personal adl}.

RatUP_Signature message
        message -       The handler for the message the signature will be
                        appended to
    This function should return a text string which will later be
    appended to the first text part of the message. The message argument is
    an handler which can be used to get information about the message (see
    the interface file for more information). Note that this routine gets
    called before the user has had any chance to edit the message so there
    will not be any interesting information available at all for new messages.
    It only contains interesting things for replies and forwards.

RatUP_Bell
    This function should notify the user that new mail has arrived. If
    this function does not exist then the terminal bell is rung.

RatUP_ShowURL url
        url -   An URL to show
    This function may get called when the user presses the left mousebutton
    over an URL in a message. It is expected to invoke a browser (in the
    background).
}
set help(title,bugreport) {Reporting bugs}
set help(bugreport) {				Reporting bugs

You should send bug reports to maf@dtek.chalmers.se. This is best done by
selecting "Send bug report..." in the Help menu (of the folder window).
This will open a compose window with a template bug report. The recipient
is already filled in as is part of the subject. You should complete the
subject and write a detailed description of what you did to create the bug
(and the bug itself) in the body of the message.

Postilion has already added an attachment which contains information about your
configuration. This attachment contains the output from "uname -a" on your
system, Postilion version number and date, tcl/tk version used and a copy of
all the settings in the preferences window.

If you wish to look exactly what is sent then it is stored in a file with
a name like ~/.ratatosk/send/rat.X.Y (it is most probably the last file).
This file gets created when you start "Send bug report..." and gets deleted
when the report is sent.
}
}
