#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_balText_it {} {
global balText
set balText(list_of_messages) {List of messages in the current mailbox.
You can use the mouse buttons as follows:

    left click   - Show the message
    double left  - (in browse mode) show message body 
		   (The message body is fetched)
    right button - Flag or unflag the message (add or
		   remove it from `the group' of other
		   flagged messages}
set balText(current_folder_name) {Name of the current mailbox}
set balText(current_folder_size) {Total size in bytes of current mailbox}
set balText(current_folder_nummsg) {Number of messages in the current mailbox}
set balText(status_text) {Messaggi da Postilion}
set balText(move_msg) {Questo menu salva una copia del messaggio corrente
nella cartella specificata e contrassegnera' il messaggio 
per la rimozione}
set balText(delete_msg) {Contrassegna il messaggio corrente per la rimozione}
set balText(compose_msg) {Componi un nuovo messaggio}
set balText(compose_menu) {This menu contains commands that are
useful when writing a message}
set balText(mailbox_menu) {This menu contains commands which
operate on a mailbox(s)}
set balText(window_menu) {This menu contains tools for inspecting your
address book, mailboxes, and old searches}
set balText(edit_menu) {This menu helps you to edit
the message you are writing}
set balText(format_menu) {This menu helps you to adjust the format
(layout) of a message you are writing}
set balText(print_menu) {Opens a dialog box for printing a
message or the grouped messages.
(Use the right mouse button or the Group
menu, to group or ungroup messages.)}
set balText(vd_open) {Open the selected mailbox in a new window}
set balText(vd_cut) {Cut the selected mailbox from the list.  It
can be pasted elsewhere in the list with the
paste command.}
set balText(vd_paste) {Paste a previously-cut mailbox into
the list, above this location}
set balText(spell) {Open a spell check session for
this message}
set balText(clear_addr) {Click here with the left mouse button
to clear all selections in this window}
set balText(reply_to_all) {Spedisci una risposta a tutti i destinatari e 
i mittenti del messaggio corrente}
set balText(reply_to_sender) {Spedisci una risposta al mittente del messaggio corrente}
set balText(no_sig) {Significa che il messaggio corrente non è firmato}
set balText(unchecked_sig) {Significa che il messaggio è firmato ma la firma
non è ancora stata verificata. Premere il tasto sinistro
per verificarla}
set balText(good_sig) {La firma del messaggio è accettata}
set balText(bad_sig) {La firma NON verifica il contenuto del messaggio}
set balText(part_sig) {Solo una parte del messaggio è firmata}
set balText(send_deferred) {Manda tutti i messaggi differiti. Il numero in
parentesi indica il numero di messaggi differiti}
set balText(show_notifications) {Apre una finestra che mostra le notifiche}
set balText(watcher_enable) {Abilita o disabilita la finestra di controllo}
set balText(reread_aliases) {Rilegge tutti i file di alias}
set balText(reread_userproc) {Rilegge il file userproc}
set balText(import_aliases) {Cerca in alcuni posti standard per file alias
di altri programmi di posta e li legge}
set balText(reread_mailcap) {Rilegge i file mailcap}
set balText(take_mail) {Cerca messaggi che Netscape ha preso dalla
inbox e li riporta nella cartella inbox}
set balText(check_dbase) {Controlla che il database Postilion non contenga errori}
set balText(check_fix_dbase) {Controlla il database Postilion e, se trova errori, fa
del suo meglio per ripararli}
set balText(see_log) {Mostra la lista dei messaggi generati internamente da Postilion}
set balText(quit) {Termina Postilion}
set balText(folder_menu) {Questo menu mostra una lista delle cartelle. E'
possibile selezionare qualsiasi cartella per vederne
il contenuto}
set balText(message_menu) {Questo menu contiene operazioni che si
possono effettuare sui messaggi}
set balText(clock) {This shows the time, date and day when the
message was sent (in local time here).
Click on teh clock with the left mouse button
as a shortcut to the Preferences window.}
set balText(mailboxes) {Opens a new window which lets you select, create
and edit your mailboxes.  You can also move a selected
message (or the grouped messages) to a selected mailbox.}
set balText(next_msg) {Selects the next message in the list.}
set balText(prev_msg) {Selects the previous message in the list.}
set balText(find) {Mostra una finestra che permette di cercare nella 
lista dei messaggi o nel messaggio corrente}
set balText(compose) {Componi un nuovo messaggio}
set balText(reply_sender) {Rispondi al mittente del messaggio corrente}
set balText(reply_quote_sender) {Write a reply to the sender, 
quoting the current message}
set balText(reply_all) {Rispondi al mittente e a tutti i destinatari del
messaggio corrente}
set balText(reply_quote_all) {Write a reply which goes to the sender and all
recipients, quoting the current message}
set balText(forward_inline) {Rispedisci il messaggio corrente}
set balText(forward_attached) {Rispedisci il messaggio corrente come allegato}
set balText(bounce) {Bounce the current message to a new address}
set balText(compose_held) {Continua a scrivere un messaggio mantenuto}
set balText(extract_adr) {Crea alias dalla lista di indirizzi del messaggio corrente}
set balText(move) {Move the current message to another mailbox}
set balText(delete) {Mark the current message for deletion.
It will not be actually deleted until you
"Compact" the mailbox}
set balText(undelete) {Rimuove il contrassegno di cancellazione del messaggio corrente}
set balText(print) {Stampa il messaggio corrente}
set balText(structure) {Questo sottomenu mostra la struttura
del messaggio e degli allegati}
set balText(show_all_headers) {Mostra tutte le intestazioni dei messaggi}
set balText(show_selected_headers) {Mostra solo le intestazioni selezionate}
set balText(show_no_headers) {Non mostra alcuna intestazione}
set balText(group_menu) {Questo menu opera sun un gruppo di messaggi.
Tutti i messaggi che fanno parte del gruppo sono
contrassegnati da una 'F'. Questi comandi valgono
solo per i messaggi contrassegnati nella cartella
attiva}
set balText(create_in_win) {Mostra una nuova lista di messaggi e permette
di effettuare selezioni di gruppi al suo interno}
set balText(create_by_expr) {Crea un gruppo utilizzando un'espressione}
set balText(use_saved_expr) {Crea un gruppo usando un'espressione salvata in precedenza}
set balText(clear_group) {Rimuove il contrassegno di raggruppamento da tutti i messaggi}
set balText(group_all) {Flag every message - add every message to the group}
set balText(delete_group) {Contrassegna tutti i messaggi del gruppo per la cancellazione}
set balText(print_group) {Stampa tutti i messaggi nel gruppo}
set balText(move_group) {Muove tutti i messaggi nel gruppo in un'altra cartella}
set balText(admin_menu) {Questo menu contiene vari comandi d'amministrazione}
set balText(browse_mode) {Modo titoli disabilita il caricamento automatico del corpo dei
messaggi. Il corpo viene caricato quando si preme "Mostra corpo" o si
fa doppio click sul titolo del messaggio nella lista dei messaggi}
set balText(update) {Controlla la cartella corrente per nuovi messaggi. Non
cancella i messaggi contrassegnati}
set balText(sync) {Sincronizza la cartella visualizzata con la cartella fisica,
cioé salva contrassegni, cancella i messaggi e controlla la
presenza di messaggi nuovi}
set balText(newedit_folder) {Opens a window for you to add mailboxes
and edit their properties.}
set balText(aliases) {Apre la finestra degli alias}
set balText(focus) {List only the flagged messages}
set balText(unfocus) {List all messages (flagged and unflagged)}
set balText(hide_size) {Hide message sizes in list}
set balText(hide_deleted) {Hide deleted messages in list}
set balText(hide) {Hide all Postilion's windows}
set balText(preferences) {Apre la finestra delle preferenze}
set balText(define_keys) {Permette la visualizzazione/modifica delle definizioni dei tasti per
questa finestra}
set balText(saved_expr) {Permette la modifica delle espressioni salvate usate per creare gruppi}
set balText(sort_order) {Permette di modificare l'ordine dei messaggi nella cartella}
set balText(sort_subjdate) {Riordina i messaggi a seconda della data, raggruppando
messaggi con lo stesso soggetto}
set balText(sort_subj) {Riordina i messaggi alfabeticamente secondo il soggetto}
set balText(sort_sender) {Riordina i messaggi alfabeticamente secondo il mittente}
set balText(sort_natural) {Non riordina i messaggi}
set balText(sort_reverse_natural) {Non riordina i messaggi ma li mostra invertiti}
set balText(sort_date) {Riordina i messaggi a seconda della data di spedizione (i primi in
alto)}
set balText(sort_reversedate) {Riordina i messaggi a seconda della data di spedizione (i primi in
basso)}
set balText(help_menu) {Fornisce vari tipi di aiuto}
set balText(balloon_help) {Abilita/disabilita l'aiuto-balloon}
set balText(show_version) {Mostra la versione corrente di Postilion}
set balText(explain_ratatosk) {Spiega l'origine del nome Ratatosk}
set balText(help_window) {Mostra la finestra d'aiuto}
set balText(send_bug) {Permette di spedire un rapporto malfunzione all'autore di Postilion}
set balText(group_list_editor) {I messaggi contrassegnati saranno membri del gruppo.
Utilizzando il bottone sinistro del mouse e possibile
cambiare la selezione del messaggio}
set balText(group_window_ok) {Chiude la finestra e trasferisce i contrassegni di gruppo alla finestra
cartella}
set balText(group_window_selall) {Contrassegna tutti i messaggi}
set balText(group_window_unselall) {Rimuove il contrassegno di tutti i messaggi}
set balText(cancel) {Annulla l'operazione e chiude la finestra}
set balText(enter_search_exp_here) {Immetti l'espressione per la ricerca}
set balText(toggle_ignore_case) {Ignora/considera maiuscole/minuscole nella ricerca}
set balText(find_exact) {Ricerca la stringa esatta}
set balText(find_regexp) {Ricerca con espressione regolare}
set balText(find_in_mlist) {Ricerca nella lista dei messaggi (non nel corpo dei messaggi)}
set balText(find_in_body) {Ricerca nel corpo del messaggio corrente}
set balText(find_first) {Inizia la ricerca dall'alto}
set balText(find_next) {Trova il prossimo}
set balText(dismiss) {Chiudi la finestra}
set balText(show_adrbook_menu) {This list shows your address books.
Left-click on a book to see its addresses.
Select an address and then press one of the
address buttons below (e.g. the  To:-list),
to have that person automatically entered in
the list of recipients for your message.
Or select a book and then press one of the
the address buttons, to address your message
to EVERYONE in that book.
TIP: You turn on the Bcc feature by add "Bcc"
to the "Headers" field in Preferences->Compose.
Bcc means `blind carbon copy' - no one can see
you've sent the mail to people in the Bcc list}
set balText(use_system_aliases) {Includi gli alias dall'agenda di sistema}
set balText(add_addrbook) {Aggiungi una nuova agenda}
set balText(delete_addrbook) {Cancella un'agenda. Rimuove il nome dell'agenda dalla lista
di Postilion, ma il file contenente gli indirizzi non viene cancellato}
set balText(set_default_addrbook) {Seleziona l'agenda di default, cioé quella in cui vengono
aggiunti i nuovi alias quando non si specifica dove appartengono}
set balText(import_aliases_from_pgm) {Importa gli alias da file generati da altri programmi,
creando una nuova agenda che utilizza un altro formato}
set balText(alias_list) {Questa è la lista degli alias}
set balText(new_alias) {Crea un nuovo alias}
set balText(edit_alias) {Modifica un alias esistente}
set balText(delete_alias) {Cancella gli alias selezionati}
set balText(move_alias) {Muove gli alias selezionati in un'altra agenda}
set balText(alias_adr_book) {Agenda a cui questo alias deve appartenere}
set balText(alias_alias) {Nome breve per l'alias. Questo è il nome che bisogna scrivere nel campo
dell'indirizzo}
set balText(alias_fullname) {Nome completo dell'alias. Questo è il nome
della persona indicata dall'alias}
set balText(alias_content) {Il contenuto dell'alias. Questo è ciò che viene espanso
quando si spedisce il messaggio}
set balText(alias_comment) {Commento alias. Questo è solo per convenienza}
set balText(name_of_adrbook) {Il nome che Postilion deve usare internamente per gestire questa agenda}
set balText(list_of_books_to_delete) {Selezionare le agende che si vogliono
rimuovere da questa lista e premere "cancella"}
set balText(aliases_adr_book) {Agenda a cui devono appartenere questi alias}
set balText(aliasadd_use) {Se questo bottone non è premuto allora
l'alias su questa linea viene ignorato}
set balText(alias_chooser) {This list lets you choose an address to add to your
address field.
There are several ways to select an address:
    * You can select one with the left mousebutton
    * You can use the up and down arrow keys
When you have made a selection, press space to 
add your selection to the "To:" line of the
active compose window, or click one of the 
buttons below to insert your selection into a
particular address line. Pressing "Return" will
insert your selection into the "To:" line,
and close this window. If a compose window is
not active, a new one will open for you. You 
can dismiss this window without selecting an
address with the esacape key or ctrl-c.}
set balText(compose_held_pick) {Seleziona il messaggio che si vuole continuare da questa lista.
Si può selezionare il messaggio e premere ok, oppure si può fare
un doppio click col mouse}
set balText(compose_insert_file) {Inserisce il contenuto di un file alla posizione del cursore}
set balText(automatic_wrap) {Controlla la funzione di a-capo automatico}
set balText(automatic_indent) {Controlla la funzione di indentazione automatica}
set balText(abort_compose) {Annulla la composizione}
set balText(undo) {Annulla l'ultima modifica}
set balText(cut) {Taglia il testo selezionato}
set balText(copy) {Copia il testo selezionato}
set balText(paste) {Incolla testo}
set balText(cut_all) {Taglia tutto il testo del messaggio}
set balText(copy_all) {Copia tutto il testo del messaggio}
set balText(wrap_lines) {Formatta le linee selezionate}
set balText(run_through_command) {Filtra il testo selezionato (tutto il messaggio se non ne 
stata selezionata una parte) attraverso un comando esterno}
set balText(headers_menu) {Questo menu permette di controllare quali intestazioni
vengono mostrate nella finestra di composizione}
set balText(copy_attached_files) {Se questa opzione è abilitata, allora una copia di tutti gli
allegati viene effettuata non appena si preme "spedisci". Se è
disabilitata allora i file allegati non sono inclusi fino a quando
il messaggio viene effettivamente spedito}
set balText(request_notification) {Richiede la notifica della consegna per questo messaggio}
set balText(pgp_sign) {Firma il messaggio utilizzando PGP}
set balText(pgp_encrypt) {Cripta i messaggi con PGP}
set balText(command_list) {Modifica la lista di comandi salvati (per filtrare testo)}
set balText(compose_body) {Il corpo del messaggio}
set balText(attach_file) {Allega un file al messaggio}
set balText(attach_special) {Allegati speciali}
set balText(attach_keys) {Allega chiavi PGP}
set balText(detach) {Rimuove l'allegato selezionato}
set balText(attachments) {Lista di allegati}
set balText(send) {Send the message and save a copy in the designated "save
outgoing" mailbox.  (You choose the save-mailbox via the
"Mailboxes" editor window.  Select a mailbox and press down
with the right mouse button, then choose "Edit...".  In the
edit window for the selected mailbox choose a mailbox for
storing your outgoing messages from the "Save to" tab.
Some people like to store all their outgoing messages
in a single mailbox called "Outgoing", others like multiple
save-mailboxes, some like no copy to be saved.)}
set balText(sendsave) {Spedisci il messaggio e salvane una copia nella
cartella specificata}
set balText(hold) {Mantieni il messaggio in maniera tale da poterlo continuare piu' tardi}
set balText(eedit) {Utilizza un editor esterno per il corpo del messaggio}
set balText(compose_to) {I destinatari primari del messaggio.
Questo è un campo d'indirizzo. Postilion cercherà di mantenere gli indirizzi
ordinati per colonna, espandendo gli alias (ai loro nomi completi), segnando
indirizzi invalidi in rosso. Premendo ^l si può accedere alla lista di
alias.}
set balText(compose_subject) {Il soggetto del messaggio}
set balText(compose_cc) {Lista di destinatari che riceveranno una copia carbone del messaggio.
Questo è un campo d'indirizzo. Postilion cercherà di mantenere gli indirizzi
ordinati per colonna, espandendo gli alias (ai loro nomi completi), segnando
indirizzi invalidi in rosso. Premendo ^l si può accedere alla lista di
alias.}
set balText(compose_bcc) {Lista di destinatari che riceveranno copie carbone cieche del messaggio.
Questo è un campo d'indirizzo. Postilion cercherà di mantenere gli indirizzi
ordinati per colonna, espandendo gli alias (ai loro nomi completi), segnando
indirizzi invalidi in rosso. Premendo ^l si può accedere alla lista di
alias.}
set balText(compose_keywords) {Una lista di parole chiave che descrivono il messaggio}
set balText(compose_content_description) {Descrizione del contenuto del messaggio}
set balText(compose_reply_to) {Indirizzo a cui mandare le risposte.
Questo è un campo d'indirizzo. Postilion cercherà di mantenere gli indirizzi
ordinati per colonna, espandendo gli alias (ai loro nomi completi), segnando
indirizzi invalidi in rosso. Premendo ^l si può accedere alla lista di
alias.}
set balText(compose_comments) {Commenti sul messaggio}
set balText(compose_from) {Mittente del messaggio}
set balText(type_menu) {Menu per specificare il tipo di allegato}
set balText(encoding_menu) {La codifica attuale dell'allegato. Non ha niente a che vedere
con la codifica con cui verrà spedito.}
set balText(attach_description) {Una breve descrizione dell'allegato}
set balText(attach_disposition) {This is the filename which an attached file will
most likely be saved as.}
set balText(attach_id) {In certi casi è necessario definire un indentificatore
per l'allegato}
set balText(bounce_to) {Enter the address of the person to whom you wish to bounce this message here}
set balText(hold_description) {Inserisci una descrizione del messaggio da mantenere}
set balText(choose_msg) {Questo messaggio contiene uno o più messaggi. Scegli a quale 
rispondere o il messaggio da rispedire}
set balText(save_cmd_as) {Se vuoi salvare questo comando per utilizzi futuri, inserisci un
identificativo e assicurati che il pulsante sia premuto}
set balText(command_to_run_through) {Inserisci il comando. Il testo selezionato verrà filtrato
attraverso questo comando}
set balText(saved_commands) {Lista di comandi salvati}
set balText(apply_changes_to_cmd) {Applica le modifiche fatte al comando}
set balText(delete_command) {Cancella il comando selezionato}
set balText(command_content) {Contenuto del comando}
set balText(notification_window) {La finestra delle notifiche contiene una lista di tutti i messaggi
per i quali è stata richiesta la notifica negli ultimi sette giorni (questo
valore è configurabile). Ciascun messaggio viene mostrato con la data di
spedizione, il soggetto e tutti i destinatari. Davanti a ciascun
destinatario viene indicato lo stato corrente. Ci sono sei stati possibili:
-		- Significa che Postilion non sa niente del destinatario
Fallito		- Il messaggio non è stato consegnato al destinatario
Consegnato	- Il messaggio è stato consegnato. Non significa che il
		  destinatario lo abbia letto
Trasferito	- Il messaggio è stato trasferito su una macchina (MTA) che
		  non ha supporto per le notifiche.
Espanso		- Il messaggio è stato consegnato, ma la destinazione era
		  un alias che è stato espanso a uno o più indirizzi
		  diversi. Potrebbero giungere ulteriori notifiche
Ritardato	- Il messaggio non ha ancora raggiunto il destinatario ma
		  ulteriori tentativi verranno effettuati

E' possibile ottenere ulteriori informazioni su qualsiasi notifica
selezionando un destinatario col pulsante sinistro del mouse}
set balText(dsn_readable) {Spiegazione del motivo per cui una
particolare notifica è stata spedita}
set balText(dsn_more_info) {Mostra le parti del messaggio originale che sono
state ritornate nel campo di testo in alto}
set balText(switch_expression) {Menu che permette di scegliere tra espressioni avanzate e base}
set balText(save_expr_as) {Se vuoi salvare questa espressione per utilizzi futuri, è sufficiente
inserire qui un identificatore e assicurarsi che il pulsante sia premuto}
set balText(exp_ok) {Chiudi la finestra espressioni e seleziona i messaggi che corrispondono
all'espressione}
set balText(clear) {Cancella tutti i campi}
set balText(exp_basic_and) {Tutte le linee qui sotto devono essere riscontrate in un messaggio 
perché questo sia selezionato}
set balText(exp_basic_or) {I messaggi in cui vengono riscontrate almeno una
delle linee qui sotto verranno selezionati}
set balText(exp_basic_field) {Questa linea viene riscontrata solo se almeno una parola
nel campo viene trovato nell'intestazione indicata}
set balText(exp_adv_exp) {Qui puoi scrivere le espressioni avanzate. Si può utilizzare la
tastiera o i pulsanti rapidi qui sotto. Esempi di espressioni sono:
	Subject has foo
	Subject is "foo bar" and (To has maf or Cc has maf)}
set balText(exp_adv_fields) {Questi bottoni corrispondono ai diversi
campi delle intestazioni che possono essere riscontrati}
set balText(exp_adv_has) {Il campo contiene al suo interno questa stringa}
set balText(exp_adv_is) {Il campo dell'intestazione deve essere riscontrato esattamente}
set balText(exp_adv_gt) {Il simbolo di maggiore ha senso solo col campo Dimensione}
set balText(exp_adv_lt) {Il simbolo di minore ha senso solo col campo Dimensione}
set balText(exp_adv_bool) {Questi termini logici possono essere usati per combinare espressioni}
set balText(exp_adv_p) {Usa parentesi per raggruppare espressioni}
set balText(exp_list) {Lista di espressioni salvate}
set balText(exp_text) {Contenuto dell'espressione}
set balText(exp_delete) {Cancella l'espressione selezionata}
set balText(fs_show) {Mostra tutti i file nella directory corrente}
set balText(fs_old) {Menu contenente directory visitate}
set balText(mode_menu) {Questo menu permette di modificare i permessi del file}
set balText(welcome_lang) {Questo menu permette di selezionare la lingua dell'interfaccia}
set balText(welcome_shutup) {Questo menu permette di scegliere se si vuole essere informati
di cambiamenti in Postilion la prossima volta che avvengono (è possibile
cambiare questo valore anche dalla finestra delle preferenze)}
set balText(welcome_cont) {Chiudi questa finestra e apri la finestra di Postilion}
set balText(ok_and_apply) {Chiudi la finestra e applica le modifiche}
set balText(keydef_delete) {Premi questo pulsante e uno dei tasti sopra per cancellare
il tasto indicato}
set balText(keydef_add) {Premi questo pulsante per agiungere un nuovo tasto
a questo evento. Dopo aver premuto il pulsante devi premere
il tasto sulla tastiera}
set balText(keydef_def) {Qui si possono vedere i tasti che causeranno questo evento}
set balText(apply_prefs) {Applica le modifiche e salva i nuovi valori}
set balText(unit_pref) {Unità di valore}
set balText(pref_clock_format) {Clock format (12 or 24 hour)}
set balText(pref_language) {La lingua dell'interfaccia utente. Perchè questa opzione abbia
effetto è necessario far ripartire Postilion}
set balText(pref_start_win) {Which windows should be opened automatically
when Postilion is started.  Make sure you start
with at least one of "Mailboxes" or "Folder", or
you won't be able to read any mail!}
set balText(pref_next_menu) {Whether to use a single NeXT style menu of submenus,
insead of the normal menubar across the top.
Note:
Only use NeXT style only with click-to-focus mode.
It won't work well with focus-follows-mouse modes}
set balText(pref_color_set) {Lo schema di colori di Postilion}
set balText(pref_paper_color) {Which color should be used for the message text areas}
set balText(pref_new_msg_col) {Which color should be used for new messages}
set balText(pref_sel_msg_col) {Which color should be used for selected messages}
set balText(pref_fnd_msg_col) {Which color should be used for found messages}
set balText(pref_flg_msg_col) {Which color should be used for flagged messages}
set balText(pref_del_msg_col) {Which color should be used for deleted messages}
set balText(pref_seen_msg_col) {Which color should be used for seen messages}
set balText(pref_ans_msg_col) {Which color should be used for answered messages}
set balText(pref_button_bar) {Should Postilion display the button bar}
set balText(pref_image_buttons) {Should Postilion display icons or text for action buttons}
set balText(pref_sync_but) {Display a mailbox synchronization button in the browser}
set balText(pref_sync_oper) {Whether the sync button should compact the mailbox,
 expunging deleted messages, or just update it.}
set balText(pref_iconic) {Determina se Postilion parte iconizzato}
set balText(pref_info_changes) {Quando l'utente esegue una nuova versione di Postilion per la prima
volta, il programma mostra un messaggio che mostra gli ultimi cambiamenti.
Questa opzione permette di disabilitare questo messaggio}
set balText(pref_mail_steal) {Se Postilion deve controllare se Netscape ha rubato i messaggi}
set balText(pref_print_command) {Il comando da utilizzare per stampare. Il '%s' nel comando verrà
sostituito con il nome del file da stampare. Se non si specifica '%s'
allora il programma deve ricevere i dati in stdin}
set balText(pref_print_header) {Quali intestazioni devono essere mandate in stampa ('Tutte',
'Selezionate', o 'Nessuna')}
set balText(pref_print_non_text) {Should non-text message parts be printed?}
set balText(pref_tmp) {Directory per file temporanei}
set balText(pref_permissions) {Permessi da usare quando vengono creati nuovi file (per esempio
quando si salvano messaggi)}
set balText(pref_userproc) {Il file dove le procedure utente vengono salvate}
set balText(pref_hold_dir) {Directory dove vengono salvati i messaggi mantenuti}
set balText(pref_fontsize) {La normale dimensione del testo}
set balText(pref_keep_pos) {Controlla se Postilion deve mantenere la posizione e la dimensione delle
finestre}
set balText(pref_mailcap_path) {I nomi dei file mailcap che Postilion proverà a caricare. Prima verranno
caricati quelli specificati nella variabile d'ambiente MAILCAP}
set balText(pref_terminal) {Quale comando da utilizzare quando si crea un terminale interattivo
per i comandi mailcap che hanno bisogno di un terminale. Questo comando
verrà messo prima del comando di visualizzazione}
set balText(pref_message_llength) {Il numero di messaggi mostrati sullo schermo nella lista dei messaggi}
set balText(pref_list_mode) {Should Postilion use the list format below for all
mailboxes (this is the default), or use the per-mailbox
settings}
set balText(pref_list_format) {Questa opzione determina l'aspetto della lista dei messaggi.
Questa stringa assomiglia ad un argomento di printf() eccetto che
l'unica cosa che può seguire '%' (a parte un altro '%') è un argomento
intero opzionale che può essere negativo e uno dei seguenti caratteri.
	s - Soggetto del messaggio
	n - Nome del mittente (o indirizzo se non c'è nome)
	m - Indirizzo del mittente
	r - Nome del destinatario (o indirizzo se non c'è nome)
	R - Indirizzo del destinatario
	b - Dimensione approssimativa in byte del messaggio
	B - Come sopra ma rappresentata con un massimo di 4 caratteri
	d - Data del messaggio (in formato leggibile)
	D - Data del messaggio (in secondi dall'epoca)
	S - Stato del messaggio (max 5 caratteri)
	    Vengono utilizzati gli stati seguenti:
	    N - il messaggio non è stato letto
	    A - il messaggio è stato risposto
	    D - il messaggio è contrassegnato per la rimozione
	    F - il messaggio è selezionato e perciò membro
	        del gruppo corrente
	    + - il messaggio è stato indirizzato direttamente a te
	i - indice del messaggio}
set balText(pref_show_header) {Quali intestazioni del messaggio vengono mostrate ('Tutte', 'Selezionate' o
'Nessuna')}
set balText(pref_show_header_selection) {Se vengono mostrati solo i messaggi selezionati, solo questi messaggi
vengono mostrati}
set balText(pref_browse) {Should Postilion always use browse mode, never
use browse mode, or use the per-mailbox setting?

Browse mode is useful when a mailbox file is not
stored on your computer.  It keeps the bodies of
messages from being loaded automatically.  The actual
body of a message only is loaded when you press the
"show body" button, or double click on the message in
the message list}
set balText(pref_sort_mode) {Should Postilion use the same message-sorting order for
all mailboxes (normal), or use the per-mailbox settings}
set balText(pref_folder_sort) {L'ordinamento della lista di messaggi}
set balText(pref_adv_on_flag) {Automatically advance to the next
message after flagging a message}
set balText(flag_seen) {Toggle this message's Seen flag (in
other words, so it does or doesn't look new)}
set balText(flag_ans) {Toggle this message's Answered flag}
set balText(flag_unseen) {Flag this message as Unseen (in
other words, so it looks new)}
set balText(seen_group) {Toggle the Seen flags of all flagged messages 
(in other words, so they do or don't look new)}
set balText(unseen_group) {Mark all flagged messages as Unseen
(in other words, so they all look new)}
set balText(ans_group) {Toggle the Answered flag of  all flagged messages}
set balText(undelete_group) {Clear the Deleted flag on all flagged messages}
set balText(pref_strsel_mode) {Should Postilion use the method below ("Select when open")
for all mailboxes (normal), or use the per-mailbox settings}
set balText(pref_start_selection) {Il messaggio da selezionare quando viene aperta una cartella}
set balText(pref_log_timeout) {Tempo (in secondi) per cui visualizzare i messaggi di stato}
set balText(pref_cache_passwd) {Determina se Postilion deve mantenere le password per connessioni IMAP e POP.
Le password vengono mantenute in memoria e vengono perciò perdute quando si 
esce da Postilion}
set balText(pref_cache_passwd_timeout) {Tempo per cui devono essere mantenute le password.
(0 significa per la durata dell'applicazione)}
set balText(pref_cache_conn) {Determina se Postilion deve mantenere aperte le connessioni IMAP dopo che la
cartella viene chiusa. Una connessione aperta viene riutilizzata per
ulteriori accessi}
set balText(pref_cache_conn_timeout) {Tempo per cui devono essere mantenute le connessioni.
(0 significa per la durata dell'applicazione)}
set balText(pref_urlprot) {Postilion evidenzia URL coi protocolli appartenenti
a questa lista}
set balText(pref_url_color) {Il colore delle URL nel testo del messaggio (su schermi a colori)}
set balText(pref_quote_color) {The color of quoted text in the message text
(only used on color displays)}
set balText(pref_url_viewer) {Il visualizzatore da usare per vedere le URL. Può essere anche una
procedura utente}
set balText(pref_netscape) {Il comando da utilizzare per eseguire Netscape}
set balText(pref_netscape_args) {Argomenti extra da dare a Netscape}
set balText(pref_dbase_dir) {Directory dove viene salvato il database}
set balText(pref_def_extype) {Azione normale di scadenza}
set balText(pref_def_exdate) {Tempo normale di scadenza (in giorni dall'inserimento nel dbase)}
set balText(pref_dbase_backup) {La directory dove mettere i messaggi scaduti dal database con l'opzione
di backup di scadenza (i messaggi vengono compressi)}
set balText(pref_chunksize) {Quanti messaggi (almeno) devono essere compressi in ciascun blocco
di messaggi nella directory di backup}
set balText(pref_expire_interval) {Quanti giorni devono trascorrere tra scadenze del database}
set balText(pref_watcher_enable) {Se si vuole vedere la finestra di controllo}
set balText(pref_watcher_time) {La frequenza con cui la finestra di controllo verifica le varie cartelle
per messaggi nuovi. Questa è espressa come l'intervallo tra controlli in
secondi. Ci sono due valori: uno per le cartelle database e uno per le
altre. Uno zero disabilita la verifica}
set balText(pref_watcher_name) {Il titolo della finestra di controllo}
set balText(pref_watcher_max_height) {L'altezza massima (in linee) della lista di nuovi messaggi}
set balText(pref_watcher_font) {Il font da utilizzare per questa finestra}
set balText(pref_watcher_show) {Quali messaggi da visualizzare ('Tutti' o 'Nuovi')}
set balText(pref_watcher_format) {Il formato della lista. Vedere l'aiuto per la finestra cartella
per informazioni su questo formato}
set balText(pref_watcher_bell) {Quanti beep da effettuare quando la finestra di controllo trova nuovi
messaggi.
NOTA: se la procedura utente RatUP_Bell esiste, allora questo valore è
bloccato e non verranno fatti beep}
set balText(pref_reply_mode) {Should Postilion use the same reply-to address for all
mailboxes (normal), or use the per-mailbox settings}
set balText(pref_reply_to_addr) {L'indirizzo rispondi-a normale}
set balText(pref_reply_to_fn) {L'indirizzo rispondi-a normale}
set balText(pref_compose_headers) {Quali intestazioni l'utente può modificare normalmente. La lista 
di intestazioni può essere cambiata nella finestra di composizione}
set balText(pref_custom_headers) {Custom headers to be displayed in compose sessions.}
set balText(pref_editor) {Editor esterno da eseguire se l'utente preme il pulsante 'Editor
esterno'. Un '%s' nel comando viene sostituito con il nome del file da
modificare. La finestra di composizione viene bloccata fino a quando
l'editor termina}
set balText(pref_attribution) {Questa linea (se definita) viene messa prima di ogni risposta. Ha la
stessa sintassi dell'opzione 'Formato lista'}
set balText(pref_forwarded_message) {Questa linea viene inserita prima del messaggio incluso}
set balText(pref_reply_lead) {Quali caratteri mettere davanti a ciascuna linea del messaggio originale
a cui si vuole rispondere. Se la linea non inizia già con questo carattere,
uno spazio verrà aggiunto}
set balText(pref_quote) {This option controls whether or not to quote the
body of a letter you are replying to in the reply}
set balText(pref_skip_sig) {Questa opzione controlla se includere o meno la signature del messaggio
a cui si sta rispondendo}
set balText(pref_no_subject) {Quale soggetto mettere nelle risposte a messaggi senza soggetto}
set balText(pref_sig_mode) {Should Postilion use the same signature file for all mailboxes
(the default), or use the per-mailbox settings}
set balText(pref_signature) {Il nome del file contenente la signature utente}
set balText(pref_lookup_name) {Opzione che determina se Postilion deve verificare indirizzi locali}
set balText(pref_copy_attached) {Opzione che determina se TkRar deve fare una copia degli allegati
non appena effettuato l'allegamento. Altrimenti Postilion andrà a cercare
l'allegato al momento della spedizione}
set balText(pref_from_mode) {Should Postilion use the same "From:" address for all
mailboxes (normal), or use the per-mailbox settings}
set balText(pref_from_addr) {Il contenuto della linea Da:. Se Da: non si riferisce al mittente,
allora una linea Mittente: verrà aggiunta}
set balText(pref_from_fn) {Il contenuto della linea Da:. Se Da: non si riferisce al mittente,
allora una linea Mittente: verrà aggiunta}
set balText(pref_date-prefix) {The prefix to use when creating dated dynamic mailboxes
(ie: if this value is "sent-mail" then the mailbox would be
named something like sent-mail-Feb-1998)}
set balText(pref_masquerade_as) {Maschera tutti i messaggi come se provenissero da questo dominio (cioè
senza specificare il nome della macchina nell'indirizzo). Questo valore ha
precedenza su qualunque dominio specificato}
set balText(pref_domain) {Il dominio a cui appartiene questa macchina. Il nome della macchina
e questo valore verranno concatenati (a meno che il nome della macchina
contenga un '.') e utilizzati. Questo avviene se 'Maschera come' non è
definito}
set balText(pref_delivery_mode) {Questa modalità determina cosa accade quando si preme uno dei pulsanti
di spedizione nella finestra di composizione. Se il modo è "Diretto", allora
la spedizione avviene immediatamente (in background). Se il modo è
"Differito" allora il messaggio viene messo in una coda e spedito quando si
seleziona "Manda differiti"}
set balText(pref_sendprot) {La modalità di spedizione dei messaggi. Tramite SMTP o programma}
set balText(pref_smtp_hosts) {Quando si spediscono messaggi via SMTP, questa è una lista di server a
cui si proverà a spedire. Ciascun host può essere seguito da una :porta che
specifica la porta a cui collegarsi}
set balText(pref_smtp_timeout) {Per quanti secondi bisogna attendere per una risposta dal server SMTP}
set balText(pref_smtp_reuse) {Determina se il canale al server SMTP deve essere chiuso e riaperto per
ciascun messaggio. Se selezionato tutti i messaggi verranno spediti
utilizzando un'unica connessione}
set balText(pref_smtp_verbose) {Il livello di dettaglio di cosa accade quando vengono spediti messaggi
tramite SMTP}
set balText(pref_sendprog) {Il programma che viene utilizzato per spedire messaggi. Deve prendere
l'indirizzo del destinatario sulla riga di comando e il messaggio su stdin
(come sendmail)}
set balText(pref_sendprog_8bit) {Il tipo di dati che il programma può gestire (sette o otto bit)}
set balText(pref_charset) {Il set di caratteri da usare}
set balText(pref_force_send) {Determina se Postilion prova a spedire messaggi anche se non conosce il nome
completo dell'host locale (nome + dominio). Non abilitare questa opzione se
non sai cosa stai facendo}
set balText(pref_dsn_directory) {Dove salvare informazioni sulle notifiche}
set balText(pref_dsn_request) {Il valore standard del selettore di notifica nel menu extra della
finestra di composizione. Il pulsante Prova verifica se il sistema supporta
le notifiche. Leggere le release-notes per maggiori dettagli}
set balText(pref_dsn_snarf_reports) {Determina se vengono mostrate le notifiche ricevute nella lista dei
messaggi. Vengono comunque mostrate nella finestra delle notifiche}
set balText(pref_dsn_expiration) {Per quanto tempo devono essere mantenuti i messaggi (e le eventuali
notifiche) nella finestra di notifiche. Il tempo è in giorni da quando il
messaggio è stato spedito}
set balText(pref_dsn_verbose) {Il livello di rapporto viene selezionato per ciascun tipo di notifica.
Ci sono tre livelli:
    Silenzioso
        Non mostrare l'arrivo di nuove notifiche.
    Mostra nella linea di stato
        Mostra un messaggio sulla linea di stato quando arriva
        una nuova notifica.
    Mostra in un'altra finestra
        Mostra la notifica completa in una finestra separata che
        appare all'utente.
N.B. Qualsiasi livello venga selezionato, le notifiche appaiono comunque
nella finestra delle notifiche}
set balText(pref_pgp_enable) {Determina se abilitare o disabilitare la parte PGP}
set balText(pref_pgp_prog) {Il nome del programma PGP}
set balText(pref_pgp_args) {Argomenti extra da passare al programma PGP}
set balText(pref_cache_pgp) {Se mantenere password PGP}
set balText(pref_cache_pgp_timeout) {Per quanto tempo devono essere mantenute le password PGP (0=per la
durata dell'applicazione)}
set balText(pref_pgp_sign) {Il valore standard del pulsante di firma nella finestra di composizione}
set balText(pref_pgp_encrypt) {Il valore standard del pulsante di crittazione nella finestra di
composizione}
set balText(body_of_message) {Il contenuto del messaggio selezionato. Il pulsante destro del mouse
mostra un menu che descrive la struttura del messaggio}
set balText(howto_display) {Questo menu permette di determinare come viene visualizzata la
componente del messaggio}
set balText(save_bodypart) {Salva la componente del messaggio in un file}
set balText(view_as_text) {Se questo pulsante è premuto allora
questa parte del messaggio viene mostrata
come se fosse testo}
set balText(view_source) {Visualizza questa parte come è stata spedita (in una finestra
a parte)}
set balText(add_to_keyring) {Aggiungi questa chiave pubblica al keyring}
set balText(run_mailcap) {Esegue il comando specificato nel mailcap per questo tipo}
set balText(bodypart_entry) {Questa selezione corrisponde a una parte. Il sottomenu ne fornisce
informazioni e permette di effettuare operazioni su di essa}
set balText(bodypart_show) {Questo pulsante permette di determinare
se questa parte deve essere mostrata oppure no}
set balText(bodypart_save) {Salva la parte in un file}
set balText(dbs_and) {Tutte le linee sotto devono essere riscontrate in un messaggio perchè
venga incluso}
set balText(dbs_or) {Almeno una delle linee non vuote sotto deve
essere riscontrato in un messaggio perchè venga
incluso}
set balText(dbs_keywords) {Questa linea viene riscontrata se una di
queste parole è stata selezionata come parola
chiave del messaggio}
set balText(dbs_subject) {Questa linea viene riscontrata se una di queste parole viene trovata
nel soggetto. Se si vogliono cercare combinazioni di parole, vanno
delimitate da ""}
set balText(dbs_all) {Questa linea viene riscontrata se una di queste parole viene trovata nel
messaggio. Se si vogliono cercare combinazioni di parole, vanno
delimitate da ""}
set balText(dbs_to) {Questa linea viene riscontrata se una di queste parole viene trovata
tra i destinatari. Se si vogliono cercare combinazioni di parole, vanno
delimitate da ""}
set balText(dbs_from) {Questa linea viene riscontrata se una di queste parole viene trovata
tra i mittenti. Se si vogliono cercare combinazioni di parole, vanno
delimitate da ""}
set balText(dbs_cc) {Questa linea viene riscontrata se una di queste parole viene trovata
tra le copie-carbone. Se si vogliono cercare combinazioni di parole, vanno
delimitate da ""}
set balText(keywords) {Parole chiave che descrivono il messaggio}
set balText(exp_none) {Il messaggio non scade mai}
set balText(exp_remove) {Cancella questo messaggio quando scade}
set balText(exp_incoming) {Aggiunge questo messaggio alla INBOX quando scade}
set balText(exp_backup) {Muove questo messaggio nel backup quando scade}
set balText(exp_date) {Quando il messaggio deve scadere. L'unico formato supportato al momento
è +N dove N è il numero di giorni per cui il messaggio deve essere mantenuto
nel database prima che scada}
set balText(vd_createsub) {Crea un nuovo sottomenu}
set balText(vd_newfile) {Create a new mailbox as a simple
Unix mailbox file}
set balText(vd_newmh) {Create a new mh mailbox}
set balText(vd_newdbase) {Create a new database mailbox}
set balText(vd_newimap) {Create new IMAP mailbox}
set balText(vd_newpop) {Create new POP3 mailbox}
set balText(vd_newdynamic) {Create a new dynamic mailbox}
set balText(vd_importdir) {Import file mailboxes from a directory}
set balText(vd_importmh) {Import mh-mailboxes from a directory}
set balText(vd_importimap) {Import IMAP mailboxes}
set balText(vd_foldermenu) {This menubutton lets you create new mailboxes,
and sub-entries for groups of mailboxes.
The new entries are placed in the list above}
set balText(vd_importmenu) {This menu lets you import groups of existing
mailboxes. The new entries are placed in the top menu}
set balText(vd_edit) {Modifica questa cartella}
set balText(vd_delete) {Cancella questa cartella (se è un sottomenu allora
viene chiesto se cancellare tutte le sottocartelle}
set balText(vd_setinbox) {Set this mailbox to be the default mailbox
 opened when Postilion starts.  Typically this
 will be the mailbox in which new mail arrives}
set balText(vd_setsaveout) {Set this mailbox to store a copy of all the messages
 you send.  This setting can be over-ridden for each
 mailbox individually}
set balText(vd_setstartup) {Set this mailbox to be opened on startup}
set balText(vd_setstartmin) {Set this mailbox to be opened minimized on startup}
set balText(vd_unsetstartup) {Set this mailbox to not be opened on startup}
set balText(vd_unsetstartmin) {Set this mailbox to not be opened minimized on startup}
set balText(vd_list) {This is a list of your mailboxes.  
   * Double-click the left mousebutton to open a mailbox in the current 
     browser window, or in a new browser window if none exists.
   * Press the right mousebutton to get a menu of commands you can
     apply to the selected entry - or to add a new mailbox after it.
   * Entries with an arrow to their right (->) have sub-entries, 
     which will appear in the next box to the right of this one.  
   * You can move back to the left by selecting an entry in the 
     box to the left of this one.}
set balText(mbv_list) {This is a list of your mailboxes.
   * Double-click the left mouse button 
     to open a mailbox in this window
   * Press the right mousebutton to 
     get a menu which lets you open
     the selected mailbox, or move the 
     currently selected messages to it.
   * Entries with an arrow to their 
     right (->) have sub-entries, 
     which will appear in the next 
     box to the right of this one.  
   * You can move back to the left 
     by selecting an entry in the 
     box to the left of this one.}
set balText(mbv_sash_open) {Click this sash with the left mouse 
button to open a view of your mailboxes.}
set balText(mbv_sash_close) {Click this sash with the left mouse 
button to close the mailbox view.}
set balText(msg_sash) {Drag this sash up or down with the 
mouse to change the relative
sizes of the message list (above) and
the message text (below) panes.}
set balText(vd_menuname) {Il nome del nuovo sottomenu}
set balText(vd_name) {Name of mailbox}
set balText(vd_mhname) {Name of mh-mailbox}
set balText(vd_host) {Il nome del server su cui si trova la cartella}
set balText(vd_user) {The user-name we should use to access the mailbox}
set balText(vd_mbox) {Name of remote IMAP mailbox}
set balText(vd_port) {Porta su cui risponde il server}
set balText(vd_filepat) {Include solo file che corrispondono con questo schema}
set balText(vd_dirpat) {Percorre directory che corrispondono con questo schema}
set balText(vd_pattern) {Includi solo le cartelle che corrispondono con questo schema}
set balText(watcher) {Premi il tasto sinistro del mouse per far apparire la
finestra principale di Postilion, premi il tasto destro per
chiudere temporaneamente la finestra}
set balText(help_subjlist) {Lista di soggetti d'aiuto. Selezionare con il tasto sinistro del mouse 
il soggetto che si vuole vedere}
set balText(help_text) {Testo di aiuto per il soggetto scelto}
set balText(pref_ispellRecheckAfterAdd) {Choose "True" for this to re-check the spelling of words 
currently marked misspelled, after you add to the dictionary 
or session.  Usually a good idea, except it will cause a
small delay after you add words to your personal dictionary.

You can also use the right mouse button to accept words from
a menu of possible corrections.}
set balText(pref_ispellon) {This turns the spell-check feature on and off.  Note that the
feature needs to be turned on BEFORE a message is brought up}
set balText(pref_ispelltextOnly) {Check this box if you want to perform spell checking only
of the text marked as 'text'.  This should avoid spell checking 
To:, Cc: & X-Face: lines, it comes at a small time penalty - turn
it off if you want to see a small improvement in response time.

Note that turning this option on will also not spell check 'attachments'
unless they are marked as Content-Type: text/enriched or text/plain.
If you find that spell checking STOPS working in a section of the
document you may want to turn this off}
set balText(pref_ispelldefaultCommand) {This is the program used to actually do the real work -
'ispell -a' is probably a good choice.  If you want to 
use an alternate dictionary, 'ispell -a -d <dictionary-file>' may be 
appropriate.  You may find that -S sorts the list of possible
words better - see the ispell(1) man page for more details.
(Really, it's got a lot of details and you can really personalize
how it works to fit best with your environment)}
set balText(pref_ispellotherCommands) {Other ways to run the 'Ispell' programs, mostly intended for 
our friends in Europe who have to work in a variety of languages.
This entry should be in label/invocation pairs.  E.g. one pair
would be "German  { ispell -a -d deutsch }"}
set balText(pref_ispellpopupBinding) {This controls what the 'popup' window is bound to, some examples include:
	ButtonPress-3 
	ButtonPress-2
	ButtonPress-1
	Shift-3
	Control-3
	Meta-2
	Alt-1
	etc...

Note that the menu is unposted (vanishes) on any ButtonRelease}
set balText(pref_ispellviewStyle) {This is how to display misspelled words.  You
can use the built in types or create your own
using 'other'.  For 'color' ones fill in the color, below.
Examples of using "other":
	-underline t
	-background red
	-foreground Bisque
	-font <font>
	-fgstipple <bitmap>
	-bgstipple <bitmap>
Bitmaps can be many things, 'gray50' and 'gray25' are popular
For example....
	 -font *italic*
    or   -font *bold*
    or   -font *24*    (Big!)
    or   -font *italic*24* (big italics)
	 -relief <relief> (see tk docs for more info...)
Effects can also be combined.  For example:
	-underline t -foreground red
	-bgstipple gray25 -color red}
set balText(pref_ispellviewStyle-Color) {color for foreground color and background color}
set balText(pref_ispellviewStyle-Other) {Style if 'other' is selected}
set balText(pref_mboxvis) {Whether or not to display the 
mailbox view at the top of the
browser window.}
set balText(pref_expunge_on_close) {If Postilion should automatically expunge all messages
marked for deletion whenever you close the mailbox}
set balText(pref_automatic_wrap) {Controlla la funzione di a-capo automatico}
set balText(pref_automatic_indent) {Controlla la funzione di indentazione automatica}
}
