#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_t_fr {} {
global t
set t(postilion) Postilion
set t(version) Version
set t(about) Apropos
set t(quit) Quitter
set t(name) Nom
set t(size) Taille
set t(messages) Messages
set t(help) Aide
set t(ok) OK
set t(cancel) Annuler
set t(ratatosk) {Ratatosk. Dans la mythologie nordique, l'écureuil qui monte et descend le cosmos ou arbre du monde, Yggdrasil, transportant les insultes du dragon Nidhog au pied de l'arbre jusqu'à l'aigle au sommet, et vice versa}
set t(posthorn) {Postillon. Il monte un cheval qui tire un chariot, pour le guider. Ce fut seulement au
début du XIXe siècle que les routes\ carrossables ont permis aux voitures (à
cheval) de traverser les alpes. La\ trompe postale était un élément essentiel
pour le postillon, qui\ l'utilisait pour signaler sa présence sur les routes.
La trompe\ postale est le symbole jaune sur l'icône de Postilion. \  Savez-vous pourquoi on trouve une trompe sur les boites aux\ lettres ? Les
messagers et postillons utilisaient une petite trompe\ pour signaler leur
arrivée. Son utilisation est vite devenue\ obligatoire pour le postillon, qui
devait connaître au moins huit\ signaux, chacun avec une signification
particulière : arrivée,\ détresse, départ, etc... Mais ce qui fit la trompe si
populaire fut\ son usage constant à travers les siècles, plus que les lois
qui\ demandaient de l'utiliser. Aujourd'hui la trompe est l'emblème postale de nombreux pays}
set t(months) {jan fév mar avr mai jun jui aou sep oct nov déc}
set t(clock_format) {Format horaire}
set t(12_hour) {12 heures}
set t(24_hour) {24 heures}
set t(move) Déplace
set t(delete) Supprime
set t(undelete) {Annuler suppression}
set t(compose) Composer
set t(reply_quote_sender) {Répondre à l'auteur en citant l'original}
set t(reply_quote_all) {Répondre à tous en citant l'original}
set t(quote) {Citer le message original}
set t(no_quote) {Ne pas citer le message original}
set t(reply_sender) {Répondre à l'expéditeur}
set t(reply_all) {Répondre à tous}
set t(here_is) {C'est un objet de type}
set t(show_all) {Montrer tout}
set t(old_dirs) {Utilisés précédemment}
set t(save_to_file) {Enregistrer dans un fichier}
set t(save_failed) {Impossible d'enregistrer}
set t(message) Message
set t(print) Imprimer
set t(show_all_headers) {Montrer tous les en-têtes}
set t(show_selected_headers) {Montrer les en-têtes sélectionnés}
set t(show_no_headers) {Ne montrer aucun en-tête}
set t(compose_name) {Composer un message}
set t(edit) Editer
set t(edit_body) {Corps du message}
set t(edit_headers) {En-têtes du message}
set t(custom_headers) {Custom headers}
set t(read_from_file) {Lire depuis un fichier}
set t(abort) Abandon
set t(headers) En-têtes
set t(attachments) Attachements
set t(attach_file) {Attacher un fichier}
set t(attach) Attacher
set t(attach_special) {Attachement spécial}
set t(detach) Détacher
set t(send) Envoyer
set t(send_save) {Envoyer & Sauver}
set t(hold) Garder
set t(getheld) {Continuer à composer}
set t(external_editor) {Editeur externe}
set t(running_ext_editor) {Lance l'éditeur externe...}
set t(filename) {Nom du fichier}
set t(description) Description
set t(disposition) Disposition
set t(id) Identifiant
set t(type) Type
set t(subtype) Sous-type
set t(encoding) Encodage
set t(current_encoding) {Encodage actuel}
set t(other) Autre
set t(custom_type) {Type utilisateur}
set t(need_to) {Tu dois spécifier au moins un destinataire (A:)}
set t(no_subject) {Sans sujet}
set t(admin) Administration
set t(newedit_folder) {Créer/éditer un dossier}
set t(update_folder) {Mettre à jour un dossier}
set t(sync_folder) {Synchroniser un dossier}
set t(update) {Mettre à jour un dossier}
set t(sync) {Synchroniser un dossier}
set t(continue) Continuer
set t(open_file) {Ouvrir le fichier}
set t(open) Ouvrir
set t(open_dbase) {Chercher dans la base de données}
set t(folders) Dossiers
set t(and) et
set t(or) ou
set t(not) non
set t(to) A
set t(subject) Sujet
set t(keywords) Mots-clés
set t(all) Tout
set t(search) Rechercher
set t(emptyexp) {Expression de recherche vide}
set t(to_file) {Dans le fichier}
set t(to_dbase) {Dans la base de données}
set t(insert_into_dbase) {Insérer dans la base de données}
set t(exdate) {Date d'expiration}
set t(extype) {Action à l'expiration}
set t(remove) Enlever
set t(add_incoming) {Insérer dans la boîte d'arrivée}
set t(backup) {Déplacer vers l'archive}
set t(insert) Insérer
set t(already_vfolderdef) {Il y a déjà une fenêtre d'édition des dossiers}
set t(vfolderdef) {Définir un dossier virtuel}
set t(window) Fenêtre
set t(close) Fermer
set t(browser) Browser
set t(folder) Dossier
set t(new_file) {Nouveau fichier dossier}
set t(new_mh) {Nouveau dossier MH}
set t(new_dbase) {Nouveau dossier dbase}
set t(new_imap) {Nouveau dossier IMAP}
set t(new_pop3) {Nouveau dossier POP3}
set t(new_dynamic) {Nouveau dossier dynamique}
set t(new_folder) {Nouveau dossier}
set t(need_name) {Tu dois spécifier un nom}
set t(create_submenu) {Créer un sous-menu}
set t(folder_name) {Nom du dossier}
set t(submenu_not_empty) {Tu veux vraiment supprimer ce menu et tous ses sous-menus ?}
set t(need_postilion_dir_title) {Créer un répertoire ?}
set t(need_postilion_dir1) {Ce programme a besoin d'un répertoire de configuration }
set t(need_postilion_dir2) {Il va être créé maintenant.}
set t(create) Créer
set t(dont_create) {Ne pas créer}
set t(failed_create) {Impossible de créer le répertoire}
set t(do_without_dir) {Je vais tenter de faire sans, mais sois averti que certaines opérations pourraient échouer}
set t(hold_message) {Garder le message}
set t(hold_failed) {Impossible de garder ce message}
set t(no_held) {Aucun message gardé}
set t(must_select) {Tu dois sélectionner un message}
set t(error_in_userproc) {Il y a une erreur dans le fichier 'userproc'}
set t(translate_error) {RatUP_Translate a produit une sortie illégale pour l'entrée suivante}
set t(reread_userproc) {Relire 'userproc'}
set t(preferences) Préférences
set t(watcher) Guetteur
set t(folderwindow) {Fenêtre Dossiers}
set t(general) Général
set t(appearance) Apparence
set t(sending) Envoi
set t(under_construction) {Aire en construction}
set t(language) Langage
set t(show_changes) {Messages changés}
set t(start_win) {Afficher la fenêtre}
set t(show) Montrer
set t(dont_show) Masquer
set t(dbase_dir) {Répertoire Base de données}
set t(apply) Appliquer
set t(reset) {Remise à zéro}
set t(unapplied_changes_title) {Changements non appliqués}
set t(unapplied_changes) {Tu as fais des changements qui ne sont pas appliqués. Que veux-tu en faire}
set t(discard) Oublier
set t(print_command) {Commande d'impression}
set t(tmp_dir) {Répertoire temporaire}
set t(file_permissions) {Droits de création des fichiers}
set t(userproc_file) {Fichier de procédures utilisateur}
set t(hold_dir) {Répertoire des brouillons}
set t(window_name) {Nom de la fenêtre}
set t(window_geometry) {Position de la fenêtre}
set t(icon_name) {Nom de l'icône}
set t(default_folder) {Dossier par défaut}
set t(default_list_format_mode) {Mode liste format}
set t(list_format) {Liste format}
set t(show_header_selection) {En-têtes sélectionnés}
set t(show_headers) {Montrer les en-têtes}
set t(default_sort_order_mode) {Mode ordre de tri}
set t(sort_order) {Ordre de tri}
set t(natural_order) {Ordre naturel}
set t(reverse_natural_order) {Ordre naturel inverse}
set t(by_date) {Par date}
set t(reverse_date) {Par date inverse}
set t(intervals) Intervalles
set t(stdfolders) {Dossiers standards}
set t(dbase_folders) {Dossiers Base de données}
set t(width) Largeur
set t(lines) lignes
set t(font) Police
set t(bell_ringings) Sonneries
set t(show_messages) {Montrer les messages}
set t(new) Nouveau
set t(reply_lead) {En-tête de réponse}
set t(signature_file) {Fichier de signature}
set t(masquerade_host_as) {Faire passer l'hôte pour}
set t(domain) Domaine
set t(smtp_hosts) {Hôte SMTP}
set t(charset) {Encodage des caractères}
set t(attribution) Attribution
set t(forwarded_label) {Libellé pour transmettre}
set t(alias) Alias
set t(fullname) {Nom complet}
set t(content) Contenu
set t(need_alias_and_content) {J'ai besoin à la fois d'un alias et d'un contenu}
set t(reread_aliases) {Relire les alias}
set t(dismiss) Fermer
set t(save) Sauver
set t(save_out) {Sauver le courrier sortant}
set t(save_to) {Sauver dans}
set t(create_vfolder) {Créer un dossier virtuel}
set t(dont_save) {Ne pas sauver}
set t(found_aliases) {J'ai scanné tes vieux fichiers et j'ai trouvé un total de}
set t(num_aliases) alias
set t(see_log) {Voir les vieux messages}
set t(seelog_title) {Vieux messages}
set t(does_not_exist) {n'existe pas}
set t(no_folder) {Pas de dossier ouvert}
set t(already_login) {Il y a un autre processus de login en route. Attends d'abord la fin de celui-là}
set t(login) Login
set t(opening) Ouvrir
set t(mailbox_on) {Boîte aux lettres sur}
set t(mailbox) {Boîte aux lettres}
set t(mailboxes) {Boîtes aux lettres}
set t(host) Hôte
set t(user) Utilisateur
set t(passwd) {Mot de passe}
set t(mbox) {Nom de la boîte aux lettres}
set t(reply_to_which) {Ce message contient des messages inclus. Choisi celui auquel tu   veux répondre}
set t(forward_which) {Ce message en contient d'autres. Lequel veux-tu transmettre ?}
set t(forwarded_message) {Message transmis}
set t(forward_as_attachment) {Transmettre comme attachement}
set t(forward_inline) {Transmettre en ligne}
set t(forward) Transmettre
set t(bounce) Bounce
set t(empty_message) {Message vide}
set t(structure) Structure
set t(view_source) {Voir le code source}
set t(source) Source
set t(help_window) {Fenêtre d'aide}
set t(site) Site
set t(access-type) {Type d'accès}
set t(directory) Répertoire
set t(server) Serveur
set t(smtp) SMTP
set t(user_program) {Programme défini par l'utilisateur}
set t(sendprot) {Expédier via}
set t(sendprog) {Programme d'expédition}
set t(progin) {Entrée du programme}
set t(eightbit) {Données en 8 bits}
set t(sevenbit) {Seulement des données 7 bits}
set t(subject_by_date) {Sujet par date}
set t(import) Importer
set t(import_directory) {Répertoire d'importation}
set t(cant_read) {Ne peut lire}
set t(ignored_not_file_not_dir) {est ignoré ; ce n'est ni un fichier, ni un répertoire.}
set t(bounce_which) {Ce message en contient d'autres.\nChoisis quel message tu veux renvoyer}
set t(lookup_name) {Recherche d'un nom}
set t(do_lookup) Rechercher
set t(dont_lookup) {Ne pas rechercher}
set t(dbase) {Base de données}
set t(dbase_backup) {Répertoire de sauvegarde}
set t(expire_interval) {Intervalle de purge}
set t(do_expire) {Purger la base de données}
set t(expire) Purger
set t(expire_result) {Résultats de la purge}
set t(scanned) Scanné
set t(deleted) Supprimé
set t(backedup) {Déplacé vers la sauvegarde}
set t(inbox) {Déplacé vers l'arrivée}
set t(db_expire) {Purge la base de données}
set t(packing_backup) {Compresse les sauvegardes}
set t(chunksize) {Taille de découpage}
set t(default_start_selection_mode) {Mode Sélection à l'ouverture}
set t(start_selection) {Sélection à l'ouverture}
set t(first_message) {Premier message du dossier}
set t(last_message) {Dernier message du dossier}
set t(first_new_message) {Premier message non lu}
set t(before_first_new_message) {Message précédant le premier message non lu}
set t(notifications) Avertissements
set t(notification) Avertissement
set t(failed) Echec
set t(delayed) {En attente}
set t(delivered) expédié
set t(relayed) transféré
set t(expanded) expansé
set t(dsn_text_failed) {Ton message à %s (%s) n'a pas réussi à arriver là-bas.}
set t(dsn_text_delayed) {Ton message à %s (%s) est en attente.}
set t(dsn_text_delivered) {Ton message à %s (%s) a été délivré.}
set t(dsn_text_relayed) {Ton message à %s (%s) a été transféré.}
set t(dsn_text_expanded) {Ton message à %s (%s) a été expansé. (?!)}
set t(see_more_of_message) {Voir plus du message retourné}
set t(original-envelope-id) {ID original de l'enveloppe}
set t(reporting-mta) {MTA ayant répondu}
set t(dsn-gateway) {Passerelle DNS}
set t(received-from-mta) {Reçu du MTA}
set t(arrival-date) {Date d'arrivée}
set t(original-recipient) {Destinataire original}
set t(final-recipient) {Destinataire final}
set t(action) Action
set t(status) Statut
set t(remote-mta) {MTA distant}
set t(diagnostic-code) {Code de diagnostique}
set t(last-attempt-date) {Date du dernier essai}
set t(final-log-id) {ID du log final}
set t(will-retry-until) {Sera retenté jusqu'à}
set t(log_timeout) {Statut du délai (timeout)}
set t(extra) Extra
set t(request_notification) {Notification de requête}
set t(dsn_directory) {Répertoire DNS}
set t(default_action) {Action par défaut}
set t(request_dsn) {Demander notification}
set t(not_request_dsn) {Ne pas demander notification}
set t(not_snarf_dsn) {Montrer les notifications dans la liste des messages}
set t(snarf_dsn) {Ne pas montrer les notifications dans la liste des messages}
set t(dsn_expiration) {Délais d'expiration}
set t(report_level) {Niveau de rapport}
set t(rl_none) Silencieux
set t(rl_status) {Dans la ligne d'état}
set t(rl_notify) {Dans une fenêtre séparée}
set t(cc) Copie-à
set t(bcc) Copie-secrète-à
set t(content_description) Description-contenu
set t(reply_to) Répondre-à
set t(bounce_to) {Bounce to}
set t(reply) Répondre
set t(comments) Commentaires
set t(comment) Commentaire
set t(default_from_mode) {Mode `From'}
set t(from) De
set t(date) Date
set t(received) Reçu
set t(message-id) Id-Message
set t(mime-version) Version-MIME
set t(content-type) Type-contenu
set t(auto-submitted) Auto-expédié
set t(default_reply_to_mode) {Mode Répondre-à standard}
set t(default_reply_to_addr) {Adresse Répondre-à standard}
set t(default_reply_to_fn) {Nom complet Répondre-à standard}
set t(default_reply_to) {Répondre-à standard}
set t(probe) Tester
set t(dsn_need_smtp) {Tu dois utiliser SMTP pour l'envoi des messages afin que les  notifications fonctionnent}
set t(probing) Teste
set t(supports_dsn) {Supporte les notifications}
set t(no_dsn_support) {Pas de support des notification}
set t(character_size) {Taille de la police}
set t(need_restart) {Tu dois relancer Postilion pour que tes changements prennent effet.}
set t(opening_folder) {Ouvre le dossier}
set t(read) lu
set t(write) écrit
set t(exec) exécute
set t(perm_user) Utilisateur
set t(perm_group) Groupe
set t(perm_other) Autres
set t(mode) Mode
set t(all_read) {Tous lus}
set t(all_read_write) {Tous lus & écrits}
set t(max_height) {Hauteur maximum}
set t(insert_failed) {Impossible d'insérer le message}
set t(define_keys) {Définir les raccourcis-clavier}
set t(folder_key_find) Rechecher
set t(folder_key_compose) Composer
set t(folder_key_quit) Quitter
set t(folder_key_nextu) {Prochain non-lu}
set t(folder_key_sync) Synchroniser
set t(folder_key_update) {Mettre à jour}
set t(folder_key_delete) Supprimer
set t(folder_key_undelete) {Annuler suppression}
set t(folder_key_flag) Marquer
set t(folder_key_seen) {Bascule marque}
set t(folder_key_ans) {Toggle Answered flag}
set t(folder_key_next) Suivant
set t(folder_key_prev) précédent
set t(folder_key_home) {Début du message}
set t(folder_key_bottom) {Fin du message}
set t(folder_key_pagedown) {Page suivante}
set t(folder_key_pageup) {Page précédente}
set t(folder_key_linedown) {Ligne suivante}
set t(folder_key_lineup) {Ligne préc.}
set t(folder_key_replya) {Répondre à tous}
set t(folder_key_replyq) {Répondre à l'auteur en citant l'original}
set t(folder_key_replyqa) {Répondre à tous en citant l'original}
set t(folder_key_replys) {Répondre à l'auteur}
set t(folder_key_forward_a) {Transmettre attaché}
set t(folder_key_forward_i) {Transmettre dans le texte}
set t(folder_key_bounce) Bounce
set t(folder_key_select_all) {Sélectionner tout}
set t(folder_key_deselect_all) {Déselectionner tout}
set t(add_key) Ajouter
set t(press_key) {Taper la nouvelle touche}
set t(key_defined) {Ce raccourci est déjà utilisée pour}
set t(replace_key) {Remplacer par la nouvelle définition}
set t(do_delete) {Tape le raccourci à supprimer}
set t(netscape_steal) {Il semble que netscape a pris tes message. Qu'est-ce qu'on en  fait ?}
set t(steal_back) {On les récupère}
set t(nothing) Rien
set t(check_stolen_mail) {Contrôler le courrier pris}
set t(check) Contrôle
set t(dont_check) {Pas de contrôle}
set t(take_mail) {Reprendre le mail de Netscape}
set t(remember_pos) {Position de la fenêtre}
set t(do_remember) Mémoriser
set t(dont_remember) Ignorer
set t(import_IMAP) {Dossiers IMAP}
set t(pattern) Motif
set t(host_required) {Tu dois spécifier un hôte}
set t(import_failed) {Import impossible}
set t(warning_sendprog) {ATTENTION : Le programme d'expédition spécifié n'existe pas ou n'est pas exécutable}
set t(automatic_wrap) {Passage à la ligne auto}
set t(automatic_indent) {Indentation auto}
set t(need_keyword) {Tu dois spécifier au moins un mot-clé}
set t(need_host_and_user) {Tu dois spécifier l'hôte ET l'utilisateur}
set t(opening_connection) Connexion...
set t(wait_greeting) {Attend le message de bienvenue du serveur...}
set t(get_capabilities) {récupère les infos des possibilités du serveur...}
set t(send_envelope) {Envoi les informations d'enveloppe...}
set t(send_from) {Envoi l'adresse...}
set t(send_rcpt) {Envoi le destinaaire...}
set t(send_data) {Envoi les données...}
set t(wait_ack) {Attend confirmation...}
set t(closing) {Ferme le canal...}
set t(sending_message) {Envoi du message...}
set t(smtpv) {Messages SMTP}
set t(normal) Normal
set t(verbose) Verbeux
set t(terse) Minimum
set t(import_aliases) {Import des alias}
set t(upgrade_dbase) {Mise à jour Base de données}
set t(old_dbase) {Tu as une vielle version de la base de données. Je dois la  convertir pour pouvoir l'utiliser.}
set t(unlinked_messages) {Messages non-liés}
set t(unl_m1) {Il y avait}
set t(unl_m2) {messages non-liés dans la base de données. Tu pourra les trouver dans le dossier `Messages non-liés'}
set t(send_deferred) {Envoi diferré}
set t(delivery_mode) {Mode d'expédition}
set t(direct) Direct
set t(deferred) Différé
set t(sending_deferred) {Envoi des messages en attente}
set t(to_send) {A envoyer}
set t(sent) Envoyé
set t(you_have) {Tu as}
set t(deferred_messages) {messages en attente. Veux-tu les envoyer maintenant ?}
set t(deferred_message) {message en attente. Veux-tu l'envoyer maintenant ?}
set t(send_now) {Envoi immédiat}
set t(no) Non
set t(waiting_on_sender) {En attente du processus d'expédition (il expédie)...}
set t(illegal_file_spec) {Fichier non valide spécifié}
set t(copy_attached_files) {Copie des fichier attachés}
set t(cache_conn) {Connexions cachées}
set t(failed_to_create_send_cache) {Tu ne pourra pas envoyer de message car je n'ai pas pu créer le  cache d'envoi}
set t(mh_name) {Nom MH}
set t(need_mh_name) {Tu dois donner un nom MH}
set t(failed_to_make_copy) {Impossible de créer une copie locale}
set t(color_scheme) {Shéma de couleurs}
set t(gray67) Gris
set t(PeachPuff2) Pêche
set t(bisque) Rose
set t(SlateBlue1) Bleu
set t(SteelBlue4) {Bleu acier}
set t(SkyBlue1) {Bleu azur}
set t(aquamarine2) {Vert clair}
set t(SpringGreen4) Vert
set t(patterns_to_use) {Séquence de caractères à rechercher dans les objets trouvés}
set t(files) Fichiers
set t(directories) Répertoires
set t(cache_passwd) {Mot de passe du cache}
set t(cache_timeout) {Délais d'expiration du cache}
set t(do_cache) Cacher
set t(do_not_cache) {Ne pas cacher}
set t(icon_bitmap) Icône
set t(normal_bitmap) {Normale (64x64)}
set t(button_bar) {Display button bar}
set t(buttons) {Icônes ou texte pour les boutons}
set t(text) Texte
set t(icon) Icône
set t(small_bitmap) {Petite (50x50)}
set t(xpm) {Image (48x48)}
set t(sync_but) {Sync button}
set t(sync_oper) {Sync button operation}
set t(set_to_inbox) {Boîte d'arrivée sélectionnée}
set t(set_to_open_on_startup) {Set to open on startup}
set t(set_to_min_on_startup) {Set to open minimized on startup}
set t(unset_to_open_on_startup) {Set to not open on startup}
set t(unset_to_min_on_startup) {Set to not open minimized on startup}
set t(group) Groupe
set t(create_in_win) {Créer dans une fenêtre}
set t(create_by_expr) {Créer par expression}
set t(use_saved_expr) {Utiliser l'expression enregistrée}
set t(clear_group) {Annuler la sélection du groupe}
set t(select_all) {Sélectionner tout}
set t(deselect_all) {Déselectionner tout}
set t(edit_group) {Editer le groupe}
set t(create_exp) {Créer une expression}
set t(basic_mode) {Mode standard}
set t(advance_on_flag) {Avancer après avoir marqué}
set t(flag_ans) {Toggle the Answered flag}
set t(flag_seen) {Marquer comme `Vu'}
set t(flag_unseen) {Marquer comme `Pas vu'}
set t(advanced_mode) {Mode avancé}
set t(save_as) {Enregistrer sous}
set t(fields) Champs
set t(operators) Opérateurs
set t(booleans) Booléens
set t(grouping) Regroupement
set t(sender) Expéditeur
set t(has) a
set t(is) est
set t(clear) Annuler
set t(error_underlined) {Erreur de syntaxe au mot souligné}
set t(syntax_error_exp) {Erreur de syntaxe dans l'expression}
set t(saved_expr) {Expression enregistrée}
set t(need_one_selected_exp) {Tu dois sélectionner une expression}
set t(here_is_text) {Il y a un texte encodé en}
set t(which_cant_be_shown) {qui ne peut être affiché correctement.}
set t(show_sevenbit) {Afficher avec les caractères 7 bits}
set t(convert_to_local_nl) {Convertir aux conventions locales}
set t(startup) Démarrage
set t(startup_mode) {Mode de démarrage}
set t(iconic) {En icône}
set t(file) Fichier
set t(insert_file) {Insérer un fichier}
set t(cut) Couper
set t(cut_all) {Tout couper}
set t(copy) Copier
set t(copy_all) {Tout copier}
set t(paste) Coller
set t(wrap_lines) {Saut de ligne automatique}
set t(run_through_command) {Filtrer par la commande}
set t(undo) Annuler
set t(redo) Refaire
set t(failed_to_open_file) {Impossible d'ouvrir le fichier}
set t(no_text_selected) {Aucun texte sélectionné}
set t(command_failed) {La commande a échoué}
set t(command) Commande
set t(command_is_running) {La commande s'exécute}
set t(folder_key_cycle_header) {Cycle les en-têtes affichés}
set t(watcher_enable) {Utilisation du guetteur}
set t(enabled) {En service}
set t(disabled) Désactivé
set t(command_list) {Liste de commande}
set t(compose_key_send) Envoyer
set t(compose_key_abort) Abandonner
set t(compose_key_editor) {Editeur externe}
set t(compose_key_undo) Annuler
set t(compose_key_cut) Couper
set t(compose_key_copy) Copier
set t(compose_key_cut_all) {Tout couper}
set t(compose_key_paste) Coller
set t(compose_key_replya) {Répondre à tous}
set t(compose_key_replyq) {Répondre à l'expéditeur (en citant)}
set t(compose_key_replyqa) {Répondre à tous (en citant)}
set t(compose_key_replys) {Répondre à l'expéditeur}
set t(compose_key_insert) {Insérer un fichier}
set t(compose_key_attach) Attacher
set t(sig_cmd_failed) {`RatUP_Signature' a échoué}
set t(bell_cmd_failed) {`RatUP_Bell' a échoué}
set t(sig_cmd_takes_precedence) {Tu as défini une RatUP_Signature qui masque le fichier signature !}
set t(more) Plus
set t(compose_sessions) {Tu as encore au moins une fenêtre de composition active}
set t(really_quit) {Vraiment quitter ?}
set t(do_quit) {Oui, quitter}
set t(dont_quit) {Non, finalement}
set t(use_from_address) {Utiliser l'adresse `From'}
set t(use_from_fn) {Utiliser Nom complet `From'}
set t(messages_shown) {Messages affichés}
set t(dbase_error) {Erreur dans la base de données ! Lancer le contrôle de la base  de données dans le menu Administration}
set t(dbase_check) {Contrôle de la base de données}
set t(check_dbase) {Contrôler la base de données}
set t(check_fix_dbase) {Contrôler & réparer la base de données}
set t(checking_dbase) {Contrôle la base de données}
set t(total_num_messages) {Nombre total de messages dans l'index}
set t(num_malformed) {Nombre d'entrées incorrectes (malformées)}
set t(num_nomessages) {Nombre d'entrées sans messages}
set t(num_unlinked) {Nombre de messages non-liés}
set t(total_size) {Taille totale des messages}
set t(waiting_dbase_lock) {Attente du verrouillage base de données}
set t(port) Port
set t(already_exists) {existe déjà}
set t(overwrite) Remplacer
set t(append) Append
set t(file_exists) {Le fichier existe}
set t(type_description) {Description du type}
set t(view) Voir
set t(view_as_text) {Voir comme du texte simple}
set t(external_viewer) {Utiliser un programme externe}
set t(cant_pipe) {Je ne peux passer les données à un programme utilisant la fenêtre de terminal}
set t(reread_mailcap) {Relire mailcap}
set t(mailcap_path) {Chemin pour mailcap}
set t(terminal_command) {Commande de terminal}
set t(vfolderedit) {Editer le dossier virtuel}
set t(delete_imap) {Supprimer aussi le dossier-IMAP réel ?}
set t(dont_delete) {Ne pas supprimer}
set t(print_headers) {Imprimer les entêtes}
set t(print_non_text) {Print non-text message parts}
set t(selected) Sélectionné
set t(aliases) Alias
set t(extract_adr) {Extraire les adresses}
set t(address) Adresse
set t(could_not_find_adr) {Je ne trouve aucune adresse à extraire}
set t(add_aliases) {Ajouter un alias}
set t(use) Utiliser
set t(missing_alias_name) {Il manque le nom de l'alias. L'entrée ne sera pas ajoutée.}
set t(alias_chooser) {Sélection d'un alias}
set t(set_to_save_outgoing) {Sélectionner pour sauver le courrier sortant}
set t(unset_to_save_outgoing) {Déactiver sauver la sortie}
set t(add) Ajouter
set t(smtp_timeout) {Hors délai SMTP}
set t(no_send_bad_host) {Postilion ne connaît pas le nom (de domaine) pleinement qualifié  sous lequel envoyer ton courrier ! Ce nom peut être fourni dans la  fenêtre préférences sous `expéditeur'. Les variables sont `faire  passer pour le domaine' et `Domaine' (l'une des deux suffit). Tu ne  pourra envoyer aucun courrier tant que ce ne sera pas défini (à moins  d'autoriser `passer outre' sur la même page).}
set t(force_send) {Forcer l'envoi}
set t(force) Forcer
set t(no_force) {Ne pas forcer}
set t(on_reply) {En réponse}
set t(skip_sig) {Ne pas incluse la signature}
set t(keep_sig) {Incluse la signature}
set t(subjectonly) {Par sujet}
set t(bysender) Expéditeur
set t(sign) Signer
set t(encrypt) Encrypter
set t(pgp_pass_phrase) {Mot de passe PGP}
set t(pgp_problem) {Problème avec PGP}
set t(retry) Réessayer
set t(sig) Sig
set t(default_signature_mode) {Mode de signature}
set t(signature) Signature
set t(none) Rien
set t(pgp_part) Part.
set t(pgp_none) Aucun
set t(pgp_unchecked) ?
set t(pgp_good) OK
set t(pgp_bad) Err.
set t(pgp_output) {Sortie PGP}
set t(warning_pgp_prog) {ATTENTION : le programme PGP spécifié n'existe pas ou n'est pas exécutable}
set t(pgp_handling) {Gestion PGP}
set t(pgp_program) {Programme PGP}
set t(pgp_extra_args) {Arguments supplémentaires pour PGP}
set t(decoded) Décodé
set t(send_bug) {Envoi d'un rapport de bogue}
set t(short_description) {Remplacer par une courte description}
set t(bug_report_template) {[Remplacer ce texte par une description détaillée du bogue. Si
tu as une erreur Tcl, n'oublie pas d'inclure la trace de la pile]}
set t(configuration_information) {Décrit ta configuration}
set t(send_bugs_etc) {S'il te plaît, envoie tes rapports de bogues et suggestions d'améliorations à nic@postilion.org pour la traduction française: dib@avo.fr}
set t(send_postcards) {Tu peux aussi envoyer une carte postale à:

Martin Forssen
Kabelgatan 13c
414 57 Göteborg
SWEDEN
(l'auteur de TkRAT)}
set t(sign_outgoing) {Contre-signer les messages}
set t(encrypt_outgoing) {Encrypter les messages}
set t(true) Oui
set t(false) Non
set t(attach_pgp_keys) {Ajouter les clés PGP}
set t(select_keys) {Clés sélectionnées}
set t(bits) Bits
set t(keyid) {ID Clé}
set t(user_id) {ID utilisateur}
set t(pgp_key_for) {Clé PGP pour}
set t(embedded_pgp_keys) {Il y a une ou plusieurs clés PGP attachées}
set t(add_to_keyring) {Ajouter à l'anneau}
set t(press_return_to_dismiss) {Appuie sur Retour pour fermer la fenêtre}
set t(decrypting) Décryptage...
set t(seconds) secondes
set t(days) jours
set t(url_viewer) Navigateur
set t(userproc) {Procédure utilisateur}
set t(netscape_cmd) {Commande Netscape}
set t(netscape_args) {Arguments pour Netscape}
set t(url_color) {Couleur URL}
set t(paper_color) {Couleur du papier}
set t(new_msg_col) {Couleur nouveau message}
set t(sel_msg_col) {Couleur message sélectionné}
set t(fnd_msg_col) {Couleur message trouvé}
set t(flg_msg_col) {Couleur message marqué}
set t(del_msg_col) {Couleur message supprimé}
set t(seen_msg_col) {Couleur message vu}
set t(ans_msg_col) {Couleur message répondu}
set t(smtp_reuse) {Réutiliser SMTP}
set t(addrbooks) {Carnets d'adresses}
set t(addrbook) {Carnet d'adresses}
set t(use_system_aliases) {Utiliser les alias systèmes}
set t(move_to) {Déplacer vers}
set t(set_default) {Définir par défaut}
set t(need_writable_book) {Tu dois laisser au moins un carnet d'adresses en écriture}
set t(book_already_exists) {Il y a déjà un carnet d'adresses avec ce nom}
set t(pgp) PGP
set t(find) Rechercher
set t(match) Correspondance
set t(exact) Exacte
set t(regexp) {Expression régulière}
set t(find_in) {Rechercher dans}
set t(message_list) {La liste des message}
set t(message_body) {Le corps du message}
set t(find_next) {Continuer la recherche}
set t(colorbug) {La version de Tcl/Tk que tu utilises a un bogue qui interdit de  changer la couleur avec cette option. Ce bogue a été réparé dans  tcl/tk 8.0}
set t(out_of_order) {Dans le désordre ;-)}
set t(default_to_browse) {Mode de parcours par défaut}
set t(browse_mode) {Mode parcours}
set t(default_browse_mode) {Mode de parcours par défaut}
set t(no_browse) {Ne pas utiliser le mode parcours}
set t(do_browse) {Utiliser le mode parcours}
set t(use_folder_default) {Utiliser la valeur par défaut du dossier}
set t(show_body) {Afficher le message}
set t(ignore_case) {Ignorer la casse}
set t(url_protocols) {Protocoles URL}
set t(prefix) {Style de date du préfixe dossier}
set t(spell_check) Orthographe
set t(balloon_help) {Bulles d'aide}
set t(subjects) Sujets
set t(warning) Attention
set t(do_not_show_again) {Ne plus montrer cet avertissement}
set t(warn_tk80) {Tu utilise tk8.0 qui a un sérieux bogue dans le code menu. Cela
provoque une erreur quand tu essaie d'ouvrir le menu dossier. Tu
devrais mettre à jour vers la version tk8.02p (ou suivante).}
set t(expunge_on_close) {Purger à la fermeture}
set t(do) Oui
set t(do_not) Non
set t(pending_cut) {Une opération 'couper' est en cours, la supprimer ?}
set t(menu_style) {Style Menu}
set t(next_style) {Style NeXT}
set t(ispellOnOff) {Utiliser Ispell}
set t(ispellRecheckAfterAdd) {Re-vérifier après des ajouts}
set t(ispellTextOnly) {Vérifier le texte seulement}
set t(ispellCommand) {Invocation d'ispell par défaut}
set t(ispellOthers) {Autres invocations}
set t(ispellPopupBinding) {Menu popup attaché à}
set t(ispellStyle) {Style des mots mal orthographiés}
set t(ispellStyleColor) {Couleurs de fond et de texte}
set t(ispellStyleOther) {Style si l'option autre est sélectionnée}
set t(underline) Souligné
set t(italic) Italique
set t(bold) Gras
set t(bgcolor) {Couleur de fond}
set t(fgcolor) {Couleur du texte}
set t(ispell) Orthographe
set t(mboxvis) {Afficher la vue Boîte aux lettres}
set t(drafts) ébauches
set t(new_user) {Nouvelles configurations d'utilisateur}
set t(finish) Finition
set t(set_name) {Veuillez écrire votre nom et 
prénoms et votre email address
comme il devrait apparaître 
dans vos messages.}
set t(compose_quit) {Do you wish to hold this draft, or abort it?}
set t(System) Systèmes
set t(Personal) Personal
set t(list) liste
set t(hide) Hide
set t(hide-sizes) {Hide Sizes}
set t(hide-deleted) {Hide Deleted}
set t(info) Info
set t(compact) Compact
set t(incorporate-mail) {Incorporate Mail}
set t(focus) Focus
set t(unfocus) Unfocus
set t(services) Services
set t(tcl-error) {Error in Tcl Script}
set t(skip-messages) {Skip Messages}
set t(stack-trace) {Stack Trace}
set t(isp-add) Add
set t(isp-dict) {to dictionary}
set t(isp-accept) Accept
set t(isp-for) {for this session}
set t(alternate) Alternate
set t(default) Default
set t(return_path) Return-Path
set t(pgp_sign) {PGP Sign}
set t(quote_color) {Quote color}
}
