#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_changes_de {} {
global changes
set changes(welcome_title) {Introduction to Postilion beta}
set changes(language) Language:
set changes(show_changes) {Changes messages:}
set changes(show) {Do show}
set changes(dont_show) {Do not show}
set changes(continue) Continue
set changes(welcome) {
Welcome to Postilion

Please select the language 
for the user interface.
}
set changes(features) {
  FEATURES

Postilion is a graphical Mail User Agent (MUA) which handles MIME. It is
mainly written in C but the user interface is done in tcl/tk. The
following is a non exhausting list of the capabilities:
    
    * Multilingual interface
	Currently English, Swedish and Italian are supported but it is not
	hard to add more languages.
    
    * MIME support
	Understands incoming text/plain, image/gif and message/rfc822
	content-types. These are decoded (if Quoted-printable or Base64)
	and shown (if the charset is compatible). Of multipart the
	multipart/mixed and multipart/alternate types are handled, all
	other multiparts are treated as mixed. All other content types
	are represented by an icon and can be either run through
	appropriate mailcap command, viewed as is or saved to file.
    
    * Supports MIME in headers
	Incoming header-lines are decoded as much as the character set allow
	and outgoing headers are encoded.
    
    * Composing
	Messages are composed with the built in editor (tk's text widget plus
	many extensions) or an external editor of your choice. You can attach
	files to your message.
 
    * Message database
	Messages can be inserted in a database. When inserting you add
	swords, expiration time and what to do when the expiration time
	is reached. Internally the messages are stored as flat text-files.

    * Virtual folders
	A virtual folder is a name that has been set on an ordinary folder
	(mbox, mh, IMAP or POP) or a database search expression.
	The user can define a menu structure which holds all the virtual
	folders and can then move messages to a folder or open a folder via
	the menu.

    * Message hold
	You can suspend the composing of a message by putting the message
	in the hold. The composing can then be continued at a later time.
	You can stop the program in the meantime. Multiple messages can
	be in the hold at the same time.

    * Watcher
	When the program is iconified it checks the current mailbox
	regularly. If a new message arrives a small window with a list
	of all messages (or only the new ones) in the mailbox is opened.
	The user can then either press the right mouse button in this
	window to make it go away and continue watching for new messages.
	Or press the left button to make the watcher window go away and
	the main window to deiconify.

    * Interface to the rest of the mail world
	The program currently understands unix mailboxes, POP, IMAP and mh
	folders. Messages are sent via SMTP or any user configured program
	(for example sendmail).

    * Supports Delivery Status Notifications
	Postilion supports the brand new DSN standard. This lets you see if  
	your message arrive safely at the destination. This requires an MTA
	that handles the DSN ESMTP extension (currently the only one I know
	of is sendmail-8.7 or later).

/MaF
}
set changes(changes_title) {Changes since you last used Postilion}
set changes(changes_in) {Changes in version}
set changes(0.8.0a) {
	*Inline support for MIME type text/html messages, thanks to 
	 Federico Di Gregorio <fog@perosa.alpcom.it> for prodding me 
	 to do this, and to Stephen Uhler (stephen.uhler@sun.com) 
	 whose html library I have incorporated.
	*TkStep8.0 support; thanks to Steve Murray 
	 <stevem@eng.uts.edu.au> and Oliver Graf for doing the 
	 wonderful port of Tk, and to Steve for giving me advanced 
	 warning of it.
	*All windows either have their own icons for miniwindows, or
	 do not allow miniturization.  Thanks to Rodrigo 
	 <rodas@geocities.com> for this suggestion, and to Marco van 
	 Hylckama Vlieg <fatal@pc23-c801.uibk.ac.at> for slaving away
	 at producing proper icons for this purpose.  These new icons 
	 are not currently included.
	*Several bug fixes; Thanks to all of you who have had problems. 
	 And also to Martin Frossen of TkRat fame, who has been killing
	 bugs just slightly faster than he's been producing them.
	*Implemented the new mailbox control window, getting rid of all
	 of the assorted mailbox menu items (such as message/move,
	 group/move and admin/new-edit mailboxes)
	*Rearranged the browser and compose windows to move the reply
	 and forward buttons onto the compose screen.  The "Reply to
	 Sender" and "Reply to All" buttons have been combined.
	*Added Ispell spell checking to the compose window; thanks to
	 George Farris <george@ve7frg.gmsys.com> for prodding me to do
	 this, and to Paul Raines (raines@slac.stanford.edu), from
	 whose TkMail package I have shamelessly stolen the TkIspell module.
	*Below are the pertinent sections from the changes file from
	 TkRat 1.0.5.  All of these changes have been incorporated into
	 Postilion-0.8.0a:
	971019: ***** released version 1.0.5 *****

	971019:	(bug fix) Both the advanced and the basic expression window
	 are now managed by teh grid manager. This hopefully fixes the problems
	 some people have with it turning into no size.

	971019:	(bug fix) Can now read the bad vfolderdef files which one
	 version generated.

	971019:	(bug fix) You could initiate a drag from an empty subfolder
	 in the New/Edit vfolder window. This gave tcl errors.

	971019: (bug fix) Should now never record a position such that no 
	 part of a window is visible. Also removed the annoying small window on
	 the first startup.
	
	971019:	(bug fix) Could dump core under some circumstances when syncing
	 an IMAP folder.

	971011:	(bug fix) You got an tcl error if you entered text in the
	 command text widget while no command was selected.

	971011:	(bug fix) Could dump core when saving copies of outgoing
	 messages to IMAP folders.

	971009:	(bug fix) An error of type "Cut & Paste" has occurred. The
	 code which did PGP checking was checking the wrong option(lookup_name)
	 to see if pgp was enabled or not.

	971008:	(bug fix) Now detects if a save copy of outgoing message fails
	 and warns the user. It could also crash when this happened.

	971007:	(bug fix) You could get a core-dump when you saved a copy of an
	 outgoing message to a file.

	971005:	(feature) The Makefiles now honors the environment variable
	 CFLAGS.  Another new feature is that the c-client libraries are not
	 rebuilt unless it is needed.
	
	971004:	(bug fix) Removed definition of global variable timezone.

	971004:	(bug fix) Fixed bad username in imap login which occured
	 when moving to an IMAP folder.

	971004:	(bug fix) Fixed case for some coredumps which occured if you
	 did cache connections but not passwords. Thanks goes to Marc Mengel
	 <mengel@FNAL.GOV>.

	971004:	(feature) Can now import mh-folder structures. Thanks goes to
	 Marc Mengel <mengel@FNAL.GOV>.

	971004:	(bug fix) Newly created vfolderlist files got the wrong version
	 number.

	971004:	(bug fix) Fixed waitpid() includes.

	971004:	(bug fix) Removed a big memory leak.

	971001:	(bug fix) Now checks that the signature file not is a directory
	 before trying to read it.

	971001:	(bug fix) Saving the aliases found when scanning the old files
	 did not work.

	971001:	(bug fix) TkRat got into an incosistent internal state if one
	 deleted a compose window with the window manager.

	971001:	(bug fix) Copying aliases from one address book to another
	 did not make sense (the names must be unique anyway).

	971001:	(bug fix) The reverse natural sort order was not reversed.

	971001:	(bug fix) Misc code cleanups which should reduce number of
	 warnings and errors on 64bit systems.

	970921:	(bug fix) The apdding macro in ratAddress had a bug so it
	 did not work to read aliases on ultric machines.

	970921:	(bug fix) The new FormatDate function added an extra space
	 to the date.

	970918:	(bug fix) Removed an old reference to option(aliases_file)
	 in convert.

	970918:	(feature) Added doc/userproc.example

	970917:	(bug fix) TkRat dumped when you tried to save to a dynamic
	 folder.

	970916:	(bug fix) Crashed when trying to save outgoing messages to an
	 IMAP folder.

	970916:	(bug fix) The conversion of aliases failed (to update the list
	 of aliases shown).

	970916:	(bug fix) You could get an error when closing the alias window.

	970912: ***** released version 1.0.4 *****

	970907:	(bug fix) The "move to inbox" expiration type did not work.

	970904:	(bug fix) Ignore set flag requests for read-only mailboxes.

	970902:	(bug fix) Made the calling for userprocs from C robus against
	 errors in the routines.

	970901:	(bug fix) Now doesn't set the answered flag when you forward
	 a message.

	970901:	(bug fix) Messages from yourself got named To: <recipient> when
	 saved to a dynamic folder.

	970831:	(bug fix) Fixed coredump which occured when one entered an
	 rfc822	group address.

	970831:	(enhancement) Did some speed optimizations.

	970827:	(enhancement) Redid the caching controls. All the different 
	 caching is now controlled by identical set of preferences and you
	 can also set infinite caching (by setting teh timeout to zero).

	970824:	(bug fix) At last! An old bug which made saving copies of
	 outgoing messages via imap to picky (well, not extremely forgiving)
	 IMAP servers fail is at last fixed. Big thanks goes to Greg Owen
	 <gowen@xis.xerox.com> for help with debuuging.

	970824:	(feature) Implemented a browse mode. In this mode the actual
	 message bodies are not shown by default. This mode is selecatble via a
	 menu and via a folder default.

	970824:	(bug fix) TkRat tried to decrypt old style encrypted PGP
	 messages even if you had pgp support turned off. This is now fixed.

	970824:	(feature) It is now impossible to change the color scheme
	 if your tk is older than 8.0. These versions had a bug which
	 made this not work anyway. You get a warning instead.

	970824:	(feature) Added a find window which can search the message
	 body or the list of messages. Had to convert the list of messages
	 to a text widget to be able to acomplish this.

	970823:	(feature) The URL parsding is now done on demand instead of all
	 at once. Also made a small modification to the search expression.

	970806:	(feature) Many internal changes in the preferences window.
	 Partly	a new look as well.

	970805:	(bug fix) The state of the Watcher button in the TkRat menu
	 was not always saved correctly.

	970804:	(bug fix) The signature was wrongly calculated when you signed
	 a message which was constructed by forward as attachment.

	970804:	(bug fix) TkRat dumped when you tried to repy to an
	 encrypted message.

	970804:	(bug fix) group move operations were not aborted when an error
	 occurred.

	970804:	(bug fix) The ChooseMessage dialog asked which message you
	 wanted	to reply to when you were forwarding inline. Message fixed.

	970803:	(feature) Added private version of bgerror with "Send bug
	 report" button to make it easier to report tcl bugs.

	970803:	(feature) Rewrote the alis window from scratch. Many
	 enhancements to the alias system in general as well.

	970728:	(feature) Aliases can now nest any level (but not loop).

	970721:	(bug fix) Fixed problem with stealing mail from netscape.

	970719:	(bug fix) The menu shortcuts <Alt-?> should no longer also
	 invoke	any other bindings.

	970706:	(feature) TkRat now send multiple messages through one
	 SMTP-channel when sending deferred. The send deferred window
	 now behaves better when you send more messages while already sending.

	970706:	(bug fix) TkRat now survies if $HOME ends with a /.

	970706:	(bug fix) TkRat is now more resistent to bad images in
	 attachments.

	970704:	(bug fix) Improved appending to imap folders code.

	970701:	(bug fix) TkRat dumped core if the users gecos field contained
	 any non us-ascii characters.

	970701:	(feature) The show URL feature is now bound to the
	 ButtonRelease event (and you can cancel by moving the pointer
	 before releasing).
}
set changes(0.8.1) {
	*Numerous bug fixes.  I've forgotton just which ones, but at this
	 point I'm not aware of any bugs.  Anyone using any version of
	 Postilion/WMRat should definately upgrade to this release
	*Added new FCC style dynamic folders, with store by date sent or
	 recipient.  Note: At this time it is not possible to move messages
	 into date sorted dynamic folders.  Hopefully this will change.
	*Added new preferences setting to control new dynamic folders
	*Added new mode selection for text or icon buttons.  Text mode is
	 much faster to load on low horsepower systems.
	*Double clicking on a mailbox in the mailbox widget will now open
	 that mailbox in the main window.
	*New configure script to fix problems with using TkStep.
}
set changes(0.8.1a) {
	*miscellanious bug fixes
}
set changes(0.8.2) {
	*Per mailbox settings for the following features:
	      Folder sort order 
	      Message list format
	      Selected message on startup
	      From address
	      Reply to address
	      Signature file
	      Save to folder (Fcc:)
	*New clock/calendar widget in the mailbox browser window which
	 shows the time and date which the message was sent (stolen
	 shamelessly from asclock).
	*Added a new setting to determine whether to advance after
	 flagging a message in the message list.
}
set changes(0.8.3) {
	*Added true multi-window support.  Multiple mailboxes can be
	 open simulaneously, as can multiple compose sessions.
	*Added NeXT style application menu.  Menu reflects current
	 context (ie: if a compose window is active, editing features
	 are available.)  All menus have been removed from individual
	 windows.  This feature really requires that the user use
	 Click-to-focus mode, as focus follows mouse can make it hard
	 to use the menus (they wont stay in the state you want).
	*Added menu choice, and accelerator key for the copy operation
	 in a compose window.
	*Fixed nagging bug with the sash widget in the mailbox window.
	*Fixed the bug where the INBOX wouldn't show up in mailbox lists
}
set changes(0.8.4) {
	*Added new menu choices and keyboard accelerators to the mailbox
	 window to support sending unquoted as well as quoted replies. R
	 is reply all unquoted, r is reply unquoted, Q is reply all
	 quoted, q is reply quoted.
	*Added keyboard accelerators to the compose window similar to
	 those above, but with Control (ie: Control-Q).
	*Added Subject: display in compose window titlebar and icontitle.
	*Added mailbox name in icontitle for mailbox windows.
	*Made compose window buttons sane with respect to above functions.
	*Messages will no longer be marked as seen until the body has been
	 displayed, in browse mode.
	*Pressing the Page-Down keybinding (the space key, by default)
	 while in browse mode will display the body of a message, and
	 then return to page-down operation, until another message is
	 selected, etc.  This allows for quick skimming through a large
	 mailbox using only the Next Message (n) or Next Unread Message
	 (tab) and Page-Down (space) keys.
	*The Folder/Open, Message/Move and Group/Move menus have been
	 eliminated.  Try using one with several hundred mailboxes and
	 you won't ask me why.  This functionality is still available
	 via the hierarchical mailbox browsing widget (the Mailboxes window).
	*When using the Find widget in the mailbox window, the next and
	 previous keybindings are restrained to messages matching the
	 find criteria, allowing quick browsing through messages.
	*Changed default keybindings to match more typical applications
	 (ie:Insert for paste).
	*Removed unused cruft left from TkRat (no disrespect intended).
	*Removed all redundant widgets (such as New/Edit vfolders and Alias editor)
	*Changed default behaviour to not delete the actual imap folders
	 when deleting an imap mailbox.
}
set changes(0.8.4a) {
	*Changed all icons and images from XPM or TIFF to GIF format. 
	 Time to start the application on my X-Terminal at work went
	 from 1 minute to 3 seconds.
	*Changed the Quit procedure to gracefully close all child windows,
	 and save all changes to disk before closing.
}
set changes(0.8.5) {
	*Incorporated all changes from TkRat 1.1 (previously used 1.0.5).
	 Some highlights include:
		*Various Makefile fixes
		*Timezone function checking in the configure cycle.
		*Other configure changes to support more platforms better
		 (ie: RedHat 5.0, Solaris, FreeBSD).
		*Spaces may now be used in the address fields without
		 special keystrokes.
		*Improvements in the code used to determine if the message
		 is from yourself.
		*Changed copyright statement.
		*When you move a flagged message to another folder the
		 flagging is cleared instead of kept as it used to be.
		*Changed the default tk binding for entries and text so
		 that the selection is not cleared as soon as you move the
		 cursor.
		* Added documentation in CONFIGURATION-file of how to set
		 the system address book.
		*Total rewrite of the help system. There are now balloon
		 help entries for most buttons and fields and the help
		 window is much more intuitive (as well as redone).
	*Updated the C-Client library, the backend for Postilion.
	*Added menu choices and key accelerators to flag messages as seen
	 or unseen.
	*Added balloon help for all Postilion menus and widgets.
	*Added Startup options such as which windows to open, etc.
}
set changes(0.8.5a) {
	*Removed invalid language entries from message, help and balloon
	 help text files.
	*Re-added traditional menus, with NeXT style menus as an option. 
	 This is set in the Startup pane in preferences.
	*Added mailbox cut and paste in the Mailboxes window.  This allows
	 you to cut a mailbox, or an entire hierarchy from the tree, and
	 paste it elsewhere in the tree.
	*When a preference requiring a restart is changed, the program will
	 close.  This is to prevent instabilities caused by changing things
	 behind the backs of some widgets.
}
set changes(0.8.5b) {
	miscellanious bug fixes
}
set changes(0.8.6) {
	*Added support for System wide IMAP mailboxes.  During startup,
	 Postilion will search for a file called sysvfolderdef in the
	 global configuration directories.  If it exists, this file is
	 sourced.  See the demo file in the docs directory for details
	 of how system mailboxes work.
	*Added Focus/Unfocus commands.  These constrain the
	 Next/Previous/Next-Unread keys to the set of flagged messages
	 in a mailbox.
	*Added a sense of focus to the find command.  When finding in a
	 message list, the function of the Next/Previous/Next-Unread keys
	 are constrained to the messages matching the find.
	*Added color coding to the message list.  Blue for answered, Red
	 for flagged, Green for unseen, Yellow for deleted.
	*Added new feature allowing a drag-to-flag behaviour.  When the
	 right mouse button is dragged across the message list, it will
	 flag a range of messages.
	*Added menu entries and keybindings for Select-All, Delselect-All
	 to facilitate bulk message flagging.
	*Removed the Create-in-window group option, as it is no longer
	 needed with the above changes.
	*Fixed a bug with pressing the enter key whilein the Find window.
}
set changes(0.8.7) {
	*Added new mailbox view area to main browser window.  This view
	 lets you select and open mailboxes and move messages between
	 mailboxes, without having the Mailboxes window on the screen. 
	 The Mailboxes window is still needed to manage mailboxes.  There
	 is a "Show Mailbox View" option which can be turned on in the
	 "Folder" pane in Preferences.  There is also a new sash above
	 the message list which, when selected, will pop down the mailbox
	 view, another click and the view closes.
	*Changed the Ispell implementation to that used by Exmh.  Spell
	 checking is now done on-the-fly, with misspelled words flagged
	 in user configurable styles.  Check the balloon help in the new
	 "Ispell" pane in the preferences window for all of the new
	 settings/options.
	*Changed the way the the date/time is set in the clock widget in
	 the Browser windows.  The clock will now display the message
	 time and date even when the Date: header is not displayed, and
	 will display all zeros when there is no message selected.
	*Changed the class and instance information of all windows.  All
	 windows now have the class "Postilion" and an instance which
	 reflects their purpose.  Anyone who is using class or instance
	 information in .Xdefaults or similar such things may need to
	 update their files.  WindowMaker users may need to update
	 configurations.  I will try not to alter this information any further.
	*Fixed a memory coruption problem in the date-style dynamic
	 folder code.  Messages can now be moved into date-style dynamic
	 folders (much thanks to Tim Chase for finding this bug).
	*No longer allow <spaces> to be entered into the alias field of
	 the address widget.  Spaces are not allowed in alias names.
	*Added a hot-key (Control-i) to the compose window to pop up the
	 Insert File dialog box.
	*Some default key bindings have changed.  Check the Define Keys
	 item in the Info menu for each window type to see what all is
	 different.
	*All windows should now hide properly.
	*Fixed an ancient bug in the window sizing code.  Postilion
	 windows will now properly remember their size and placement. 
	 Only the first window of a given type will be mapped into the
	 stored location, and only the last one closed will record it's
	 size/position.
	*Fixed a bug which sometimes caused dialog boxes to not map correctly.
	*Numerous other major and minor bug fixes.
}
set changes(0.8.8) {
	*Copyright changed to GPL 2.0
	*Addresslist made more compatable with regular Tk (as opposed to
	 TkStep).
	*Postilion will now let you send a message with no address in To:, as
	 long as there is at least one address in either Cc: or Bcc:.
	*The Spell Check button has been removed from the compose window.
	 On the fly spell checking remains, and there is a Spell Check item 
	 in the Edit menu.
	*Attach and Detach buttons on the Compose window have been stacked
	 together, to save space.
	*Changed the default when quitting a compose session to be "abort"
	 instead of "hold".
	*Changed alias expansion to expand to full address, with full name,
	 if available.  Previous behavior was only to expand upon sending.
	*Changed file attachment symantics to comply with newer RFCs.  
	 Postilion should now interoperate cleanly with all modern MUAs when
	 attaching files, preserving filenames appropriately.  Buffer overflow
	 file attachment trojan horses are not a problem.
	*Added simple Date field to expressions.  This is not fully functional
	 yet, but can allow for simple selection by date and date range.
	 (expect more in coming releases).
	*Changes have been made in some icons (Thanks Marco!!).  Each
	*window type gets its own mini-window icon now.
	*Mailbox Compact (sync) button has been removed from the Mailbox 
	 browser window to save space.  The menu choice is still there, as is
	 the hot key.
	*Message status colors are now user settable, in Preferences.
	*Numerous window sizing and placement bugs have been fixed (thanks
	 to Kenneth J. Dowling <kdowling@concentric.net>).
	*Numerous bugs with message list selection, sorting, etc. fixed.
	*Fixed bug with Ispell process not ending, and Postilion processes
	 hanging around (thanks to Kenneth J. Dowling 
	 <kdowling@concentric.net>).
	*Help text changed to eliminate references to TkRat. (thanks to 
	 Dave Whitinger <dwhiting@adc.com>).
	*Some improvements have been made in the focus of windows during
	 various operations.
	*Several new image types are now supported with the use of 
	 Jan Nijtmans' <nijtmans@nici.kun.nl> Img library.  This
	 library will be used, if present, to automatically display all
	 MIME attachments of supported formats (JPEG, PNG, TIFF, GIF, XPM,
	 XBM, Postscript, PDF).
	*Fixed numerous bugs with un-initialized variables.
	*New Preferences pane, Appearance, which collects all of the 
	 appearance related settings, such as colors, in one place. 
	*Postilion will no longer close if there is a sharing violation
	 on a mailbox.  The mailbox browser will close for that mailbox, but
	 the main program will only close if that mailbox browser is the only
	 window open.
	 *Postilion will now automatically close when its last window is 
	 closed.
	*The newest version of the C-client library is included.
}
set changes(0.8.8a) {
	*Fixed typo which caused color choice settings in the preferences
	 dialog to not be saved.
}
set changes(0.8.8b) {
	*Reinstalled code which closes program when last window closes.
	 (lost in code transfer).
	*Fixed message selection during and after moves.
}
set changes(0.8.9) {
	*Fixed focus problem when new mail comes in to a different window
	 than the currently active one.
	*Fixed bug with message flagging.
	*Other minor bug fixes.
	*Upgraded c-client toolkit.
}
set changes(0.9.0) {
	*Added new PGP buttons to the compose window when PGP is enabled.
	 Note: The meaning of the PGP lock button is now encrypt, where
	 it used to be attach keys.  There are now separate buttons for attach
	 keys and sign.  There is also now a button for DSN notification
	 request.  These buttons will auto size and auto arrange to account
	 for different PGP confiigurations, so your compose windows may
	 appear different from the picture on the web site.
	*Fixed longstanding bug with mailbox sorting.  Much thanks to
	 Luke Kendall <luke@zeta.org.au>, the newset member of the
	 Postilion development team.
	*Added CREDITS and COPYRIGHT.images files.
	*Added check for tkstepConfig.sh to the configure script.
	*Proper detection and configuration for AIX4.2.
	*Added option to expunge deleted messages on mailbox close.
	*Fixed bug with password caching.
	*Added option to display a Syncronize button in the browser
	 window.  The operation mode of this button is configurable.
	*Added option to not print non-text attachments.
	*Added options to open selected mailboxes on startup.  Such
	 mailboxes may be opened minimized or not.
	*Added option to append to an existing file when saving message
	 parts from the message window.
	*Numerous bug fixes in address book.
	*When quoting a message, if text is selected in the message being
	 quoted, only that text will be quoted.
	*Bug fixed in importing mailrc file aliases.
	*Fixed the behavior of the New button in the Mailboxes window.
	*Fixed a bug with clicking on URLs with commas in them.
}
set changes(0.9.1) {
	*Changed copyright on all images to OpenContent license (OPL).
	*Added new Bounce command, which will bounce a message to a new 
	 address or addresses.
	*Fixed bug with saving messages with no From: header to a dynamic
	 mailbox (thanks Luke!).
	*Fixed memory leak in folder sort code (Luke again).
	*Fixed bugs introduced into printing code, and other areas, in last
	 release.
	*Fixed bug which prevented salvaging messages which couldn't
	 be sent properly.
	*Fixed some bugs with the message hold.
	*Fixed bug which caused preferences window to think you had made
	 changes when you hadn't.
	*Fixed bug in expire code.
	*Fixed Changes alerting system (what you're reading right now).
}
set changes(0.9.1a) {
	*Fixed bugs with send/save, bounce and Send bug report.
	*Added new setting "Display Button Bar" to Appearences
	 pane in Preferences.
	*Added Send and Send/Save entries to Compose menu.
}
set changes(0.9.2) {
	*Fixed bugs with send/save, bounce and Send bug reort.
	 I really mean it this time!!
	*Added "Flag as answered" command.
	*Changed all "Flag as ..." commands to act as toggles.
	*Fixed bug with "Import MH Directory" function.
	*Fixed bugs introduced into DND functions.
	*Fixed Sender style dynamic folders to create files with
	 usable names.  For example, a message sent by
	   "John Smith" <jsmith@abcdef.com>
	 used to get saved as 
	   John Smith <jsmith
	 which Postilion could then not open. Now it will be saved as
	   John Smith
	 which Postilion can open. (Thanks to Tim Wundke!).
	*Cleaned up mailbox list maintenance code.  This should reduce
	 the size of "vfolderlist" files.
	*Removed the HTML parsing code.  This was the single largest
	 source of bug reports, so it is now gone.  I am working with
	 some replacements, and should have something worked out soon.
	*Updated Swedish translation (Thanks to Martin S.!).
}
set changes(0.9.3) {
	*Added new graphical configurator-builder-installer.
	*Added German language translations for messages and balloon
	 help (thanks to Rene´ Gerard Herrmann <rene.herrmann@gmx.de>).
	*Changed most references to "Folder(s)" to "Mailbox(es)".
	*Added support for more recent versions of AIX.
	*Added new listformat option, %f, which shows filename for MH
	 mailbox entries (Thanks to Darko Koruga <darko.koruga@hermes.si>).
	*Fixed problem with compiler warnings in ratMessage.c
	*Fixed bug which prevented deleting addressbooks.
	*Added mouse wheel support (Thanks to Stephen Ryan
	 <stephen.ryan@dartmouth.edu>).
	*Added option to disable automatic word wrap and automatic
	 indent globally.
	*Added option to cancel when aborting a compose session.
	*Added menu entry and keyboard shortcut for Attach.
	*Fixed bug with "...dummy is an array..." in Ispell implementation.
	*Modified Mailboxes window so that user can't delete dynamic
	 mailbox children (caused problems).
	*Added menu entry for External Editor.
	*Improved internationalization support in areas where it was weak,
	 such as menus, Ispell, etc.
	*Changed default for Drag and Drop support to off.
	*Added feature to use environment variable MAIL to determine
	 location of Inbox, if not otherwise set.
	*Added feature to color quoted lines in messages.
	*Re-implemented support for HTML - this is still a bit rough.
	*Improved URL parsing.
}
set changes(0.9.3a) {
	*Fixed various bugs with language files and preferences names.
}
set changes(0.9.3b) {
	*Fixed another bug in the preferences code.
	*Added support for Dutch language (Thanks to Pieter J. Kersten
	 <kersten@dia.eur.nl>).
}
set changes(0.9.3c) {
	*(This apparently didn't make it into the last release) fixed 
	 another bug in the preferences code.
}
}
