#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_t_it {} {
global t
set t(postilion) Postilion
set t(version) Versione
set t(about) Informazioni
set t(quit) Esci
set t(name) Nome
set t(size) Dimensione
set t(messages) Messaggi
set t(help) Aiuto
set t(ok) Ok
set t(cancel) Annulla
set t(ratatosk) {Ratatosk. Nella mitologia norvegese, lo scoiattolo che corre su e giù per l'albero cosmico, Yggdrasil, portando insulti dal drago Nidhog, ai piedi dell'albero, all'aquila in cima, e viceversa.}
set t(posthorn) {Postilion. A person who rides on a horse which is pulling a carriage, to guide it. It was only in the early nineteenth century that roads suitable for vehicles made it possible for coaches to cross Alpine passes. The postal horn was an essential instrument to the postilion, who used it to signal his presence on the steep, winding roads. The postal horn is the symbol in yellow shown in the icon for Postilion. Do you know why a horn appears on mailboxes? Messengers and postilions used a small brass horn to signal their arrival. Use of the horn soon became obligatory for the postilion, who had to know at least eight signals, each with a particular meaning: arrival, distress, departure, and so on. But what made the horn so popular was its constant use over several centuries, rather than the regulations requiring that it be carried. Today the horn is the postal emblem of many countries.}
set t(months) {Gen Feb Mar Apr Mag Giu Lug Ago Set Ott Nov Dic}
set t(clock_format) {Clock format}
set t(12_hour) {12 Hour}
set t(24_hour) {24 Hour}
set t(move) Muovi
set t(delete) Cancella
set t(undelete) {Annulla cancella}
set t(compose) Componi
set t(reply_quote_sender) {Quote to sender}
set t(reply_quote_all) {Quote to all}
set t(quote) {Quote original message}
set t(no_quote) {Do not quote original message}
set t(reply_sender) {Rispondi al mittente}
set t(reply_all) {Rispondi a tutti}
set t(here_is) {Qui c'è un oggetto di tipo}
set t(show_all) {Mostra tutti}
set t(old_dirs) {Usato in precedenza}
set t(save_to_file) {Salva file}
set t(save_failed) {Impossibile salvare}
set t(message) Messaggio
set t(print) Stampa
set t(show_all_headers) {Mostra tutte le intestazioni}
set t(show_selected_headers) {Mostra alcune intestazioni}
set t(show_no_headers) {Non mostrare intestazioni}
set t(compose_name) {Componi messaggio}
set t(edit) Modifica
set t(edit_body) {Corpo del messaggio}
set t(edit_headers) {Intestazioni del messaggio}
set t(custom_headers) {Custom headers}
set t(read_from_file) {Leggi da file}
set t(abort) Anulla
set t(headers) Intestazioni
set t(attachments) Allegati
set t(attach_file) {Allega file}
set t(attach) Allega
set t(attach_special) {Allega speciale}
set t(detach) Rimuovi
set t(send) Spedisci
set t(send_save) {Spedisci e Salva}
set t(hold) Mantieni
set t(getheld) {Composizione mantenuta}
set t(external_editor) {Editor esterno}
set t(running_ext_editor) {Eseguendo editor esterno...}
set t(filename) {Nome file}
set t(description) Descrizione
set t(disposition) Disposition
set t(id) Identificatore
set t(type) Tipo
set t(subtype) Sottotipo
set t(encoding) Codifica
set t(current_encoding) {Codifica corrente}
set t(other) altro
set t(custom_type) {Tipo utente}
set t(need_to) {Devi specificare almeno un destinatario (A:)}
set t(no_subject) {Nessun soggetto}
set t(admin) Amministrazione
set t(newedit_folder) {Nuova/Modifica cartella}
set t(update_folder) {Aggiorna cartella}
set t(sync_folder) {Sincronizza cartella}
set t(update) {Aggiorna cartella}
set t(sync) {Sincronizza cartella}
set t(continue) Continua
set t(open_file) {Apri file}
set t(open) Apri
set t(open_dbase) {Cerca nel database}
set t(folders) Cartelle
set t(and) e
set t(or) o
set t(not) non
set t(to) A
set t(subject) Soggetto
set t(keywords) {Parole chiave}
set t(all) Tutti
set t(search) Cerca
set t(emptyexp) {Chiave di ricerca vuota}
set t(to_file) {In file}
set t(to_dbase) {In database}
set t(insert_into_dbase) {Inserisci in database}
set t(exdate) {Data di scadenza}
set t(extype) {Azione di scadenza}
set t(remove) Rimuovi
set t(add_incoming) {Inserisci in entrata}
set t(backup) {Muovi in archivio}
set t(insert) Inserisci
set t(already_vfolderdef) {C'è già una finestra di modifica cartella}
set t(vfolderdef) {Definisci cartella virtuale}
set t(window) Finestra
set t(close) Chiudi
set t(browser) Browser
set t(folder) Cartella
set t(new_file) {Nuova cartella file}
set t(new_mh) {Nuova cartella mh}
set t(new_dbase) {Nuova cartella database}
set t(new_imap) {Nuova cartella IMAP}
set t(new_pop3) {Nuova cartella POP3}
set t(new_dynamic) {Nuova cartella dinamica}
set t(new_folder) {Nuova cartella}
set t(need_name) {Devi specificare un nome}
set t(create_submenu) {Crea sottomenu}
set t(folder_name) {Nome cartella}
set t(submenu_not_empty) {Vuoi davvero cancellare questo menu è tutti i sottostanti?}
set t(need_postilion_dir_title) {Crea una directory?}
set t(need_postilion_dir1) {Questo programma ha bisogno di una directory di configurazione }
set t(need_postilion_dir2) {Verrà creata ora}
set t(create) Crea
set t(dont_create) {Non creare}
set t(failed_create) {Impossibile creare la directory}
set t(do_without_dir) {L'esecuzione continuerà senza, ma certe operazioni potrebbero fallire.}
set t(hold_message) {Mantieni messaggio}
set t(hold_failed) {Impossibile mantenere messaggio}
set t(no_held) {Non ci sono messaggi}
set t(must_select) {Devi selezionare un messaggio}
set t(error_in_userproc) {C'è un eroore nel file delle procedure utente}
set t(translate_error) {RatUP_Translate ha generato un risultato incorretto per il seguente parametro}
set t(reread_userproc) {Rileggi userproc}
set t(preferences) Preferenze
set t(watcher) Controllo
set t(folderwindow) {Finestra cartella}
set t(general) Generale
set t(appearance) Appearance
set t(sending) Spedizione
set t(under_construction) {Lavori in corso}
set t(language) Lingua
set t(show_changes) {Messaggi cambiamenti}
set t(start_win) {Show windows}
set t(show) Mostra
set t(dont_show) {Non mostrare}
set t(dbase_dir) {Directory database}
set t(apply) Aggiorna
set t(reset) Azzera
set t(unapplied_changes_title) {Cambiamenti non aggiornati}
set t(unapplied_changes) {Hai fatto dei cambiamenti che non sono stati aggiornati. Cosa vuoi farne}
set t(discard) Scarta
set t(print_command) {Comando di stampa}
set t(tmp_dir) {Directory temporanea}
set t(file_permissions) {Parametri d'accesso}
set t(userproc_file) {File userproc}
set t(hold_dir) {Directory d'attesa}
set t(window_name) {Nome finestra}
set t(window_geometry) {Posizionamento finestra}
set t(icon_name) {Nome icona}
set t(default_folder) {Cartella iniziale}
set t(default_list_format_mode) {Moda formato lista}
set t(list_format) {Formato lista}
set t(show_header_selection) {Intestazioni selezionate}
set t(show_headers) {Mostra intestazioni}
set t(default_sort_order_mode) {Ordine moda}
set t(sort_order) Ordine
set t(natural_order) {Ordine naturale}
set t(reverse_natural_order) {Ordine naturale inverso}
set t(by_date) {Per data}
set t(reverse_date) {Per data inversa}
set t(intervals) Intervalli
set t(stdfolders) {Cartelle normali}
set t(dbase_folders) {Cartelle database}
set t(width) Larghezza
set t(lines) Linee
set t(font) Carattere
set t(bell_ringings) {Numero di beep}
set t(show_messages) {Mostra messaggi}
set t(new) Nuovo
set t(reply_lead) Risposta
set t(signature_file) {File signature}
set t(masquerade_host_as) {Host appare come}
set t(domain) Dominio
set t(smtp_hosts) {Host SMTP}
set t(charset) {Gruppo di caratteri}
set t(attribution) Attribuzione
set t(forwarded_label) {Etichetta rispedita}
set t(alias) Alias
set t(fullname) {Nome completo}
set t(content) Contenuto
set t(need_alias_and_content) {Sono necessari sia un alias sia un contenuto}
set t(reread_aliases) {Rileggi alias}
set t(dismiss) Chiudi
set t(save) Salva
set t(save_out) {Salva uscite}
set t(save_to) {Salva in}
set t(create_vfolder) {Crea cartella virtuale}
set t(dont_save) {Non salvare}
set t(found_aliases) {Nei file vecchi ho trovato}
set t(num_aliases) alias
set t(see_log) {Mostra messaggi vecchi}
set t(seelog_title) {Messaggi vecchi}
set t(does_not_exist) {non esiste}
set t(no_folder) {Nessuna cartella aperta}
set t(already_login) {C'è già un altro processo di login. Completa prima l'altro}
set t(login) Login
set t(opening) Aprendo
set t(mailbox_on) {cartella su}
set t(mailbox) Cartella
set t(mailboxes) Cartelle
set t(host) Host
set t(user) Utente
set t(passwd) Password
set t(mbox) {Nome cartella}
set t(reply_to_which) {Questo messaggio contiene messaggi allegati.
Scegli a quale vuoi rispondere}
set t(forward_which) {Questo messaggio contiene messaggi allegati.
Scegli quale vuoi
rispedire}
set t(forwarded_message) {Messaggio rispedito}
set t(forward_as_attachment) {Rispedisci come allegato}
set t(forward_inline) {Rispedisci come incluso}
set t(forward) Rispedisci
set t(bounce) Bounce
set t(empty_message) {Messaggio vuoto}
set t(structure) Struttura
set t(view_source) {Mostra sorgente}
set t(source) Sorgente
set t(help_window) {Finestra d'aiuto}
set t(site) Indirizzo
set t(access-type) {Tipo d'accesso}
set t(directory) Directory
set t(server) Server
set t(smtp) SMTP
set t(user_program) {Programma definito dall'utente}
set t(sendprot) {Manda attraverso}
set t(sendprog) {Programma spedizione}
set t(progin) {Input del programma}
set t(eightbit) {Dati 8 bit}
set t(sevenbit) {Solo dati 7 bit}
set t(subject_by_date) {Soggetto per data}
set t(import) Importa
set t(import_directory) {Directory d'importazione}
set t(cant_read) {Non posso leggere}
set t(ignored_not_file_not_dir) {viene ignorato non è né un file né una directory.}
set t(bounce_which) {Questo messaggio contiene messaggi allegati.
Scegli quale messaggio rimbalzare}
set t(lookup_name) {Ricerca nome}
set t(do_lookup) {Esegui ricerca}
set t(dont_lookup) {Non cercare}
set t(dbase) Database
set t(dbase_backup) {Directory archivio}
set t(expire_interval) {Periodo di scadenza}
set t(do_expire) {Database di scadenza}
set t(expire) Spira
set t(expire_result) {Risultati di scadenza}
set t(scanned) Scansionati
set t(deleted) Cancellati
set t(backedup) {Messo nell'archivio}
set t(inbox) {Messo nella inbox}
set t(db_expire) {Database di scadenza}
set t(packing_backup) {Comprimendo archivi}
set t(chunksize) {Dimensione blocco}
set t(default_start_selection_mode) {Seleziona all'apertura moda}
set t(start_selection) {Seleziona all'apertura}
set t(first_message) {Primo messaggio nella cartella}
set t(last_message) {Ultimo messaggio nella cartella}
set t(first_new_message) {Primo messaggio non letto nella cartella}
set t(before_first_new_message) {Il messaggio precedente il primo non letto}
set t(notifications) Notifiche
set t(notification) Notifica
set t(failed) Fallito
set t(delayed) {In attesa}
set t(delivered) Consegnato
set t(relayed) Trasferito
set t(expanded) Espanso
set t(dsn_text_failed) {Il tuo messaggio per %s (%s) non è giunto a destinazione.}
set t(dsn_text_delayed) {Il tuo messaggio per %s (%s) è in attesa.}
set t(dsn_text_delivered) {Il tuo messaggio per %s (%s) è stato consegnato.}
set t(dsn_text_relayed) {Il tuo messaggio per %s (%s) è stato trasferito.}
set t(dsn_text_expanded) {Il tuo messaggio per %s (%s) è stato espanso.}
set t(see_more_of_message) {Mostra altro del messaggio di ritorno}
set t(original-envelope-id) {Id Busta Originale}
set t(reporting-mta) {Rispondendo MTA}
set t(dsn-gateway) {Gateway DSN}
set t(received-from-mta) {Ricevuto Da MTA}
set t(arrival-date) {Data d'arrivo}
set t(original-recipient) {Destinatario originale}
set t(final-recipient) {Destinatario Finale}
set t(action) Azione
set t(status) Stato
set t(remote-mta) {MTA remoto}
set t(diagnostic-code) {Codice diagnostico}
set t(last-attempt-date) {Data Ultimo Tentativo}
set t(final-log-id) {ID finale}
set t(will-retry-until) {Proverò fino}
set t(log_timeout) {Scadenza per stato}
set t(extra) Extra
set t(request_notification) {Richiedi notifica}
set t(dsn_directory) {Directory DSN}
set t(default_action) {Azione standard}
set t(request_dsn) {Richiedi notifica}
set t(not_request_dsn) {Non richiedere notifica}
set t(not_snarf_dsn) {Mostra notifiche nella lista messaggi}
set t(snarf_dsn) {Non mostrare notifiche nella lista messaggi}
set t(dsn_expiration) {Ora di scadenza}
set t(report_level) {Livello di relazione}
set t(rl_none) Silenzioso
set t(rl_status) {Mostra nella linea di stato}
set t(rl_notify) {Mostra in un'altra finestra}
set t(cc) Copia
set t(bcc) {Copia cieca}
set t(content_description) {Descrizione contenuto}
set t(reply_to) Rispondi-A
set t(bounce_to) {Bounce to}
set t(reply) Rispondi
set t(comments) Commenti
set t(comment) Commento
set t(default_from_mode) {Da moda}
set t(from) Da
set t(date) Data
set t(received) Ricevuto
set t(message-id) Id-Messaggio
set t(mime-version) Versione-MIME
set t(content-type) Tipo-Contenuto
set t(auto-submitted) AutoSpedito
set t(default_reply_to_mode) {Moda rispondi-A Standard}
set t(default_reply_to_addr) {Indirizzo Rispondi-A Standard}
set t(default_reply_to_fn) {Nome completo Rispondi-A Standard}
set t(default_reply_to) {Rispondi-A Standard}
set t(probe) Prova
set t(dsn_need_smtp) {Devi usare SMTP per mandare messagi in modo che le notifiche funzionino}
set t(probing) provando
set t(supports_dsn) {supporta notifiche}
set t(no_dsn_support) {non supporta notifiche}
set t(character_size) {Dimensione carattere}
set t(need_restart) {Devi riiniziare Postilion perche' le tue modifiche abbiano effetto.}
set t(opening_folder) {Aprendo cartella}
set t(read) Leggi
set t(write) Scrivi
set t(exec) Esegui
set t(perm_user) Utente
set t(perm_group) Gruppo
set t(perm_other) Altro
set t(mode) Modo
set t(all_read) {Tutti lettura}
set t(all_read_write) {Tutti lettura e scrittura}
set t(max_height) {Max altezza}
set t(insert_failed) {Impossibile inserire messaggio}
set t(define_keys) {Definisci tasti}
set t(folder_key_find) Ricerca
set t(folder_key_compose) Componi
set t(folder_key_quit) Esci
set t(folder_key_nextu) {Prossimo nuovo}
set t(folder_key_sync) Sincronizza
set t(folder_key_update) Aggiorna
set t(folder_key_delete) Cancella
set t(folder_key_undelete) {Annulla cancella}
set t(folder_key_flag) {Contrassegna messaggio}
set t(folder_key_seen) {Toggle Seen flag}
set t(folder_key_ans) {Toggle Answered flag}
set t(folder_key_next) Prossimo
set t(folder_key_prev) Precedente
set t(folder_key_home) {Inizio del messaggio}
set t(folder_key_bottom) {Fine del messaggio}
set t(folder_key_pagedown) {Pagina giù}
set t(folder_key_pageup) {Pagina su}
set t(folder_key_linedown) {Linea giù}
set t(folder_key_lineup) {Linea su}
set t(folder_key_replya) {Rispondi a tutti}
set t(folder_key_replyq) {Quote to sender}
set t(folder_key_replyqa) {Quote to all}
set t(folder_key_replys) {Rispondi al mittente}
set t(folder_key_forward_a) {Rispedisci come allegato}
set t(folder_key_forward_i) {Rispedisci come incluso}
set t(folder_key_bounce) Bounce
set t(folder_key_select_all) {Seleziona tutti}
set t(folder_key_deselect_all) {Deseleziona tutti}
set t(add_key) Aggiungi
set t(press_key) {Premi il nuovo tasto}
set t(key_defined) {Questo tasto è già assegnato a}
set t(replace_key) {Cambia con nuovo assegnamento}
set t(do_delete) {Premi il tasto assegnato per cancellare}
set t(netscape_steal) {Sembra che Netscape abbia preso alcuni dei tuoi messaggi. Cosa vuoi fare?}
set t(steal_back) Riprendili
set t(nothing) Niente
set t(check_stolen_mail) {Controlla posta rubata}
set t(check) Controlla
set t(dont_check) {Non controllare}
set t(take_mail) {Prendi posta da Netscape}
set t(remember_pos) {Geometria finestra}
set t(do_remember) Ricorda
set t(dont_remember) {Non ricordare}
set t(import_IMAP) {Cartelle IMAP}
set t(pattern) Chiave
set t(host_required) {Devi specificare un host}
set t(import_failed) {Importazione impossibile}
set t(warning_sendprog) {ATTENZIONE: Il programma specificato per spedire non esiste o non è eseguibile}
set t(automatic_wrap) {A capo automatico}
set t(automatic_indent) {Indentazione automatica}
set t(need_keyword) {Devi specificare almeno una parola chiave.}
set t(need_host_and_user) {Devi specificare entrambi sia l'Host sia l'Utente.}
set t(opening_connection) {Aprendo connessione...}
set t(wait_greeting) {In attesa di connessione...}
set t(get_capabilities) {Richiedendo caratteristiche...}
set t(send_envelope) {Spedendo informazioni busta...}
set t(send_from) {Mandando indirizzo destinatario...}
set t(send_rcpt) {Mandando destinatario}
set t(send_data) {Mandando dati...}
set t(wait_ack) {In attesa di conferma...}
set t(closing) {Chiudendo canale...}
set t(sending_message) {Spedendo messaggio...}
set t(smtpv) {SMTP dettagliato}
set t(normal) Normale
set t(verbose) Dettagliato
set t(terse) Breve
set t(import_aliases) {Importa alias}
set t(upgrade_dbase) {Aggiorna database}
set t(old_dbase) {Hai una vecchia versione del database. Devo convertirlo prima di usarlo}
set t(unlinked_messages) {Messaggio scollegato}
set t(unl_m1) C'erano
set t(unl_m2) {messaggi scollegati nel database. Possono essere reperiti nella cartella UnlinkedMessages (che è una cartella file nella directory ~)}
set t(send_deferred) {Manda differiti}
set t(delivery_mode) {Modo consegna}
set t(direct) Diretta
set t(deferred) Differita
set t(sending_deferred) {Spedendo messaggi differiti}
set t(to_send) {Da spedire}
set t(sent) Spedito
set t(you_have) Hai
set t(deferred_messages) {messaggi differiti. Vuoi mandarli ora?}
set t(deferred_message) {messaggio differito. Vuoi mandarlo ora?}
set t(send_now) {Spedisci ora}
set t(no) No
set t(waiting_on_sender) {In attesa del processo di spedizione (sta mandando)...}
set t(illegal_file_spec) {File non valido specificato}
set t(copy_attached_files) {Copia file allegati}
set t(cache_conn) {Mantieni connessioni}
set t(failed_to_create_send_cache) {Non potrai spedire messaggi poiché non ho potuto creare la cache}
set t(mh_name) Nome-MH
set t(need_mh_name) {Devi dare un nome-mh}
set t(failed_to_make_copy) {Impossibile creare copia locale}
set t(color_scheme) {Schema colore}
set t(gray67) Grigio
set t(PeachPuff2) Albicocca
set t(bisque) Rosa
set t(SlateBlue1) Blu
set t(SteelBlue4) {Blu acciaio}
set t(SkyBlue1) Azzurro
set t(aquamarine2) {Verde chiaro}
set t(SpringGreen4) Verde
set t(patterns_to_use) {Chiave di ricerca}
set t(files) File
set t(directories) Directory
set t(cache_passwd) {Mantieni password}
set t(cache_timeout) {Timeout cache}
set t(do_cache) Mantieni
set t(do_not_cache) {Non mantenere}
set t(icon_bitmap) {Bitmap icona}
set t(normal_bitmap) {Normale (64x64)}
set t(button_bar) {Display button bar}
set t(buttons) {Icons or text for buttons}
set t(text) Text
set t(icon) Icona
set t(small_bitmap) {Piccola (50x50)}
set t(xpm) {Image (48x48)}
set t(sync_but) {Sync button}
set t(sync_oper) {Sync button operation}
set t(set_to_inbox) {Seleziona inbox}
set t(set_to_open_on_startup) {Set to open on startup}
set t(set_to_min_on_startup) {Set to open minimized on startup}
set t(unset_to_open_on_startup) {Set to not open on startup}
set t(unset_to_min_on_startup) {Set to not open minimized on startup}
set t(group) Gruppo
set t(create_in_win) {Crea in finestra}
set t(create_by_expr) {Crea per chiave}
set t(use_saved_expr) {Usa chiave salvata}
set t(clear_group) {Cancella selezione di gruppo}
set t(select_all) {Seleziona tutti}
set t(deselect_all) {Deseleziona tutti}
set t(edit_group) {Modifica gruppo}
set t(create_exp) {Crea chiave}
set t(basic_mode) {Modo base}
set t(advance_on_flag) {Advance on flag}
set t(flag_ans) {Toggle the Answered flag}
set t(flag_seen) {Toggle the Seen flag}
set t(flag_unseen) {Flag as unseen}
set t(advanced_mode) {Modo avanzato}
set t(save_as) {Salva come}
set t(fields) Campi
set t(operators) Operatori
set t(booleans) Booleani
set t(grouping) Raggruppamento
set t(sender) Mittente
set t(has) ha
set t(is) è
set t(clear) Cancella
set t(error_underlined) {C'è un errore di sintassi}
set t(syntax_error_exp) {Errore di sintassi nella chiave}
set t(saved_expr) {Chiavi salvate}
set t(need_one_selected_exp) {Devi selezionare una chiave}
set t(here_is_text) {Qui c'è del testo codificato in}
set t(which_cant_be_shown) {che non può essere visualizzato correttamente.}
set t(show_sevenbit) {Mostra caratteri a sette bit}
set t(convert_to_local_nl) {Conversione metodo a-capo locale}
set t(startup) Startup
set t(startup_mode) {Modalità iniziale}
set t(iconic) Iconizzata
set t(file) File
set t(insert_file) {Inserisci file}
set t(cut) Taglia
set t(cut_all) {Taglia tutto}
set t(copy) Copia
set t(copy_all) {Copia tutto}
set t(paste) Incolla
set t(wrap_lines) {Spezza linee}
set t(run_through_command) {Filtra con comando}
set t(undo) {Annulla modifica}
set t(redo) Ripristina
set t(failed_to_open_file) {Non è possibile aprire il file}
set t(no_text_selected) {Nessun testo selezionato}
set t(command_failed) {Comando fallito}
set t(command) Comando
set t(command_is_running) {Comando in esecuzione}
set t(folder_key_cycle_header) {Scorri intestazioni visibili}
set t(watcher_enable) {Abilita controllo}
set t(enabled) Abilitato
set t(disabled) Disabilitato
set t(command_list) {Lista comandi}
set t(compose_key_send) Spedisci
set t(compose_key_abort) Anulla
set t(compose_key_editor) {Editor esterno}
set t(compose_key_undo) {Annulla modifica}
set t(compose_key_cut) Taglia
set t(compose_key_copy) Copia
set t(compose_key_cut_all) {Taglia tutto}
set t(compose_key_paste) Incolla
set t(compose_key_replya) {Rispondi a tutti}
set t(compose_key_replyq) {Quote to sender}
set t(compose_key_replyqa) {Quote to all}
set t(compose_key_replys) {Rispondi al mittente}
set t(compose_key_insert) {Inserisci file}
set t(compose_key_attach) Allega
set t(sig_cmd_failed) {RatUP_Signature fallito}
set t(bell_cmd_failed) {RatUP_Bell fallito}
set t(sig_cmd_takes_precedence) {Hai definito una RatUP_Signature che ha precedenza sul file firma!}
set t(more) Altro
set t(compose_sessions) {C'è almeno una finestra composizione aperta}
set t(really_quit) {Esci davvero?}
set t(do_quit) Esci
set t(dont_quit) {Non uscire}
set t(use_from_address) {Usa indirizzo mittente}
set t(use_from_fn) {Usa Nome completo mittente}
set t(messages_shown) {Messaggi visualizzati}
set t(dbase_error) {Errore nel database! Esegui una verifica del database dal menu Amministrazione}
set t(dbase_check) {Verifica database}
set t(check_dbase) {Verifica database}
set t(check_fix_dbase) {Verifica e ripara database}
set t(checking_dbase) {Verificando database}
set t(total_num_messages) {Numero totale di messaggi nell'indice}
set t(num_malformed) {Numero di entrate danneggiate}
set t(num_nomessages) {Numero di entrate senza messaggi}
set t(num_unlinked) {Numero di messaggi scollegati}
set t(total_size) {Dimensione totale di tutti i messaggi}
set t(waiting_dbase_lock) {Attendendo sul blocco del database}
set t(port) Porta
set t(already_exists) {esiste già}
set t(overwrite) Sovrascrivere
set t(append) Append
set t(file_exists) {Il file esiste già}
set t(type_description) {Descrizione del tipo}
set t(view) Visualizza
set t(view_as_text) {Visualizza come testo semplice}
set t(external_viewer) {Programma esterno}
set t(cant_pipe) {Non è possibile mandare l'input a programmi che usano la finestra terminale}
set t(reread_mailcap) {Rileggi mailcap}
set t(mailcap_path) {Posizione mailcap}
set t(terminal_command) {Comando terminale}
set t(vfolderedit) {Modifica cartella virtuale}
set t(delete_imap) {Cancellare anche la cartella IMAP fisica?}
set t(dont_delete) {Non cancellare}
set t(print_headers) {Stampa intestazioni}
set t(print_non_text) {Print non-text message parts}
set t(selected) Selezionato
set t(aliases) Alias
set t(extract_adr) {Estrai indirizzi}
set t(address) Indirizzo
set t(could_not_find_adr) {Non sono stati trovati indirizzi da estrarre}
set t(add_aliases) {Aggiungi alias}
set t(use) Usa
set t(missing_alias_name) {Nome alias mancante. Una entrata non verrà aggiunta.}
set t(alias_chooser) {Selettore alias}
set t(set_to_save_outgoing) {Attiva per salvare in uscita}
set t(unset_to_save_outgoing) {Disattiva per salvare in uscita}
set t(add) Aggiungi
set t(smtp_timeout) {Timeout SMTP}
set t(no_send_bad_host) {Postilion non conosce il nome con cui la tua posta verra' spedita! Il nome
puo' essere specificato nella finestra preferenze sotto la voce spedizione.
I campi sono "Host appare come" e "Dominio" (uno dei due e' sufficiente).
Non si potranno spedire messaggi fino a quando non verra' corretto il
problema (a meno che non si scelga l'opzione apposita sulla stessa pagina)}
set t(force_send) {Forza spedizione}
set t(force) Forza
set t(no_force) {Non forzare}
set t(on_reply) {In risposta}
set t(skip_sig) {Non includere la signature}
set t(keep_sig) {Includi signature}
set t(subjectonly) {Per soggetto}
set t(bysender) {Per mittente}
set t(sign) Firma
set t(encrypt) Cripta
set t(pgp_pass_phrase) {Frase passaggio PGP}
set t(pgp_problem) {Problema PGP}
set t(retry) Riprova
set t(sig) Sig
set t(default_signature_mode) {Moda firma}
set t(signature) Firma
set t(none) Nulla
set t(pgp_part) Parte
set t(pgp_none) Nulla
set t(pgp_unchecked) ?
set t(pgp_good) Ok
set t(pgp_bad) Err.
set t(pgp_output) {Output PGP}
set t(warning_pgp_prog) {ATTENZIONE: Il programma pgp specificato non esiste o non è eseguibile}
set t(pgp_handling) {Gestione PGP}
set t(pgp_program) {Programma PGP}
set t(pgp_extra_args) {Argomenti extra PGP}
set t(decoded) Decodificato
set t(send_bug) {Rapporto malfunzione}
set t(short_description) {Sostituisci con descrizione breve}
set t(bug_report_template) {[Sostituisci questo testo con una descrizione dettagliata della
malfunzione. Se l'errore è un errore tcl allora includi lo stack trace]}
set t(configuration_information) {Descrizione della tua configurazione}
set t(send_bugs_etc) {Prego mandare errori e suggerimenti a nic@postilion.org}
set t(send_postcards) {Potete anche spedirmi una cartolina (per favore scrivete in inglese perché non parlo italiano)

Martin Forssen
Kabelgatan 13c
414 57 Göteborg
SWEDEN}
set t(sign_outgoing) {Contrassegna messaggi}
set t(encrypt_outgoing) {Cripta messaggi}
set t(true) Vero
set t(false) Falso
set t(attach_pgp_keys) {Allega chiavi PGP}
set t(select_keys) {Seleziona chiavi}
set t(bits) Bit
set t(keyid) IDchiave
set t(user_id) {ID utente}
set t(pgp_key_for) {Chiave PGP per}
set t(embedded_pgp_keys) {Qui ci sono una o più chiavi PGP allegate}
set t(add_to_keyring) {Aggiungi al keyring}
set t(press_return_to_dismiss) {Premi invio per chiudere la finestra}
set t(decrypting) Decriptando...
set t(seconds) secondi
set t(days) giorni
set t(url_viewer) {Visualizzatore URL}
set t(userproc) {Procedura utente}
set t(netscape_cmd) {Comando Netscape}
set t(netscape_args) {Argomenti Netscape}
set t(url_color) {Colore URL}
set t(paper_color) {Paper color}
set t(new_msg_col) {New message color}
set t(sel_msg_col) {Selected message color}
set t(fnd_msg_col) {Found message color}
set t(flg_msg_col) {Flagged message color}
set t(del_msg_col) {Deleted message color}
set t(seen_msg_col) {Seen message color}
set t(ans_msg_col) {Answered message color}
set t(smtp_reuse) {Riutilizzo SMTP}
set t(addrbooks) Agende
set t(addrbook) Agenda
set t(use_system_aliases) {Usa alias di sistema}
set t(move_to) {Muovi in}
set t(set_default) {Seleziona default}
set t(need_writable_book) {Bisogna avere almeno un'agenda scrivibile}
set t(book_already_exists) {Esiste già un'agenda con quel nome}
set t(pgp) PGP
set t(find) Ricerca
set t(match) Cerca
set t(exact) Esatta
set t(regexp) {Espressione regolare}
set t(find_in) {Cerca in}
set t(message_list) {Lista messaggi}
set t(message_body) {Corpo messaggio}
set t(find_next) {Cerca prossimo}
set t(colorbug) {La versione di tcl/tk che stai usando ha una malfunzione che rende  impossibile il cambiamento del colore tramite questa opzione. Questo  problema è stato risolto in tcl/tk 8.0}
set t(out_of_order) {Non funzionante}
set t(default_to_browse) {Sempre in modo titoli}
set t(browse_mode) {Modo titoli}
set t(default_browse_mode) {Modo titoli normale}
set t(no_browse) {Non usare modo titoli}
set t(do_browse) {Usa modo titoli}
set t(use_folder_default) {Usa modalità della cartella}
set t(show_body) {Mostra corpo}
set t(ignore_case) {Ignora maiuscole/minuscole}
set t(url_protocols) {Protocolli URL}
set t(prefix) {Date style mailbox prefix}
set t(spell_check) Spell
set t(balloon_help) Aiuto-balloon
set t(subjects) Soggetti
set t(warning) Attenzione
set t(do_not_show_again) {Non mostrare piu questo avviso}
set t(warn_tk80) {Stai usando Tk8.0 che ha un grave errore nel codice
che gestisce i menu. Questo causera un errore quando
si provera ad aprire il menu cartelle. Dovresti
aggiornare Tk alla versione 8.0p2 o successiva.}
set t(expunge_on_close) {Rimuovi in chiusura}
set t(do) Farlo
set t(do_not) Non
set t(pending_cut) {There is a pending cut operation, delete it?}
set t(menu_style) {Menu style}
set t(next_style) {NeXT style}
set t(ispellOnOff) {Use Ispell}
set t(ispellRecheckAfterAdd) {Re-Verify after Adds}
set t(ispellTextOnly) {Spell Check 'Text' only}
set t(ispellCommand) {Default speller invocation}
set t(ispellOthers) {Other Invocations}
set t(ispellPopupBinding) {Menu popup bound to:}
set t(ispellStyle) {Miss-spelled word style}
set t(ispellStyleColor) {color for fgcolor and bgcolor}
set t(ispellStyleOther) {Style if 'other' is selected}
set t(underline) Underline
set t(italic) Italic
set t(bold) Bold
set t(bgcolor) {Background color}
set t(fgcolor) {Foreground color}
set t(ispell) Ispell
set t(mboxvis) {Show mailbox view}
set t(drafts) {Brutte copie}
set t(new_user) {Nuove regolazioni dell' utente}
set t(finish) Rivestimento
set t(set_name) {Entrare prego nel vostro nome
completo e nel vostro email 
address come dovrebbe comparire
nei vostri messaggi.}
set t(compose_quit) {Do you wish to hold this draft, or abort it?}
set t(System) Sistema
set t(Personal) Personal
set t(list) lista
set t(hide) Hide
set t(hide-sizes) {Hide Sizes}
set t(hide-deleted) {Hide Deleted}
set t(info) Info
set t(compact) Compact
set t(incorporate-mail) {Incorporate Mail}
set t(focus) Focus
set t(unfocus) Unfocus
set t(services) Services
set t(tcl-error) {Error in Tcl Script}
set t(skip-messages) {Skip Messages}
set t(stack-trace) {Stack Trace}
set t(isp-add) Add
set t(isp-dict) {to dictionary}
set t(isp-accept) Accept
set t(isp-for) {for this session}
set t(alternate) Alternate
set t(default) Default
set t(return_path) Return-Path
set t(pgp_sign) {PGP Sign}
set t(quote_color) {Quote color}
}
