#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_balText_sv {} {
global balText
set balText(list_of_messages) {List of messages in the current mailbox.
You can use the mouse buttons as follows:

    left click   - Show the message
    double left  - (in browse mode) show message body 
		   (The message body is fetched)
    right button - Flag or unflag the message (add or
		   remove it from `the group' of other
		   flagged messages}
set balText(current_folder_name) {Name of the current mailbox}
set balText(current_folder_size) {Total size in bytes of current mailbox}
set balText(current_folder_nummsg) {Number of messages in the current mailbox}
set balText(status_text) {Meddelanden från Postilion}
set balText(move_msg) {Denna menyn sparar en kopia av det aktiva brevet
i den angivna mappen och markera brevet som raderat
i denna mappen}
set balText(delete_msg) {Markera det aktiva brevet för radering}
set balText(compose_msg) {Skriv ett nytt brev}
set balText(compose_menu) {This menu contains commands that are
useful when writing a message}
set balText(mailbox_menu) {This menu contains commands which
operate on a mailbox(s)}
set balText(window_menu) {This menu contains tools for inspecting your
address book, mailboxes, and old searches}
set balText(edit_menu) {This menu helps you to edit
the message you are writing}
set balText(format_menu) {This menu helps you to adjust the format
(layout) of a message you are writing}
set balText(print_menu) {Opens a dialog box for printing a
message or the grouped messages.
(Use the right mouse button or the Group
menu, to group or ungroup messages.)}
set balText(vd_open) {Open the selected mailbox in a new window}
set balText(vd_cut) {Cut the selected mailbox from the list.  It
can be pasted elsewhere in the list with the
paste command.}
set balText(vd_paste) {Paste a previously-cut mailbox into
the list, above this location}
set balText(spell) {Open a spell check session for
this message}
set balText(clear_addr) {Click here with the left mouse button
to clear all selections in this window}
set balText(reply_to_all) {Skicka ett svar till samtilga mottagare och
avsändare av det aktiva brevet}
set balText(reply_to_sender) {Skicka ett svar till avsändaren av det aktiva brevet}
set balText(no_sig) {Detta betyder att det aktiva brevet inte är signerat}
set balText(unchecked_sig) {Detta betyder att brevet är signerat men att
signaturen har inte har kontrollerats ännu.
Tryck på den vänstra knappen för att kontrollera den}
set balText(good_sig) {Detta brev är korrekt signerat}
set balText(bad_sig) {Signaturen passar INTE till brevets innehåll}
set balText(part_sig) {En del av brevet var signerat, meninte allt}
set balText(send_deferred) {Skickar alla uppskjutna brev. Numret mellan
klamrarna visar antalet uppskjutna brev}
set balText(show_notifications) {Skapar ett fönster där alla kvittenser visas}
set balText(watcher_enable) {Låter dig sätta på eller stänga av väktarfönstret}
set balText(reread_aliases) {Läser om alla dina aliasfiler}
set balText(reread_userproc) {Läser om din userproc-fil}
set balText(import_aliases) {Ser på ett par standardplatser efter aliasfiler
från andra brevprogram och läser in dessa}
set balText(reread_mailcap) {Läser om alla mailcap-filer}
set balText(take_mail) {Tittar efter brev som netscape har tagit
från din inkommande brevlåda och stjäl
tillbaka dem /till den inkommande kådan)}
set balText(check_dbase) {Kontrollerar om det finns fel i Postilion's databas}
set balText(check_fix_dbase) {Kontrollerar om det finns fel i Postilion's databas,
gör också sitt bästa att reparera alla fel som hittas}
set balText(see_log) {Visar en lista äver alla interna meddelanden som genererats
av Postilion}
set balText(quit) {Avslutar Postilion}
set balText(folder_menu) {Denna meny listar dina mappar. Du kan välja en
mapp i menyn för att titta på den mappen istället}
set balText(message_menu) {Denna meny innehåller operationer
på enstaka brev}
set balText(clock) {This shows the time, date and day when the
message was sent (in local time here).
Click on teh clock with the left mouse button
as a shortcut to the Preferences window.}
set balText(mailboxes) {Opens a new window which lets you select, create
and edit your mailboxes.  You can also move a selected
message (or the grouped messages) to a selected mailbox.}
set balText(next_msg) {Selects the next message in the list.}
set balText(prev_msg) {Selects the previous message in the list.}
set balText(find) {Skapar ett fönster där du kan söka i brevlistan
eller i det aktiva brevet}
set balText(compose) {Skriv ett nytt brev}
set balText(reply_sender) {Skriv ett svar till avsändaren av det aktiva brevet}
set balText(reply_quote_sender) {Write a reply to the sender, 
quoting the current message}
set balText(reply_all) {Skriv ett svar som går tillsåväl avsändaren
som alla mottagare av det aktiva brevet}
set balText(reply_quote_all) {Write a reply which goes to the sender and all
recipients, quoting the current message}
set balText(forward_inline) {Skicka vidare det aktiva brevet}
set balText(forward_attached) {Skicka vidare det aktiva brevet som en bilaga}
set balText(bounce) {Bounce the current message to a new address}
set balText(compose_held) {Fortsätt att skriva ett sparat brev}
set balText(extract_adr) {Skapa alias från adresserna i det aktiva brevet}
set balText(move) {Move the current message to another mailbox}
set balText(delete) {Mark the current message for deletion.
It will not be actually deleted until you
"Compact" the mailbox}
set balText(undelete) {Ta bort raderingsmarkeringen på det aktiva brevet}
set balText(print) {Skriv ut det aktiva brevet}
set balText(structure) {Denna undermeny visar strukturen på
brevet och dess bilagor}
set balText(show_all_headers) {Visa alla huvudrader i meddelanden}
set balText(show_selected_headers) {Visa endast de valda huvudraderna}
set balText(show_no_headers) {Visa inga huvudrader}
set balText(group_menu) {Denna meny innehåller kommandon som arbetar
med en grupp av brev. Alla brev som ingår i
gruppen är märkta med ett 'F'. Dessa kommandon
appliceras endast på markerade brev i den
aktiva mappen}
set balText(create_in_win) {Skapa en ny lista |ver meddelanden och gör
gruppmarkeringen i det fönstret}
set balText(create_by_expr) {Skapa grupp mha uttryck}
set balText(use_saved_expr) {Skapa en grupp mha ett sparat uttryck}
set balText(clear_group) {Ta bort gruppmarkeringen från alla brev}
set balText(group_all) {Flag every message - add every message to the group}
set balText(delete_group) {Markera alla brev i gruppen för radering}
set balText(print_group) {Skriv ut alla brev i gruppen}
set balText(move_group) {Flytta samtliga brev i gruppen till en annan mapp}
set balText(admin_menu) {Denna meny innehåller diverse administrativa kommandon}
set balText(browse_mode) {Tiitta-mod ser till att brödtexten i breven inte laddas automatiskt.
För att se brödtexten av ett brev så måste man trycka på knappen
"Visa texten" eller dubbleklicka på brevet i brevlistan}
set balText(update) {Tittar efter nya brev i den aktiva mappen, denna
funktion raderar inte brev markerade för radering}
set balText(sync) {Synkroniserar den visade mappen med mappen på disk, dvs
skriver ut eventuella ändrade flaggor raderar brev som markerats
för radering och tittar efter nya brev}
set balText(newedit_folder) {Opens a window for you to add mailboxes
and edit their properties.}
set balText(aliases) {Öppnar aliasfönstret}
set balText(focus) {List only the flagged messages}
set balText(unfocus) {List all messages (flagged and unflagged)}
set balText(hide_size) {Hide message sizes in list}
set balText(hide_deleted) {Hide deleted messages in list}
set balText(hide) {Hide all Postilion's windows}
set balText(preferences) {Öppnar inställningsfönstret}
set balText(define_keys) {Låter dig inspektera och ändra tangentbordsdefinitionerna för detta fönster}
set balText(saved_expr) {Låter dig redigera de sparade uttrycken som används för att skapa grupper}
set balText(sort_order) {Låter dig ändra sorteringsordningen bland breven i mappen}
set balText(sort_subjdate) {Sortera breven efter datum, men gruppera
ihop brev med samma ämne}
set balText(sort_subj) {Sortera breven alfabetsikt efter ämne}
set balText(sort_sender) {Sortera breven alfabetsikt efter avsändare}
set balText(sort_natural) {Sortera inte breven}
set balText(sort_reverse_natural) {Sortera inte breven men vänd ordningen}
set balText(sort_date) {Sortera breven efter avsändningstid (tidigare högre upp)}
set balText(sort_reversedate) {Sortera breven efter avsändningstid (tidigare längre ner)}
set balText(help_menu) {Ger diverse olika former av hjälp}
set balText(balloon_help) {Sätter på/stänger av ballonghjälpen}
set balText(show_version) {Visa vilken version av Postilion du använder}
set balText(explain_ratatosk) {Förklarar varifrån namnet Ratatosk kommer}
set balText(help_window) {Visar hjälpfönstret}
set balText(send_bug) {Låter dig skicka en felrapport till författaren av Postilion}
set balText(group_list_editor) {Markerade brev kommer att ingå i gruppen. Använd
vänster musknapp för att markera/demarkera brev}
set balText(group_window_ok) {Stäng detta fönster och flytta gruppmarkeringarna till mappfönstret}
set balText(group_window_selall) {Markera alla brev}
set balText(group_window_unselall) {Ta bort markeringen från alla brev}
set balText(cancel) {Avbryt operationen och stäng fönstret}
set balText(enter_search_exp_here) {Skriv in ditt sökuttryck här}
set balText(toggle_ignore_case) {Ignorera stora/små bokstäver vid sökning på/av}
set balText(find_exact) {Hitta exakt samma sträng}
set balText(find_regexp) {Sök med reguljäruttryck}
set balText(find_in_mlist) {Sök i brevlistan (inte i själva breven)}
set balText(find_in_body) {Sök i det aktiva brevet}
set balText(find_first) {Sök från toppen}
set balText(find_next) {Hitta nästa}
set balText(dismiss) {Stäng fönstret}
set balText(show_adrbook_menu) {This list shows your address books.
Left-click on a book to see its addresses.
Select an address and then press one of the
address buttons below (e.g. the  To:-list),
to have that person automatically entered in
the list of recipients for your message.
Or select a book and then press one of the
the address buttons, to address your message
to EVERYONE in that book.
TIP: You turn on the Bcc feature by add "Bcc"
to the "Headers" field in Preferences->Compose.
Bcc means `blind carbon copy' - no one can see
you've sent the mail to people in the Bcc list}
set balText(use_system_aliases) {Inkludera adresser från systemts globala adressbok}
set balText(add_addrbook) {Lägg till en ny adressbok}
set balText(delete_addrbook) {Radera en adressbok, tar bara bort boken ur Postilions listor.
Dvs boken raderas inte från disken}
set balText(set_default_addrbook) {Välj standardbok, dvs vilken adressbok som nya adresser
skall läggas in i om du inte explicit anger något annat}
set balText(import_aliases_from_pgm) {Importera adresser från filer som skapats av andra program,
dvs skapa en ny adressbok som använder ett anat format på disk}
set balText(alias_list) {Detta är en lista över dina adresser}
set balText(new_alias) {Skapa en ny adress}
set balText(edit_alias) {Ändra en existerande adress}
set balText(delete_alias) {Radera de valda adressera}
set balText(move_alias) {Flytta de valda adresserna till en annan adressbok}
set balText(alias_adr_book) {Adressbok som denna address skall ingå i}
set balText(alias_alias) {Adressens korta namn, detta är det namn du skriver in i ett adressfält}
set balText(alias_fullname) {Addressens långa namn, detta är namnet på
den person som adressen pekar på}
set balText(alias_content) {Adressens innehåll, detta är var adressen expanderas
till när ett brev skickas}
set balText(alias_comment) {Addresskommentar, detta är bara för din egen användning}
set balText(name_of_adrbook) {Namnet som Postilion akll använda internt för att referea till denna bok}
set balText(list_of_books_to_delete) {Välj de adressböcker som du vill radera
i denna listan, tryck sen på "radera"}
set balText(aliases_adr_book) {Addressbok som dessa adresser skall ingå i}
set balText(aliasadd_use) {Om denna knappen är omarkerad så kommer
addressen på denna rad att ignoreras}
set balText(alias_chooser) {This list lets you choose an address to add to your
address field.
There are several ways to select an address:
    * You can select one with the left mousebutton
    * You can use the up and down arrow keys
When you have made a selection, press space to 
add your selection to the "To:" line of the
active compose window, or click one of the 
buttons below to insert your selection into a
particular address line. Pressing "Return" will
insert your selection into the "To:" line,
and close this window. If a compose window is
not active, a new one will open for you. You 
can dismiss this window without selecting an
address with the esacape key or ctrl-c.}
set balText(compose_held_pick) {Välj brevet du vill fortsätta komponera ur denna listan.
Du kan markera det och trycka på "ok" eller dubbelklicka på det}
set balText(compose_insert_file) {Läs in innehållet i en fil vid markörens position i texten}
set balText(automatic_wrap) {Kontrollerar den automatiska radbrytningen}
set balText(automatic_indent) {Kontrollerar den automatiska indenteringen}
set balText(abort_compose) {Avbryt komponerandet}
set balText(undo) {Ogör den senaste ändringen}
set balText(cut) {Klipp ut den markerade texten}
set balText(copy) {Kopiera den markerade texten}
set balText(paste) {Klipp in text}
set balText(cut_all) {Klipp ut all text ur brevet}
set balText(copy_all) {Kopiera all text i brevet}
set balText(wrap_lines) {Formatera de markerade raderna}
set balText(run_through_command) {Kör den markerade texten (all text om ingen är markerad)
genom ett externt kommando}
set balText(headers_menu) {Denna meny låter dig kontrollera vilka
huvudrader som visas i fönstret}
set balText(copy_attached_files) {Om denna knapp är på så görs en kopia av alla bilagor så fort
du trycker på "skicka". Omd en är av så läses själva filen som
bilagan tas från först när brevet verkligen lämnar din dator}
set balText(request_notification) {Begär leveranskvittens på detta brev}
set balText(pgp_sign) {Signera brevet med en PGP-signatur}
set balText(pgp_encrypt) {Kryptera brevet mha PGP}
set balText(command_list) {Ändra listan över sparade kommandon (som man kan skicka text igenom)}
set balText(compose_body) {Brevets brödtext}
set balText(attach_file) {Lägg till en fil som bilaga till brevet}
set balText(attach_special) {Speciella type of bilagor}
set balText(attach_keys) {Lägg till PGP nycklar}
set balText(detach) {Ta bort den markerade bilagan}
set balText(attachments) {Lista över bilagor}
set balText(send) {Send the message and save a copy in the designated "save
outgoing" mailbox.  (You choose the save-mailbox via the
"Mailboxes" editor window.  Select a mailbox and press down
with the right mouse button, then choose "Edit...".  In the
edit window for the selected mailbox choose a mailbox for
storing your outgoing messages from the "Save to" tab.
Some people like to store all their outgoing messages
in a single mailbox called "Outgoing", others like multiple
save-mailboxes, some like no copy to be saved.)}
set balText(sendsave) {Skicka brevet och spara en kopia i en mapp
(som specificeras via denna meny)}
set balText(hold) {Lagra brevet så att vi kan fortsätta komponerandet vid en senare tidpunkt}
set balText(eedit) {Använd en extern textredigerare på brödtexten}
set balText(compose_to) {De primära mottagarana av brevet.
Detta är ett adressfält vilket betyder att Postilion kommer att försöka
ordna adresserna i kolumner, adresser som finns i adressboken kommer att
expanderas (med addresatens fulla namn) och syntaktiskt ogiltiga adresser
markeras med rött. Du kan använda ^l för att få en lista över dina alias}
set balText(compose_subject) {Brevet ämne}
set balText(compose_cc) {De som skall få kopior av brevet.
Detta är ett adressfält vilket betyder att Postilion kommer att försöka
ordna adresserna i kolumner, adresser som finns i adressboken kommer att
expanderas (med addresatens fulla namn) och syntaktiskt ogiltiga adresser
markeras med rött. Du kan använda ^l för att få en lista över dina alias}
set balText(compose_bcc) {De som skall få blinda kopior, dvs de övriga mottagarna av brevet
kommer inte att se att dessa personer också fått kopior.
Detta är ett adressfält vilket betyder att Postilion kommer att försöka
ordna adresserna i kolumner, adresser som finns i adressboken kommer att
expanderas (med addresatens fulla namn) och syntaktiskt ogiltiga adresser
markeras med rött. Du kan använda ^l för att få en lista över dina alias}
set balText(compose_keywords) {Några nyckelord som beskriver brevet}
set balText(compose_content_description) {En beskrivning av brevets innehåll}
set balText(compose_reply_to) {Vart svara på brevet skall skickas.
Detta är ett adressfält vilket betyder att Postilion kommer att försöka
ordna adresserna i kolumner, adresser som finns i adressboken kommer att
expanderas (med addresatens fulla namn) och syntaktiskt ogiltiga adresser
markeras med rött. Du kan använda ^l för att få en lista över dina alias}
set balText(compose_comments) {Kommentarer på brevet}
set balText(compose_from) {Vem brevet kommer ifrån}
set balText(type_menu) {Använd denna meny för att specificera vilken typ bilagan har}
set balText(encoding_menu) {Vilken kodning bilagan har just NU. Detta har ingenting att
göra med vilken kodning den kommer att få när den skickas}
set balText(attach_description) {En kort beskrivning av denna bilaga}
set balText(attach_disposition) {This is the filename which an attached file will
most likely be saved as.}
set balText(attach_id) {Under vissa förutsättningar så kan man behöva skicka med
en identifierare med bilagan}
set balText(bounce_to) {Enter the address of the person to whom you wish to bounce this message here}
set balText(hold_description) {Skriv en beskrivning av brevet som skall lagras här}
set balText(choose_msg) {Detta brevet innehöll ett eller flera andra brev som bilagor.
Du måste nu välja vilket brev du vill svara på (eller skicka vidare.)}
set balText(save_cmd_as) {Om du vill att detta kommando skall sparas för framtida användning
så skriv in namnet det skall sparas under här och se till att knappen
är markerad}
set balText(command_to_run_through) {Skriv in en kommandorad här. Den valda texten kommer att köras
igenom kommandoraden}
set balText(saved_commands) {Lista över sparade kommandon}
set balText(apply_changes_to_cmd) {Applicera de gjorda ändringarna på kommandot}
set balText(delete_command) {Radera det valda kommandot}
set balText(command_content) {Kommandots innehåll}
set balText(notification_window) {Kvittenser-fönstret innehåller en lista över all brev där kvittens har
begärts som har skickats de senaste sju dagarna (tiden kan ändras). Varje
brev visas med datumet det skickades, dess ärende och en lista över alla
mottagare. Framför varje mottagare så visas aktuell status. Det finns sex
stycken olika status:

-		- Betyder att Postilion inte vet något om denna mottagaren ännu
Misslyckades	- Brevet kom ej fram till denna mottagaren
Levererat	- Brevet har blivit levererat till mottagaren. Observera att
		  detta INTE implicerar att mottagaren ens har sett brevet ännu
Vidareskickat	- Brevet har skickats vidare till en agent (MTA) som inte
		  klarar av att returnera kvittenser
Expanderat	- Brevet har levererats, men mottagaren var ett alias som
		  expanderade till en eller flera andra adresser. Fler
		  kvittenser kan komma
Försenat	- Brevet har inte nått mottagaren ännu, men systemet kommer
		  att göra flera försök att leverera det

Man kan få mera information om varje kvittens genom att peka på mottagaren
och trycka på vänster musknapp}
set balText(dsn_readable) {Här ser du en förklaring varför denna
kvittens skickade}
set balText(dsn_more_info) {Visa de delar av originalbrevet som skickades med
kvittensen i textfönstret ovan}
set balText(switch_expression) {Denna meny låter dig välja mellan avancerade eller enkla uttryck}
set balText(save_expr_as) {Om du vill att detta uttryck skall sparas för framtida användning
så skriv in namnet det skall sparas under här och se till att knappen
är markerad}
set balText(exp_ok) {Stäng uttrycksfönstret och maerka de brev
som matchar uttrycket}
set balText(clear) {Rensa alla fält}
set balText(exp_basic_and) {Alla raderna nedan måste matcha brevet för att det skall markeras}
set balText(exp_basic_or) {Alla brev som matchar minst en av de icke
tomma raderna nedan kommer att markeras}
set balText(exp_basic_field) {Denna rad matchar om minst ett av orden i fältet finns
i den specificerade huvudraden}
set balText(exp_adv_exp) {Här kan du skriva in ett avancerat uttryck, man kan använda tangentbordet
och/eller knapparna here. Exemple på giltiga uttryck är:
	Subject has foo
	Subject is "foo bar" and (To has maf or Cc has maf)}
set balText(exp_adv_fields) {Dessa knappar representerar de olika
huvudrader som vi kan matcha innehållet i}
set balText(exp_adv_has) {Huvudraden innehåller henna sträng och kan innehålla mer text}
set balText(exp_adv_is) {Huvudfältet matchar detta exakt}
set balText(exp_adv_gt) {Denna större än symbol går endast att använda tillsammans med
storleksfältet}
set balText(exp_adv_lt) {Denna minder än symbol går endast att använda tillsammans med
storleksfältet}
set balText(exp_adv_bool) {Dessa logiska termer kan användas för att kombinera uttryck}
set balText(exp_adv_p) {Använd parenteser för att gruppera uttryck}
set balText(exp_list) {En lista över sparade uttryck}
set balText(exp_text) {Uttryckets innehåll}
set balText(exp_delete) {Radera det valda uttrycket}
set balText(fs_show) {Visa alla filer i det aktiva biblioteket}
set balText(fs_old) {Meny som innehåller gamla bibliotek}
set balText(mode_menu) {Denna meny låter dig påverka rättigheterna på filen}
set balText(welcome_lang) {Denna meny låter dig välja språk på applikationen}
set balText(welcome_shutup) {Denna meny låter dig välja om du även i fortsättningen vill bli
informaerad om ändringar i Postilion (den är även tillgänglig via
instalällningsfönstret)}
set balText(welcome_cont) {Stäng detta fönster och öppna Postilions huvudfönster}
set balText(ok_and_apply) {Stäng fönster och applicera ändringarna}
set balText(keydef_delete) {Tryck på denna knapp och sedan någon av tangendefinitionerna
ovan för att readera definitionen}
set balText(keydef_add) {Tryck på denna knapp för att lägga till tangenter
till denna händelse. Efter att du tryckt på knappen så
skall du trycka den önskade tangenten på tangentbordet}
set balText(keydef_def) {Här se du tangentkombinationerna som orsakar denna händelse}
set balText(apply_prefs) {Applicera ändringarna och spara de nya värdena}
set balText(unit_pref) {Värdets enhet}
set balText(pref_clock_format) {Clock format (12 or 24 hour)}
set balText(pref_language) {Språket som användargränssnittet använder. Om man ändrar denna
inställningen så måste man starta om Postilion för att det skall märkas}
set balText(pref_start_win) {Which windows should be opened automatically
when Postilion is started.  Make sure you start
with at least one of "Mailboxes" or "Folder", or
you won't be able to read any mail!}
set balText(pref_next_menu) {Whether to use a single NeXT style menu of submenus,
insead of the normal menubar across the top.
Note:
Only use NeXT style only with click-to-focus mode.
It won't work well with focus-follows-mouse modes}
set balText(pref_color_set) {Vilken färgskala som Postilion skall använda}
set balText(pref_paper_color) {Which color should be used for the message text areas}
set balText(pref_new_msg_col) {Which color should be used for new messages}
set balText(pref_sel_msg_col) {Which color should be used for selected messages}
set balText(pref_fnd_msg_col) {Which color should be used for found messages}
set balText(pref_flg_msg_col) {Which color should be used for flagged messages}
set balText(pref_del_msg_col) {Which color should be used for deleted messages}
set balText(pref_seen_msg_col) {Which color should be used for seen messages}
set balText(pref_ans_msg_col) {Which color should be used for answered messages}
set balText(pref_button_bar) {Should Postilion display the button bar}
set balText(pref_image_buttons) {Should Postilion display icons or text for action buttons}
set balText(pref_sync_but) {Display a mailbox synchronization button in the browser}
set balText(pref_sync_oper) {Whether the sync button should compact the mailbox,
 expunging deleted messages, or just update it.}
set balText(pref_iconic) {Här kan man säga åt Postilion att starta i ikonifierat läge}
set balText(pref_info_changes) {När användaren startar en ny version ev Postilion för första gången så
visar programmet en ruta med information om nya features. Denna
inställningen låter användaren stänga av denna information}
set balText(pref_mail_steal) {Om Postilion skall leta efter brev som netscape har tagit eller inte}
set balText(pref_print_command) {Kommando som skriver ut brev. Alla '%s' i kommandonamnet kommer att
bytas ut mot namnet på filen som skall skrivas ut. Om det inte finns
några '%s' så får kommandot data som skall skrivas ut på stdin}
set balText(pref_print_header) {Vilka huvudfält som skall skickas till utskriftkommandot ('Alla',
'Valda' eller 'Inga')}
set balText(pref_print_non_text) {Should non-text message parts be printed?}
set balText(pref_tmp) {Biblioteket där temporärfiler skapas}
set balText(pref_permissions) {Rättigheter när nya filer skapas (tex när ett brev sparas)}
set balText(pref_userproc) {Filen där användarnas användardefinierade procedurer skall finnas}
set balText(pref_hold_dir) {Bibliotek där lagrade brev lagras}
set balText(pref_fontsize) {Normalstorleken på all text}
set balText(pref_keep_pos) {Bestämmer om Postilion skall komma ihåg var fönstren var placerade och 
hur stora de är}
set balText(pref_mailcap_path) {Namnen på de mailcap-filer som Postilion kommer att leta efter. Dessutom
så försöker Postilion alltid först med de filer som näms i omgivnings-
variabeln MAILCAP}
set balText(pref_terminal) {Det kommando som används när Postilion skall skapa en interaktiv  
terminal för de ingångar i mailcap-filerna som har egenskapen 
needsterminal. Kommandot från mailcap-filen kommer att läggas
till efter detta kommando}
set balText(pref_message_llength) {Hur många brev som visas i listan övewr brev på skärmen}
set balText(pref_list_mode) {Should Postilion use the list format below for all
mailboxes (this is the default), or use the per-mailbox
settings}
set balText(pref_list_format) {Denna inställning bestämmer hur listan över brev ser ut. Den ser ut
som ett argument till printf() förutom att det enda som får komma
efter ett '%' är (förutom ytterligare ett '%') ett heltal (måste ej
finnas) som kan vara negativt och en av följande bokstäver.
        s - Brevets ämne
        n - Namnet på avsändaren (eller epostadress om namnet ej är
            tillgängligt).
        m - Avsändarens epostadress.
        r - Mottagarens namn (eller epostadress om namnet ej är
            tillgängligt).
        R - Mottagarens epostadress.
        b - Ungefärlig storlek på brevet (i bytes).
        B - Som ovan men skrivet med max fyra tecken.
        d - Brevets datum (i läsbar form).
        D - Brevets datum (i sekunder sedan tidens början).
        S - Brevets status (max 5 tecken).
            Följande statusbokstäver används:
            N - brevet är oläst
            A - du har svarat på brevet
            D - brevet är markerat för radering
            F - brevet ärr markerat ("flagged") och tillhör därför
                den aktiva gruppen.
            + - brevet var adresserat till dig personligen
        i - Brevets index i listan}
set balText(pref_show_header) {Vilka huvudfält som skall visas ('alla', 'Valda', och 'Inga')}
set balText(pref_show_header_selection) {Om man visar valda huvudfält så kommer bara de fält som näms i denna
listan att visas}
set balText(pref_browse) {Should Postilion always use browse mode, never
use browse mode, or use the per-mailbox setting?

Browse mode is useful when a mailbox file is not
stored on your computer.  It keeps the bodies of
messages from being loaded automatically.  The actual
body of a message only is loaded when you press the
"show body" button, or double click on the message in
the message list}
set balText(pref_sort_mode) {Should Postilion use the same message-sorting order for
all mailboxes (normal), or use the per-mailbox settings}
set balText(pref_folder_sort) {Hur breven skall sorteras}
set balText(pref_adv_on_flag) {Automatically advance to the next
message after flagging a message}
set balText(flag_seen) {Toggle this message's Seen flag (in
other words, so it does or doesn't look new)}
set balText(flag_ans) {Toggle this message's Answered flag}
set balText(flag_unseen) {Flag this message as Unseen (in
other words, so it looks new)}
set balText(seen_group) {Toggle the Seen flags of all flagged messages 
(in other words, so they do or don't look new)}
set balText(unseen_group) {Mark all flagged messages as Unseen
(in other words, so they all look new)}
set balText(ans_group) {Toggle the Answered flag of  all flagged messages}
set balText(undelete_group) {Clear the Deleted flag on all flagged messages}
set balText(pref_strsel_mode) {Should Postilion use the method below ("Select when open")
for all mailboxes (normal), or use the per-mailbox settings}
set balText(pref_start_selection) {Vilket brev som skall väljas när en mapp öppnas}
set balText(pref_log_timeout) {Hur länge som statusmeddelanden skall visas (i sekunder)}
set balText(pref_cache_passwd) {Bestämmer om Postilion skall komma ihåg lösenord till IMAP och POP-brevlådor.
Lösenorden sparas endast i minnet och går däför förlorade när Postilion avslutas}
set balText(pref_cache_passwd_timeout) {Hur länge lösenorden skall kommas ihåg
(0 betyder tills applikationen avslutas)}
set balText(pref_cache_conn) {Bestämmer om Postilion skall hålla IMAP-förbindelser öppna efter det att
mappen i fråga stängts. En öppen förbindelse kan senare återanvändas}
set balText(pref_cache_conn_timeout) {Hur länge förbindelserna skall hållas öppna
(0 betyder tills applikationen avslutas)}
set balText(pref_urlprot) {Postilion kommer bara att maerkera URLer med
ett protokoll som finns i denna liastan}
set balText(pref_url_color) {Vilken färg som URLer har (används endast på färgskärmar)}
set balText(pref_quote_color) {The color of quoted text in the message text
(only used on color displays)}
set balText(pref_url_viewer) {Vilket program som skall användas för att visa URLer. Kan också
vara en egendefinierad procedur}
set balText(pref_netscape) {Vilket kommando som skall användas för att starta netscape}
set balText(pref_netscape_args) {Extra argument som skall ges till netscape}
set balText(pref_dbase_dir) {Var databasen skall lagras}
set balText(pref_def_extype) {Vilken expireringsåtgärd som skall föreslås}
set balText(pref_def_exdate) {Vilken expireringsdag som skall föreslås (i dagar sedan brevet
lades in i databasen)}
set balText(pref_dbase_backup) {Biblioteket där man lägger bev som har expirerat från databasen med
åtgärden "arkivera". Breven lagras komprimerade}
set balText(pref_chunksize) {Hur många brev (minst) så ingår i ett komprimerat block med brev som
lagras i arkivbiblioteket}
set balText(pref_expire_interval) {Hur många dagar som det skall vara mellan expireringar av databasen}
set balText(pref_watcher_enable) {Om väktaren överhuvudtaget skall visas}
set balText(pref_watcher_time) {Hur ofta väktaren skall leta efter nya brev i olika mappar. Tiden
som anges är intervallet mellan tester i sekunder. Det finns två
olika tider, en för databasen och en för alla andra (standard).
Värdet noll stänger av funktionen}
set balText(pref_watcher_name) {Titeln på väktarfönstret}
set balText(pref_watcher_max_height) {Hur hög listan över nya brev får bli}
set balText(pref_watcher_font) {Vilket typsnitt som skall användas i detta fönstret}
set balText(pref_watcher_show) {Vilka brev som skall visas ('Alla' eller 'Nya')}
set balText(pref_watcher_format) {Formatet på listan. Se hjälpen för mappfönstret för detaljer}
set balText(pref_watcher_bell) {Hur många gånger terminalens klocka skall ringa när väktaren
upptäcker ny post.
OBSERVERA att om användarproceduren RatUP_Bell finns så kommer
detta värde att vara låst och klockan rings ej}
set balText(pref_reply_mode) {Should Postilion use the same reply-to address for all
mailboxes (normal), or use the per-mailbox settings}
set balText(pref_reply_to_addr) {Standardvärdet för Svara-Till (Reply-To) fältet i brev som skickas}
set balText(pref_reply_to_fn) {Standardvärdet för Svara-Till (Reply-To) fältet i brev som skickas}
set balText(pref_compose_headers) {Vilka huvudfält som användaren normalt kan ändra. Användaren kan
dock ändra listan i "Skriva brev"-fönstret}
set balText(pref_custom_headers) {Custom headers to be displayed in compose sessions.}
set balText(pref_editor) {Vilket editor som skall köras när användaren trycker på knappen
'Extern editor'. Ett '%s' i kommandot kommer att bytas ut mot namnet
på filen som skall editeras. "Skriva brev"-fönstret kommer att vara
låst tills editorn avslutas}
set balText(pref_attribution) {Denna raden (om den är definierad) läggs in först i varje svar.
Raden har samma syntax som "Listformat"-inställningen}
set balText(pref_forwarded_message) {Denna raden läggs in före varje inbäddat brev som skickas vidare}
set balText(pref_reply_lead) {Vilket tecken som skall placeras först på varje rad från ursprungs-
brevet när man kontruerar ett svar. Om raden inte redan börjar med
detta tecken så läggs dessutom ett mellanslag in}
set balText(pref_quote) {This option controls whether or not to quote the
body of a letter you are replying to in the reply}
set balText(pref_skip_sig) {Denna inställningen kontrollerar om signaturen på brev man svarar
på skall inkluderas i svaret}
set balText(pref_no_subject) {Ämnet på svar på brev som inte har något ämne}
set balText(pref_sig_mode) {Should Postilion use the same signature file for all mailboxes
(the default), or use the per-mailbox settings}
set balText(pref_signature) {Namnet på filen som innehåller användarens signatur}
set balText(pref_lookup_name) {Sant om Postilion skall försöka verifiera lokala adresser i passwd-listan}
set balText(pref_copy_attached) {Sant om Postilion skall kopiera bilagefilerna så fort de läggs till. Om
det är falskt så antar Postilion att filerna finns kvar när brevet skickas}
set balText(pref_from_mode) {Should Postilion use the same "From:" address for all
mailboxes (normal), or use the per-mailbox settings}
set balText(pref_from_addr) {Sätter vilken avsändaradress som skall anges i brevet. Vänligen
observera att om inte avsändaradressen pekar på dig så kommer en
extra avsändaradress att läggas in (Sender:)}
set balText(pref_from_fn) {Sätter vilken avsändaradress som skall anges i brevet. Vänligen
observera att om inte avsändaradressen pekar på dig så kommer en
extra avsändaradress att läggas in (Sender:)}
set balText(pref_date-prefix) {The prefix to use when creating dated dynamic mailboxes
(ie: if this value is "sent-mail" then the mailbox would be
named something like sent-mail-Feb-1998)}
set balText(pref_masquerade_as) {Se till att alla brev som skickas ser ut som om de kommer från denna
domänen (dvs ha inte med något maskinnamn i adressen). Detta värde
används istället för domännamnet}
set balText(pref_domain) {Domänen som denna maskin tillhör. Maskinnamnet och detta värde
kommer att slås ihop (om inte maskinnamnet innhåller '.') och sedan
användas. Men detta gäller INTE om masquerade_as är definierad}
set balText(pref_delivery_mode) {Denna inställningen påverkar vad som hänmder när du trycker på
någon av skicka-knapparna i "komponera-brev"-fönstret. Om typen
är "direkt" så skickas brevet direkt (men i backgrunden). Om
typen är uppskjuten så läggs brevet in i en kö och du kan vid
nögon senare tidpunkt skicka iväg alla breven som ligger i kön}
set balText(pref_sendprot) {Hur Postilion skall skicka brev. Via SMTP eller ett program}
set balText(pref_smtp_hosts) {Om vi skickar brev via SMTP så är detta en lista över maskiner som
vi skall försöka skicka brevet till. Varje maskinnamn kan sluta med
:port där port är nummret på den port på maskinen som man skall
prata SMTP med}
set balText(pref_smtp_timeout) {Hur länge vi är beredda att vänta på SMTP-servern (i sekunder)}
set balText(pref_smtp_reuse) {Om falsk så kommer förbindelsen till SMTP-servern att kopplas
ner och upp mellan alla brev som skickas. Om sant så kommer alla
brev att skickas i en enda förbindelse}
set balText(pref_smtp_verbose) {Hur mycket vi vill veta om vad som händer när man skickar ett brev
med SMTP}
set balText(pref_sendprog) {Det här är kommandot som används om man väljer att skicka brev via
ett program. Programet förväntas ta mottagarnas adress som argument
och själva brevet på stdin (dvs sendmail)}
set balText(pref_sendprog_8bit) {Definierar vilken typ av data som programmet kan hantera (sju eller
åttabitarsdata)}
set balText(pref_charset) {Vilket typsnitt vi använder}
set balText(pref_force_send) {Om detta är sant så kommer Postilion att försöka skicka brev trots att
Postilion inte vet det fulla lokala maskinnamnet (namn plus domän).
Slå INTE på detta om du inte vet vad du gör!}
set balText(pref_dsn_directory) {Var kvittenserna skall sparas}
set balText(pref_dsn_request) {Standardvärdet på "Begär kvittens" knappen i Extra-menyn i
"Skriva brev"-fönstret. "Testa"-knappen testar om ditt lokala system
stödjer kvittenser, se release-notes för mera detaljer}
set balText(pref_dsn_snarf_reports) {Denna inställningen avgör om de mottagna kvittenserna skall visas
i listan över brev i mapparna. Kvittenserna kommer alltid att synas
i Kvittenser-fönstret}
set balText(pref_dsn_expiration) {Hur länge skall breven (och eventuella kvittenser) ligga kvar i
kvittsenfönstret innan de tas bort. Tiden mäts i dagar sedan
originalmeddelandet skickades}
set balText(pref_dsn_verbose) {Hur tkrat skall informera användaren när en ny kvittens anländer.
Rapporteringsnivån ställs in individuellt för varje typ av kvittens.
Det finns tre olika nivåer:
    Håll tyst
        Rapportera inte att en ny kvittens har kommit.
    Visa i statusraden
        När en kvittens kommer så visas ett meddelande i statusraden
        för ett par sekunder.
    Visa i separat fönster
        När en kvittens kommer så visas den i ett separat fönster
        som dyker upp.
Vänligen observera att, oavsätt vad du ställer in för värden, som
kommer alla kvittenser att synas i kvittensfönstret}
set balText(pref_pgp_enable) {Denna inställning låter dig stänga av PGP delen}
set balText(pref_pgp_prog) {Namnet på pgp-programmet}
set balText(pref_pgp_args) {Eventuella extra argument som måste ges till PGP-kommandot}
set balText(pref_cache_pgp) {Om vi skall komma ihåg PGP-lösenord}
set balText(pref_cache_pgp_timeout) {Hur länge som Postilion skall komma ihåg ditt PGP-lösenord
(0=applikationens livstid)}
set balText(pref_pgp_sign) {Startvärdet för knappen signera i brevskrivningsfönstret}
set balText(pref_pgp_encrypt) {Startvärdet för knappen kryptera i brevskrivningsfönstret}
set balText(body_of_message) {Här ser du det valda brevets innehåll. Den högra musknappen ger
en meny som innehåller information om brevets struktur}
set balText(howto_display) {Denna meny låter dig bestämma hur brevdelen skall visas}
set balText(save_bodypart) {Spara denna del av brevet på fil}
set balText(view_as_text) {Om denna knapp är markerad så visas
brevdelen som om den vore text}
set balText(view_source) {Se denna brevdel som den skickades (i ett separat fönster)}
set balText(add_to_keyring) {Lägg till denna publika nykel till din nyckelring}
set balText(run_mailcap) {Kör det kommando som definieras i mailcap för denna typ}
set balText(bodypart_entry) {Denna ingång ger information om denna brevdel. Undermenyn
ger mer information och låter dig utföra vissa operationer på den}
set balText(bodypart_show) {Denna knapp låter dig bestämma om
denna brevdel skall visas eller inte}
set balText(bodypart_save) {Spara brevdelen till fil}
set balText(dbs_and) {Alla raderna nedan måste matcha brevet för att det skall inkluderas}
set balText(dbs_or) {Alla brev som matchar minst en av de icke
tomma raderna nedan kommer att inkluderas}
set balText(dbs_keywords) {Denna rad matchar om minst ett av dessa
ord has satts som nyckelord på brevet}
set balText(dbs_subject) {Denna rad matchar om minst ett av dessa ord finns i brevets ämne.
Om du vill matcha en följd av ord så omge den med ""}
set balText(dbs_all) {Denna rad matchar om minst ett av dessa ord finns någonstans i brevet
Om du vill matcha en följd av ord så omge den med ""}
set balText(dbs_to) {Denna rad matchar om minst ett av dessa ord finns i Till-raden
Om du vill matcha en följd av ord så omge den med ""}
set balText(dbs_from) {Denna rad matchar om minst ett av dessa ord finns i Från-raden
Om du vill matcha en följd av ord så omge den med ""}
set balText(dbs_cc) {Denna rad matchar om minst ett av dessa ord finns i Cc-raden
Om du vill matcha en följd av ord så omge den med ""}
set balText(keywords) {Nyckelord som beskriver brevet}
set balText(exp_none) {Expirera inte detta brev}
set balText(exp_remove) {Radera detta brev när det expirerar}
set balText(exp_incoming) {Lägg till detta brev till den inkommande brevlådan när det expirerar}
set balText(exp_backup) {Flytta detta brev till backup när det expirerar}
set balText(exp_date) {När brevet skall expireras. Den för tillfället enda godkända formen
är +N där N är antalet dagar från som brevet skall ligga i databasen
innan det expireras}
set balText(vd_createsub) {Skapa en ny undermeny}
set balText(vd_newfile) {Create a new mailbox as a simple
Unix mailbox file}
set balText(vd_newmh) {Create a new mh mailbox}
set balText(vd_newdbase) {Create a new database mailbox}
set balText(vd_newimap) {Create new IMAP mailbox}
set balText(vd_newpop) {Create new POP3 mailbox}
set balText(vd_newdynamic) {Create a new dynamic mailbox}
set balText(vd_importdir) {Import file mailboxes from a directory}
set balText(vd_importmh) {Import mh-mailboxes from a directory}
set balText(vd_importimap) {Import IMAP mailboxes}
set balText(vd_foldermenu) {This menubutton lets you create new mailboxes,
and sub-entries for groups of mailboxes.
The new entries are placed in the list above}
set balText(vd_importmenu) {This menu lets you import groups of existing
mailboxes. The new entries are placed in the top menu}
set balText(vd_edit) {Redigera denna ingång}
set balText(vd_delete) {Radera denna ingång (om det är en undermeny så kommer
du att få frågan om du vill radera alla barnen)}
set balText(vd_setinbox) {Set this mailbox to be the default mailbox
 opened when Postilion starts.  Typically this
 will be the mailbox in which new mail arrives}
set balText(vd_setsaveout) {Set this mailbox to store a copy of all the messages
 you send.  This setting can be over-ridden for each
 mailbox individually}
set balText(vd_setstartup) {Set this mailbox to be opened on startup}
set balText(vd_setstartmin) {Set this mailbox to be opened minimized on startup}
set balText(vd_unsetstartup) {Set this mailbox to not be opened on startup}
set balText(vd_unsetstartmin) {Set this mailbox to not be opened minimized on startup}
set balText(vd_list) {This is a list of your mailboxes.  
   * Double-click the left mousebutton to open a mailbox in the current 
     browser window, or in a new browser window if none exists.
   * Press the right mousebutton to get a menu of commands you can
     apply to the selected entry - or to add a new mailbox after it.
   * Entries with an arrow to their right (->) have sub-entries, 
     which will appear in the next box to the right of this one.  
   * You can move back to the left by selecting an entry in the 
     box to the left of this one.}
set balText(mbv_list) {This is a list of your mailboxes.
   * Double-click the left mouse button 
     to open a mailbox in this window
   * Press the right mousebutton to 
     get a menu which lets you open
     the selected mailbox, or move the 
     currently selected messages to it.
   * Entries with an arrow to their 
     right (->) have sub-entries, 
     which will appear in the next 
     box to the right of this one.  
   * You can move back to the left 
     by selecting an entry in the 
     box to the left of this one.}
set balText(mbv_sash_open) {Click this sash with the left mouse 
button to open a view of your mailboxes.}
set balText(mbv_sash_close) {Click this sash with the left mouse 
button to close the mailbox view.}
set balText(msg_sash) {Drag this sash up or down with the 
mouse to change the relative
sizes of the message list (above) and
the message text (below) panes.}
set balText(vd_menuname) {Namnet på den nya undermenyn}
set balText(vd_name) {Name of mailbox}
set balText(vd_mhname) {Name of mh-mailbox}
set balText(vd_host) {Maskin som mappen finns på}
set balText(vd_user) {The user-name we should use to access the mailbox}
set balText(vd_mbox) {Name of remote IMAP mailbox}
set balText(vd_port) {Port som servern lyssnar på}
set balText(vd_filepat) {Inkludera bara filer som matchar detta glob-stil mönster}
set balText(vd_dirpat) {Gå bara ner i bibliotek som matchar detta glob-stil mönster}
set balText(vd_pattern) {Inkludera bara mappar som matchar detta mönster}
set balText(watcher) {Tryck vänster musknapp för att öppna Postilions huvudfönster,
höger musknapp stänger detta fönster för tillfället}
set balText(help_subjlist) {Lista över hjälptexternas ämnen. Klicka med vänster musknapp på en
av dem för att se motsvarande hjälptext}
set balText(help_text) {Hjälptext för det valda ämnet}
set balText(pref_ispellRecheckAfterAdd) {Choose "True" for this to re-check the spelling of words 
currently marked misspelled, after you add to the dictionary 
or session.  Usually a good idea, except it will cause a
small delay after you add words to your personal dictionary.

You can also use the right mouse button to accept words from
a menu of possible corrections.}
set balText(pref_ispellon) {This turns the spell-check feature on and off.  Note that the
feature needs to be turned on BEFORE a message is brought up}
set balText(pref_ispelltextOnly) {Check this box if you want to perform spell checking only
of the text marked as 'text'.  This should avoid spell checking 
To:, Cc: & X-Face: lines, it comes at a small time penalty - turn
it off if you want to see a small improvement in response time.

Note that turning this option on will also not spell check 'attachments'
unless they are marked as Content-Type: text/enriched or text/plain.
If you find that spell checking STOPS working in a section of the
document you may want to turn this off}
set balText(pref_ispelldefaultCommand) {This is the program used to actually do the real work -
'ispell -a' is probably a good choice.  If you want to 
use an alternate dictionary, 'ispell -a -d <dictionary-file>' may be 
appropriate.  You may find that -S sorts the list of possible
words better - see the ispell(1) man page for more details.
(Really, it's got a lot of details and you can really personalize
how it works to fit best with your environment)}
set balText(pref_ispellotherCommands) {Other ways to run the 'Ispell' programs, mostly intended for 
our friends in Europe who have to work in a variety of languages.
This entry should be in label/invocation pairs.  E.g. one pair
would be "German  { ispell -a -d deutsch }"}
set balText(pref_ispellpopupBinding) {This controls what the 'popup' window is bound to, some examples include:
	ButtonPress-3 
	ButtonPress-2
	ButtonPress-1
	Shift-3
	Control-3
	Meta-2
	Alt-1
	etc...

Note that the menu is unposted (vanishes) on any ButtonRelease}
set balText(pref_ispellviewStyle) {This is how to display misspelled words.  You
can use the built in types or create your own
using 'other'.  For 'color' ones fill in the color, below.
Examples of using "other":
	-underline t
	-background red
	-foreground Bisque
	-font <font>
	-fgstipple <bitmap>
	-bgstipple <bitmap>
Bitmaps can be many things, 'gray50' and 'gray25' are popular
For example....
	 -font *italic*
    or   -font *bold*
    or   -font *24*    (Big!)
    or   -font *italic*24* (big italics)
	 -relief <relief> (see tk docs for more info...)
Effects can also be combined.  For example:
	-underline t -foreground red
	-bgstipple gray25 -color red}
set balText(pref_ispellviewStyle-Color) {color for foreground color and background color}
set balText(pref_ispellviewStyle-Other) {Style if 'other' is selected}
set balText(pref_mboxvis) {Whether or not to display the 
mailbox view at the top of the
browser window.}
set balText(pref_expunge_on_close) {If Postilion should automatically expunge all messages
marked for deletion whenever you close the mailbox}
set balText(pref_automatic_wrap) {Kontrollerar den automatiska radbrytningen}
set balText(pref_automatic_indent) {Kontrollerar den automatiska indenteringen}
}
