#
# DO NOT EDIT!
#
# This file is automatically generated from files in the Text/ subdirectory
#
#  TkRat software and its included text is Copyright 1996,1997,1998
#  by Martin Forssén
# 
#  Postilion software and its included text and images
#  Copyright (C) 1998, 1999, 2000 Nic Bernstein
# 
#  The full text of the legal notices is contained in the files called
#  COPYING and COPYRIGHT.TkRat, included with this distribution.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# The following is the function which does the actual work
proc init_balText_de {} {
global balText
set balText(list_of_messages) {Liste der Nachrichten im aktuellen Postfach.
Sie können die Maus wie folgt benutzen:

 linke Maustaste  - Nachricht ansehen
 doppelt links    - (im Browse-Modus) zeige Nachr.-Text
                    (Der Nachrichtentext wird geholt)
 rechte Maustaste - Nachrichten markieren / nicht markieren
                    (zur Gruppe der markierten
                     hinzufügen/entfernen)}
set balText(current_folder_name) {Name des aktuellen Postfachs}
set balText(current_folder_size) {Bytes im aktuellen Postfach}
set balText(current_folder_nummsg) {Anzahl der Nachrichten im aktuellen Postfach}
set balText(status_text) {Nachrichten vom Postilion}
set balText(move_msg) {Dieses Menü kopiert die aktuelle Nachricht in das
ausgewählte Postfach und markiert sie zum Löschen in
diesem Postfach.}
set balText(delete_msg) {Diese Nachricht zum Löschen markieren.}
set balText(compose_msg) {Neue Nachricht schreiben}
set balText(compose_menu) {Dieses Menü enthält nützliches Kommandos
zum Schreiben von Nachrichten.}
set balText(mailbox_menu) {Dieses Menü enthält Kommandos die
sich auf Postfächer beziehen}
set balText(window_menu) {Dieses Menü enthält Such-Werkzeuge für Adressbücher,
Postfächer und Gespeicherte Ausdrücke.}
set balText(edit_menu) {Dieses Menü hilft bei der 
Bearbeitung der aktuellen Nachricht.}
set balText(format_menu) {Dieses Menü hilft beim Formatieren
der aktuellen Nachricht.}
set balText(print_menu) {Öffnet eine Dialogbox zum Drucken einer
Nachricht oder einer Gruppe von Nachrichten.}
set balText(vd_open) {Öffnet das ausgewählte Postfach im neuen Fenster}
set balText(vd_cut) {Das ausgewählte Postfach ausschneiden. Er
kann zusammen mit dem Einfügen-Kommando an eine
andere Stelle verschoben werden.}
set balText(vd_paste) {Fügt das vorher ausgeschnittene Postfach
in die Liste ein. (Oberhalb)}
set balText(spell) {Öffnet die Rechtschreibprüfung für
diese Nachricht.}
set balText(clear_addr) {Klicken (links) Sie hier um alle
Markierungen zu entfernen.}
set balText(reply_to_all) {Sendet eine Antwort an alle Absender/innen
und Empfänger/innen der aktuellen Nachricht}
set balText(reply_to_sender) {Sendet eine Antwort an die Absender/in der
aktuellen Nachricht.}
set balText(no_sig) {Das bedeutet, dass die aktuelle Nachicht
nicht unterschrieben ist.}
set balText(unchecked_sig) {Das bedeutet, dass die aktuelle Nachicht
unterschrieben aber nicht geprüft ist. Drücken
Sie die linke Maustaste um jetzt zu überprüfen.}
set balText(good_sig) {Die Unterschrift der Nachricht ist korrekt.}
set balText(bad_sig) {Die Unterschrift ist NICHT korrekt!
(passt nicht zur Nachricht)}
set balText(part_sig) {Ein Teil der Nachricht ist unterschrieben, aber nicht alles.}
set balText(send_deferred) {Versendet sofort alle zurückgestellten Nachrichten.
(Die Zahl in Klammern zeigt die Anzahl der
zurückgestellten Nachrichten an.)}
set balText(show_notifications) {Zeigt den Status (per Popup-Fenster) der
Empfangsbestätigung dieser Nachricht an.}
set balText(watcher_enable) {Hiermit können Sie das EB-Popup-Fenster
ein- oder ausblenden.}
set balText(reread_aliases) {Liest alle Post-Adressdateien erneut ein.}
set balText(reread_userproc) {Liest alle Nutzer/in-Scripte erneut ein.}
set balText(import_aliases) {Durchsucht die `Standard-Stellen' für Mail-Adress-Dateien
von anderen Programmen und liest diese ein.}
set balText(reread_mailcap) {Liest alle System-Mail-Cap-Dateien erneut ein.}
set balText(take_mail) {Schaut nach, ob Netscape Mails aus dem Posteingang
übernommen hat und holt sie ggf. zurück.}
set balText(check_dbase) {Prüft die Postilion Datenbank auf Fehler.}
set balText(check_fix_dbase) {Prüft die Postilion Datenbank auf Fehler und versucht
diese zu korrigieren.}
set balText(see_log) {Zeigt alle vom Postilion intern erzeugten Nachrichten
in Protokollform.}
set balText(quit) {Beendet Postilion}
set balText(folder_menu) {Dieses Menü zeigt eine Liste Ihrer Postfächer. Ein Doppelklick
auf einem Namen öffnet das Postfach im aktuellen Browserfenster.
Um das Postfach in einem neuen Fenster zu öffnen, markieren Sie
den Namen und wählen den Öffnen-Knopf.}
set balText(message_menu) {Diese Menü enthält Befehle die sich auf
Nachrichten beziehen.}
set balText(clock) {Hier steht die Zeit, das Datum und der Tag
an dem die Nachricht versandt wurde (in lokaler Zeit).}
set balText(mailboxes) {Öffnet ein neues Fenster in dem Sie mit Postfächern
arbeiten können (Neu/Bearbeiten usw.) Außerdem können Sie
die markierten Nachrichten (oder die gruppierten) in das
markierte Postfach verschieben.}
set balText(next_msg) {Markiert die nächste Nachricht in der Liste.}
set balText(prev_msg) {Markiert die vorherige Nachricht in der Liste.}
set balText(find) {Öffnet ein Popup-Fenster mit dem Sie die Liste
der Nachrichten oder die aktuelle Nachricht durchsuchen
können.}
set balText(compose) {Bearbeiten einer neuen Nachricht.}
set balText(reply_sender) {Schreiben Sie eine Antwort an die Absender/in der
aktuellen Nachricht.}
set balText(reply_quote_sender) {Schreiben Sie eine Antwort an die
Absender/in der aktuellen Nachricht. Der
Nachrichtentext wird als Zitat eingefügt.}
set balText(reply_all) {Schreiben Sie eine Antwort an alle Absender/innen
und Emfänger/innen der aktuellen Nachricht.}
set balText(reply_quote_all) {Schreiben Sie eine Antwort an alle Absender/innen
und Emfänger/innen der aktuellen Nachricht. Der
Nachrichtentext wird als Zitat eingefügt.}
set balText(forward_inline) {Schreiben Sie eine Nachricht, die die
aktuelle Nachricht beeinhaltet. Diese wird
als `Weitergeleitet' gekennzeichnet.}
set balText(forward_attached) {Schreiben Sie eine Nachricht, die die
aktuelle Nachricht als Anlage beeinhaltet.}
set balText(bounce) {Leitet die aktuelle Nachricht
zu einer neuen Adresse weiter.}
set balText(compose_held) {Geparkte Nachrichten weiterbearbeiten.}
set balText(extract_adr) {Adressen (auch einzelne) die in der aktuellen Nachricht
enthalten sind, können hiermit in eines Ihrer Adressbücher
aufgenommen werden.}
set balText(move) {Verschiebt die aktuelle Nachricht in einen anderes Postfach.}
set balText(delete) {Markiert die aktuelle Nachricht zum Löschen.
Sie wird erst gelöscht, wenn Sie das nächste Mal
das Postfach "Packen".}
set balText(undelete) {Entfernt die Löschmarkierung von der aktuellen Nachricht.}
set balText(print) {Druckt die aktuelle Nachricht.}
set balText(structure) {Dieses Untermenü zeigt die interne Struktur
der Nachricht und deren Anlagen.}
set balText(show_all_headers) {Zeigt den gesamten Nachrichtenkopf an. Normalerweise werden
nur einige Zeilen wie `Von' und `Betreff' gezeigt.}
set balText(show_selected_headers) {Zeige nur die ausgewählten Nachrichtenkopfzeilen.
Z.B. `Von', `Betreff' und `Cc'.}
set balText(show_no_headers) {Zeige den Nachrichtenkopf nicht an.}
set balText(group_menu) {Dieses Menü bearbeitet die gruppierten Nachrichten.
Das sind die Nachrichten, die mit einem `F' (flagged)
markiert sind. Die Befehle werden auf alle so
markierten Nachrichten im aktiven Postfach angewandt.

Sie können Nachrichten mit der rechten Maustaste markieren,
oder über die Suchbefehle.}
set balText(create_in_win) {Öffnet ein neues Fenster mit einer
Nachrichtenliste und markiert die Nachrichten in
diesem Fenster.}
set balText(create_by_expr) {Führt eine Suche durch und markiert die Treffer.
(Markierte Nachrichten werden auch als `Gruppe'
bezeichnet.)}
set balText(use_saved_expr) {Fügt der Gruppe weitere Nachrichten hinzu und nutzt
dafür einen bestehenden (vorher gespeicherten) Suchausdruck.}
set balText(clear_group) {Löscht die Gruppen-Markierung (F) von allen Nachrichten.}
set balText(group_all) {Markiert alle Nachrichten.}
set balText(delete_group) {Ändert den Löschstatus von allen markierten Nachrichten.}
set balText(print_group) {Druckt alle markierten Nachrichten.}
set balText(move_group) {Verschiebt alle markierten Nachrichten in ein
anderes Postfach.}
set balText(admin_menu) {Diese Menü enthält verschiedene Befehle zur
Administration (Verwaltung) des Programms.}
set balText(browse_mode) {Der Browse-Modus ist nützlich, wenn das Postfach nicht auf Ihrem
Computer gespeichert ist. Der Nachrichtentext (Body) wird nicht
automatisch übertragen, sondern muß mit dem Knopf `Zeige
Nachrichtentext', oder einem Doppelklick in der Nachrichtenliste
manuell übertragen werden.}
set balText(update) {Prüft das aktuelle Postfach auf neue Nachrichten.
(Zum Löschen markierte Nachrichten werden nicht gelöscht.)}
set balText(sync) {Zum Löschen markierte Nachrichten im aktuellen Postfach
werden entgültig gelöscht. Außerdem wird auf neue Nachrichten
geprüft.}
set balText(newedit_folder) {Öffnet ein Fenster mit dem Sie Postfächer verwalten können.
(Neu/Bearbeiten usw.)}
set balText(aliases) {Öffnet das Adressbuch-Fenster.}
set balText(focus) {Zeigt nur die markierten Nachrichten.}
set balText(unfocus) {Zeigt alle Nachrichten (markiert oder nicht)}
set balText(hide_size) {Versteckt die Nachrichtengröße in der Liste.}
set balText(hide_deleted) {Versteckt die zum Löschen markierten
Nachrichten in der Liste.}
set balText(hide) {Versteckt alle Postilion-Fenster.}
set balText(preferences) {Öffnet das Eigenschaften-Fenster (Postilion-Konfiguration).}
set balText(define_keys) {Hier können Sie die Shortcuts für die Tastatur
bearbeiten, die im Hauptfenster gültig sind.}
set balText(saved_expr) {Hier können Sie die gespeicherten Ausdrücke bearbeiten,
die auf die Gruppen (markierten Nachrichten) angewandt werden
können.}
set balText(sort_order) {Ändert die Sortierung des Postfachs.}
set balText(sort_subjdate) {Sortiert Nachrichten nach Datum, gruppiert Nachrichten mit gleichem
Betreff zueinander. (Sehr guter Modus!)}
set balText(sort_subj) {Sortiert nach Betreff (alphabetisch)}
set balText(sort_sender) {Sortiert nach Absender/in (alphabetisch)}
set balText(sort_natural) {Keine Sortierung. Zeigt die Nachrichten
in der Reihenfolge des Eingangs an.}
set balText(sort_reverse_natural) {Zeigt die Nachrichten in der umgekehrten
Reihenfolge des Eingangs an.}
set balText(sort_date) {Sortiert nach Datum (aufsteigend).}
set balText(sort_reversedate) {Sortiert nach Datum (absteigend).}
set balText(help_menu) {Verschiedene Hilfestellungen.}
set balText(balloon_help) {Schaltet die Popup-Informationen (balloon help) ein oder aus.}
set balText(show_version) {Zeigt Versionsinformationen vom Postilion.}
set balText(explain_ratatosk) {Was bedeutet Ratatosk.}
set balText(help_window) {Öffnet das Hilfefenster.}
set balText(send_bug) {Hiermit können Sie einen Fehlerreport
an den Autor von Postilion senden.}
set balText(group_list_editor) {Markierte Nachrichten werden Mitglieder der Gruppe.
Benutzen Sie die linke Maustaste um die Nachricht zu
markieren oder die Markierung zu entfernen.}
set balText(group_window_ok) {Schließt das Fenster. Die Markierungen werden
in das Postfach-Fenster übertragen.}
set balText(group_window_selall) {Markiert alle Nachrichten als Teil der Gruppe.}
set balText(group_window_unselall) {Alle Nachrichtenmarkierungen entfernen.}
set balText(cancel) {Abbrechen und Fenster schließen.}
set balText(enter_search_exp_here) {Hier geben Sie den Suchbegriff ein.}
set balText(toggle_ignore_case) {Groß-/Kleinschreibung bei der Suche beachten oder nicht.}
set balText(find_exact) {Exakte Suche.}
set balText(find_regexp) {Suche mit regulärem Ausdruck.}
set balText(find_in_mlist) {Suche in der Nachrichtenliste
(nicht der aktuellen Nachricht).}
set balText(find_in_body) {Durchsuche den Text der aktuellen Nachricht.}
set balText(find_first) {Starte die Suche am Anfang des Postfachs.}
set balText(find_next) {Mit dem Suchausdruck weitersuchen.}
set balText(dismiss) {Fenster schliessen.}
set balText(show_adrbook_menu) {Diese Liste zeigt Ihre Adressbücher. Ein
Mausklick auf einen Eintrag zeigt die Adressen
an. Markieren Sie eine Adresse und drücken Sie
den An-Knopf, um die Adresse in die
Empfänger/innen-Liste aufzunehmen. Wenn Sie
keine einzelne Adresse ausgewählt haben, können
auch ALLE Adressen eines Adressbuchs in die
Liste aufnehmen.}
set balText(use_system_aliases) {Einträge vom system-weiten (lokalen) Adressbuch.}
set balText(add_addrbook) {Neues Adressbuch anlegen. Die Adressen
werden in der angegebenen Datei gespeichert.}
set balText(delete_addrbook) {Versteckt ein Adressbuch. Die Datei wird nicht gelöscht,
sondern nur von den Positlion-internen Tabellen entfernt.}
set balText(set_default_addrbook) {Zum Standardadressbuch erklären. Dort werden neue
Adressen gespeichert, wenn Sie kein anderes Adressbuch angeben.}
set balText(import_aliases_from_pgm) {Importiert Adressen aus anderen Programmen.}
set balText(alias_list) Adressliste.
set balText(new_alias) {Neue Adresse.}
set balText(edit_alias) {Adresse bearbeiten.}
set balText(delete_alias) {Adresse löschen.}
set balText(move_alias) {Verschiebt die markierte Adresse
in ein anderes Adressbuch.}
set balText(alias_adr_book) {Das Adressbuch wo die Adresse hingehören könnte.}
set balText(alias_alias) {Eine Kurzbezeichnung (Alias) den Sie statt
der gesamten EMail-Adresse eingeben können.
Leerzeichen sind nicht erlaubt.
Postilion ersetzt den Alias in `An', `Cc' oder
`Bcc'-Felder automatisch mit der vollständigen Adresse.
Die Adresse kann in mehreren Adressbüchern geführt
werden, aber der Alias muß eindeutig sein.}
set balText(alias_fullname) {Der volle Name der Person. So erscheint der Name
im Adressbuch und in den Adresszeilen der Nachrichten.}
set balText(alias_content) {Die aktuelle EMail-Adresse, z.B. rene@gmx.de.
Diese wird beim Senden benutzt.}
set balText(alias_comment) {Kommentar, nur für Sie. ::-)}
set balText(name_of_adrbook) {Diesen Namen benutzt Postilion als interne
Referenz für dieses Adressbuch.}
set balText(list_of_books_to_delete) {Markieren Sie die Adressbücher die Sie aus
der Liste löschen möchten. Dann drücken Sie
"Löschen".}
set balText(aliases_adr_book) {Das Adressbuch zu dem die Adressen gehören.}
set balText(aliasadd_use) {Wenn dieser Knopf nicht aktiviert ist,
wird die Adresse dieser Zeile ignoriert.}
set balText(alias_chooser) {Aus dieser Liste können Sie eine Adresse auswählen.
Es gibt verschiedene Möglichkeiten dies zu tun:
   * Die linke Maustaste
   * Die Pfeiltasten oben/unten
Wenn Sie eine Adresse ausgewählt haben, fügt ein Druck
auf die Leertaste die Adresse dem `An'-Feld hinzu.
`Return' fügt dem An-Feld hinzu und schließt das Fenster.
Wenn kein Bearbeitungsfenster geöffnet ist, wird ein neues
aufgemacht. Mit Escape oder STRG-C können Sie das Fenster
ohne weitere Aktion schließen.}
set balText(compose_held_pick) {Markieren Sie die Nachricht die Sie weiterbearbeiten wollen.
Sie können auch Doppelklicken oder OK drücken.}
set balText(compose_insert_file) {Am Cursor (Einfügemarke) wird der Inhalt einer Datei eingefügt.}
set balText(automatic_wrap) {Kontrolle des automatischen Zeilenumbruchs.}
set balText(automatic_indent) {Kontrolle der automatischen Ident-Funktion.}
set balText(abort_compose) {Bearbeiten abbrechen.}
set balText(undo) {Rückgängig (letzte Änderung).}
set balText(cut) {Den markierten Text in die
interne Zwischenablage ausschneiden.}
set balText(copy) {Den markierten Text in die
interne Zwischenablage kopieren.}
set balText(paste) {Text aus der internen Zwischenablage
am Cursor in die Nachicht einfügen.
Anmerkung: Die mittlere Maustaste fügt den
Inhalt der X-Zwischenablage ein.}
set balText(cut_all) {Den gesamten Text in die
interne Zwischenablage ausschneiden.}
set balText(copy_all) {Den gesamten Text in die
interne Zwischenablage kopieren.}
set balText(wrap_lines) {Formatiert die makrierten Zeilen.}
set balText(run_through_command) {Der markierten Text (alles wenn nichts markiert ist)
wird einem externen Befehl übergeben und durch das Ergebnis
ersetzt.}
set balText(headers_menu) {In diesem Menü können Sie die Zeilen des Nachrichtenkopfes
bestimmen, die im `Nachricht-Bearbeiten-Fenster'
angezeigt werden.}
set balText(copy_attached_files) {Wenn Sie dies einschalten, werden die Datei-Anlagen
beim Drücken des Senden-Knopfs kopiert. Ausgeschaltet
müssen Sie selbst darauf achten, dass zum Zeitpunkts des
tatsächlichen Sendens die Dateien noch vorhanden sind.}
set balText(request_notification) {Fordert eine Empfangsbestätigung an.}
set balText(pgp_sign) {Nachricht mit PGP unterschreiben.}
set balText(pgp_encrypt) {Nachricht mit PGP verschlüsseln.}
set balText(command_list) {Bearbeitet die Liste der gespeicherten Befehle
(mit welchen Sie Text bearbeiten können).}
set balText(compose_body) {Der Nachrichtentext (Body).}
set balText(attach_file) {Eine Datei als Anlage zur Nachricht hinzufügen.}
set balText(attach_special) {Spezielle Typen von Anlagen.}
set balText(attach_keys) {Öffnet ein Fenster mit den verfügbaren
*öffentlichen* PGP-Schlüsseln, die Sie als Anlage
versenden können.}
set balText(detach) {Die markierten Anlagen entfernen.}
set balText(attachments) {Hier werden die Anlagen angezeigt, die
Sie dieser Nachricht beigefügt haben.}
set balText(send) {Verschickt die Nachricht und speichert eine Kopie im
dafür vorgesehenen Postfach. Dieses können Sie im
Postfächer-Fenster mit der rechten Maustaste festlegen
(Bearbeiten). Viele Menschen mögen ein einzelnes
Postfach `Gesendete Objekte', andere mehrere Postfächer,
wieder andere wollen nichts speichern.}
set balText(sendsave) {Versendet die Nachricht und speichert eine Kopie
im auszuwählenden Postfach. Dafür öffnet sich das
Postfachfenster.}
set balText(hold) {Speichert (parkt) die Nachricht in einer Datei. Sie können
diese dann später weiter bearbeiten. Dazu nutzen Sie bitte das
Menü Neue Nachricht/Entwürfe/Geparkte bearbeiten.}
set balText(eedit) {Externes Bearbeitungsprogramm benutzen.}
set balText(compose_to) {An diese Menschen wird die Nachricht verschickt.
Sie können Alias'e eingeben und mit einem Komma oder
Return abschließen. Postilion wird dann in den
Adressbüchern suchen. Fehlerhafte Adressen werden
rot markiert. STRG-L öffnet die Adressbücher.}
set balText(compose_subject) {Der Betreff der Nachricht.}
set balText(compose_cc) {Wenn Sie eine Kopie der Nachricht an andere
Menschen verschicken wollen, können Sie die
Cc(Carbon Copy)-Zeile benutzen.
Sie können Alias'e eingeben und mit einem Komma oder
Return abschließen. Postilion wird dann in den
Adressbüchern suchen. Fehlerhafte Adressen werden
rot markiert. STRG-L öffnet die Adressbücher.}
set balText(compose_bcc) {Wenn Sie eine Kopie der Nachricht an andere
Menschen verschicken wollen, ohne das dies die
anderen Empfänger/innen sehen können, benutzen Sie
die Bcc(Blind Carbon Copy)-Zeile.
Sie können Alias'e eingeben und mit einem Komma oder
Return abschließen. Postilion wird dann in den
Adressbüchern suchen. Fehlerhafte Adressen werden
rot markiert. STRG-L öffnet die Adressbücher.}
set balText(compose_keywords) {Stichwörter die die Nachricht beschreiben.}
set balText(compose_content_description) {Eine Beschreibung des Inhalts der Nachricht.}
set balText(compose_reply_to) {Die Anwort soll an dieser Adresse gesendet werden.
(Standardmäßig wird zur Absender/in-Adresse geantwortet.)
Sie können Alias'e eingeben und mit einem Komma oder
Return abschließen. Postilion wird dann in den
Adressbüchern suchen. Fehlerhafte Adressen werden
rot markiert. STRG-L öffnet die Adressbücher.}
set balText(compose_comments) {Kommentare für die Nachricht.}
set balText(compose_from) {Von wem die Nachricht ist.}
set balText(type_menu) {Benutzen Sie dieses Menü, um den Typ der Anlage zu bestimmen.}
set balText(encoding_menu) {Das Format (encoding) der Anlage zur Zeit. Das hat nichts
mit dem Format beim Senden zu tun.}
set balText(attach_description) {Eine kurze Beschreibung der Anlage.}
set balText(attach_disposition) {Der Dateiname unter dem eine Datei-Anlage
gespeichert wird.}
set balText(attach_id) {Manchmal muß eine Identifizierung der Anlage gesendet werden.}
set balText(bounce_to) {Geben Sie die EMail-Adresse ein zu der die Nachricht
weitergeleitet werden soll.}
set balText(hold_description) {Geben Sie eine Beschreibung für den
zurückzustellenden Entwurf ein.}
set balText(choose_msg) {Diese Nachricht enthält eine oder mehrere
eingeschlossene Nachrichten. Wählen Sie den
weiterzuleitenden Teil aus.}
set balText(save_cmd_as) {Wenn Sie den Befehlt speichern möchten, aktivieren
Sie den Schalter und schreiben Sie eine Bezeichnung.}
set balText(command_to_run_through) {Schreiben Sie hier die Befehlszeile. Der markierte Text
wird dem Befehl übergeben und der Text wird durch die Ausgabe
ersetzt.}
set balText(saved_commands) {Liste der gespeicherten Befehle.}
set balText(apply_changes_to_cmd) {Die Änderungen übernehmen.}
set balText(delete_command) {Der markierten Befehl löschen.}
set balText(command_content) {Schreiben Sie hier die Befehlszeile. Markierter Text
kann dem Befehl übergeben werden und die Ausgabe des
Befehls wird diesen Text ersetzen. %s heißt, dass eine
Datei den Text enthält.}
set balText(notification_window) {Das Benachrichtigungsfenster enhält eine Liste aller Nachrichten
für die eine Benachrichtigung innerhalb der letzen 7 Tage angefordert
wurde (Die Anzahl der Tage kann eingestellt werden.) Jede Nachricht
wird mit dem Tag des Sendens, dem Betreff und allen Empfänger/innen
angezeigt. Vor jede/r/m Empfänger/in steht der aktuelle Status.
Es gibt sechs verschiedene Stati:
-              - bedeutet, dass Postilion bisher keine Information hat.
fehlgeschlagen - bedeutet, dass die Nachricht nicht angekommen ist.
ausgeliefert   - bedeutet, dass die Nachricht übermittelt wurde.
                 Das heißt nicht, dass die/der  Empfänger/in die
                 Nachricht gelesen hat!
Weitergeleitet - bedeutet, dass die Nachricht an andere Programme
                 weitergeleitet wurde, die Benachrichtigungen nicht
                 unterstützen.
Ausgedehnt     - bedeutet, dass die Nachricht von einem anderen
                 Programm an einen oder mehrere Empfänger/innen
                 weitergeleitet wurde (die Adresse ist ein Alias).
                 Es werden evt. weitere Benachrichtungen eintreffen.
Verspätet      - Die Nachricht hat das Ziel noch nicht erreicht.

Weitere Informationen über Benachrichtigungen erhalten Sie, wenn Sie die
linke Maustaste oberhalb der Empfänger/in drücken.}
set balText(dsn_readable) {Hier sehen Sie den Grund warum die
Benachrichtigung versandt wurde.}
set balText(dsn_more_info) {Zeige die Teile der Originalnachricht, die
im oberen Textfeld angegeben sind.}
set balText(switch_expression) {Diese Menü wechselt die Einstellungen zwischen
einfacher und erweiterter Suche.}
set balText(save_expr_as) {Wenn Sie den Suchausdruck später wiederverwenden wollen,
geben Sie einen Titel ein und aktivieren Sie den Schalter.}
set balText(exp_ok) {Suche durchführen, Fenster schließen und die Nachrichten
die dem Ausdruck entsprechen markieren.}
set balText(clear) {Löschen Sie den Suchausdruck.}
set balText(exp_basic_and) {Jede Zeile unter dem `und' muß auf eine
Nachricht zutreffen, damit diese markiert wird.}
set balText(exp_basic_or) {Jede Nachricht, die einer der nicht leeren
Zeilen entspricht, wird markiert.}
set balText(exp_basic_field) {Diese Zeile findet Nachrichten, wenn eines der Wörter in
der angegebenen Kopfzeile gefunden wird.}
set balText(exp_adv_exp) {Hier können Sie Ihren erweiterten Sichbegriff eingeben.
Sie können die Tastatur oder die Schalter benutzen.
Beispielausdrücke:
  Betreff hat foo
  Betreff ist "foo bar" und (An hat maf oder Cc hat maf)}
set balText(exp_adv_fields) {Diese Schalter entsprechen den verschiedenen
Zeilen des Nachrichtenkopfes, nach
denen gesucht werden kann.}
set balText(exp_adv_has) {Dieses Feld enthält den Ausdruck.}
set balText(exp_adv_is) {Exakter Treffer in der Kopfzeile.}
set balText(exp_adv_gt) {Das Größer-als-Symbol macht nur mit einem Größenfeld Sinn.}
set balText(exp_adv_lt) {Das Kleiner-als-Symbol macht nur mit einem Größenfeld Sinn.}
set balText(exp_adv_bool) {Die logischen Ausdrücke können Sie zum Kombinieren benutzen.}
set balText(exp_adv_p) {Benutzen Sie die Klammern um Ausdrücke zu gruppieren.}
set balText(exp_list) {Liste der gespeicherten Ausdrücke.}
set balText(exp_text) {Inhalt der Ausdrücke.}
set balText(exp_delete) {Löscht den markierten Ausdruck.}
set balText(fs_show) {Zeige alle Dateien im aktuellen Verzeichnis.}
set balText(fs_old) {Das Menü enthält alte Verzeichnisse.}
set balText(mode_menu) {Hier können Sie die Zugriffberechtigungen der Datei verändern.}
set balText(welcome_lang) {Hier wählen Sie die zu benutzende Sprache aus.
Es wäre besser eine Sprache zu wählen, die Sie
lesen können!}
set balText(welcome_shutup) {Hier bestimmen Sie, ob bei Änderungen des Postilion-Programms
ein Informationsfenster geöffnet wird. Sie erreichen dieses Fenster
auch über das Eigenschaften-Menü.}
set balText(welcome_cont) {Schließt dieses Fenster und öffnet
das Post-Postilion-Fenster.}
set balText(ok_and_apply) {Schließt das Fenster und wendet die Änderungen an.}
set balText(keydef_delete) {Um den Shortcut zu löschen, drücken Sie erst
diesen Schalter, dann einen der oberen.}
set balText(keydef_add) {Um einen neuen Shortcut für den Befehl zu definieren,
drücken Sie diesen Schalter und dann die Taste auf der
Tastatur (gleichzeitig mit der Alt- oder Umschalttaste).}
set balText(keydef_def) {Hier sehen Sie die Tastaturshortcuts, welche Sie für den
Befehl benutzen können.}
set balText(apply_prefs) {Änderungen übernehmen und die
neuen Einstellungen speichern.}
set balText(unit_pref) {Einheit des Werts.}
set balText(pref_clock_format) {Zeitformat (12 oder 24 Stunden).}
set balText(pref_language) {Hier wählen Sie die zu benutzende Sprache aus.
Es wäre besser eine Sprache zu wählen, die Sie
lesen können! Postilion muß neu gestartet werden,
damit die Änderungen wirksam werden.}
set balText(pref_start_win) {Welches Fenster soll automatisch beim Starten
geöffnet werden. Wählen Sie mindestens ein
Postfachfenster aus, sonst können Sie keine Mail
lesen!}
set balText(pref_next_menu) {NeXT Styl für Untermenüs, statt normaler Menüs.}
set balText(pref_color_set) {Welches Farbschema soll Postilion benutzen?}
set balText(pref_paper_color) {Welche Farbe für Nachrichtentext?}
set balText(pref_new_msg_col) {Welche Farbe für neuen Nachrichten?}
set balText(pref_sel_msg_col) {Welche Farbe für markierten Nachrichten?}
set balText(pref_fnd_msg_col) {Welche Farbe für gefundene Nachrichten?}
set balText(pref_flg_msg_col) {Welche Farbe für gruppierte Nachrichten?}
set balText(pref_del_msg_col) {Welche Farbe für gelöschte Nachrichten?}
set balText(pref_seen_msg_col) {Welche Farbe für gelesene Nachrichten?}
set balText(pref_ans_msg_col) {Welche Farbe für beantwortete Nachrichten?}
set balText(pref_button_bar) {Soll Postilion die Schalterleiste zeigen?}
set balText(pref_image_buttons) {Soll Postilion die Schalterleiste mit Ikonen oder Text anzeigen?}
set balText(pref_sync_but) {Den Synchronisieren-Schalter anzeigen?}
set balText(pref_sync_oper) {Mailbox beim Synchronisieren packen oder nur aktualisieren?}
set balText(pref_iconic) {Wenn die Fenster beim Start ikonisiert sein sollen,
können Sie das hier einstellen.}
set balText(pref_info_changes) {Beim ersten Start einer neuen Version vom Postilion,
wird ein Fenster mit den Neuerungen geöffnet. Sie können
das hier abschalten.}
set balText(pref_mail_steal) {Wenn Postilion prüfen soll, ob Netscape Nachrichten übernommen hat.}
set balText(pref_print_command) {Der Druckbefehl. Z.B. lpr %s
Das %s wird mit dem Dateinamen ersetzt. Wenn kein %s
angegeben ist, wird die Standardeingabe benutzt.}
set balText(pref_print_header) {Welche Nachrichtenkopfzeilen (wie Von:, An:, usw.)
sollen mit ausgedruckt werden? Sie können `Alle',
`Ausgewählte' oder `Keine' anwählen.}
set balText(pref_print_non_text) {Sollen auch Nachrichtenteile die kein Text
sind gedruckt werden?}
set balText(pref_tmp) {Verzeichnis in dem die Temporärdateien
gespeichert werden.}
set balText(pref_permissions) {Die Zugriffsrechte die einer neuen Datei
zugeteilt werden sollen. Der empfohlene Wert für
eine private und gesicherte Datei ist 0600.}
set balText(pref_userproc) {Die Datei, in der die Nutzer/in-Scripte gespeichert werden.}
set balText(pref_hold_dir) {Verzeichnis in dem die geparkten
Nachrichten gespeichert werden.}
set balText(pref_fontsize) {Die Größe der normalen Textes.}
set balText(pref_keep_pos) {Hier können Sie das `Erinnerungsvermögen' bezüglich
der Fenstergröße und -position anpassen.}
set balText(pref_mailcap_path) {Die Namen der Mailcap Dateien. Schauen Sie in das Mailcap
Handbuch für weitergehende Informationen. Postilion wird versuchen
diese Dateien einzulesen (z.B. /etc/mailcap, $HOME/.mailcap).
Die in der Umgebungsvariablen MAILCAP eingegebenen Dateien
werden zuerst versucht.}
set balText(pref_terminal) {Den Befehl der für ein interaktives Terminalfenster
benutzt werden soll, wenn ein Mailcap-Eintrag die Eigenschaft
"needsterminal" gesetzt hat. Dieser Befehl wird dem
View-Befehl vorausgeschickt.}
set balText(pref_message_llength) {Die Anzahl der Nachrichten, die in der Nachrichtenliste gezeigt wird.}
set balText(pref_list_mode) {Soll Postilion das Listenformat für alle Postfächer
benutzen, oder für jedes Postfach eigene Einstellungen?}
set balText(pref_list_format) {Diese Option bestimmt das Erscheinungsbild der Nachrichten.
Die Syntax entspricht der C-Funktion printf() außer dem `%'.
Diesem folgt eine optionale Integerzahl (auch negativ) und eines
der folgenden Zeichen:
 s - Betreff der Nachricht
 n - Name der Absender/in (oder EMailadressen falls ohne Namen)
 m - EMailadresse der/s Absenders/in
 r - Name der/s Empfängers/in (oder EMailadresse falls o. Namen)
 R - EMailadresse der/s Empfängers/in
 b - Größe in Bytes (ungefähr)
 B - Wie oben, aber mit maximal vier Buchstaben
 d - Nachrichtendatum (für Menschen lesbar)
 D - Nachrichtendatum (in Sekunden sein der Epoche)
 S - Nachrichtenstatus (höchstens fünf Buchstaben)
     Folgende werden benutzt:
     N - nicht gelesen
     A - beantwortet
     D - zum Löschen markiert
     F - Nachricht ist gruppiert und Mitglied
         der aktuellen Gruppe
     + - an Sie persönliche adressiert
 i - aktuelle Nachrichtennummer
Zum Beispiel:
 %3i: %4S %6d  %-24n %4B %s
bedeutet: Zeige die Nachrichtennummer (3 Zeichen breit), dann einen :,
dann den Status (4 Zeichen breit), dann das Datum (6 Zeichen), dann
zwei Leerzeichen, dann den Namen der/s Absenders/in (24 Zeichen von
links), dann die Nachrichtengröße und letztlich den Betreff.}
set balText(pref_show_header) {Welche Nachrichtenkopfzeilen sollen angezeigt werden?
(wie "An", "Betreff" usw.)}
set balText(pref_show_header_selection) {Nur die in der Liste definierten
Zeilen des Nachrichtenkopfes anzeigen
(wenn der Kopf angezeigt wird).}
set balText(pref_browse) {Voreinstellung für den Browse-Modus. Immer oder die
Einstellungen des jeweiligen Postfachs benutzen?

Der Browse-Modus ist nützlich, wenn das Postfach nicht auf Ihrem
Computer gespeichert ist. Der Nachrichtentext (Body) wird nicht
automatisch übertragen, sondern muß mit dem Knopf `Zeige
Nachrichtentext', oder einem Doppelklick in der Nachrichtenliste
manuell übertragen werden.}
set balText(pref_sort_mode) {Voreinstellung für den Sortiermodus. Für alle Postfächer
gleich (normal), oder für jedes Postfach getrennt.}
set balText(pref_folder_sort) {Sortierung der Nachrichtenliste}
set balText(pref_adv_on_flag) {Automatisch zur nächsten Nachricht wechseln,
nachdem eine Nachricht markiert wurde.}
set balText(flag_seen) {Ändern des Gelesen-Status.}
set balText(flag_ans) {Ändern des Antwort-Status.}
set balText(flag_unseen) {Als ungelesen markieren.}
set balText(seen_group) {Ändern des Gelesen-Status für alle Nachrichten.}
set balText(unseen_group) {Alle Nachrichten als ungelesen markieren.}
set balText(ans_group) {Ändern des Antwort-Status aller markierten Nachrichten.}
set balText(undelete_group) {Löschmarkierung von allen markierten Nachrichten entfernen.}
set balText(pref_strsel_mode) {Voreinstellung für alle Postfächer gleich,
oder pro Postfach getrennt?}
set balText(pref_start_selection) {Die Nachricht zu der gesprungen wird, wenn ein Postfach
geöffnet wird. Wenn bei oberer Option "Benutze Einstellung des
Postfachs" eingestellt ist, müssen Sie diese Option in dem
jeweiligen Postfach getrennt einstellen.}
set balText(pref_log_timeout) {Die Anzahl der Sekunden, die die Statusmeldung
angezeigt werden.}
set balText(pref_cache_passwd) {Sollen Passwörter für IMAP- und POP-Verbindungen
zwischengespeichert werden? Die Passwörter werden nur
im RAM gespeichert und bei Programmende gelöscht.}
set balText(pref_cache_passwd_timeout) {Wie lange sollen Passwörter gespeichert werden?
0 bedeutet bis Programmende.}
set balText(pref_cache_conn) {IMAP-Protokoll-Verbindung offenhalten, auch wenn das
Postfach geschlossen wird. Eine solche Verbindung kann
eventuell für andere Postfächer genutzt werden.}
set balText(pref_cache_conn_timeout) {Wie lange soll die Verbindung offengehalten werden?
0 bedeutet bis Programmende}
set balText(pref_urlprot) {Postilion wird URLs nur hervorheben, wenn ein
Protokoll in dieser Liste erwähnt wird.}
set balText(pref_url_color) {Die Farbe der URLs im Nachrichtentext.}
set balText(pref_quote_color) {The color of quoted text in the message text
(only used on color displays)}
set balText(pref_url_viewer) {Welches Programm soll zum Ansehen von URLs genutzt werden?
Es kann auch ein Nutzer/in-Script sein.}
set balText(pref_netscape) {Befehl zum Starten von Netscape.}
set balText(pref_netscape_args) {Parameter für Netscape.}
set balText(pref_dbase_dir) {Wo die Datenbank gespeichert wird.}
set balText(pref_def_extype) {Die Standardaktion bei der Wartung.}
set balText(pref_def_exdate) {Die Standard Wartungszeit (in Tagen nach Einfügen in die Datenbank)}
set balText(pref_dbase_backup) {Wenn bei der Wartung eine Sicherungskopie erstellt wird,
werden die Nachrichten in diesem Verzeichnis komprimiert gespeichert.}
set balText(pref_chunksize) {Minimalanzahl der Nachrichten die in jedem komprimierten
Block im Sicherungsverzeichnis gespeichert werden sollen.}
set balText(pref_expire_interval) {Wieviele Tage sollen zwischen den Wartungen vergehen.}
set balText(pref_watcher_enable) {Benachrichtungfenster bei Ankunft neuer Nachrichten
öffnen oder nicht.}
set balText(pref_watcher_time) {Wie oft soll nach neuen Nachrichten geschaut werden? Es
gibt zwei Einstellungen (in Sekunden). Eine für die Datenbank
und eine für alle anderen Postfächer.}
set balText(pref_watcher_name) {Die Titelzeile des Benachrichtigungsfensters (neue Nachrichten).}
set balText(pref_watcher_max_height) {Die maximale Höhe (in Zeilen) der Nachrichtenliste (neue).}
set balText(pref_watcher_font) {Welcher Zeichensatz soll in diesem Fenster benutzt werden?}
set balText(pref_watcher_show) {Welche Nachrichten sollen angezeigt werden (Alle oder Neue).}
set balText(pref_watcher_format) {Das Listenformat. (In der Hilfe zum Postfachfenster
finden Sie weiterführende Informationen.}
set balText(pref_watcher_bell) {Wie oft soll der Lautsprecher sich melden,
wenn neue Nachrichten eingehen?
Bemerkung: Wenn das Nutzer/in-Script RatUP_Bell
existiert, wird diese Einstellung ignoriert.}
set balText(pref_reply_mode) {Voreinstellung für die Antwortadresse. In jedem Postfach
gleich (normal) oder individuell.}
set balText(pref_reply_to_addr) {Die Standard Antwortadresse.}
set balText(pref_reply_to_fn) {Der Standard Antwortname.}
set balText(pref_compose_headers) {Welche Zeilen des Nachrichtenkopfes sollen
normalerweise bearbeitet werden? Die Liste der
Kopfzeilen kann auch im Bearbeitungsfenster
geändert werden.}
set balText(pref_custom_headers) {Die Zeilen des Nachrichtenkopfes die
im Bearbeitungsfenster angezeigt werden.}
set balText(pref_editor) {Das externe Bearbeitungsprogramm. Ein `%s' im Befehl wird
durch den Namen der Datei die bearbeitet werden soll ersetzt.
Das Bearbeitungsfenster wird während das externe Programm läuft
eingefroren.}
set balText(pref_attribution) {Diese Zeile (falls dort etwas steht) wird in jede Antwort
eingefügt. Die Syntax ist mit dem Listenformat im Postfach
Eigenschaftenfenster identisch. Zum Beispiel:
  Hallo %n, du schriebst am %d:
%d wird durch das Datum ersetzt,
%n durch den Namen der Person der geantwortet wird.}
set balText(pref_forwarded_message) {Diese Zeile wird jeder weitergeleiteten Nachricht vorangestellt.
(Wenn sie diese bearbeiten.)}
set balText(pref_reply_lead) {Mit welchem Zeichen sollen Zitate gekennzeichnet werden?
Außerdem wird ein Leerzeichen nach dem Zeichen eingefügt.
Sie sollten das `>' benutzen, da es mehr als üblich ist.}
set balText(pref_quote) {Voreinstellung für das Einfügen (Zitat) beim Antworten.}
set balText(pref_skip_sig) {Voreinstellung für das Einfügen einer Unterschriftsdatei.}
set balText(pref_no_subject) {Welchen Betreff bei der Beantwortung von Nachrichten ohne Betreff.}
set balText(pref_sig_mode) {Voreinstellung für die Unterschriftsdatei (Footer). Für
alle Postfächer gleich (normal), oder je Postfach individuell.}
set balText(pref_signature) {Dateiname der Unterschriftsdatei (Footer).}
set balText(pref_lookup_name) {Auf `wahr' einstellen, wenn Postilion die lokalen Adressen
in der Passwortliste überprüfen soll.}
set balText(pref_copy_attached) {Wahr, wenn Postilion beim Anhängen einer Anlage eine Kopie
der Datei erstellen soll. Falsch, wenn Postilion die Datei erst
beim Versenden als Anlage anhängt. (Muß dann noch vorhanden sein!}
set balText(pref_from_mode) {Voreinstellung der Von:-Kopfzeile. Für alle Postfächer
gleich (normal), oder individuell.}
set balText(pref_from_addr) {Welchen Wert die `Von:'-Zeile haben soll. Wenn diese Zeile nicht Sie
sind, wird eine `Absender:'-Zeile hinzugefügt.}
set balText(pref_from_fn) {Welchen Wert die `Von:'-Zeile haben soll. Wenn diese Zeile nicht Sie
sind, wird eine `Absender:'-Zeile hinzugefügt.}
set balText(pref_date-prefix) {Der Präfix von dynamischen Postfächern. (z.B. wenn der
Wert "Gesendete-Objekte" ist, wird das Postfach einen Name
erhalten in der Art "Gesendete-Objekte-Mai-1999).}
set balText(pref_masquerade_as) {Weist alle Nachrichten die Sie senden als gesendet von dieser
Domäne aus. Wenn hier xxx.de steht, wird die EMail-Adresse zu
Ihr_Name@xxx.de erweitert. Üblicherweise steht hier die Domäne Ihres
InternetServiceProviders. (Oder zum Beispiel von gmx.de, wenn Sie einen
Freemail-Service benutzen.)}
set balText(pref_domain) {Die Domäne in der sich diese/r Rechner/in befindet (z.B. gmx.net).
Wenn Sie "Rechnerdomäne ausgeben als" nicht definiert haben, wird
dieser Wert zusammen mit Ihrem Rechnernamen vergeben. D.h, dass
die Mail versandt wird mit Ihrem_Namen@Ihr_Rechnername.Ihre_Domäne
und die Antworten werden dorthin geschickt. Wenn der Name dieser/s
Rechner/in/s einen `.' enthält, wird der Name nicht benutzt.}
set balText(pref_delivery_mode) {Voreinstellung für die Sendeschalter im Bearbeitungsfenster.
Wenn der Direkt-Modus angewählt ist, wird die Nachricht sofort (im
Hintergrund) gesendet. Wenn Sie `Zurückgestellen' wählen, wird die
Nachricht in eine Postilion-Warteschlange gespeichert. Sie können
dann später alle zurückgestellten Nachrichten versenden.}
set balText(pref_sendprot) {Wie Nachrichten zu versenden sind. Per SMTP oder mit einem
Programm. Wenn mittels Programm, dann wird das Progrmamm in der
unten stehende Zeile benutzt.}
set balText(pref_smtp_hosts) {Wenn mit SMPT versandt wird, notieren Sie hier
alle Server mit denen das Senden versucht werden soll.
Bitte geben Sie diese in der Form `Server:Port' ein.
Dabei bedeutet Port die Portnummer die benutzt werden soll.}
set balText(pref_smtp_timeout) {Wieviele Sekunden soll auf eine Antwort vom SMPT-Server
gewartet werden.}
set balText(pref_smtp_reuse) {Wenn `Falsch' eingestellt wird, schließt Postilion den SMTP
Kanal nach jeder Nachricht. Wenn `Wahr', wird der Kanal für alle
zu versendenen Nachrichten benutzt.}
set balText(pref_smtp_verbose) {Wieviel möchten wir über den SMTP-Sendeprozeß erfahren?}
set balText(pref_sendprog) {Dieses Programm wird zum Senden von Nachrichten benutzt.
Die Adresszeile wird in der Befehlszeile übergeben und der
Text auf der Standardeingabe. (z.B. /usr/sbin/sendmail oder
/bin/qmail).}
set balText(pref_sendprog_8bit) {Diesen Datentyp kann das Programm benutzen. (7 oder 8bit).}
set balText(pref_charset) {Welchen Zeichensatz wollen wir benutzen?}
set balText(pref_force_send) {Wenn hier `Wahr' eingestellt wird, versucht Postilion auch
zu senden, wenn der vollständige Name der/s lokalen Rechner/in/s
nicht bekannt ist (Name und Domäne). Schalten Sie das nicht ein,
wenn Sie nicht genau wissen was Sie tun!}
set balText(pref_dsn_directory) {Wo sollen die Benachritigungsinformationen
gespeichert werden?}
set balText(pref_dsn_request) {Die Voreinstellung des Werts des Benachrichtigenschalters im
Bearbeitungsfenster. Eine Übermittlungsbestätigung ist eine
automatische Benachrichtigung der Zustellung der Nachricht.
Einige Systeme unterstützen dies jedoch nicht.}
set balText(pref_dsn_snarf_reports) {Wenn Sie Übermittlungsbestätigungen angefragt haben,
werden diese als Mail-Teile behandelt. Diese Option definiert,
ob Sie diese in der Nachrichtenliste sehen oder nicht.
(Im Benachrichtigungsfenster sehen Sie sie immer.)}
set balText(pref_dsn_expiration) {Wie lange sollen Nachrichten (und ggf. deren angeforderte
Benachrichtigungen) im Benachrichtigungsfenster angezeigt werden?
Die Zeit wird in Tagen angegeben, seitdem die Originalnachricht
versandt wurde.}
set balText(pref_dsn_verbose) {Es können für jeden Typ von Benachrichtigung einzelne
Berichte definiert werden. Es gibt drei Typen:
	Keine
    Nichts berichten.
	Zeige in Statuszeile
    In der Statuszeile werden neue Benachrichtigungen angezeigt.
  Zeige in eigenem Fenster
    Wenn eine Benachrichtigung eingeht, wird eine eigenes
    Fenster geöffnet.
Egal welchem Typ Sie anwählen, im Benachrichtigungsfenster
werden die Benachrichtigungen immer angezeigt.}
set balText(pref_pgp_enable) {PGP generell aktivieren?}
set balText(pref_pgp_prog) {Der vollständige Pfad zum PGP-Programm.
(z.B. /usr/local/bin/pgp)}
set balText(pref_pgp_args) {Zusätzliche Parameter für PGP. Testen Sie diese an der
Systemkonsole, denn die Syntax muß stimmen!}
set balText(pref_cache_pgp) {PGP-Mantra im RAM zwischenspeichern.}
set balText(pref_cache_pgp_timeout) {Wie lange soll sich Postilion an das Mantra erinnern?
(0 bedeutet bis zum Programmende)}
set balText(pref_pgp_sign) {Hiermit können Sie Nachrichten mit dem Programm PGP
digital Unterschreiben.
Sie müssen vorher einen Schlüssel erstellt haben!
Weitere Informationen finden Sie im PGP-Handbuch.
PGP heißt `Pretty Good Privacy' und ist ein
gutes Verschlüsselungssystem.}
set balText(pref_pgp_encrypt) {Hiermit verschlüsseln Sie Nachrichten mit PGP.
Sie müssen vorher einen Schlüssel erstellt haben!
Weitere Informationen finden Sie im PGP-Handbuch.
PGP heißt `Pretty Good Privacy' und ist ein
gutes Verschlüsselungssystem.}
set balText(body_of_message) {Hier sehen Sie den Inhalt der markierten Nachricht.
Mit der rechten Maustaste bekommen Sie ein Menü mit
Befehlen und weiteren Informationen.}
set balText(howto_display) {In diesem Menü stellen Sie das Layout für
den Textteil von Nachrichten ein.}
set balText(save_bodypart) {Speichert den aktuellen Nachrichtentext
in einer auszuwählenden Datei.}
set balText(view_as_text) {Wenn dieser Schaltern gesetzt ist, wird
der Nachrichtentext-Teil gezeigt als ob es
`echter' Text wäre.}
set balText(view_source) {Zeigt den Nachrichtentext-Teil der Nachricht
wie zugestellt an (in eigenem Fenster).}
set balText(add_to_keyring) {Diesen öffentlichen Schlüssel zum eigenen
Schlüsselbund hinzufügen.}
set balText(run_mailcap) {Den im Mailcap für diesen Typ definierten Befehl ausführen.}
set balText(bodypart_entry) {Ein Menü für diesen Nachrichtentext-Teil. Das
Untermenü hält einige zusätzliche Befehle  und
Informationen bereit.}
set balText(bodypart_show) {Mit diesem Schalter können Sie diesen Teil
des Textes anzeigen oder verstecken. Nach einem
Verstecken, müssen Sie das Postfach schließen und
wieder öffnen, um den Text wieder anzuzeigen.}
set balText(bodypart_save) {Diesen Teil des Textes in eine Datei speichern.}
set balText(dbs_and) {Um die Treffer zur aktuellen Gruppe hinzuzufügen,
müssen alle (nicht leeren) Zeilen unterhalb eine
Übereinstimmung erzielen.}
set balText(dbs_or) {Um die Treffer zur aktuellen Gruppe hinzuzufügen,
genügt es, wenn eine der (nicht leeren) Zeilen
unterhalb eine Übereinstimmung erzielen.}
set balText(dbs_keywords) {Diese Zeile ergibt einen Treffer, wenn einer
der Suchbegriffe als Stichwort der Nachricht
zugeordnet wurde.}
set balText(dbs_subject) {Diese Zeile ergibt einen Treffer, wenn einer
der Suchbegriffe im Betreff der Nachricht gefunden
wird.
Wenn Sie mehrere Suchbegriffe in der Reihenfolge
suchen wollen (Hans Wurst aber nicht Hans hat Wurst),
schließen Sie diese mit "" ein. ("Hans Wurst").}
set balText(dbs_all) {Diese Zeile ergibt einen Treffer, wenn einer
der Suchbegriffe irgendwo in der Nachricht gefunden
wird.
Wenn Sie mehrere Suchbegriffe in der Reihenfolge
suchen wollen (Hans Wurst aber nicht Hans hat Wurst),
schließen Sie diese mit "" ein. ("Hans Wurst").}
set balText(dbs_to) {Diese Zeile ergibt einen Treffer, wenn einer
der Suchbegriffe in der An-Zeile der Nachricht gefunden
wird.
Wenn Sie mehrere Suchbegriffe in der Reihenfolge
suchen wollen (Hans Wurst aber nicht Hans hat Wurst),
schließen Sie diese mit "" ein. ("Hans Wurst").}
set balText(dbs_from) {Diese Zeile ergibt einen Treffer, wenn einer
der Suchbegriffe in der Von-Zeile der Nachricht gefunden
wird.
Wenn Sie mehrere Suchbegriffe in der Reihenfolge
suchen wollen (Hans Wurst aber nicht Hans hat Wurst),
schließen Sie diese mit "" ein. ("Hans Wurst").}
set balText(dbs_cc) {Diese Zeile ergibt einen Treffer, wenn einer
der Suchbegriffe in der Cc-Zeile der Nachricht gefunden
wird.
Wenn Sie mehrere Suchbegriffe in der Reihenfolge
suchen wollen (Hans Wurst aber nicht Hans hat Wurst),
schließen Sie diese mit "" ein. ("Hans Wurst").}
set balText(keywords) {Stichwörter die die Nachricht beschreiben.}
set balText(exp_none) {Nachricht nicht beim Aufruf von
"Alte Einträge löschen" löschen.}
set balText(exp_remove) {Nachricht beim Aufruf von
"Alte Einträge löschen" löschen,
wenn das Mindesthaltbarkeitsdatum
abgelaufen ist.}
set balText(exp_incoming) {Nachricht beim Aufruf von
"Alte Einträge löschen" in den Posteingang
verschieben, wenn das Mindesthaltbarkeitsdatum
abgelaufen ist.}
set balText(exp_backup) {Nachricht beim Aufruf von
"Alte Einträge löschen" in die Datensicherung
verschieben, wenn das Mindesthaltbarkeitsdatum
abgelaufen ist.}
set balText(exp_date) {Wann die Nachricht beim Aufruf von
"Alte Einträge löschen" gelöscht werden soll.
Zur Zeit wird nur `+N' unterstützt, wobei N
die Anzahl in Tagen angibt (sozusagen ein
Mindesthaltbarkeitsdatum).}
set balText(vd_createsub) {Einen neuen Untereintrag erstellen,
welcher wiederum mehrere eigene Postfächer
enthalten kann.}
set balText(vd_newfile) {Erstellt ein neues Postfach als
einfache Unix Postfach Datei.}
set balText(vd_newmh) {Erstellt ein neues mh Postfach.}
set balText(vd_newdbase) {Erstellt ein neues Datenbank Postfach.}
set balText(vd_newimap) {Erstellt ein neues IMAP Postfach.}
set balText(vd_newpop) {Erstellt ein neues POP3 Postfach.}
set balText(vd_newdynamic) {Erstellt ein neues dynamisches Postfach.}
set balText(vd_importdir) {Importiert Datei Postfächer (aus einem Verzeichnis).}
set balText(vd_importmh) {Importiert mh Postfächer (aus einem Verzeichnis).}
set balText(vd_importimap) {Importiert IMAP Postfächer (aus einem Verzeichnis).}
set balText(vd_foldermenu) {Mit diesem Menüpunkt erstellen Sie neue Postfächer
und Untereinträge für Gruppen von Postfächern.}
set balText(vd_importmenu) {Mit diesem Menüpunkt importieren Sie Gruppen von
bereits bestehenden Postfächern. Die neuen Einträge
werden oben im Menü angezeigt.}
set balText(vd_edit) {Berbeitet diesen Eintrag.}
set balText(vd_delete) {Löscht diesen Eintrag (wenn Untereinträge vorhanden sind,
werden Sie gefragt ob Sie alles löschen wollen!).}
set balText(vd_setinbox) {Erklärt dieses Postfach zum Standardpostfach.
Dieses wird beim Start von Postilion geöffnet.
Meist wird das zum Posteingang erklärte Postfach
dazu benutzt.}
set balText(vd_setsaveout) {Erklärt dieses Postfach zum Standardspeicherort
für die Gesendeten Objekte. Sie können in jedem
Postfach hierfür individuelle Einstellungen vornehmen.}
set balText(vd_setstartup) {Öffnet dieses Postfach beim Start vom Postilion.}
set balText(vd_setstartmin) {Öffnet dieses Postfach minimiert beim Start vom Postilion.}
set balText(vd_unsetstartup) {Öffnet dieses Postfach beim Start
vom Postilion nicht mehr.}
set balText(vd_unsetstartmin) {Öffnet dieses Postfach beim Start
vom Postilion nicht mehr minimiert.}
set balText(vd_list) {Eine Liste Ihrer Postfächer:
   * Ein linker Doppelklick öffnet das Postfach im aktuellen
     Browserfenster, oder in einem neuen (falls keines geöffnet).
   * Über die rechte Maustaste erreichen Sie Befehle für den
     angewählten Eintrag, oder zum Bearbeiten eines neuen Eintrags.
   * Der Pfeil (->) rechts in einem Eintrag bedeutet, dass es dort
     Untereinträge gibt. Bei einfachem Anklicken erscheinen diese
     in der jeweils rechten Liste.
   * Wenn Sie wieder zurück möchten, klicken Sie in der jeweiligen
     linken Liste.}
set balText(mbv_list) {Eine Liste Ihrer Postfächer:
   * Ein linker Doppelklick öffnet das Postfach
     im aktuellen Fenster.
   * Über die rechte Maustaste können Sie ebenfalls
     Öffnen, oder die aktuell markierte Nachricht
     in das Postfach verschieben.
   * Der Pfeil (->) rechts in einem Eintrag bedeutet,
     dass es dort Untereinträge gibt. Bei einem
     einfachen Anklicken erscheinen diese in der
     jeweils rechten Liste.
   * Wenn Sie wieder zurück möchten, klicken Sie
     in der jeweiligen linken Liste.}
set balText(mbv_sash_open) {Klicke (links) auf diesen Fensterrahmen,
um das Postfach zu öffnen.}
set balText(mbv_sash_close) {Klicke (links) auf diesen Fensterrahmen,
um das Postfach zu schließen.}
set balText(msg_sash) {Ziehen Sie den Fensterrahmen hoch oder runter,
um die Größe der Nachrichtenliste und gegenüber der
des (unteren) Textteils zu verändern.}
set balText(vd_menuname) {Name des neuen Untereintrags.}
set balText(vd_name) {Name des Postfachs}
set balText(vd_mhname) {Name des mh Postfachs}
set balText(vd_host) {Name des Servers auf dem das Postfach gespeichert ist.}
set balText(vd_user) {Der Name der/s Benutzers/in der für den Zugang zum
Postfach benutzt werden soll.}
set balText(vd_mbox) {Name des entfernten IMAP Postfachs}
set balText(vd_port) {Nummer des Ports, auf die der Server antwortet.}
set balText(vd_filepat) {Schließe nur die Dateien ein, die dem Suchbegriff entsprechen.
Z.B. *text wird alle Dateien finden, die auf "text" enden.}
set balText(vd_dirpat) {Nur die Verzeichnisse einschließen, die dem
Suchbegriff entsprechen.}
set balText(vd_pattern) {Nur die Postfächer einschließen, die dem
Suchbegriff entsprechen.}
set balText(watcher) {Drücken Sie die linke Maustaste, um das Postilion
Hauptfenster zu sehen. Die rechte Maustaste wird
dieses Fenster vorerst schließen.}
set balText(help_subjlist) {Liste der Hilfeeinträge. Drücken Sie die linke
Maustaste über einem Eintrag um die entsprechende
Hilfe anzuzeigen.}
set balText(help_text) {Hilfetext für den angewählte Eintrag.}
set balText(pref_ispellRecheckAfterAdd) {Wenn Sie in dieser Sitzung dem Wörterbuch neue Einträge
hinzugefügt haben, wählen Sie "Wahr" aus. Dann werden die als
fehlerhaft gekennzeichneten Wörter nochmals überprüft.

Sie können auch die rechte Maustaste benutzen, um Wörter
zu korrigieren.}
set balText(pref_ispellon) {Hiermit können Sie die Rechtschreibprüfung ein- bzw. ausschalten.
Sie müssen dies allerdings VOR dem Schreiben ein Nachricht einstellen.}
set balText(pref_ispelltextOnly) {Wenn dieser Schalter aktiviert ist, wird nur der `Text' einer
Nachricht vom Rechtschreibprogramm geprüft. Der Nachrichtenkopf
und bleibt außen vor. Außerdem werden alle Anlage ignoriert, außer
sie sind als text/enriched oder text/plain klassifiziert.
Wenn die Rechtschreibprüfung in einem Teil Ihrer Nachrichten anhält,
möchten Sie vielleicht diese Option aktivieren.}
set balText(pref_ispelldefaultCommand) {Dieses Programm wird für die echte Arbeit benutzt. `ispell -a'
ist ein wirklich gute Wahl. Wenn Sie Ihr eigenes Wörterbuch benutzen
möchten, sollten Sie mit `ispell -a -d <Wörterbuch>' aufrufen.
Für weitergehende Informationen lesen Sie auch das Onlinehandbuch
(man 1 ispell). Der Befehl kann sehr individuell benutzt werden.}
set balText(pref_ispellotherCommands) {Sie können ein Rechtschreibprogramm auch anders aufrufen.
Die Freunde in  Europa arbeiten ja in verschiedenen Sprachen.
Der Eintrag muß in geschwungenen Klammern eingeschlossen sein.
Z.B. "German { ispell -a -d deutsch }"}
set balText(pref_ispellpopupBinding) {Hier bestimmen Sie wie das Popup-Fenster geöffnet wird,
zum Beispiel:
  Maustaste-3-gedrückt
  Maustaste-2-gedrückt
  Maustaste-1-gedrückt
  Umschalttaste-3
  Steuerung-3
  Alt-1
  etc...
Beachten Sie bitte, dass das Fenster geschlossen wird, wenn die
entsprechende Taste nicht mehr gedrückt ist.}
set balText(pref_ispellviewStyle) {Hier können Sie die Anzeige von fehlerhaften Wörtern bestimmen.
Sie können die Voreingestellungen benutzen, oder neue Einträge
erstellen, indem Sie `andere' anwählen. Wenn Sie `Farben' benutzen,
wählen Sie unten eine Farbe aus.
Beipiele für `andere':
	-underline t                (Unterstrichen)
	-background red             (Hintergrund rot)
	-foreground Bisque          (Vordergrund Aprikose)
	-font <font>                (Zeichensatz)
	-fgstipple <bitmap>
	-bgstipple <bitmap>
<Bitmap> kann wiederum für viele Einträge stehen, wie 'gray50'
und 'gray25' sind beliebt. Ein paar Beispiele:
	 -font *italic*             (Kursiv)
    oder -font *bold*         (Fett)
    oder -font *24*           (Groß!)
    oder -font *italic*24*    (Kursiv und Groß)
	 -relief <relief> (in der tk Dokumentation finden Sie mehr hierzu)
Sie können auch kombinieren. Noch zwei Beispiele:
	-underline t -foreground red
	-bgstipple gray25 -color red}
set balText(pref_ispellviewStyle-Color) {Farbe für den Vorder- und Hintergrund}
set balText(pref_ispellviewStyle-Other) {Stil, wenn `andere' angewählt wurde.}
set balText(pref_mboxvis) {Ob im Browserfenster die Postfachliste eingeblendet
werden soll oder eben nicht.}
set balText(pref_expunge_on_close) {Beim Schließen des Postfachs kann Postilion automatisch
die zum Löschen markierten Nachrichten entfernen. Hier
wird dieses Verhalten eingestellt.}
set balText(pref_automatic_wrap) {Kontrolle des automatischen Zeilenumbruchs.}
set balText(pref_automatic_indent) {Kontrolle der automatischen Ident-Funktion.}
}
